DROP Schema if Exists DAF02;
Create Schema DAF02;
use DAF02;

DROP TABLE IF EXISTS `DAF02`.`Storage`;
CREATE TABLE  `DAF02`.`Storage` (
  `Storage_ID` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `Path` varchar(100) NOT NULL,
  `UserName` varchar(50) NOT NULL,
  `PassWord` varchar(50) NOT NULL,
  `Storage_TimeStamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`Storage_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `DAF02`.`JobCondition`;
CREATE TABLE  `DAF02`.`JobCondition` (
  `JC_ID` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `JC_Name` varchar(50) NOT NULL,
  `JC_Description` text,
  `JC_TimeStamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`JC_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `DAF02`.`JobStatus`;
CREATE TABLE  `DAF02`.`JobStatus` (
  `JS_ID` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `JS_Name` varchar(50) NOT NULL,
  `JS_Description` text,
  `JS_TimeStamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`JS_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `DAF02`.`Permission`;
CREATE TABLE  `DAF02`.`Permission` (
  `Perm_ID` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `Perm_Description` text,
  `Perm_TimeStamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`Perm_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `DAF02`.`Role`;
CREATE TABLE  `DAF02`.`Role` (
  `Role_ID` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `Role_Description` text,
  `Role_TimeStamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`Role_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `DAF02`.`Device`;
CREATE TABLE  `DAF02`.`Device` (
  `Device_ID` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `Device_Name` varchar(50) NOT NULL,
  `Device_Description` text,
  `Device_TimeStamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`Device_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `DAF02`.`OperatingSystem`;
CREATE TABLE  `DAF02`.`OperatingSystem` (
  `OS_ID` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `OS_Name` varchar(50) NOT NULL,
  `OS_TimeStamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`OS_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `DAF02`.`Role_Permission`;
CREATE TABLE  `DAF02`.`Role_Permission` (
  `Role_ID` int(10) unsigned NOT NULL,
  `Perm_ID` int(10) unsigned NOT NULL,
  PRIMARY KEY (`Role_ID`,`Perm_ID`),
  KEY `Perm_ID` (`Perm_ID`),
  CONSTRAINT `Role_Permission_ibfk_1` FOREIGN KEY (`Role_ID`) REFERENCES `Role` (`Role_ID`),
  CONSTRAINT `Role_Permission_ibfk_2` FOREIGN KEY (`Perm_ID`) REFERENCES `Permission` (`Perm_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `DAF02`.`User`;
CREATE TABLE  `DAF02`.`User` (
  `User_ID` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `User_Name` varchar(50) NOT NULL,
  `User_Password` varchar(50) NOT NULL,
  `User_AnyPhase` tinyint(1) NOT NULL,
  `User_MaxJobs` int(11) DEFAULT NULL,
  `User_IsActive` tinyint(1) NOT NULL,
  `Role_ID` int(10) unsigned NOT NULL,
  `User_isLDAP` tinyint(1) NOT NULL,
  `User_TimeStamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`User_ID`),
  UNIQUE  KEY `UserName` (`User_Name`),
  KEY `Role_ID` (`Role_ID`),
  CONSTRAINT `User_ibfk_1` FOREIGN KEY (`Role_ID`) REFERENCES `Role` (`Role_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `DAF02`.`Workstation`;
CREATE TABLE  `DAF02`.`Workstation` (
  `Wrkst_ID` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `Wrkst_Name` varchar(50) NOT NULL,
  `Wrkst_WorkingDirectory` varchar(200) NOT NULL,
  `Wrkst_AnyPhase` tinyint(1) NOT NULL,
  `Wrkst_IsActive` tinyint(1) NOT NULL,
  `Wrkst_Comment` nvarchar(600) ,
  `OS_ID` int(11) unsigned NOT NULL,
  `Wrkst_Location` varchar(50) DEFAULT NULL,
  `Wrkst_TimeStamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`Wrkst_ID`),
   UNIQUE  KEY `WSName` (`Wrkst_Name`),
  KEY `OS_ID` (`OS_ID`),
  CONSTRAINT `Workstation_ibfk_1` FOREIGN KEY (`OS_ID`) REFERENCES `OperatingSystem` (`OS_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `DAF02`.`Collection`;
CREATE TABLE  `DAF02`.`Collection` (
  `Coll_ID` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `Coll_Name` varchar(50) NOT NULL,
  `Coll_Abbreviation` varchar(4) NOT NULL,
  `Coll_DefaultPath` varchar(200) NOT NULL,
  `Coll_Priority` int(11) NOT NULL,
  `Coll_AnyUser` tinyint(1) NOT NULL,
  `Coll_AnyWorkstation` tinyint(1) NOT NULL,
  `Coll_Active` tinyint(1) NOT NULL,
  `Coll_Comment` nvarchar(600) ,
  `Own_ID` int(11) unsigned NOT NULL,
  `Prj_ID` int(11) unsigned NOT NULL,
  `Icg_ID` int(11) unsigned NOT NULL,
  `Coll_TimeStamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`Coll_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `DAF02`.`JobType`;
CREATE TABLE  `DAF02`.`JobType` (
  `JT_ID` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `JT_Name` varchar(50) NOT NULL,
  `JT_Description` text ,
  `JT_LifeTime` int(10) unsigned NOT NULL,
  `JT_NamingConvention` varchar(200) DEFAULT NULL,
  `JT_TimeStamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`JT_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `DAF02`.`Phase`;
CREATE TABLE  `DAF02`.`Phase` (
  `Phase_ID` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `Phase_Name` varchar(50) NOT NULL,
  `Phase_Sequence` int(11) DEFAULT NULL,
  `Phase_MaxPeriod` int(11) DEFAULT NULL,
  `Phase_Description` text ,
  `Phase_XMLDescription` text  NOT NULL,
  `JT_ID` int(10) unsigned NOT NULL,
  `Phase_TimeStamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`Phase_ID`,`JT_ID`),
  KEY `JT_ID` (`JT_ID`),
  CONSTRAINT `Phase_ibfk_1` FOREIGN KEY (`JT_ID`) REFERENCES `JobType` (`JT_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `DAF02`.`Batch`;
CREATE TABLE  `DAF02`.`Batch` (
  `Batch_ID` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `Batch_Name` varchar(100) NOT NULL,
  `Batch_Date` datetime NOT NULL,
  `Batch_Comment` nvarchar(600) ,
  `Coll_ID` int(11) unsigned NOT NULL,
  `JT_ID` int(10) unsigned DEFAULT NULL,
  `Batch_TimeStamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`Batch_ID`),
  KEY `Coll_ID_FK` (`Coll_ID`),
  KEY `Batch_ibfk_2` (`JT_ID`),
  -- CONSTRAINT `Coll_ID_FK` FOREIGN KEY (`Coll_ID`) REFERENCES `Collection` (`Coll_ID`),
  CONSTRAINT `Batch_ibfk_2` FOREIGN KEY (`JT_ID`) REFERENCES `JobType` (`JT_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `DAF02`.`User_Collection`;
CREATE TABLE  `DAF02`.`User_Collection` (
  `Coll_ID` int(10) unsigned NOT NULL,
  `User_ID` int(10) unsigned NOT NULL,
  PRIMARY KEY (`Coll_ID`,`User_ID`),
  KEY `User_Collection_ibfk_2` (`User_ID`),
  CONSTRAINT `User_Collection_ibfk_1` FOREIGN KEY (`Coll_ID`) REFERENCES `Collection` (`Coll_ID`),
  CONSTRAINT `User_Collection_ibfk_2` FOREIGN KEY (`User_ID`) REFERENCES `User` (`User_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `DAF02`.`Workstation_Collection`;
CREATE TABLE  `DAF02`.`Workstation_Collection` (
  `Coll_ID` int(10) unsigned NOT NULL,
  `Wrkst_ID` int(10) unsigned NOT NULL,
  PRIMARY KEY (`Coll_ID`,`Wrkst_ID`),
  KEY `Workstation_Collection_ibfk_2` (`Wrkst_ID`),
  CONSTRAINT `Workstation_Collection_ibfk_1` FOREIGN KEY (`Coll_ID`) REFERENCES `Collection` (`Coll_ID`),
  CONSTRAINT `Workstation_Collection_ibfk_2` FOREIGN KEY (`Wrkst_ID`) REFERENCES `Workstation` (`Wrkst_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `DAF02`.`Workstation_Device`;
CREATE TABLE  `DAF02`.`Workstation_Device` (
  `Device_ID` int(10) unsigned NOT NULL,
  `Wrkst_ID` int(10) unsigned NOT NULL,
  PRIMARY KEY (`Device_ID`,`Wrkst_ID`),
  KEY `Workstation_Device_ibfk_2` (`Wrkst_ID`),
  CONSTRAINT `Workstation_Device_ibfk_1` FOREIGN KEY (`Device_ID`) REFERENCES `Device` (`Device_ID`),
  CONSTRAINT `Workstation_Device_ibfk_2` FOREIGN KEY (`Wrkst_ID`) REFERENCES `Workstation` (`Wrkst_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `DAF02`.`User_Phase`;
CREATE TABLE  `DAF02`.`User_Phase` (
  `User_ID` int(10) unsigned NOT NULL,
  `Phase_ID` int(10) unsigned NOT NULL,
  PRIMARY KEY (`User_ID`,`Phase_ID`),
  KEY `Phase_ID` (`Phase_ID`),
  CONSTRAINT `User_Phase_ibfk_1` FOREIGN KEY (`User_ID`) REFERENCES `User` (`User_ID`),
  CONSTRAINT `User_Phase_ibfk_2` FOREIGN KEY (`Phase_ID`) REFERENCES `Phase` (`Phase_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `DAF02`.`Workstation_Phase`;
CREATE TABLE  `DAF02`.`Workstation_Phase` (
  `Wrkst_ID` int(10) unsigned NOT NULL,
  `Phase_ID` int(10) unsigned NOT NULL,
  PRIMARY KEY (`Wrkst_ID`,`Phase_ID`),
  KEY `wrkst_Phase_ibfk_2` (`Phase_ID`),
  CONSTRAINT `Workstation_Phase_ibfk_1` FOREIGN KEY (`Wrkst_ID`) REFERENCES `Workstation` (`Wrkst_ID`),
  CONSTRAINT `Workstation_Phase_ibfk_2` FOREIGN KEY (`Phase_ID`) REFERENCES `Phase` (`Phase_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `DAF02`.`Job`;
CREATE TABLE  `DAF02`.`Job` (
  `Job_ID` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `Job_Date` datetime DEFAULT NULL,
  `Job_Path` varchar(200) DEFAULT NULL,
  `Job_Priority` int(10) unsigned default 10 NOT NULL,
  `Job_DueDate` datetime DEFAULT NULL,
   `Batch_ID` int(10) unsigned NOT NULL,
  `JT_ID` int(10) unsigned NOT NULL,
  `JC_ID` int(10) unsigned DEFAULT NULL,
  `TL_ID` int(10) unsigned DEFAULT NULL,
  `Storage_ID` int(10) unsigned DEFAULT NULL,
  `Job_TimeStamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`Job_ID`),
   KEY `Job_ibfk_2` (`Batch_ID`),
  KEY `Job_ibfk_3` (`JT_ID`),
   KEY `Job_ibfk_6` (`JC_ID`),
  KEY `Job_ibfk_7` (`Storage_ID`),
  CONSTRAINT `Job_ibfk_2` FOREIGN KEY (`Batch_ID`) REFERENCES `Batch` (`Batch_ID`),
  CONSTRAINT `Job_ibfk_3` FOREIGN KEY (`JT_ID`) REFERENCES `JobType` (`JT_ID`),
   CONSTRAINT `Job_ibfk_6` FOREIGN KEY (`JC_ID`) REFERENCES `JobCondition` (`JC_ID`),
  CONSTRAINT `Job_ibfk_7` FOREIGN KEY (`Storage_ID`) REFERENCES `Storage` (`Storage_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `DAF02`.`TransactionLog`;
CREATE TABLE  `DAF02`.`TransactionLog` (
  `TL_ID` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `Job_ID` int(10) unsigned NOT NULL,
  `Phase_ID` int(10) unsigned NOT NULL,
  `User_ID` int(10) unsigned NOT NULL,
  `Wrkst_ID` int(10) unsigned DEFAULT NULL,
  `JS_ID` int(10) unsigned NOT NULL,
  `TL_Date` datetime NOT NULL,
  `TL_NoOfFiles` int(10) unsigned DEFAULT NULL,
  `TL_Status_Data` text ,
  PRIMARY KEY (`TL_ID`),
  KEY `Job_ID` (`Job_ID`),
  KEY `Phase_ID` (`Phase_ID`),
  KEY `User_ID` (`User_ID`),
  KEY `Wrkst_ID` (`Wrkst_ID`),
  KEY `JS_ID` (`JS_ID`),
  CONSTRAINT `TransactionLog_ibfk_1` FOREIGN KEY (`Job_ID`) REFERENCES `Job` (`Job_ID`),
  CONSTRAINT `TransactionLog_ibfk_2` FOREIGN KEY (`Phase_ID`) REFERENCES `Phase` (`Phase_ID`),
  CONSTRAINT `TransactionLog_ibfk_3` FOREIGN KEY (`User_ID`) REFERENCES `User` (`User_ID`),
  CONSTRAINT `TransactionLog_ibfk_4` FOREIGN KEY (`Wrkst_ID`) REFERENCES `Workstation` (`Wrkst_ID`),
  CONSTRAINT `TransactionLog_ibfk_5` FOREIGN KEY (`JS_ID`) REFERENCES `JobStatus` (`JS_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `DAF02`.`OldTransactionLog`;
CREATE TABLE  `DAF02`.`OldTransactionLog` (
  `OTL_ID` int(10) unsigned NOT NULL ,
  `Job_ID` int(10) unsigned NOT NULL,
  `Phase_ID` int(10) unsigned NOT NULL,
  `User_ID` int(10) unsigned NOT NULL,
  `Wrkst_ID` int(10) unsigned DEFAULT NULL,
  `JS_ID` int(10) unsigned NOT NULL,
  `OTL_Date` datetime NOT NULL,
  `OTL_NoOfFiles` int(10) unsigned DEFAULT NULL,
  `OTL_Status_Data` text ,
  PRIMARY KEY (`OTL_ID`),
  KEY `OldTransactionLog_ibfk_1` (`Job_ID`),
  KEY `OldTransactionLog_ibfk_2` (`Phase_ID`),
  KEY `OldTransactionLog_ibfk_3` (`User_ID`),
  KEY `OldTransactionLog_ibfk_4` (`Wrkst_ID`),
  KEY `OldTransactionLog_ibfk_5` (`JS_ID`),
  CONSTRAINT `OldTransactionLog_ibfk_1` FOREIGN KEY (`Job_ID`) REFERENCES `Job` (`Job_ID`),
  CONSTRAINT `OldTransactionLog_ibfk_2` FOREIGN KEY (`Phase_ID`) REFERENCES `Phase` (`Phase_ID`),
  CONSTRAINT `OldTransactionLog_ibfk_3` FOREIGN KEY (`User_ID`) REFERENCES `User` (`User_ID`),
  CONSTRAINT `OldTransactionLog_ibfk_4` FOREIGN KEY (`Wrkst_ID`) REFERENCES `Workstation` (`Wrkst_ID`),
  CONSTRAINT `OldTransactionLog_ibfk_5` FOREIGN KEY (`JS_ID`) REFERENCES `JobStatus` (`JS_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `DAF02`.`Reports`;
CREATE TABLE `DAF02`.`Reports` (
 `Report_ID` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `Report_Name` varchar(100) NOT NULL,
  `Report_Date` datetime NOT NULL,
  `Report_Description` nvarchar(600) ,
  `User_ID` int(10) unsigned NOT NULL ,
  `Report_Query` text ,
   PRIMARY KEY (`Report_ID`) ,
   KEY `User_fk` (`User_ID`) ,
   UNIQUE  KEY `ReportName` (`Report_Name`) ,
	 CONSTRAINT `User_fk` FOREIGN KEY (`User_ID`) REFERENCES `User` (`User_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


	
DROP TABLE IF EXISTS `DAF02`.`Reason`;
CREATE TABLE `DAF02`.`Reason` (
`Reason_ID` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `Reason_Name` varchar(50) NOT NULL,
  `Reason_Description` nvarchar(1000) ,
  `Phase_ID` int(10) unsigned NOT NULL ,
  `Reason_TimeStamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`Reason_ID`),
  KEY `Reason_ibfk_1` (`Phase_ID`),
  CONSTRAINT `Reason_ibfk_1` FOREIGN KEY (`Phase_ID`) REFERENCES `Phase` (`Phase_ID`)
  ) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `DAF02`.`MediaType`;
CREATE TABLE  `DAF02`.`MediaType` (
  `MT_ID` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `MT_Name` varchar(50) NOT NULL,
  `MT_Size` FLOAT,
  `Storage_ID` int(10) unsigned DEFAULT NULL,
  `MT_TimeStamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `MT_Abbreviation` varchar(4) NOT NULL,
  `MT_LastBarcode` integer(6) ZEROFILL Default 0 ,
  PRIMARY KEY (`MT_ID`),
  KEY `strg_ibfk_7` (`Storage_ID`),
 CONSTRAINT `strg_ibfk_7` FOREIGN KEY (`Storage_ID`) REFERENCES `Storage` (`Storage_ID`)

) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `DAF02`.`Media`;
CREATE TABLE  `DAF02`.`Media` (
  `Media_ID` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `Media_BarCode` varchar(50) NOT NULL ,
  `Media_Location` varchar(50) NOT NULL ,
  `MT_ID` int(10) unsigned,
  `Media_DelConfirm` tinyint(1) NOT NULL default 0,
  `Media_TimeStamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `User_ID` int(10) unsigned NOT NULL,
  `Wrkst_ID` int(10) unsigned Not NULL,
  PRIMARY KEY (`Media_ID`),
  KEY `MT_ID` (`MT_ID`),
  UNIQUE  KEY `Media_BarCode` (`Media_BarCode`),
  CONSTRAINT `Media-MediaType_FK` FOREIGN KEY (`MT_ID`) REFERENCES `MediaType` (`MT_ID`),
  CONSTRAINT `Media_UserID_FK` FOREIGN KEY (`User_ID`) REFERENCES `User` (`User_ID`),
  CONSTRAINT `Media_WrkstID_FK` FOREIGN KEY (`Wrkst_ID`) REFERENCES `Workstation` (`Wrkst_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `DAF02`.`Job_Media`;
CREATE TABLE  `DAF02`.`Job_Media` (
   `Media_ID` int(10) unsigned NOT NULL,
	`TL_ID` int(10) unsigned NOT NULL,
  `Job_Media_TimeStamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`Media_ID`,`TL_ID`),
  CONSTRAINT `Job-Media-FK2` FOREIGN KEY (`Media_ID`) REFERENCES `Media` (`Media_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `DAF02`.`Workstation_MediaType`;
CREATE TABLE  `DAF02`.`Workstation_MediaType` (
  `Wrkst_ID` int(10) unsigned NOT NULL,
  `MT_ID` int(10) unsigned NOT NULL,
  PRIMARY KEY (`Wrkst_ID`,`MT_ID`),
  CONSTRAINT `WS-MediaType-FK1` FOREIGN KEY (`Wrkst_ID`) REFERENCES `Workstation` (`Wrkst_ID`),
  CONSTRAINT `WS-MediaType-FK2` FOREIGN KEY (`MT_ID`) REFERENCES `MediaType` (`MT_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `DAF02`.`JobType_MediaType`;
CREATE TABLE  `DAF02`.`JobType_MediaType` (
  `JT_ID` int(10) unsigned NOT NULL,
  `MT_ID` int(10) unsigned NOT NULL,
  PRIMARY KEY (`JT_ID`,`MT_ID`),
  CONSTRAINT `JT-MediaType-FK1` FOREIGN KEY (`JT_ID`) REFERENCES `JobType` (`JT_ID`),
  CONSTRAINT `JT-MediaType-FK2` FOREIGN KEY (`MT_ID`) REFERENCES `MediaType` (`MT_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `DAF02`.`Sequence`;
CREATE TABLE `DAF02`.`Sequence` (
  `Seq_ID` int(10) unsigned NOT NULL,
  `Seq_Name` varchar(50) NOT NULL,
  `Seq_Value` int(10) unsigned DEFAULT NULL,
  PRIMARY KEY (`Seq_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;



CREATE or Replace ALGORITHM=UNDEFINED  SQL SECURITY DEFINER VIEW `DAF02`.`RedirectedJobs` AS select `DAF02`.`TransactionLog`.`Job_ID` AS `Job_ID` from (`DAF02`.`TransactionLog` join `DAF02`.`Job` on((`DAF02`.`TransactionLog`.`TL_ID` = `DAF02`.`Job`.`TL_ID`))) where (`DAF02`.`TransactionLog`.`JS_ID` = 4);


CREATE or Replace ALGORITHM=UNDEFINED  SQL SECURITY DEFINER VIEW `DAF02`.`RejectedJobs` AS select `DAF02`.`TransactionLog`.`Job_ID` AS `Job_ID` from (`DAF02`.`TransactionLog` join `DAF02`.`Job` on((`DAF02`.`TransactionLog`.`TL_ID` = `DAF02`.`Job`.`TL_ID`))) where (`DAF02`.`TransactionLog`.`JS_ID` = 5);


CREATE or Replace ALGORITHM=UNDEFINED  SQL SECURITY DEFINER VIEW `DAF02`.`PendingJobs` AS select `DAF02`.`TransactionLog`.`Job_ID` AS `Job_ID` from (`DAF02`.`TransactionLog` join `DAF02`.`Job` on((`DAF02`.`TransactionLog`.`TL_ID` = `DAF02`.`Job`.`TL_ID`))) where ((`DAF02`.`TransactionLog`.`JS_ID` = 4) or (`DAF02`.`TransactionLog`.`JS_ID` = 5));


CREATE or Replace ALGORITHM=UNDEFINED SQL SECURITY DEFINER VIEW `DAF02`.`JobPhaseVisitedTimes` AS select `DAF02`.`Job`.`Job_ID` AS `Job_ID`,`DAF02`.`Job`.`TL_ID` AS `TL_ID`,`DAF02`.`TransactionLog`.`Phase_ID` AS `Phase_ID`,`DAF02`.`Phase`.`JT_ID` AS `JT_ID`,count(`DAF02`.`TransactionLog`.`TL_ID`) AS `count(TransactionLog.TL_ID)` from ((`DAF02`.`TransactionLog` join `DAF02`.`Job` on((`DAF02`.`TransactionLog`.`Job_ID` = `DAF02`.`Job`.`Job_ID`))) join `DAF02`.`Phase` on((`DAF02`.`Phase`.`Phase_ID` = `DAF02`.`TransactionLog`.`Phase_ID`) and (`DAF02`.`Phase`.`JT_ID`=`DAF02`.`Job`.`JT_ID`))) where ((`DAF02`.`TransactionLog`.`JS_ID` = 2) and (`DAF02`.`TransactionLog`.`TL_ID` < `DAF02`.`Job`.`TL_ID`)) group by `DAF02`.`Job`.`Job_ID`,`DAF02`.`TransactionLog`.`Phase_ID`,`DAF02`.`Phase`.`JT_ID`;

CREATE or Replace ALGORITHM=UNDEFINED  SQL SECURITY DEFINER VIEW `DAF02`.`Job_Collection` AS select `DAF02`.`Job`.`Job_ID` AS `Job_ID`,`Collection`.`Coll_ID` AS `Coll_ID` from ((`DAF02`.`Batch` join `DAF02`.`Collection` on((`DAF02`.`Batch`.`Coll_ID` = `DAF02`.`Collection`.`Coll_ID`))) join `DAF02`.`Job` on(((`DAF02`.`Job`.`Batch_ID` = `DAF02`.`Batch`.`Batch_ID`) and (`DAF02`.`Job`.`TL_ID` > 0)))) where (`DAF02`.`Job`.`TL_ID` > 0);

CREATE or Replace ALGORITHM=UNDEFINED  SQL SECURITY DEFINER VIEW `DAF02`.`Job_MaxCheckOut` AS select `DAF02`.`t1`.`Job_ID` AS `Job_ID`,`DAF02`.`t1`.`TL_ID` AS `TL_ID` from (`DAF02`.`TransactionLog` `t1` left join `DAF02`.`TransactionLog` `t2` on(((`t2`.`TL_ID` > `t1`.`TL_ID`) and (`t1`.`Job_ID` = `t2`.`Job_ID`) and (`t2`.`JS_ID` = 7)))) where ((`t1`.`JS_ID` = 7) and `t1`.`Job_ID`) group by `t1`.`Job_ID`,`t1`.`TL_ID` having (count(`t2`.`TL_ID`) = 0);


/*Database initilizations*/
	/* Sequence Table Initialization*/
	Insert Into DAF02.Sequence (Seq_ID, Seq_Name, Seq_Value) Values (1, 'Job_ID', 0);

	
		
	insert into DAF02.Role (Role_Description) values ('root account');
		
	insert into DAF02.User (User_Name,User_Password,User_AnyPhase,User_MaxJobs,User_IsActive,Role_ID,User_isLDAP)values ('Auto','auto',1,10000,1,1,1);
	update  DAF02.User set DAF02.User.User_ID=0 where DAF02.User.User_Name='Auto';
	insert into DAF02.User (User_Name,User_Password,User_AnyPhase,User_MaxJobs,User_IsActive,Role_ID,User_isLDAP)values ('root','DAFroot',1,100,1,1,1);
	
	insert into DAF02.JobStatus (JS_Name,JS_Description)values ('Started', 'Start a job');
	insert into DAF02.JobStatus (JS_Name,JS_Description)values ('Finished', 'Finish a job');
	insert into DAF02.JobStatus (JS_Name,JS_Description)values ('PreAssigned', 'PreAssigne a job');
	insert into DAF02.JobStatus (JS_Name,JS_Description)values ('Redirected', 'Redirect a job');
	insert into DAF02.JobStatus (JS_Name,JS_Description)values ('Rejected', 'Reject a job');
	insert into DAF02.JobStatus (JS_Name,JS_Description)values ('Assigned', 'Assigne a job');
	insert into DAF02.JobStatus (JS_Name,JS_Description)values ('CheckedOut', 'Check out a job');
	insert into DAF02.JobStatus (JS_Name,JS_Description)values ('Uploaded', 'Upload a job');
	insert into DAF02.JobStatus (JS_Name,JS_Description)values ('Downloaded', 'Download a job');
	
	truncate table DAF02.MediaType;
	insert into DAF02.MediaType (MT_Name,MT_Size,MT_Abbreviation)values ('Online Media Storage',0,'OnSr');
	insert into DAF02.MediaType (MT_Name,MT_Size,MT_Abbreviation)values ('Tape',4000,'TP');
	insert into DAF02.MediaType (MT_Name,MT_Size,MT_Abbreviation)values ('CD',700,'CD');
	
	
									
Insert into DAF02.Collection (Coll_Name,Coll_Abbreviation,Coll_DefaultPath,Coll_Priority,Coll_AnyUser,Coll_AnyWorkstation,Coll_Active,Coll_Comment,Own_ID,Prj_ID,Icg_ID)
							  values ('Default Coll','Dflt','',0,0,0,0,'',0,0,0);
Update DAF02.Collection set DAF02.Collection.Coll_ID=0 Where DAF02.Collection.Coll_ID=Last_Insert_ID();

Insert into DAF02.JobType (JT_Name,JT_Description,JT_LifeTime,JT_NamingConvention)
							values('Default JobType','',0,'');
Update DAF02.JobType set DAF02.JobType.JT_ID=0 Where DAF02.JobType.JT_ID=Last_Insert_ID();

Insert into DAF02.Phase(Phase_Name,Phase_MaxPeriod,Phase_Description,Phase_XMLDescription,JT_ID) 
					values ('Default',0,'Default','',0);
Update DAF02.Phase set DAF02.Phase.Phase_ID=0 Where DAF02.Phase.JT_ID=0;
				
Insert into DAF02.Batch (Batch_Name,Batch_Date,Batch_Comment,Coll_ID,JT_ID) 
				   values ('Default',now(),'',0,0);
Update DAF02.Batch set DAF02.Batch.Batch_ID=0 Where DAF02.Batch.Batch_ID=Last_Insert_ID();
					


Insert into DAF02.Job (Batch_ID,JT_ID,TL_ID) values (0,0,0);
Update DAF02.Job set DAF02.Job.Job_ID=0 Where  DAF02.Job.Job_ID=Last_Insert_ID();

Insert into DAF02.OperatingSystem (OS_Name) values ('MS Windows');
Insert into DAF02.OperatingSystem (OS_Name) values ('Linux');

Insert into DAF02.Workstation (Wrkst_Name,Wrkst_WorkingDirectory,Wrkst_AnyPhase,Wrkst_IsActive,Wrkst_Comment,OS_ID,Wrkst_Location)
								 values ('Default WS','',0,0,'',1,'');
Update DAF02.Workstation set DAF02.Workstation.Wrkst_ID=0 Where DAF02.Workstation.Wrkst_ID=Last_Insert_ID();
	
-- DAF02 TL
Insert into DAF02.TransactionLog(Job_ID,Phase_ID,User_ID,Wrkst_ID,JS_ID,TL_Date,TL_NoOfFiles,TL_Status_Data)
										values(0,0,0,0,7,now(),0,'');
Update DAF02.TransactionLog set DAF02.TransactionLog.TL_ID=0 Where DAF02.TransactionLog.TL_ID=Last_Insert_ID();

-- create relation between TransactionLog and Job based on TransactionLog.TL_ID = Job.TL_ID
ALTER TABLE `DAF02`.`Job` ADD CONSTRAINT `FK_Job_TL` FOREIGN KEY `FK_Job_TL` (`TL_ID`)
    REFERENCES `DAF02`.`TransactionLog` (`TL_ID`)
    ON DELETE RESTRICT
    ON UPDATE RESTRICT;
		
ALTER TABLE DAF02.Permission 
ADD Perm_ParentID int(10) ;

insert into DAF02.Permission(Perm_Description) values ('AdminManager');
insert into DAF02.Permission(Perm_Description) values ('PhaseManager');
insert into DAF02.Permission(Perm_Description) values ('ReportManager');
insert into DAF02.Permission(Perm_Description) values ('CheckInManager');
insert into DAF02.Permission(Perm_Description) values ('ArchiveManager');
insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('SelectJob',2);
insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('Redirect',2);
insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('Reject',2);
insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('Download',2);
insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('Roles',1);
insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('Job-Types',1);
insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('Settings',1);
insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('Phases',1);
insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('Users',1);
insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('Workstations',1);
insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('Collections',1);

insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('System Workflow',3);
insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('Pending Jobs',3);
insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('Late Jobs',3);
insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('User Rates',3);
insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('Report Builder',3);


insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('Batch',4);
insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('New Job',4);
insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('Retrieve Job',4);
insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('Search',4);
insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('Advanced Search',4);
insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('Report Data',4);


insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('Archiver',5);
insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('Archived and Active',5);
insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('Confirm Media',5);

insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('Assign',27);
insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('Change Type',27);
insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('Delete',27);
insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('Overwrite',27);
insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('Retrieve',27);

insert into DAF02.Permission (Perm_Description,Perm_ParentID) values ('View All',20);

insert into DAF02.Role_Permission (Role_ID,Perm_ID) values (1,1);
insert into DAF02.Role_Permission (Role_ID,Perm_ID) values (1,2);
insert into DAF02.Role_Permission (Role_ID,Perm_ID) values (1,3);
insert into DAF02.Role_Permission (Role_ID,Perm_ID) values (1,4);
insert into DAF02.Role_Permission (Role_ID,Perm_ID) values (1,5);
insert into DAF02.Role_Permission (Role_ID, Perm_ID) values (1,10);

