/*Create DB*/
DROP Schema if Exists Metadata;
Create Schema Metadata;
use Metadata;
DROP TABLE IF EXISTS  Metadata.`ExternalID`;
DROP TABLE IF EXISTS  Metadata.`Object`;
DROP TABLE IF EXISTS  Metadata.`Language`;
DROP TABLE IF EXISTS  Metadata.`Project`;
DROP TABLE IF EXISTS  Metadata.`Owner`;
DROP TABLE IF EXISTS  Metadata.`InCharge`;


DROP TABLE IF EXISTS  Metadata.`ExternalID_Type`;

CREATE TABLE   Metadata.`Language` (
  `Lang_ID` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `Lang_Name` varchar(50) NOT NULL,
  `Lang_Abbreviation` varchar(3) NOT NULL,
  `Lang_TimeStamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`Lang_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE  Metadata.`Project` (
  `Prj_ID` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `Prj_Name` varchar(50) NOT NULL,
  `Prj_Abbreviation` varchar(4) NOT NULL,
  `Prj_Comment` nvarchar(600) ,
  `Prj_TimeStamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`Prj_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE   Metadata.`Owner` (
  `Own_ID` int(11) unsigned NOT NULL AUTO_INCREMENT,
  `Own_Name` varchar(150) NOT NULL,
  `Own_Abbreviation` varchar(4) NOT NULL,
  `Own_Comment` nvarchar(600) ,
  `Own_TimeStamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`Own_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS  Metadata.`InCharge`;
CREATE TABLE `InCharge` (
  `Icg_ID` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `Icg_Name` varchar(50) NOT NULL,
  `Icg_Abbreviation` char(3) NOT NULL,
  `Icg_Description` varchar(200) DEFAULT NULL,
  `Icg_TimeStamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`Icg_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

CREATE TABLE   Metadata.`Object` (
  `Obj_ID` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `Obj_Title` varchar(100) NOT NULL,
  `Obj_Creator` varchar(100) NOT NULL,
  `Obj_Info1` varchar(100) DEFAULT NULL,
  `Obj_Info2` varchar(100) DEFAULT NULL,
  `Obj_Info3` varchar(100) DEFAULT NULL,
  `Obj_BinaryMarc21` blob,  
	`Obj_Volume` varchar(50) DEFAULT NULL,
  `Own_ID` int(10) unsigned,
  `Prj_ID` int(10) unsigned,
  `Icg_ID` int(10) unsigned,
  `Lang_ID` int(10) unsigned NOT NULL,
  `Obj_TimeStamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
	`Job_ID` int(10) unsigned,
	Obj_Date datetime DEFAULT null ,
  PRIMARY KEY (`Obj_ID`),
  KEY `Obj_ibfk_0` (`Lang_ID`),
  CONSTRAINT `Obj_ibfk_1` FOREIGN KEY (`Lang_ID`) REFERENCES `Language` (`Lang_ID`),
  CONSTRAINT `Obj_ibfk_2` FOREIGN KEY (`Own_ID`) REFERENCES `Owner` (`Own_ID`),
  CONSTRAINT `Obj_ibfk_3` FOREIGN KEY (`Prj_ID`) REFERENCES `Project` (`Prj_ID`),
  CONSTRAINT `Obj_ibfk_4` FOREIGN KEY (`Icg_ID`) REFERENCES `InCharge` (`Icg_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE   Metadata.`ExternalID_Type` (
  `ExtIDType_ID` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `ExtIDType_Name` varchar(50) NOT NULL,
  `ExtIDType_TimeStamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`ExtIDType_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE   Metadata.`ExternalID` (
	`ExtID_ID` int(10) unsigned NOT NULL AUTO_INCREMENT,
	`ExtID_Value` varchar(50) NOT NULL,
	`ExtIDType_ID` int(10) unsigned  NULL,
	`ExtID_isDefault` TinyInt(1) DEFAULT 0 NOT NULL,
	`Obj_ID` int(10) unsigned  NOT NULL,
	`ExtID_TimeStamp` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
	PRIMARY KEY (`ExtID_ID`),
	CONSTRAINT `ExtID_fk_1` FOREIGN KEY (`ExtIDType_ID`) REFERENCES `ExternalID_Type` (`ExtIDType_ID`),
	CONSTRAINT `ObjID_fk_1` FOREIGN KEY (`Obj_ID`) REFERENCES `Object` (`Obj_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


INSERT INTO  Metadata.`Language` (`Lang_ID`,`Lang_Name`,`Lang_Abbreviation`,`Lang_TimeStamp`) VALUES 
 (1,'Arabic','ara','2006-12-27 14:26:00'),
 (2,'Czech','cze','2006-12-27 14:26:00'),
 (3,'English','eng','2006-12-27 14:26:00'),
 (4,'French','fre','2006-12-27 14:26:00'),
 (5,'German','ger','2006-12-27 14:26:00'),
 (6,'Greek, Ancient (to 1453)','grc','2006-12-27 14:26:00'),
 (7,'Iranian','ira','2006-12-27 14:26:01'),
 (8,'Italian','ita','2006-12-27 14:26:01'),
 (9,'Japanese (use for related languages)','jpn','2006-12-27 14:26:01'),
 (10,'Korean (use for related lang. and dial.)','kor','2006-12-27 14:26:01'),
 (11,'Latin','lat','2006-12-27 14:26:01'),
 (12,'Miscellaneous','mis','2006-12-27 14:26:01'),
 (13,'Norwegian','nor','2006-12-27 14:26:01'),
 (14,'Persian, Modern','per','2006-12-27 14:26:01'),
 (15,'Polish','pol','2006-12-27 14:26:01'),
 (16,'Portuguese','por','2006-12-27 14:26:01'),
 (17,'Russian','rus','2006-12-27 14:26:01'),
 (18,'Slovak','slo','2006-12-27 14:26:01'),
 (19,'Spanish','spa','2006-12-27 14:26:01'),
 (20,'Turkish','tur','2006-12-27 14:26:01');
INSERT INTO `Language` (`Lang_ID`,`Lang_Name`,`Lang_Abbreviation`,`Lang_TimeStamp`) VALUES 
 (21,'None','non','2007-05-14 09:27:49');
/*!40000 ALTER TABLE `Language` ENABLE KEYS */;

/*Views*/
Drop View if Exists Metadata.`JobView`;
Drop View If Exists Metadata.`LanguageView`;
Drop View If Exists Metadata.`ExternalID_TypeView`;
Drop View If Exists Metadata.`ExternalIDView`;
Drop View If Exists Metadata.`ProjectView`;
Drop View If Exists Metadata.`OwnerView`;
Drop View If Exists Metadata.`InChargeView`;

CREATE ALGORITHM=UNDEFINED  SQL SECURITY DEFINER VIEW Metadata.`ExternalID_TypeView` AS select `ExternalID_Type`.`ExtIDType_ID` AS `ExtIDType_ID`,`ExternalID_Type`.`ExtIDType_Name` AS `ExtIDType_Name`,`ExternalID_Type`.`ExtIDType_TimeStamp` AS `ExtIDType_TimeStamp` from `ExternalID_Type`;
CREATE ALGORITHM=UNDEFINED  SQL SECURITY DEFINER VIEW Metadata.`ExternalIDView` AS select `ExternalID`.`ExtID_ID` AS `ExtID_ID`,`ExternalID`.`ExtID_Value` AS `ExtID_Value`,`ExternalID`.`ExtIDType_ID` AS `ExtIDType_ID`,`ExternalID`.`ExtID_isDefault` AS `ExtID_isDefault`,`Object`.`Job_ID` AS `Job_ID`,`ExternalID`.`ExtID_TimeStamp` AS `ExtID_TimeStamp` from (`ExternalID` join `Object` on((`ExternalID`.`Obj_ID` = `Object`.`Obj_ID`)));
CREATE ALGORITHM=UNDEFINED  SQL SECURITY DEFINER VIEW Metadata.`InChargeView` AS select `InCharge`.`Icg_ID` AS `Icg_ID`,`InCharge`.`Icg_Name` AS `Icg_Name`,`InCharge`.`Icg_Abbreviation` AS `Icg_Abbreviation`,`InCharge`.`Icg_Description` AS `Icg_Description`,`InCharge`.`Icg_TimeStamp` AS `Icg_TimeStamp` from `InCharge`;
CREATE ALGORITHM=UNDEFINED  SQL SECURITY DEFINER VIEW Metadata.`JobView` AS select `Object`.`Job_ID` AS `Job_ID`,`Object`.`Obj_Title` AS `Job_Title`,`Object`.`Obj_Creator` AS `Job_Creator`,(case when isnull(`Object`.`Obj_Info1`) then `Object`.`Obj_Volume` else `Object`.`Obj_Info1` end) AS `Job_Info1`,`Object`.`Obj_Info2` AS `Job_Info2`,`Object`.`Obj_Info3` AS `Job_Info3`,`Object`.`Obj_BinaryMarc21` AS `Job_Lob`,`Object`.`Own_ID` AS `Own_ID`,`Object`.`Prj_ID` AS `Prj_ID`,`ExternalID`.`ExtID_Value` AS `Job_External_ID`,`ExternalID`.`ExtIDType_ID` AS `ExtIDType_ID`,`Object`.`Lang_ID` AS `Lang_ID`,`Object`.`Obj_BinaryMarc21` AS `Job_IdentifyingLob` from (`Object` left join `ExternalID` on(((`Object`.`Obj_ID` = `ExternalID`.`Obj_ID`) and (`ExternalID`.`ExtID_isDefault` = 1))));
CREATE ALGORITHM=UNDEFINED  SQL SECURITY DEFINER VIEW Metadata.`LanguageView` AS select `Language`.`Lang_ID` AS `Lang_ID`,`Language`.`Lang_Name` AS `Lang_Name`,`Language`.`Lang_Abbreviation` AS `Lang_Abbreviation`,`Language`.`Lang_TimeStamp` AS `Lang_TimeStamp` from `Language`;
CREATE ALGORITHM=UNDEFINED  SQL SECURITY DEFINER VIEW Metadata.`OwnerView` AS select `Owner`.`Own_ID` AS `Own_ID`,`Owner`.`Own_Name` AS `Own_Name`,`Owner`.`Own_Abbreviation` AS `Own_Abbreviation`,`Owner`.`Own_Comment` AS `Own_Comment`,`Owner`.`Own_TimeStamp` AS `Own_TimeStamp` from `Owner`;
CREATE ALGORITHM=UNDEFINED  SQL SECURITY DEFINER VIEW Metadata.`ProjectView` AS select `Project`.`Prj_ID` AS `Prj_ID`,`Project`.`Prj_Name` AS `Prj_Name`,`Project`.`Prj_Abbreviation` AS `Prj_Abbreviation`,`Project`.`Prj_Comment` AS `Prj_Comment`,`Project`.`Prj_TimeStamp` AS `Prj_TimeStamp` from `Project`;

ALTER TABLE `DAF02`.`Collection` CHANGE `Own_ID` Own_ID INT(10) UNSIGNED NOT NULL,
  CHANGE `Prj_ID` Prj_ID INT(10) UNSIGNED NOT NULL,
  CHANGE `Icg_ID` Icg_ID INT(10) UNSIGNED NOT NULL;

Update	DAF02.Collection set DAF02.Collection.Own_ID=1 where DAF02.Collection.Own_ID=0;
Update	DAF02.Collection set DAF02.Collection.Prj_ID=13 where DAF02.Collection.Prj_ID=0;
Update	DAF02.Collection set DAF02.Collection.Icg_ID=1 where DAF02.Collection.Icg_ID=0;

Update  Metadata.Object, DAF02.Job, DAF02.Batch, DAF02.Collection
Set  Metadata.Object.Prj_ID = DAF02.Collection.Prj_ID,  Metadata.Object.Own_ID = DAF02.Collection.Own_ID,  Metadata.Object.Icg_ID = DAF02.Collection.Icg_ID 
Where  Metadata.Object.Job_ID = DAF02.Job.Job_ID
And DAF02.Job.Batch_ID = DAF02.Batch.Batch_ID
And DAF02.Batch.Coll_ID = DAF02.Collection.Coll_ID;

insert into Metadata.Owner(Own_Name,Own_Abbreviation,Own_Comment)values('Default','Dft','');
update Metadata.Owner set Metadata.Owner.Own_ID=0 where Metadata.Owner.Own_ID=Last_insert_ID();

insert into Metadata.InCharge(Icg_Name,Icg_Abbreviation,Icg_Description)values('Default','Dft','');
update Metadata.InCharge set Metadata.InCharge.Icg_ID=0 where Metadata.InCharge.Icg_ID=Last_insert_ID();


insert into Metadata.Project(Prj_Name,Prj_Abbreviation,Prj_Comment)values('Default','Dft','');
update Metadata.Project set Metadata.Project.Prj_ID=0 where Metadata.Project.Prj_ID=Last_insert_ID();




