
DROP PROCEDURE IF EXISTS Job_CreatePool;
CREATE PROCEDURE Job_CreatePool()
BEGIN

/*Create Job_Pool*/
	DROP TABLE IF EXISTS Job_Pool;
	CREATE TABLE   Job_Pool(
	`Job_ID` int(10) unsigned NOT NULL,
	`Coll_ID` int(10) unsigned NOT NULL,
	`JS_ID` int(10) unsigned NOT NULL,
	`Phase_ID` int(10) unsigned NOT NULL,
	`User_ID` int(10) unsigned NOT NULL,
		KEY `Job_ID` (`Job_ID`),
		KEY `Coll_ID` (`Coll_ID`),
		KEY `JS_ID` (`JS_ID`),
		KEY `Phase_ID` (`Phase_ID`),
		KEY `User_ID` (`User_ID`),
		CONSTRAINT `Pool_Job_ID` FOREIGN KEY (`Job_ID`) REFERENCES `Job` (`Job_ID`),
		CONSTRAINT `Pool_Collection` FOREIGN KEY (`Coll_ID`) REFERENCES `Collection` (`Coll_ID`),
		CONSTRAINT `Pool_JS` FOREIGN KEY (`JS_ID`) REFERENCES `JobStatus` (`JS_ID`),
		CONSTRAINT `Pool_Phase` FOREIGN KEY (`Phase_ID`) REFERENCES `Phase` (`Phase_ID`),
		CONSTRAINT `Pool_User` FOREIGN KEY (`User_ID`) REFERENCES `User` (`User_ID`),
		PRIMARY KEY (`Job_ID`)
	
	) ENGINE=HEAP;
	
	
	/*Fill Job_Pool*/
	insert into Job_Pool(Job_ID,Coll_ID,JS_ID,Phase_ID,User_ID)
	(select TransactionLog.Job_ID,
				Job_Collection.Coll_ID,
				TransactionLog.JS_ID,
				getNextPhase(TransactionLog.Job_ID),
				if(JS_ID=2,0,TransactionLog.User_ID)
		
	from Job
	inner join TransactionLog on TransactionLog.TL_ID=Job.TL_ID and Job.TL_ID>0
	inner join Job_Collection on Job_Collection.Job_ID=Job.Job_ID
	where JS_ID in (2,6)
	);


END;

DROP PROCEDURE IF EXISTS Job_getJobs;
CREATE PROCEDURE Job_getJobs(UserID_Val Integer,WsID_Val Integer)
BEGIN
		Declare allPhasesUser		Integer Default 0;
		Declare allPhasesWS		Integer Default 0;
		Declare tableExists	Integer Default 0;
		/*Check Pool Existence*/
		select count(*) into tableExists FROM information_schema.tables 
		WHERE table_schema = 'DAF02' AND table_name = 'Job_Pool';
		if(tableExists=0)THEN
		call Job_CreatePool();
		END IF;
		
		select User.User_AnyPhase
		into allPhasesUser
		from User where User_ID=UserID_Val;
		
			
		select Workstation.Wrkst_AnyPhase
		into allPhasesWS
		from Workstation where Workstation.Wrkst_ID=WsID_Val;
		

		
		if(allPhasesUser=0)Then
			/*take phases that user can work on, in consideration*/
			select distinct Job_Pool.Job_ID,
						 Metadata.JobView.Job_Title,
						Phase.Phase_Name,
						User.User_Name,
						Metadata.JobView.Job_External_ID ,
						 Metadata.ExternalID_TypeView.ExtIDType_Name,
						-1,
						if ((Workstation_Collection.Coll_ID is not null or Collection.Coll_AnyWorkstation=1) 
						AND (Workstation_Phase.Phase_ID is not null or allPhasesWS=1)
						,WsID_Val,0) as validWS,
						Job.JT_ID,
						Phase.Phase_ID,
						Job_Pool.JS_ID
					 						
			from Job_Pool 
			inner join User on User.User_ID=Job_Pool.User_ID
			inner join Collection on Collection.Coll_ID=Job_Pool.Coll_ID
			inner join Phase on Phase.Phase_ID=Job_Pool.Phase_ID 
			inner join Job on Job.Job_ID=Job_Pool.Job_ID and Job.TL_ID>0
			inner join Metadata.JobView	on Metadata.JobView.Job_ID=Job_Pool.Job_ID
			left outer join Metadata.ExternalID_TypeView on Metadata.JobView.ExtIDType_ID = Metadata.ExternalID_TypeView.ExtIDType_ID
			left outer join Workstation_Collection on Workstation_Collection.Coll_ID=Job_Pool.Coll_ID and Workstation_Collection.Wrkst_ID=WsID_Val
			left outer join Workstation_Phase on Workstation_Phase.Phase_ID=Job_Pool.Phase_ID and Workstation_Phase.Wrkst_ID=WsID_Val
	
			where Job_Pool.Phase_ID>0 
			and  Job_Pool.User_ID in(0 ,UserID_Val)
			and (Collection.Coll_AnyUser=1 or Job_Pool.Coll_ID in (select Coll_ID from User_Collection where User_ID=UserID_Val))
			and (Job_Pool.Phase_ID in (select Phase_ID from User_Phase where User_ID=UserID_Val))
			Order by if(Job_Pool.JS_ID=6 and Job_Pool.User_ID=UserID_Val, 0,1),Job.Job_Priority Desc,Job.Job_DueDate,Job_Pool.Job_ID ;
			
		ELSE
			/*dont filter on phases, this user can work on all phases*/
		select distinct Job_Pool.Job_ID,
						 Metadata.JobView.Job_Title,
						Phase.Phase_Name,
						User.User_Name,
						Metadata.JobView.Job_External_ID ,
						 Metadata.ExternalID_TypeView.ExtIDType_Name,
						-1,
						if ((Workstation_Collection.Coll_ID is not null or Collection.Coll_AnyWorkstation=1) 
						AND (Workstation_Phase.Phase_ID is not null or allPhasesWS=1)
						,WsID_Val,0) as validWS,
						Job.JT_ID,
						Phase.Phase_ID,
						Job_Pool.JS_ID
			
			from Job_Pool 
			inner join User on User.User_ID=Job_Pool.User_ID
			inner join Collection on Collection.Coll_ID=Job_Pool.Coll_ID
			inner join Phase on Phase.Phase_ID=Job_Pool.Phase_ID 
			inner join Job on Job.Job_ID=Job_Pool.Job_ID and Job.TL_ID>0
			inner join Metadata.JobView	on Metadata.JobView.Job_ID=Job_Pool.Job_ID
			left outer join Metadata.ExternalID_TypeView on Metadata.JobView.ExtIDType_ID = Metadata.ExternalID_TypeView.ExtIDType_ID
			left outer join Workstation_Collection on Workstation_Collection.Coll_ID=Job_Pool.Coll_ID and Workstation_Collection.Wrkst_ID=WsID_Val
			left outer join Workstation_Phase on Workstation_Phase.Phase_ID=Job_Pool.Phase_ID and Workstation_Phase.Wrkst_ID=WsID_Val
	
			where Job_Pool.Phase_ID>0 
			and  Job_Pool.User_ID in(0 ,UserID_Val)
			and (Collection.Coll_AnyUser=1 or Job_Pool.Coll_ID in (select Coll_ID from User_Collection where User_ID=UserID_Val))
			Order by if(Job_Pool.JS_ID=6 and Job_Pool.User_ID=UserID_Val, 0,1),Job.Job_Priority Desc,Job.Job_DueDate,Job_Pool.Job_ID ;
		END IF;
			
END;

drop TRIGGER if exists updatePool;
CREATE TRIGGER updatePool AFTER UPDATE ON Job
  FOR EACH ROW 
	BEGIN
	Declare Job_Coll	Integer Default 0;
	Declare Job_JS	Integer Default 0;
	Declare Job_User Integer Default 0;
	Declare tableExists	Integer Default 0;
	/*Check Pool Existence*/
	select count(*) into tableExists FROM information_schema.tables 
	WHERE table_schema = 'DAF02' AND table_name = 'Job_Pool';
	if(tableExists=0)THEN
		call Job_CreatePool();
	END IF;

	/*get Collection*/
	Select Collection.Coll_ID
	into Job_Coll
	From Job
	inner join Batch on Batch.Batch_ID=Job.Batch_ID
	inner join 	Collection on Batch.Coll_ID=Collection.Coll_ID
	where Job.Job_ID=New.Job_ID;
 
	/*getCurrent Status*/
	Select JS_ID,if(JS_ID=2,0,User_ID)
	into Job_JS,Job_User
	From TransactionLog where TL_ID=New.TL_ID;
	/*Remove entry from Pool*/
	Delete from Job_Pool where Job_Pool.Job_ID=New.Job_ID;
	/*Filter on Status*/
	IF(Job_JS in (2,6))THEN
	/*insert into pool*/
	insert into Job_Pool(Job_ID,Coll_ID,JS_ID,Phase_ID,User_ID)values(New.Job_ID,Job_Coll,Job_JS,getNextPhase(New.Job_ID),Job_User);
	END IF;
	
	
  END;
drop procedure if exists WorkStation_updatePhases;
CREATE  PROCEDURE `WorkStation_updatePhases`(
		wsID_Val 					 Integer ,			
		phasesVal						 nvarchar(500),
		delimiterVal				 char(1)
	)
BEGIN
	START TRANSACTION;
			DELETE FROM Workstation_Phase	
			WHERE (Workstation_Phase.Wrkst_ID=wsID_Val);
			
			CALL SplitIDs(phasesVal,delimiterVal);
			
			INSERT INTO Workstation_Phase (Wrkst_ID,Phase_ID) 
  										( SELECT    wsID_Val,IDVal
												FROM SplittedTempTable
												WHERE IDVal not in (1,2)
											);											
				
		IF (1 in (select IDVal from SplittedTempTable) )THEN
				INSERT INTO Workstation_Phase (Wrkst_ID,Phase_ID) values (wsID_Val,1);
		END IF;
		
		IF (2 in (select IDVal from SplittedTempTable) )THEN
				INSERT INTO Workstation_Phase (Wrkst_ID,Phase_ID) values (wsID_Val,2);
		END IF;
		Drop Temporary Table If Exists `SplittedTempTable`;
		
		SELECT * FROM Workstation_Phase 
		WHERE (Workstation_Phase.Wrkst_ID=wsID_Val);
										
COMMIT;
	
END;

drop procedure if exists User_updatePhases;
CREATE  PROCEDURE `User_updatePhases`(
		userID_Val 					 Integer ,			
		phasesVal						 nvarchar(500),
		delimiterVal				 char(1)
	)
BEGIN
	START TRANSACTION;
			DELETE FROM User_Phase	
			WHERE (User_Phase.User_ID=userID_Val);
			
			CALL SplitIDs(phasesVal,delimiterVal);
			INSERT INTO User_Phase (User_ID,Phase_ID) 
  										( SELECT   userID_Val,IDVal
												FROM SplittedTempTable
												WHERE IDVal not in (1,2)
											);											
				
		IF (1 in (select IDVal from SplittedTempTable) )THEN
				INSERT INTO User_Phase (User_ID,Phase_ID) values (userID_Val,1);
		END IF;
		
			IF (2 in (select IDVal from SplittedTempTable) )THEN
				INSERT INTO User_Phase (User_ID,Phase_ID) values (userID_Val,2);
		END IF;
		
		Drop Temporary Table If Exists `SplittedTempTable`;
		
		SELECT * FROM User_Phase 
		WHERE (User_Phase.User_ID=userID_Val);
										
	COMMIT;
	
END;