

DROP FUNCTION IF EXISTS `DAF02`.`ActiveJob`$$
CREATE  FUNCTION  `DAF02`.`ActiveJob`(JobID_Val 		integer
													 	) RETURNS int(11)
BEGIN
  /*
	This function is to checks if the job ready to check out or not
	* ready to check out job means archived jobs and currently in finished state for the backup phase
	*/
	Declare canCheckOut Integer default 0;
	
	DECLARE CONTINUE HANDLER FOR SQLWARNING RETURN (0);
	
	/*check if the job in finish state for backup phase*/		
	SELECT count(TransactionLog.TL_ID)
	INTO  canCheckOut
	FROM Job
	INNER JOIN TransactionLog
	ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
	WHERE (Job.Job_ID=JobID_Val)
	AND (TransactionLog.JS_ID=2)
	AND (TransactionLog.Phase_ID=1 or TransactionLog.Phase_ID=2);
	
	IF(canCheckOut>0) Then 
		RETURN 0;
	ELSE
		RETURN 1;
	END IF;
	
	RETURN (canCheckOut);
END;

 $$
DROP FUNCTION IF EXISTS `DAF02`.`Job_AddWithID`$$
CREATE PROCEDURE `DAF02`.`Job_AddWithID`( 
	JobID_Val				Integer,
	JobTitle_Val 			nvarchar(500),
	JobCreator_Val 			nvarchar(100),
	JobDate_Val 			DateTime,
	JobInfo1_Val 			nvarchar(500),
	JobInfo2_Val 			nvarchar(500),
	JobInfo3_Val 			nvarchar(500),
	JobPath_Val 			nvarchar(200),
	JobPriority_Val			Integer,
	JobDueDate_Val 			DateTime,
	JobIdentifyingLob_Val	Blob,
	BatchID_Val 			Integer,
	JTID_Val				Integer,
	LangID_Val			Integer,
	JCID_Val 				Integer,
	TLID_Val				Integer,
	StorageID_Val			Integer
)
BEGIN
								
			Declare insertedJobID integer default -1;
			Declare OwnerID integer default -1;
			Declare PrjID integer default -1;
			Declare InChargeJobID integer default -1;
			
			Declare tableExists	Integer Default 0;
			
			START TRANSACTION;
	select count(*) into tableExists FROM information_schema.tables 
	WHERE table_schema = 'DAF02' AND table_name = 'Job_Pool';
	if(tableExists=0)THEN
		call Job_CreatePool();
	END IF;

			/*Get CollectionOwner, ProjectID and InChargeID from Collection table usinf Batch_ID*/
			SELECT Collection.Own_ID,Collection.Prj_ID,Collection.Icg_ID
				Into OwnerID,PrjID,InChargeJobID
			From Collection
			inner join Batch On Batch.Coll_ID=Collection.Coll_ID
			where Batch.Batch_ID=BatchID_Val;
			
			/*Add new Job into DAF02 DB*/
				INSERT INTO Job  (Job_ID,
													Job_Date					,
													Job_Path					,
													Job_Priority			,
													Job_DueDate				,
													Batch_ID				,
													JT_ID					,
													JC_ID					,
													TL_ID,
													Storage_ID
													)
									values (JobID_Val								,
													JobDate_Val 			 			,
													JobPath_Val 			 			,
													JobPriority_Val				  ,
													JobDueDate_Val 				  ,
													BatchID_Val 					,
													JTID_Val             	,
													JCID_Val 							,
													TLID_Val,
													StorageID_Val						 
													);
									
			/*call Object_Add to insert metadata into Metadata DB*/
			call Metadata.Object_Add(	JobTitle_Val,
															JobCreator_Val,
															JobInfo1_Val,
															JobInfo2_Val,
															JobInfo3_Val,
															JobIdentifyingLob_Val,
															OwnerID,
															PrjID,
															InChargeJobID,
															LangID_Val,
															JobID_Val
															);
			/*Select inserted Data*/
			Select 	Job.Job_ID,
							Metadata.JobView.Job_External_ID,
							Metadata.JobView.ExtIDType_ID,
							Metadata.JobView.Job_Title,
							Metadata.JobView.Job_Creator,
							Job_Date,
							Metadata.JobView.Job_Info1,
							Metadata.JobView.Job_Info2,
							Metadata.JobView.Job_Info3,
							Job_Path,
							Job_Priority,
							Job_DueDate,
							Metadata.JobView.Job_IdentifyingLob,
							Batch_ID,
							JT_ID,
							Metadata.JobView.Lang_ID,
							JC_ID,
							TL_ID,
							Storage_ID,
							Job_TimeStamp
			From Job
			inner join Metadata.JobView on Metadata.JobView.Job_ID=Job.Job_ID
			where Job.Job_ID=JobID_Val;
			
			
		COMMIT;
END

$$



DROP PROCEDURE IF EXISTS `DAF02`.`AdvancedSearch`$$
CREATE  PROCEDURE  `DAF02`.`AdvancedSearch`(
CollIDs nvarchar(200),
BatcheIDs nvarchar(300),
LangIDs nvarchar(100),
StorageIDs nvarchar(100),
JobTypeIDs nvarchar(200),
PhaseIDs nvarchar(300),
ExtTypeIDs nvarchar(100),
UserIDs nvarchar(500),
StatusIDs nvarchar(100),
OldNewIDs nvarchar(100),
jobID		integer,
jobExtID  nvarchar(100),
fromDate 	DateTime,
toDate		DateTime
)
BEGIN
Declare selectStmt nvarchar(1000);
Declare FromStmt nvarchar(1000);
Declare WhereStmt nvarchar(2000) ;
Declare compare Integer default -1;

-- initialize where clause
SET WhereStmt=' WHERE (1=1) ';

/*check if old or new job
 * -1 -- any
 * 0 --> old
 * 1 -->new
*/
-- check if the jobs to be searched New or Old
-- 1) Any Jobs
SELECT STRCMP(OldNewIDs,"-1") into compare;
-- STRCMP return 0 on equality
-- OR no entries selected (0) length
-- OR Old + ane selected (1,2) (3) length
IF (compare=0 OR Length(OldNewIDs)=0 OR  Length(OldNewIDs)=3) THEN
	-- Any Job
  -- initialize select caluse
  SET selectStmt ='SELECT Distinct Job.Job_ID,Job.Job_Path, Metadata.JobView.Job_Title,if(Job.TL_ID>0,JobStatus.JS_Name,"Checked Out"),if(Job.TL_ID>0,TransactionLog.TL_Date,getOTLDate(Job.Job_ID,7)),Batch.Batch_Name,Collection.Coll_Name,JobType.JT_Name,Metadata.LanguageView.Lang_Name,if(Job.TL_ID>0,Storage.Path,"No Server"),Job.TL_ID  ';
  -- initialize from clause
	SET FromStmt=' FROM Job INNER JOIN Storage ON (Job.Storage_ID=Storage.Storage_ID) INNER JOIN JobType on (Job.JT_ID=JobType.JT_ID) INNER JOIN Batch ON (Job.Batch_ID=Batch.Batch_ID) INNER JOIN Collection ON (Batch.Coll_ID=Collection.Coll_ID) INNER JOIN TransactionLog on (Job.TL_ID=TransactionLog.TL_ID ) INNER JOIN JobStatus on (TransactionLog.JS_ID=JobStatus.JS_ID) inner join Metadata.JobView on Metadata.JobView.Job_ID=Job.Job_ID inner join Metadata.LanguageView on Metadata.JobView.Lang_ID=Metadata.LanguageView.Lang_ID';
	-- SET FromStmt==concat(FromStmt,' inner join Metadata.JobView on Metadata.JobView.Job_ID=Job.Job_ID inner join Metadata.LanguageView on Metadata.JobView.Lang_ID=Metadata.LanguageView.Lang_ID ');
	SET WhereStmt =concat(WhereStmt,' AND if(Job.TL_ID>0,TransactionLog.TL_Date>="',fromDate ,'" and TransactionLog.TL_Date<= "',toDate,'",getOTLDate(Job.Job_ID,7)>="',fromDate,'" and getOTLDate(Job.Job_ID,7)<="',toDate,'") ');
		
END IF;

-- 2) Old Jobs
SELECT STRCMP(OldNewIDs,"0") into compare;
-- STRCMP return 0 on equality
IF (compare=0) THEN
	-- Old Job
	-- initialize select caluse
	SET selectStmt =concat('SELECT Distinct Job.Job_ID,Job.Job_Path,Metadata.JobView.Job_Title,"Checked Out",getOTLDate(Job.Job_ID,7),Batch.Batch_Name,Collection.Coll_Name,JobType.JT_Name,Metadata.LanguageView.Lang_Name,"No Server",Job.TL_ID');
	-- initialize from clause
	SET FromStmt=' FROM Job  INNER JOIN Batch ON (Job.Batch_ID=Batch.Batch_ID ) INNER JOIN Collection ON (Collection.Coll_ID=Batch.Coll_ID)  inner join Metadata.JobView on Metadata.JobView.Job_ID=Job.Job_ID inner join Metadata.LanguageView on Metadata.JobView.Lang_ID=Metadata.LanguageView.Lang_ID INNER JOIN JobType on (Job.JT_ID=JobType.JT_ID )';
	-- initialize where clause 
	SET WhereStmt =concat(WhereStmt,' AND Job.TL_ID=0  ');
	SET WhereStmt = concat(WhereStmt,' AND getOTLDate(Job.Job_ID,7) >= "',fromDate,'" AND getOTLDate(Job.Job_ID,7) <= "',toDate,'"');
		
END IF;

-- 3) New Jobs
SELECT STRCMP(OldNewIDs,"1") into compare;
-- STRCMP return 0 on equality
IF (compare=0) THEN
	-- new Job
	-- initialize select caluse
	SET selectStmt ='SELECT Distinct Job.Job_ID,Job.Job_Path,Metadata.JobView.Job_Title,JobStatus.JS_Name,TransactionLog.TL_Date,Batch.Batch_Name,Collection.Coll_Name,JobType.JT_Name,Metadata.LanguageView.Lang_Name,Storage.Path,Job.TL_ID';
	-- initialize from clause
	SET FromStmt=' FROM Job INNER JOIN Storage ON (Job.Storage_ID=Storage.Storage_ID)  inner join Metadata.JobView on Metadata.JobView.Job_ID=Job.Job_ID inner join Metadata.LanguageView on Metadata.JobView.Lang_ID=Metadata.LanguageView.Lang_ID  INNER JOIN JobType on (Job.JT_ID=JobType.JT_ID)  INNER JOIN Batch ON (Job.Batch_ID=Batch.Batch_ID) INNER JOIN Collection ON (Batch.Coll_ID=Collection.Coll_ID) INNER JOIN TransactionLog on (Job.TL_ID=TransactionLog.TL_ID and Job.TL_ID>0) INNER JOIN JobStatus on (TransactionLog.JS_ID=JobStatus.JS_ID)';
	-- initialize where clause related to TransactionLog
	SET WhereStmt = concat(WhereStmt,' AND TransactionLog.TL_Date >= "',fromDate,'" AND TransactionLog.TL_Date <= "',toDate,'"');
	
	IF (Length(PhaseIDs)>0) Then
	SET WhereStmt = concat(WhereStmt,' AND TransactionLog.Phase_ID in (',PhaseIDs,')');
	END IF;
	
	IF (Length(UserIDs)>0) Then
	SET WhereStmt = concat(WhereStmt,' AND TransactionLog.User_ID in (',UserIDs,')');
	END IF;

	IF (Length(StatusIDs)>0) Then
		SET WhereStmt = concat(WhereStmt,' AND TransactionLog.JS_ID in (',StatusIDs,')');
	END IF;
	
	IF (Length(StorageIDs)>0) Then
	SET WhereStmt = concat(WhereStmt,' AND Storage.Storage_ID in (',StorageIDs,')');
	END IF;

END IF;


-- initialize where clause (independent of New or Old job)

IF (Length(CollIDs)>0) Then
	SET WhereStmt = concat(WhereStmt,' AND Collection.Coll_ID in (',CollIDs,')');
END IF;

IF (Length(BatcheIDs)>0) Then
	SET WhereStmt = concat(WhereStmt,' AND Batch.Batch_ID in (',BatcheIDs,')');
END IF;

IF (Length(LangIDs)>0) Then
	SET WhereStmt = concat(WhereStmt,' AND Metadata.LanguageView.Lang_ID in (',LangIDs,')');
END IF;

IF (Length(JobTypeIDs)>0) Then
	SET WhereStmt = concat(WhereStmt,' AND JobType.JT_ID in (',JobTypeIDs,')');
END IF;


IF (Length(ExtTypeIDs)>0) Then
	SET WhereStmt = concat(WhereStmt,' AND Metadata.JobView.ExtIDType_ID in (',ExtTypeIDs,')');
END IF;


IF (jobID>-1) Then
	SET WhereStmt = concat(WhereStmt,' AND Job.Job_ID = (',jobID,')');
END IF;


IF (Length(jobExtID)>0) Then
	SET WhereStmt = concat(WhereStmt,' AND  Metadata.JobView.Job_External_ID = ("',jobExtID,'")');
END IF;

-- execute the query
select @a:=concat(selectStmt,FromStmt,WhereStmt);
Prepare stmt from @a;
execute stmt;
DEALLOCATE PREPARE stmt;
	
	
	

END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Batch_Add`$$
CREATE  PROCEDURE  `DAF02`.`Batch_Add`(
		BatchName_Val 					 nvarchar(100) ,			
		BatchDate_Val 					 DateTime			,
		BatchComment_Val 			   Text					,
		FKCollID_Val 						 Integer      ,
		FKJTID_Val							 Integer)
BEGIN
	START TRANSACTION;
				INSERT INTO Batch (Batch_Name 		,
													 Batch_Date			,
													 Batch_Comment	,
													 Coll_ID			,
													 JT_ID
													 )
									
										values (BatchName_Val,
														BatchDate_Val,
														BatchComment_Val,
														FKCollID_Val,
														FKJTID_Val
														);			
														
				SELECT * FROM Batch WHERE Batch_ID=Last_Insert_ID();										
			COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Batch_Delete`$$
CREATE  PROCEDURE  `DAF02`.`Batch_Delete`(
		PKBatchID_Val		Integer
	)
BEGIN
	START TRANSACTION;
				DELETE FROM Batch	WHERE Batch_ID=PKBatchID_Val;
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Batch_getByID`$$
CREATE  PROCEDURE  `DAF02`.`Batch_getByID`(
		PKBatchID_Val		Integer
	)
BEGIN
	
				SELECT * FROM Batch	WHERE Batch_ID=PKBatchID_Val;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Batch_loadAll`$$
CREATE  PROCEDURE  `DAF02`.`Batch_loadAll`()
BEGIN
			SELECT * FROM Batch
			WHERE Batch.Batch_ID>0
			Order By Batch.Batch_Date desc,Batch.Batch_Name;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Batch_loadSpecial`$$
CREATE  PROCEDURE  `DAF02`.`Batch_loadSpecial`()
BEGIN
	
				SELECT Batch.Batch_ID,
				COnCAT(Collection.Coll_Name,':',Batch.Batch_Name)
				FROM Batch 
				INNER Join Collection
				ON Batch.Coll_ID=Collection.Coll_ID
				WHERE Batch.Batch_ID>0
				ORDER BY Collection.Coll_Name,Batch.Batch_Date desc, Batch.Batch_Name;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Batch_Update`$$
CREATE  PROCEDURE  `DAF02`.`Batch_Update`(
		PKBatchID_Val					   Integer      ,
		BatchName_Val 					 nvarchar(100) ,			
		BatchDate_Val 					 DateTime			,
		BatchComment_Val 			   Text					,
		FKCollID_Val 						 Integer      ,
		FKJTID_Val							 Integer
)
BEGIN
	START TRANSACTION;
				UPDATE Batch  SET Batch_ID  		=	PKBatchID_Val			,
														Batch_Name		= BatchName_Val		  ,
													  Batch_Date 		=	BatchDate_Val		  ,
													  Batch_Comment =	BatchComment_Val  ,
													  Coll_ID  	= FKCollID_Val 			,
													  JT_ID			= FKJTID_Val
												
												WHERE Batch_ID= PKBatchID_Val;
								
				SELECT * FROM Batch WHERE Batch_ID=PKBatchID_Val;										
			COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Collection_Add`$$
CREATE  PROCEDURE  `DAF02`.`Collection_Add`(
		CollName_Val 				    	nvarchar(50)	,			
		CollAbreviation_Val 		  nvarchar(4)	,
		CollDefaultPath_Val 			nvarchar(200),
		CollPriority_Val 					Integer			,
		CollAnyUser_Val						TinyInt(1)	,
		CollAnyWorkstation_Val		TinyInt(1)	,
		CollActive_Val 						TinyInt(1)	,
		CollComment_Val						Text				,
		CollOwnID_Val 					Integer,
		Prj_ID_Val 					Integer,
		Icg_ID_Val 					Integer
		
)
BEGIN
	START TRANSACTION;
				INSERT INTO Collection (Coll_Name						,
																Coll_Abbreviation		,
																Coll_DefaultPath		,
																Coll_Priority				,
																Coll_AnyUser				,
																Coll_AnyWorkstation	,
																Coll_Active					,
																Coll_Comment				,
																Own_ID,
																Prj_ID,
																Icg_ID
																 )
				
												values  (CollName_Val						,
																 CollAbreviation_Val		,
																 CollDefaultPath_Val		,
																 CollPriority_Val				,
																 CollAnyUser_Val				,
																 CollAnyWorkstation_Val	,
																 CollActive_Val					,
																 CollComment_Val				,
																 CollOwnID_Val,
																	Prj_ID_Val,
																	Icg_ID
																 );
																			
							
				SELECT * FROM Collection WHERE Coll_ID=Last_Insert_ID();										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Collection_Delete`$$
CREATE  PROCEDURE  `DAF02`.`Collection_Delete`(
		PKCollID_Val		Integer
	)
BEGIN
	START TRANSACTION;
				DELETE FROM Collection WHERE Coll_ID=PKCollID_Val;
																
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Collection_DeleteCascade`$$
CREATE  PROCEDURE  `DAF02`.`Collection_DeleteCascade`(
		PKColl_Val		Integer
	)
BEGIN
	START TRANSACTION;
				
				DELETE FROM User_Collection WHERE User_Collection.Coll_ID=PKColl_Val;
				DELETE FROM Workstation_Collection WHERE Workstation_Collection.Coll_ID=PKColl_Val;
				DELETE FROM Collection	WHERE Coll_ID= PKColl_Val;
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Collection_getAllBatches`$$
CREATE  PROCEDURE  `DAF02`.`Collection_getAllBatches`(CollectionID_Val Integer)
BEGIN
  Select
		Batch.Batch_ID,
		Batch.Batch_Name,
		Batch.Batch_Date,
		Batch.Batch_Comment,
		Batch.Coll_ID,
		Batch.JT_ID,
		Batch.Batch_TimeStamp
  From Batch
  Where Batch.Coll_ID = CollectionID_Val
  Order By Batch.Batch_Date;
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Collection_getByID`$$
CREATE  PROCEDURE  `DAF02`.`Collection_getByID`(
		PKCollID_Val		Integer
	)
BEGIN
	
				SELECT * FROM Collection WHERE Coll_ID=PKCollID_Val;
																
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Collection_getOwner`$$
CREATE  PROCEDURE  `DAF02`.`Collection_getOwner`(
		CollID_Val		Integer
	)
BEGIN
		/*Gets Collection Owner*/
				SELECT  Metadata.OwnerView.Own_ID				,
								Metadata.OwnerView.Own_Name,
								 Metadata.OwnerView.Own_Abbreviation,
								 Metadata.OwnerView.Own_Comment
								
				FROM Metadata.OwnerView
				INNER JOIN Collection
				ON Metadata.OwnerView.Own_ID=Collection.Own_ID
				WHERE Collection.Coll_ID=CollID_Val		;
								
		
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Collection_getUsers`$$
CREATE  PROCEDURE  `DAF02`.`Collection_getUsers`(
		CollID_Val		Integer
	)
BEGIN
				
				SELECT User.User_ID		,
							 User_Name		,
							 User_Password,
							 User_AnyPhase,
							 User_MaxJobs ,
							 User_IsActive,
							 Role_ID,
							 User_isLDAP
				FROM User
				INNER JOIN User_Collection
				ON User.User_ID= User_Collection.User_ID
				WHERE (User_Collection.Coll_ID=CollID_Val)
				 	AND (User.User_IsActive = 1)
				 	ORDER BY User_Name
					 ;
								
																
		
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Collection_getWorkStations`$$
CREATE  PROCEDURE  `DAF02`.`Collection_getWorkStations`(
		CollID_Val		Integer
	)
BEGIN
	
				
				SELECT Workstation.Wrkst_ID						,
							 Wrkst_Name							,
							 Wrkst_WorkingDirectory	,
							 Wrkst_AnyPhase					,
							 Wrkst_IsActive					,
							 Wrkst_Comment					,
							 OS_ID								,
							 Wrkst_Location 
				FROM Workstation
				INNER JOIN Workstation_Collection
				ON Workstation.Wrkst_ID= Workstation_Collection.Wrkst_ID
				WHERE (Workstation_Collection.Coll_ID=CollID_Val)
				AND (Workstation.Wrkst_IsActive=1)
				;
								
		
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Collection_loadAll`$$
CREATE  PROCEDURE  `DAF02`.`Collection_loadAll`()
BEGIN
				SELECT * FROM Collection
				WHERE Collection.Coll_ID>0;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Collection_Update`$$
CREATE  PROCEDURE  `DAF02`.`Collection_Update`(
		CollID_Val							Integer,
		CollName_Val 				    	nvarchar(50)	,			
		CollAbreviation_Val 		  nvarchar(4)	,
		CollDefaultPath_Val 			nvarchar(200),
		CollPriority_Val 					Integer			,
		CollAnyUser_Val						TinyInt(1)	,
		CollAnyWorkstation_Val		TinyInt(1)	,
		CollActive_Val 						TinyInt(1)	,
		CollComment_Val						Text				,
		CollOwnID_Val 					Integer,
		Prj_ID_Val 					Integer,
		Icg_ID_Val 					Integer
		
)
BEGIN
	START TRANSACTION;
				/*Update Collection Data*/
				UPDATE Collection  SET 	Coll_ID=CollID_Val											,
																Coll_Name	=	CollName_Val										,
																Coll_Abbreviation=CollAbreviation_Val				,
																Coll_DefaultPath=CollDefaultPath_Val				,
																Coll_Priority	=CollPriority_Val							,
																Coll_AnyUser	=CollAnyUser_Val							,
																Coll_AnyWorkstation=CollAnyWorkstation_Val	,
																Coll_Active	=CollActive_Val									,
																Coll_Comment	=CollComment_Val							,
																Own_ID=CollOwnID_Val,
																Prj_ID=Prj_ID_Val,
																Icg_ID=Icg_ID_Val
																
																 
														WHERE Coll_ID=CollID_Val;
								
				SELECT * FROM Collection WHERE Coll_ID=CollID_Val;										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Collection_updateUsers`$$
CREATE  PROCEDURE  `DAF02`.`Collection_updateUsers`(
		collID_Val 					 Integer ,			
		usersVal						 nvarchar(500),
		delimiterVal				 char(1)
	)
BEGIN
	START TRANSACTION;
			DELETE FROM User_Collection	
			WHERE (User_Collection.Coll_ID=collID_Val);
			
			CALL SplitIDs(usersVal,delimiterVal);
			INSERT INTO User_Collection (Coll_ID,User_ID) 
  										( SELECT   collID_Val,IDVal
												FROM SplittedTempTable
											);											
				
		Drop Temporary Table If Exists `SplittedTempTable`;
		
		SELECT * FROM User_Collection 
		WHERE (User_Collection.Coll_ID=collID_Val);
										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Collection_updateWorkstations`$$
CREATE  PROCEDURE  `DAF02`.`Collection_updateWorkstations`(
		collID_Val 					 Integer ,			
		wsVal						 nvarchar(500),
		delimiterVal				 char(1)
	)
BEGIN
	START TRANSACTION;
			DELETE FROM Workstation_Collection	
			WHERE (Workstation_Collection.Coll_ID=collID_Val);
			
			CALL SplitIDs(wsVal,delimiterVal);
			INSERT INTO Workstation_Collection (Coll_ID,Wrkst_ID) 
  										( SELECT   collID_Val,IDVal
												FROM SplittedTempTable
											);											
				
		Drop Temporary Table If Exists `SplittedTempTable`;
		
		SELECT * FROM Workstation_Collection 
		WHERE (Workstation_Collection.Coll_ID=collID_Val);
										
COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`CollectionOwner_loadAll`$$
CREATE  PROCEDURE  `DAF02`.`CollectionOwner_loadAll`()
BEGIN
	
	
		SELECT * FROM Metadata.Owner
		WHERE Metadata.Owner.Own_ID>0;
		
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Device_Add`$$
CREATE  PROCEDURE  `DAF02`.`Device_Add`(
		DeviceName_Val				nvarchar(50),
		DeviceDescription_Val Text
 )
BEGIN
	START TRANSACTION;
				INSERT INTO Device (Device_Name			,
														Device_Description
														) 
										values (DeviceName_Val	,
														DeviceDescription_Val
														);			
				SELECT * FROM Device WHERE Device_ID=Last_Insert_ID();										
			COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Device_Delete`$$
CREATE  PROCEDURE  `DAF02`.`Device_Delete`(
		PKDeviceID_Val		Integer
	)
BEGIN
	START TRANSACTION;
				DELETE FROM Device	WHERE Device_ID=PKDeviceID_Val;
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Device_DeleteCascade`$$
CREATE  PROCEDURE  `DAF02`.`Device_DeleteCascade`(
		PKDeviceID_Val		Integer
	)
BEGIN
	START TRANSACTION;
				
				DELETE FROM Workstation_Device	WHERE Device_ID=PKDeviceID_Val;
				DELETE FROM Device	WHERE Device_ID=PKDeviceID_Val;
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Device_getByID`$$
CREATE  PROCEDURE  `DAF02`.`Device_getByID`(
		PKDeviceID_Val		Integer
	)
BEGIN
	
	SELECT * FROM Device	WHERE Device_ID=PKDeviceID_Val;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Device_loadAll`$$
CREATE  PROCEDURE  `DAF02`.`Device_loadAll`()
BEGIN
	
	SELECT * FROM Device ;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Device_Update`$$
CREATE  PROCEDURE  `DAF02`.`Device_Update`(
		PKDeviceID_Val					   Integer      ,
		DeviceName_Val						 nvarchar(50)	,
		DeviceDescription_Val			 Text  			
	)
BEGIN
	START TRANSACTION;
				UPDATE Device  SET  Device_ID			=	PKDeviceID_Val		    ,
														Device_Name				= DeviceName_Val		 	  ,
														Device_Description= DeviceDescription_Val
												
												WHERE Device_ID	=	PKDeviceID_Val;
								
				SELECT * FROM Device WHERE Device_ID	=	PKDeviceID_Val;										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`ExternalID_Add`$$
CREATE  PROCEDURE  `DAF02`.`ExternalID_Add`(
ExtID_Value_Val Varchar(50),
ExtIDType_ID_Val Integer,
ExtID_isDefault_Val Tinyint(1),
Job_ID_Val Integer
)
BEGIN

call Metadata.ExternalID_Add(ExtID_Value_Val, ExtIDType_ID_Val, ExtID_isDefault_Val, Job_ID_Val);
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`ExternalID_getByID`$$
CREATE  PROCEDURE  `DAF02`.`ExternalID_getByID`(
ID_Val Integer
)
BEGIN
	SELECT *
	FROM Metadata.ExternalIDView
	WHERE Metadata.ExternalIDView.ExtID_ID = ID_Val;
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`ExternalID_getByJob`$$
CREATE  PROCEDURE  `DAF02`.`ExternalID_getByJob`(
JobID_Val Integer
)
BEGIN
	SELECT *
	FROM Metadata.ExternalIDView
	WHERE  Metadata.ExternalIDView.Job_ID = JobID_Val;
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`ExternalID_GetOccurrences`$$
CREATE  PROCEDURE  `DAF02`.`ExternalID_GetOccurrences`(
ExtIDType_ID_Val Integer,
ExtID_Value_Val VARCHAR(50)
)
BEGIN
	SELECT COUNT(*) AS 'Count'
  FROM Metadata.ExternalIDView
  WHERE Metadata.ExternalIDView.ExtIDType_ID = ExtIDType_ID_Val AND Metadata.ExternalIDView.ExtID_Value = ExtID_Value_Val;
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`ExternalID_Type_getByID`$$
CREATE  PROCEDURE  `DAF02`.`ExternalID_Type_getByID`(
		ExtIDTypeID_Val		Integer
	)
BEGIN
	
		SELECT * FROM Metadata.ExternalID_TypeView	WHERE Metadata.ExternalID_TypeView.ExtIDType_ID=ExtIDTypeID_Val;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`ExternalID_Type_loadAll`$$
CREATE  PROCEDURE  `DAF02`.`ExternalID_Type_loadAll`()
BEGIN
	
	SELECT * FROM Metadata.ExternalID_TypeView ;
	
	
END $$





DROP FUNCTION IF EXISTS `DAF02`.`FinishedJobsAlotCnt`$$
CREATE  FUNCTION  `DAF02`.`FinishedJobsAlotCnt`(
							JobTypeID_Val Integer,
							PhaseID_Val Integer
							) RETURNS int(11)
BEGIN
/* This function returns the number of Job visited Phase PhaseID_Val more than once
		and currently Finished in this Phase.
*/
  Declare Cnt Integer default 0;

	select count(JobPhaseVisitedTimes.Job_ID) into Cnt
	from JobPhaseVisitedTimes inner join TransactionLog on JobPhaseVisitedTimes.TL_ID = TransactionLog.TL_ID
														inner join Phase on TransactionLog.Phase_ID = Phase.Phase_ID 
	where JobPhaseVisitedTimes.JT_ID = JobTypeID_Val
		and JobPhaseVisitedTimes.Phase_ID = PhaseID_Val
		and TransactionLog.JS_ID = 2 /*Currently Finished Jobs*/
		and TransactionLog.Phase_ID = PhaseID_Val
		and Phase.JT_ID = JobTypeID_Val;
		
	RETURN (Cnt);
END;

 $$





DROP FUNCTION IF EXISTS `DAF02`.`FinishedJobsCnt`$$
CREATE  FUNCTION  `DAF02`.`FinishedJobsCnt`(
							JobTypeID_Val Integer,
							PhaseID_Val Integer
							) RETURNS int(11)
BEGIN
  Declare Cnt Integer default 0;
	
	select count(Job.Job_ID) into Cnt
	from Job inner join TransactionLog on (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
						inner join Phase on (Phase.Phase_ID = TransactionLog.Phase_ID  and Phase.JT_ID=Job.JT_ID)
	where TransactionLog.JS_ID =	2	/*Finished*/
				and TransactionLog.Phase_ID = PhaseID_Val
				and Phase.JT_ID = JobTypeID_Val;
	RETURN (Cnt);
END;

 $$





DROP FUNCTION IF EXISTS `DAF02`.`getNextPhase`$$
CREATE  FUNCTION  `DAF02`.`getNextPhase`(selectedJob_ID 				integer
																		) RETURNS int(11)
BEGIN

	Declare nPhaseID		Integer default 0;
	
	Declare LastPhaseID  Integer default 0;
	Declare LastStatusID  Integer default 0;
	Declare JobTypeID  Integer default 0;
	Declare CurPhaseSeq  Integer default 0;
	
	
	
	DECLARE CONTINUE HANDLER FOR SQLWARNING RETURN (0);
	select TransactionLog.Phase_ID, 
					TransactionLog.JS_ID,
					Phase.Phase_Sequence,
					Job.JT_ID
					into
					LastPhaseID,
					LastStatusID,
					CurPhaseSeq,
					JobTypeID
					
	from Job 	inner join TransactionLog on (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
						inner join Phase on (TransactionLog.Phase_ID = Phase.Phase_ID AND Phase.JT_ID = Job.JT_ID)
	where Job.Job_ID = selectedJob_ID
	limit 1;
						
	if(LastStatusID is null) Then RETURN(0);  -- record not in TransactionLog
	Else
			If (LastStatusID = 6 or LastStatusID = 4)		Then -- Assigned or Redirected
				
				If (LastPhaseID = 0)	Then			-- Assigned to Auto Phase
							select 	Phase2.Phase_ID into nPhaseID
							from 		TransactionLog 	inner join Job on TransactionLog.Job_ID = Job.Job_ID 
																			inner join Phase on (TransactionLog.Phase_ID = Phase.Phase_ID and Job.JT_ID =Phase.JT_ID)
																			inner join Phase Phase2  on Phase.JT_ID = Phase2.JT_ID					
							where TransactionLog.Job_ID = selectedJob_ID
								and TransactionLog.JS_ID	= 2			-- Finised entries
								and Phase2.Phase_Sequence = (Phase.Phase_Sequence +1) 
							order by TransactionLog.TL_ID desc
							limit 1;
				
				Else			-- Not Auto Phase
							set nPhaseID = LastPhaseID;
				End if;
			ElseIf (LastStatusID = 2 or LastStatusID = 1)	Then	-- Finished or Started
					
					Select 	Phase.Phase_ID into nPhaseID
					From 		Phase
					where Phase.Phase_Sequence = (CurPhaseSeq+1)
						and Phase.JT_ID = JobTypeID;
			Elseif (LastStatusID = 5)	Then	-- Rejected
			
					select TransactionLog.Phase_ID into nPhaseID
					from TransactionLog inner join Job on TransactionLog.Job_ID = Job.Job_ID
					where TransactionLog.JS_ID = 1	-- The last started entry
						and TransactionLog.Job_ID = selectedJob_ID
					order by TransactionLog.TL_ID desc					
					limit 1;
					
			End If;
		RETURN (nPhaseID);		
	End if;
					
END;

 $$





DROP FUNCTION IF EXISTS `DAF02`.`getOTLDate`$$
CREATE  FUNCTION  `DAF02`.`getOTLDate`(JobID_Val 		integer, StatusID integer
													 	) RETURNS datetime
BEGIN
  /*
	This function return the OldTransactionLog date for the argument StatusID
	*/
	Declare checkOutDate DateTime Default '1900-01-01 12:00:00';
	
	SELECT if(count(OTL_ID)>0,OldTransactionLog.OTL_Date,'1900-01-01 00:00:00')
	INTO checkOutDate
	FROM OldTransactionLog
	WHERE OldTransactionLog.JS_ID =StatusID
	and OldTransactionLog.Job_ID=JobID_Val
	ORDER BY OldTransactionLog.OTL_ID desc
	LIMIT 1;
	
	RETURN (checkOutDate);

END;

 $$





DROP FUNCTION IF EXISTS `DAF02`.`GetPermissionTree`$$
CREATE  FUNCTION  `DAF02`.`GetPermissionTree`(PermID_Val int) RETURNS varchar(500) CHARSET latin1
BEGIN
	Declare PermissionTree varchar(500) default '';
	Declare ParentPermissionTree varchar(500) default '';
	Declare ParentID int default null;
	
	Select Perm_Description Into PermissionTree from Permission Where Perm_ID = PermID_Val;	
	Select Perm_ParentID Into ParentID from Permission Where Perm_ID = PermID_Val;
	
	While ParentID is not null Do
		Select Perm_Description Into ParentPermissionTree from Permission Where Perm_ID = ParentID;	
		Select Perm_ParentID Into ParentID from Permission Where Perm_ID = ParentID;
		Set PermissionTree = Concat(Concat(ParentPermissionTree, '$'), PermissionTree);
	End While;
	
	
	RETURN PermissionTree;
END;

 $$





DROP PROCEDURE IF EXISTS `DAF02`.`Incharge_getByID`$$
CREATE  PROCEDURE  `DAF02`.`Incharge_getByID`(
		IcgID_Val		Integer
	)
BEGIN
	
	SELECT  Metadata.InChargeView.Icg_ID,
					Metadata.InChargeView.Icg_Name,
					Metadata.InChargeView.Icg_Abbreviation,
					Metadata.InChargeView.Icg_Description,
					Metadata.InChargeView.Icg_TimeStamp
	FROM  Metadata.InChargeView	WHERE  Metadata.InChargeView.Icg_ID=IcgID_Val;
		
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`InCharge_loadAll`$$
CREATE  PROCEDURE  `DAF02`.`InCharge_loadAll`()
BEGIN
	Select Icg_ID,Icg_Name,Icg_Abbreviation,Icg_Description,Icg_TimeStamp from Metadata.InChargeView;
	
END $$





DROP FUNCTION IF EXISTS `DAF02`.`isFirst`$$
CREATE  FUNCTION  `DAF02`.`isFirst`(JobID_Val		integer,
																PhaseID_Val integer,	
																UserID_Val integer,
																fromDate 		DateTime,
																toDate			DateTime,
																isOld 			TinyInt(1)
													) RETURNS int(11)
BEGIN
/*This function checks if the first done of argument phase between fromDate and toDate
*	if yes then return 1 else return 0
*/
		
	Declare elementCount integer default 0;
			
			IF (isOld=0) THEN
		 				SELECT if((min(TransactionLog.TL_Date)>=fromDate AND min(TransactionLog.TL_Date)<=toDate),1,0) 
						Into elementCount
						FROM  TransactionLog
						WHERE (TransactionLog.Phase_ID =PhaseID_Val)
						and (TransactionLog.Job_ID=JobID_Val)
					  and (TransactionLog.JS_ID =2)
						and (TransactionLog.User_ID=UserID_Val)
						group by  TransactionLog.Phase_ID,TransactionLog.User_ID,TransactionLog.Job_ID;
			ELSE
				 		SELECT if((min(OldTransactionLog.OTL_Date)>=fromDate AND min(OldTransactionLog.OTL_Date)<=toDate),1,0) 
						Into elementCount
						FROM  OldTransactionLog
						WHERE (OldTransactionLog.Phase_ID =PhaseID_Val)
						and (OldTransactionLog.Job_ID=JobID_Val)
					  and (OldTransactionLog.JS_ID =2)
						and (OldTransactionLog.User_ID=UserID_Val)
						group by  OldTransactionLog.Phase_ID,OldTransactionLog.User_ID,OldTransactionLog.Job_ID;
			END IF;
												 				
	RETURN elementCount;
END;

 $$





DROP FUNCTION IF EXISTS `DAF02`.`isReCount`$$
CREATE  FUNCTION  `DAF02`.`isReCount`(PhaseID_Val integer,
													JobID_Val		integer,
													JobStatus_Val integer
													) RETURNS int(11)
BEGIN
  Declare elementCount integer default 0;
	
	
					 SELECT  count(TransactionLog.TL_ID)
						INTO  elementCount
						FROM  TransactionLog
						WHERE (TransactionLog.Phase_ID =PhaseID_Val)
						and (TransactionLog.Job_ID=JobID_Val)
						and (TransactionLog.JS_ID=JobStatus_Val);
												 
				
	RETURN elementCount;
END;

 $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_Add`$$
CREATE  PROCEDURE  `DAF02`.`Job_Add`( 
	JobTitle_Val 					 nvarchar(500) ,
	JobCreator_Val 				 nvarchar(100) ,
	JobDate_Val 					 DateTime			,
	JobInfo1_Val 					 nvarchar(500) ,
	JobInfo2_Val 					 nvarchar(500) ,
	JobInfo3_Val 					 nvarchar(500) ,
	JobPath_Val 					 nvarchar(200) ,
	JobPriority_Val				 Integer			,
	JobDueDate_Val 				 DateTime			,
	JobIdentifyingLob_Val  Blob					,
	BatchID_Val 				 Integer			,
	JTID_Val             Integer			,
	LangID_Val				   Integer			,
	JCID_Val 						 Integer			,
	TLID_Val						 Integer,
	StorageID_Val						 Integer
)
BEGIN
			Declare insertedJobID integer default -1;
			Declare OwnerID integer default -1;
			Declare PrjID integer default -1;
			Declare InChargeJobID integer default -1;
			START TRANSACTION;
			/*Get CollectionOwner, ProjectID and InChargeID from Collection table usinf Batch_ID*/
			SELECT Collection.Own_ID,Collection.Prj_ID,Collection.Icg_ID
				Into OwnerID,PrjID,InChargeJobID
			From Collection
			inner join Batch On Batch.Coll_ID=Collection.Coll_ID
			where Batch.Batch_ID=BatchID_Val;
			
			/*Add new Job into DAF02 DB*/
				INSERT INTO Job  (Job_Date					,
													Job_Path					,
													Job_Priority			,
													Job_DueDate				,
													Batch_ID				,
													JT_ID					,
													JC_ID					,
													TL_ID,
													Storage_ID
													)
									values (JobDate_Val 			 			,
													JobPath_Val 			 			,
													JobPriority_Val				  ,
													JobDueDate_Val 				  ,
													BatchID_Val 					,
													JTID_Val             	,
													JCID_Val 							,
													TLID_Val,
													StorageID_Val						 
													);
			/*Get inserted Job ID*/
			 set insertedJobID=Last_Insert_ID();										
			/*call Object_Add to insert metadata into Metadata DB*/
			call Metadata.Object_Add(	JobTitle_Val,
															JobCreator_Val,
															JobInfo1_Val,
															JobInfo2_Val,
															JobInfo3_Val,
															JobIdentifyingLob_Val,
															OwnerID,
															PrjID,
															InChargeJobID,
															LangID_Val,
															insertedJobID
															);
			/*Select inserted Data*/
			Select 	Job.Job_ID,
							Metadata.JobView.Job_External_ID,
							Metadata.JobView.ExtIDType_ID,
							Metadata.JobView.Job_Title,
							Metadata.JobView.Job_Creator,
							Job_Date,
							Metadata.JobView.Job_Info1,
							Metadata.JobView.Job_Info2,
							Metadata.JobView.Job_Info3,
							Job_Path,
							Job_Priority,
							Job_DueDate,
							Metadata.JobView.Job_IdentifyingLob,
							Batch_ID,
							JT_ID,
							Metadata.JobView.Lang_ID,
							JC_ID,
							TL_ID,
							Storage_ID,
							Job_TimeStamp
			From Job
			inner join Metadata.JobView on Metadata.JobView.Job_ID=Job.Job_ID
			where Job.Job_ID=insertedJobID;
			
			
		COMMIT;
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_archivedANDActive`$$
CREATE  PROCEDURE  `DAF02`.`Job_archivedANDActive`()
BEGIN
DECLARE GUIcheckBox TinyINT(1) DEFAULT 0; 

/*Get all Archived Jobs and ready to be checked out the workflow*/
	 SELECT distinct TransactionLog.Job_ID,
									 GUIcheckBox,
									 Metadata.JobView.Job_Title,
								   Metadata.JobView.Job_External_ID,
									 Job.Job_Path,
									ActiveJob(TransactionLog.Job_ID) as active
		FROM Job_Media
		INNER JOIN TransactionLog
		ON Job_Media.TL_ID=TransactionLog.TL_ID
		INNER JOIN Job
		ON TransactionLog.Job_ID=Job.Job_ID
		inner join Metadata.JobView 
		on Metadata.JobView.Job_ID=Job.Job_ID
	-- 	 where ActiveJob(TransactionLog.Job_ID)=0
		ORDER BY Job_Path
		;


	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_Assign`$$
CREATE  PROCEDURE  `DAF02`.`Job_Assign`(
		FKJobID_Val 				Integer		,			
		FKPhaseID_Val 		  Integer		,
		FKUserID_Val 			  Integer	  ,
		FKWrkstID_Val 			Integer		,
		TLNoOfFiles_Val			Integer 	,
		TLStatusData_Val		Text	,
		TLDate_Val				DateTime
		
)
BEGIN
	Declare toSelect			Integer Default -1;
	Declare validUserPhase	Integer Default 0;
		
	 	/*evaluate auto phase if exist*/
			IF (FKPhaseID_Val=0) THEN
				CALL Phase_getAutoPhaseValue(FKJobID_Val,@AutoPhase,@AutoPhaseSeq);
				IF (@AutoPhase<>0) THEN
					SET FKPhaseID_Val=@AutoPhase;
				END IF;
			END IF;
			
		
			/*Phase ID must not equal 0 to insert in TL*/
			IF (FKPhaseID_Val<>0) THEN
							/*check if user can be assigned to this phase*/
							SELECT IF(COUNT(User.User_ID)>0,1,0)
							INTO validUserPhase
							FROM User
							INNER JOIN User_Phase
							ON (User.User_ID =User_Phase.User_ID or User.User_AnyPhase = 1)
							WHERE (User_Phase.Phase_ID=FKPhaseID_Val)
								AND (User.User_ID=FKUserID_Val)
								AND (User.User_IsActive=1);
								
								IF(validUserPhase=1) THEN													
									
									CALL TransLog_AddWithoutCommit(FKJobID_Val	,
																										FKPhaseID_Val	,
																										FKUserID_Val		,
																										FKWrkstID_Val	,
																										6							,
																										TLDate_Val					,
																										TLNoOfFiles_Val,
																										TLStatusData_Val				
																										);
													SET toSelect = Last_Insert_ID();														
										/* Update the last job status to refer to this inserted record as last record*/
													UPDATE Job 
													SET Job.TL_ID=toSelect
													WHERE Job.Job_ID=FKJobID_Val;
							  END IF;
								
					END IF;
						
			
			
			SELECT * FROM TransactionLog WHERE TransactionLog.TL_ID=toSelect;		
			
			
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_AssignFromScratch`$$
CREATE  PROCEDURE  `DAF02`.`Job_AssignFromScratch`(
		FKJobID_Val 				Integer		,			
		FKPhaseID_Val 		  Integer		,
		FKUserID_Val 			  Integer	  ,
		FKWrkstID_Val 			Integer		,
		TLNoOfFiles_Val			Integer 	,
		TLStatusData_Val		Text			,
		TLDate_Val				DateTime
)
BEGIN
	Declare toSelect			Integer Default -1;
	Declare lastJobStatus	Integer Default 0;
	Declare validUserPhase	Integer Default 0;
	
	
	/*Get last state*/
	SELECT TransactionLog.JS_ID
			INTO lastJobStatus
			FROM TransactionLog
			INNER JOIN Job
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			WHERE (Job.Job_ID=FKJobID_Val)
			FOR UPDATE;
		
			select 1 into validUserPhase
			from User
			where User.User_ID=FKUserID_Val and User.User_AnyPhase = 1;
			/*check if user can be assigned to this phase*/
			if (validUserPhase=0)THEN
			SELECT IF(COUNT(User.User_ID)>0,1,0)
			INTO validUserPhase
			FROM User
			INNER JOIN User_Phase
			ON (User.User_ID =User_Phase.User_ID or User.User_AnyPhase = 1)
			WHERE (User_Phase.Phase_ID=FKPhaseID_Val)
				AND (User.User_ID=FKUserID_Val)
				AND (User.User_IsActive=1);
			END IF;
				
			IF (validUserPhase=1) THEN
				
					CALL TransLog_AddWithoutCommit(FKJobID_Val	,
																		 		 FKPhaseID_Val	,
																		 		 FKUserID_Val		,
																		     FKWrkstID_Val	,
																		 		 6							,
																		 		 TLDate_Val					,
																		  	 TLNoOfFiles_Val,
																		 		 TLStatusData_Val				
																				 );
							SET toSelect = Last_Insert_ID();														
							/* Update the last job status to refer to this inserted record as last record*/
							UPDATE Job 
							SET Job.TL_ID=toSelect
							WHERE Job.Job_ID=FKJobID_Val;
				END IF;
						
					
			SELECT * FROM TransactionLog WHERE TransactionLog.TL_ID=toSelect;		
			
								
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_AssignRestricted`$$
CREATE  PROCEDURE  `DAF02`.`Job_AssignRestricted`(
		FKJobID_Val 				Integer		,			
		FKPhaseID_Val 		  Integer		,
		FKUserID_Val 			  Integer	  ,
		FKWrkstID_Val 			Integer		,
		TLNoOfFiles_Val			Integer 	,
		TLStatusData_Val		Text		,
		TLDate_Val				DateTime
		
)
BEGIN
	Declare toSelect			Integer Default -1;
	Declare lastJobUser 	Integer Default 0;
	Declare lastJobStatus 	Integer Default 0;
	Declare validUserPhase	Integer Default 0;
		
		START TRANSACTION;	 
		/*Get last state*/
			SELECT TransactionLog.User_ID,TransactionLog.JS_ID
			INTO lastJobUser,lastJobStatus
			FROM TransactionLog
			INNER JOIN Job
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			WHERE (Job.Job_ID=FKJobID_Val)
			FOR UPDATE;
			
			/*evaluate auto phase if exist*/
			IF (FKPhaseID_Val=0) THEN
				CALL Phase_getAutoPhaseValue(FKJobID_Val,@AutoPhase,@AutoPhaseSeq);
				IF (@AutoPhase<>0) THEN
					SET FKPhaseID_Val=@AutoPhase;
				
				END IF;
			END IF;
			
			
			/*check if user can be assigned to this phase*/
			SELECT IF(COUNT(User.User_ID)>0,1,0)
			INTO validUserPhase
			FROM User
			INNER JOIN User_Phase
			ON (User.User_ID =User_Phase.User_ID or User.User_AnyPhase = 1)
			WHERE (User_Phase.Phase_ID=FKPhaseID_Val)
				AND (User.User_ID=FKUserID_Val)
				AND (User.User_IsActive=1);
			
			/*
			* job can be assigned to any phase and to any user, the only restriction is
			* job can't be assigned to user x if it's assigned to user y
			* If last user did the job is auto, ignore it
			*/
			
			/*Phase ID must not equal 0 to insert in TL*/
			if (lastJobStatus=6 AND validUserPhase=1)THEN
			
					IF ((lastJobUser=0 OR lastJobUser=FKUserID_Val ) AND (FKPhaseID_Val<>0))THEN
					
							CALL TransLog_AddWithoutCommit(FKJobID_Val	,
																										FKPhaseID_Val	,
																										FKUserID_Val		,
																										FKWrkstID_Val	,
																										6							,
																										TLDate_Val					,
																										TLNoOfFiles_Val,
																										TLStatusData_Val				
																										);
												SET toSelect = Last_Insert_ID();														
										/* Update the last job status to refer to this inserted record as last record*/
													UPDATE Job 
													SET Job.TL_ID=toSelect
													WHERE Job.Job_ID=FKJobID_Val;
												
					
					END IF;
					
				ELSEIF (lastJobStatus in (2,4,5) and FKPhaseID_Val<>0 AND validUserPhase=1) THEN
				
				CALL TransLog_AddWithoutCommit(FKJobID_Val	,
																										FKPhaseID_Val	,
																										FKUserID_Val		,
																										FKWrkstID_Val	,
																										6							,
																										TLDate_Val					,
																										TLNoOfFiles_Val,
																										TLStatusData_Val				
																										);
												SET toSelect = Last_Insert_ID();														
										/* Update the last job status to refer to this inserted record as last record*/
													UPDATE Job 
													SET Job.TL_ID=toSelect
													WHERE Job.Job_ID=FKJobID_Val;
					
			END IF;
			
			SELECT * FROM TransactionLog WHERE TransactionLog.TL_ID=toSelect;		
			
			COMMIT;
						
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_canChangeType`$$
CREATE  PROCEDURE  `DAF02`.`Job_canChangeType`(jobID_Val integer, oldOrNew Integer)
BEGIN
 Declare jobsCount integer default 0;
START TRANSACTION;

	IF (oldOrNew=1) THEN
		/*job in TL*/
			SELECT count(*)
			INTO jobsCount
			FROM Job
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			WHERE (Job.Job_ID=jobID_Val)
				AND(TransactionLog.JS_ID=2)/*finished state*/
			;
	
	ELSEIF (oldOrNew=0) THEN
	  /*job in OTL*/
		/*jobs in OTL must finish baackup phase before checking out*/
		set jobsCount=1;
	END IF;
	
	/*1 means the job in finish state and can change its type, otherwise select 0*/
	IF(jobsCount>0) THEN
		SELECT 1;
	ELSE 
		SELECT 0;
	END IF;
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_canCheckOut`$$
CREATE  PROCEDURE  `DAF02`.`Job_canCheckOut`(JobID_Val		Integer	)
BEGIN
	Declare canCheckOut Integer default 0;
	START TRANSACTION;
	/*check if the job in finish state for backup phase*/		
	SELECT count(Job.Job_ID)
	INTO  canCheckOut
	FROM Job
	INNER JOIN TransactionLog
	ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
	WHERE (Job.Job_ID=JobID_Val)
	AND (TransactionLog.JS_ID=2)
	AND (TransactionLog.Phase_ID=1 or TransactionLog.Phase_ID=2)
	FOR UPDATE;
	
	IF (canCheckOut>0) THEN
		SELECT 1;
	ELSE
		SELECT 0;
	END IF;
	
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_canDownload`$$
CREATE  PROCEDURE  `DAF02`.`Job_canDownload`(JobID_Val		Integer, Wrkst_Val Integer,UserID_Val Integer)
BEGIN
	DECLARE valid  Integer	Default 0;
		/*If user has download permission then he can download unconditionally*/
		SELECT if(count(Permission.Perm_ID)>0,1,0)
		INTO valid	
		FROM Permission
		INNER JOIN Role_Permission
		ON Permission.Perm_ID= Role_Permission.Perm_ID
		INNER JOIN User	
		ON (User.Role_ID = Role_Permission.Role_ID and User.User_IsActive=1) 			
		WHERE (User.User_ID=UserID_Val)
					and (Permission.Perm_ID = 9); -- download permission
	
	/*cehck if the state of job in (finished,redirected, rejected,assigned or uploaded), which 
	* guarantee that the job is on the server 
	*/
		IF (valid=0) THEN
			select if(TransactionLog.JS_ID in (2,4,5,6,8)
				OR ((TransactionLog.JS_ID=1 OR TransactionLog.JS_ID=9)  AND TransactionLog.Wrkst_ID=Wrkst_Val ) ,1,0)
				into valid
			from TransactionLog inner join Job on TransactionLog.Job_ID = Job.Job_ID			
			where TransactionLog.Job_ID  = JobID_Val
			order by TransactionLog.TL_ID desc 
			limit 1;
		END IF;
		
		select valid;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_canFinishReject`$$
CREATE  PROCEDURE  `DAF02`.`Job_canFinishReject`(JobID_Val	Integer, WSID_Val Integer)
BEGIN
/*
	This procedure returns 0 if the job can not Finish ot Rejeted from the current workstation
*/
			select if(TransactionLog.JS_ID in (1,9)
				and TransactionLog.Wrkst_ID = WSID_Val ,1,0)-- if(count(TransactionLog.TL_ID)>0,1,0)
			from TransactionLog inner join Job on TransactionLog.Job_ID = Job.Job_ID			
			where TransactionLog.Job_ID  = JobID_Val
			order by TransactionLog.TL_ID desc 
			limit 1;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_canStart`$$
CREATE  PROCEDURE  `DAF02`.`Job_canStart`(
		JobID_Val					Integer		,
		UserID_Val 			  Integer	  ,
		WrkstID_Val 			Integer		,
		PhaseID_Val				Integer   	
		)
BEGIN
	Declare canStart 	 	 Integer Default 0;
	DECLARE Valid  			TinyInt(1);
	START TRANSACTION;
	
		CALL Validate_UserWSPhase(JobID_Val,UserID_Val,WrkstID_Val,PhaseID_Val,canStart);	
		CALL User_ValidateLimit(UserID_Val,Valid);
		SELECT canStart AND Valid  ;
		
	
	COMMIT;									
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_canUpload`$$
CREATE  PROCEDURE  `DAF02`.`Job_canUpload`(JobID_Val			Integer)
BEGIN
	/*
	This procedure returns 0 if the job can not be Uploaded
*/

			
			select if(TransactionLog.JS_ID in (1,9),1,0)
			from TransactionLog inner join Job on TransactionLog.Job_ID = Job.Job_ID
			where TransactionLog.Job_ID  = JobID_Val
			order by TransactionLog.TL_ID desc 
			limit 1;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_checkIn`$$
CREATE  PROCEDURE  `DAF02`.`Job_checkIn`(
	JobID_Val				Integer	
	)
BEGIN
		START TRANSACTION;
	
		INSERT INTO TransactionLog( TransactionLog.TL_ID			,
																TransactionLog.Job_ID			,
																TransactionLog.Phase_ID		,
																TransactionLog.User_ID		,
																TransactionLog.Wrkst_ID		,
																TransactionLog.JS_ID			,
																TransactionLog.TL_Date		,
																TransactionLog.TL_NoOfFiles	,
																TransactionLog.TL_Status_Data
																)
									 (	SELECT  OldTransactionLog.OTL_ID			,
															OldTransactionLog.Job_ID		,
															OldTransactionLog.Phase_ID	,
															OldTransactionLog.User_ID		,
															OldTransactionLog.Wrkst_ID	,
															OldTransactionLog.JS_ID			,
															OldTransactionLog.OTL_Date 	,
															OldTransactionLog.OTL_NoOfFiles	,
															OldTransactionLog.OTL_Status_Data
															FROM OldTransactionLog
															WHERE (OldTransactionLog.Job_ID=JobID_Val)
											);
		
		
		
		/*get the last stable state of this job to update Job.TL_ID*/
		Update Job Set Job.TL_ID =(
																SELECT TransactionLog.TL_ID 
																FROM TransactionLog
																WHERE TransactionLog.JS_ID in (1,2,4,5,6)
																and (TransactionLog.Job_ID=JobID_Val)
																ORDER BY TransactionLog.TL_ID desc
																LIMIT 1
															)
		Where Job.Job_ID= JobID_Val;
	
	/*Remove Job data from old TransactionLog*/
		DELETE FROM OldTransactionLog WHERE (OldTransactionLog.Job_ID=JobID_Val);
		
			
		SELECT * FROM TransactionLog WHERE (TransactionLog.Job_ID=JobID_Val);
			
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_checkNonConfirmedMedia`$$
CREATE  PROCEDURE  `DAF02`.`Job_checkNonConfirmedMedia`(jobID integer)
BEGIN
	
	/*Media_DelConfirm =1 means media confirmed otherwise Media_DelConfirm=0*/
	SELECT distinct Job_Media.Media_ID,
				 Media.Media_BarCode
	FROM Job_Media
	INNER JOIN Media
	ON Job_Media.Media_ID=Media.Media_ID
	INNER JOIN TransactionLog 
	ON TransactionLog.TL_ID=Job_Media.TL_ID
	WHERE (TransactionLog.Job_ID=jobID) 
		 AND(Media.Media_DelConfirm=0)
	;
	

	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_checkOut`$$
CREATE  PROCEDURE  `DAF02`.`Job_checkOut`(
	JobID_Val				Integer,
	userID_Val			Integer,
	WSID_Val				Integer,
	comment					Text,
	TLDate_Val				DateTime
	)
BEGIN

START TRANSACTION;
	
	/*insert record in TL tells that the job is checked out*/
	call TransLog_AddWithoutCommit(JobID_Val,
																 0,
																userID_Val,
																WSID_Val,
																7,-- checked out status=7
																TLDate_Val,
																0,
																comment
																);
	
	
	/*Update Job.TL_ID to refere to -1*/
	Update Job Set Job.TL_ID=0 
	WHERE Job.Job_ID=JobID_Val;
	
	/*Move records from TL to OTL*/
		INSERT INTO OldTransactionLog( OldTransactionLog.OTL_ID			,
																		OldTransactionLog.Job_ID		,
																		OldTransactionLog.Phase_ID	,
																		OldTransactionLog.User_ID		,
																		OldTransactionLog.Wrkst_ID	,
																		OldTransactionLog.JS_ID			,
																		OldTransactionLog.OTL_Date 	,
																		OldTransactionLog.OTL_NoOfFiles	,
																		OldTransactionLog.OTL_Status_Data
																)
									 (	SELECT  TransactionLog.TL_ID			,
											TransactionLog.Job_ID			,
											TransactionLog.Phase_ID		,
											TransactionLog.User_ID		,
											TransactionLog.Wrkst_ID		,
											TransactionLog.JS_ID			,
											TransactionLog.TL_Date		,
											TransactionLog.TL_NoOfFiles	,
											TransactionLog.TL_Status_Data
											FROM TransactionLog
											WHERE (TransactionLog.Job_ID=JobID_Val)
										
											
		);
		
		/*Remove Job data from TransactionLog*/
		
		DELETE FROM TransactionLog WHERE (TransactionLog.Job_ID=JobID_Val);
		
		SELECT * FROM OldTransactionLog WHERE (OldTransactionLog.Job_ID=JobID_Val);
			
							
			
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_checkOutRollback`$$
CREATE  PROCEDURE  `DAF02`.`Job_checkOutRollback`(JobID_Val		Integer	)
BEGIN
Declare JSID integer default 0;
Declare TLID integer default -1;
	START TRANSACTION;
	
		/*get the last inserted record*/
		SELECT TransactionLog.TL_ID,TransactionLog.JS_ID
		INTO TLID,JSID
		FROM TransactionLog
		WHERE TransactionLog.Job_ID=JobID_Val
		ORDER BY TransactionLog.TL_ID desc
		LIMIT 1
		FOR UPDATE;
		/*check if last record is check out record*/
		IF (JSID=7) THEN
			DELETE FROM TransactionLog
			WHERE TransactionLog.TL_ID=TLID;
		END IF;
		
		SELECT * FROM TransactionLog WHERE (TransactionLog.Job_ID=JobID_Val);
					
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_Delete`$$
CREATE  PROCEDURE  `DAF02`.`Job_Delete`(
		PKJobID_Val		Integer
	)
BEGIN
	START TRANSACTION;
				DELETE FROM Job	WHERE Job_ID=PKJobID_Val;
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_DeleteCascade`$$
CREATE  PROCEDURE  `DAF02`.`Job_DeleteCascade`(JobID_Val		Integer	)
BEGIN
	START TRANSACTION;
		/*Delete from DAF02 DB*/
		Update Job set Job.TL_ID=0 WHERE  Job.Job_ID=JobID_Val;
		DELETE FROM Job_Media WHERE Job_Media.TL_ID in (Select TransactionLog.TL_ID FROM TransactionLog WHERE TransactionLog.Job_ID=JobID_Val );
		DELETE FROM TransactionLog WHERE TransactionLog.Job_ID=JobID_Val;
		DELETE FROM OldTransactionLog WHERE OldTransactionLog.Job_ID=JobID_Val;
		DELETE FROM Job	WHERE Job_ID=JobID_Val;
		/*Delete from Metadata DB*/
		call Metadata.Object_DeleteCascade(JobID_Val);
	COMMIT;
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_Download`$$
CREATE  PROCEDURE  `DAF02`.`Job_Download`(
		JobID_Val 				Integer		,			
		PhaseID_Val 		  Integer		,
		UserID_Val 			  Integer	  ,
		WrkstID_Val 			Integer		,
		TLNoOfFiles_Val			Integer 	,
		TLStatusData_Val		Text		,
		TLDate_Val				DateTime
	)
BEGIN
		DECLARE TLID Integer Default -1;
		START TRANSACTION;
			
			CALL TransLog_AddWithoutCommit(JobID_Val		,
																		 PhaseID_Val	,
																	   UserID_Val		,
																		 WrkstID_Val	,
																		 9							,
																		 TLDate_Val					,
																		 TLNoOfFiles_Val,
																		 TLStatusData_Val
																		);
		
			SET TLID=Last_Insert_ID();		
			SELECT * FROM TransactionLog
			WHERE
			TransactionLog.TL_ID=TLID;
		
		COMMIT;

END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_ExternalIDExists`$$
CREATE  PROCEDURE  `DAF02`.`Job_ExternalIDExists`( 
	JobExternalID_Val      nvarchar(50)	,
	ExtIDTypeName_Val			 varchar(50)
)
BEGIN
	SELECT 
							Job.Job_ID,
							Metadata.JobView.Job_External_ID,
							Metadata.JobView.ExtIDType_ID,
							Metadata.JobView.Job_Title,
							Metadata.JobView.Job_Creator,
							Job_Date,
							Metadata.JobView.Job_Info1,
							Metadata.JobView.Job_Info2,
							Metadata.JobView.Job_Info3,
							Job_Path,
							Job_Priority,
							Job_DueDate,
							Metadata.JobView.Job_IdentifyingLob,
							Batch_ID,
							JT_ID,
							Metadata.JobView.Lang_ID,
							JC_ID,
							TL_ID,
							Storage_ID,
							Job_TimeStamp	,
							ExternalID_TypeView.ExtIDType_ID,
							ExternalID_TypeView.ExtIDType_Name,
							ExternalID_TypeView.ExtIDType_TimeStamp
  FROM Metadata.JobView 
	INNER JOIN Metadata.ExternalID_TypeView 
	ON ( Metadata.JobView.ExtIDType_ID = Metadata.ExternalID_TypeView.ExtIDType_ID)
	INNER JOIN Job 
	ON Job.Job_ID=Metadata.JobView.Job_ID
 	WHERE (Metadata.JobView.Job_External_ID = JobExternalID_Val)
   AND (Metadata.ExternalID_TypeView.ExtIDType_Name = ExtIDTypeName_Val);
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_Finish`$$
CREATE  PROCEDURE  `DAF02`.`Job_Finish`(
	JobID_Val				Integer	,
	UserID_Val			Integer	,
	WrkStID_Val			Integer	,
	TLNoOfFiles_Val		Integer	,
	TLStatusData_Val	Text,
	TLDate_Val				DateTime
	)
BEGIN
  	DECLARE TLID_Val			    Integer	Default -1;
		DECLARE TLrecord 					Integer Default -1;
		Declare PhaseID_Val Integer;
		Declare nUser Integer Default -1;
		Declare nPhase Integer Default -1;
		
	DECLARE CONTINUE HANDLER FOR SQLWARNING 
	BEGIN 
			set TLID_Val = -1;
		END;
	START TRANSACTION;

	-- Getting the Current status of the Job if it is STARTED
	SELECT Job.TL_ID,TransactionLog.Phase_ID	INTO TLID_Val, PhaseID_Val
	FROM Job	INNER JOIN TransactionLog	ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
	WHERE  (TransactionLog.JS_ID=1)		-- IFF Started
		 AND (Job.Job_ID=JobID_Val)
	FOR UPDATE;

	IF (TLID_Val>0) Then/*last job state is started*/
			/* insert finish record in the TL*/
			INSERT INTO TransactionLog (Job_ID,    Phase_ID,    User_ID,    Wrkst_ID,   JS_ID, TL_Date,    TL_NoOfFiles,    TL_Status_Data)
   												values (JobID_Val, PhaseID_Val, UserID_Val, WrkStID_Val, 2,    TLDate_Val, TLNoOfFiles_Val, TLStatusData_Val);
	
			SET TLrecord = Last_Insert_ID();
			
			/*Get next phase and check if this phase was done before or not
			* if yes then assign the next phase to the user who done it
			*/														
			-- getting the next user if the job started the next Phase or pre-assigned to it

		select getNextPhase(JobID_Val) into nPhase;

			select TransactionLog.User_ID  into nUser
			from TransactionLog inner join Job on (TransactionLog.Job_ID = Job.Job_ID and Job.Job_ID = JobID_Val)
			where TransactionLog.JS_ID in (3,1)		--  PreAssign or start
				and TransactionLog.Phase_ID =  nPhase
			order by TransactionLog.TL_ID desc      -- If a Pre-Assign entry followed by start for the same Phase then start entry is the one required
			limit 1;

			if( nUser >-1) Then  -- Inserting an Assign record in the TransactionLog for the nUser
				
			-- check if nUser is inactive, if yes then assign to auto user
					Select if(User.User_IsActive=1,nUser,0) into nUser from User
					where User.User_ID=nUser;
					
					INSERT INTO TransactionLog (Job_ID, Phase_ID, User_ID,Wrkst_ID,    JS_ID, TL_Date,                        TL_NoOfFiles, TL_Status_Data)
															values (JobID_Val, nPhase,   nUser,WrkStID_Val, 6,      ADDTIME(TLDate_Val,'00:00:01'),0,            TLStatusData_Val );
					SET TLrecord = Last_Insert_ID();
			End If;
			-- Updating the Job last state
			UPDATE Job 
			SET Job.TL_ID=TLrecord
			WHERE Job.Job_ID=JobID_Val;
	End if;
	
	select *
	from TransactionLog
	where TransactionLog.TL_ID = TLrecord;

	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_getAllPhases`$$
CREATE  PROCEDURE  `DAF02`.`Job_getAllPhases`(
FKJobID_Val			Integer
)
BEGIN
/*Get all valid including sequence phases of to this job*/
 		
	SELECT  Phase.Phase_ID,
					Phase.Phase_Sequence,
					Phase.Phase_MaxPeriod,
					Phase.Phase_Description,
					Phase.Phase_XMLDescription,
					Phase.JT_ID,
					Phase_Name
	FROM Phase
	INNER JOIN Job
	ON Phase.JT_ID=Job.JT_ID
	WHERE Job.Job_ID=FKJobID_Val
	;

		
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_getAllPhasesWithLastUser`$$
CREATE  PROCEDURE  `DAF02`.`Job_getAllPhasesWithLastUser`(FKJobID_Val			Integer)
BEGIN
/*Get all valid including sequence phases of to this job, with the last User appended*/
	START TRANSACTION;
	if exists (Select * from Job Inner Join TransactionLog On(Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0) Where Job.Job_ID = FKJobID_Val)
	Then
	
		SELECT	Distinct  Phase.Phase_ID,
						Phase.Phase_Sequence,
						Phase.Phase_MaxPeriod,
						Phase.Phase_Description,
						Phase.Phase_XMLDescription,
						Phase.JT_ID,
						Phase_Name, TransactionLog.User_ID
		FROM Phase
		INNER JOIN Job
		ON Phase.JT_ID=Job.JT_ID
		Left Outer Join TransactionLog On Job.Job_ID = TransactionLog.Job_ID
		AND Phase.Phase_ID = TransactionLog.Phase_ID
		WHERE Job.Job_ID=FKJobID_Val 
		And Phase.Phase_Name <> 'Auto'
		AND (TransactionLog.TL_Date in (
			Select  Max(TL.TL_Date) 
			From TransactionLog TL Where 
			TL.Job_ID = FKJobID_Val And TL.Phase_ID = TransactionLog.Phase_ID
		--	And TL.JS_ID in (1,2)
			/*Group By TL.Phase_ID*/)
		Or TL_Date is null)
		Order by Phase.Phase_Sequence
		;
	Else
		SELECT	Distinct  Phase.Phase_ID,
						Phase.Phase_Sequence,
						Phase.Phase_MaxPeriod,
						Phase.Phase_Description,
						Phase.Phase_XMLDescription,
						Phase.JT_ID,
						Phase_Name, OldTransactionLog.User_ID
		FROM Phase
		INNER JOIN Job
		ON Phase.JT_ID=Job.JT_ID
		Left Outer Join OldTransactionLog On Job.Job_ID = OldTransactionLog.Job_ID
		AND Phase.Phase_ID = OldTransactionLog.Phase_ID
		WHERE Job.Job_ID=FKJobID_Val 
		And Phase.Phase_Name <> 'Auto'
		AND (OldTransactionLog.OTL_Date in (
			Select  Max(OTL.OTL_Date) 
			From OldTransactionLog OTL Where 
			OTL.Job_ID = FKJobID_Val And OTL.Phase_ID = OldTransactionLog.Phase_ID
		--	And OTL.JS_ID in (1,2)
			/*Group By OTL.Phase_ID*/)
		Or OTL_Date is null)
		Order by Phase.Phase_Sequence
		;
	End If;
COMMIT;
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_getAllUsers`$$
CREATE  PROCEDURE  `DAF02`.`Job_getAllUsers`(
FKJobID_Val			Integer
)
BEGIN
/*Get all valid users related to this job
 * this result is just listing of valid users in this job
 * without specifying which phase of the job
*/
Declare CollID Integer Default 0;
	
		
	SELECT  Collection.Coll_ID
	INTO CollID
	FROM Collection
	INNER JOIN Batch
	ON Batch.Coll_ID = Collection.Coll_ID
	INNER JOIN Job
	ON Job.Batch_ID = Batch.Batch_ID
	WHERE Job.Job_ID=FKJobID_Val;
	
	CALL Collection_getUsers(CollID);
	
		
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_getArchivingHistory`$$
CREATE  PROCEDURE  `DAF02`.`Job_getArchivingHistory`(jobID_Val Integer)
BEGIN
Declare oldJob Integer default 0;
START TRANSACTION;

 	SELECT count(*) 
	INTO oldJob
 	FROM TransactionLog
 	WHERE TransactionLog.Job_ID=jobID_Val
	;
	
	IF (oldJob>0) THEN
	/*job is existed in TL not OTL*/
			SELECT 	Job_Media.TL_ID,
							MediaType.MT_ID,
							Job_Media.Media_ID,
							MediaType.MT_Name,
							Media.Media_BarCode,
							EXTRACTVALUE(TransactionLog.TL_Status_Data,'/Status/Backup/@Version') as  Version,
							EXTRACTVALUE(TransactionLog.TL_Status_Data,'/Status/Backup/@Size') as  Size,
							TransactionLog.TL_Date					
			FROM Job_Media
			INNER JOIN Media
			ON Job_Media.Media_ID= Media.Media_ID
			INNER JOIN MediaType
			ON Media.MT_ID = MediaType.MT_ID
			INNER JOIN TransactionLog
			ON (Job_Media.TL_ID=  TransactionLog.TL_ID and TransactionLog.Job_ID =jobID_Val)
			ORDER BY TransactionLog.TL_ID	
			;
		
		ELSE
		/*job in OTL*/
			SELECT 	Job_Media.TL_ID,
							MediaType.MT_ID,
							Job_Media.Media_ID,
							MediaType.MT_Name,
							Media.Media_BarCode,
							EXTRACTVALUE(OldTransactionLog.OTL_Status_Data,'/Status/Backup/@Version') as  Version,
							EXTRACTVALUE(OldTransactionLog.OTL_Status_Data,'/Status/Backup/@Size') as  Size,
							OldTransactionLog.OTL_Date					
			FROM Job_Media
			INNER JOIN Media
			ON Job_Media.Media_ID= Media.Media_ID
			INNER JOIN MediaType
			ON Media.MT_ID = MediaType.MT_ID
			INNER JOIN OldTransactionLog
			ON (Job_Media.TL_ID=  OldTransactionLog.OTL_ID and OldTransactionLog.Job_ID =jobID_Val)
			ORDER BY OldTransactionLog.OTL_ID	
			;
				
	END IF;

 COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_getArchivingMatrix`$$
CREATE  PROCEDURE  `DAF02`.`Job_getArchivingMatrix`(jobID_Val Integer )
BEGIN
	
			
			SELECT TransactionLog.Job_ID,
						EXTRACTVALUE(TL_Status_Data,'/Status/Backup/@Version') as VersionName,
						Media.Media_BarCode,
						MediaType.MT_Name,
						MediaType.MT_ID,
						Media.Media_ID,
						Job_Media.TL_ID
			FROM  Job_Media
			INNER JOIN Media
			ON Job_Media.Media_ID=Media.Media_ID
			INNER JOIN MediaType
			ON Media.MT_ID=MediaType.MT_ID
			INNER JOIN TransactionLog
			ON Job_Media.TL_ID=TransactionLog.TL_ID
			inner join Job on Job.Job_ID=TransactionLog.Job_ID and Job.TL_ID>0
	  	inner join JobType_MediaType on JobType_MediaType.JT_ID=Job.JT_ID and JobType_MediaType.MT_ID=Media.MT_ID
			left outer join Job_MaxCheckOut on Job_MaxCheckOut.Job_ID=TransactionLog.Job_ID
				where 	if (Job_MaxCheckOut.Job_ID is not null,TransactionLog.TL_ID>Job_MaxCheckOut.TL_ID,true)
			
			Group BY TransactionLog.Job_ID,TransactionLog.TL_ID,Media.Media_ID
			HAVING Job_ID=jobID_Val
			;
			
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_getAutoIncrementValue`$$
CREATE  PROCEDURE  `DAF02`.`Job_getAutoIncrementValue`()
BEGIN
	Start Transaction;
		Set @SeqValue = -1;
		Select (Seq_Value + 1) into @SeqValue from Sequence Where Seq_ID = 1;
		Select Max(Job_ID) into @MaxJobID from Job;
		/*Select @SeqValue, @MaxJobID;*/
		If (@SeqValue = -1 Or @SeqValue is null Or (@SeqValue - 1) <= @MaxJobID)
		Then
			Set @SeqValue = @MaxJobID + 2;
		End IF;
		Update Sequence Set Seq_Value = @SeqValue Where Seq_ID = 1;
		Select @SeqValue - 1 As Auto_increment;
	Commit;
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_getAutoPhaseEquivalent`$$
CREATE  PROCEDURE  `DAF02`.`Job_getAutoPhaseEquivalent`(
FKJobID_Val					Integer
)
BEGIN
	Declare lastPhase Integer Default 0;
	Declare AutoPhase Integer Default 0;
	Declare AutoPhaseSeq Integer Default 0;
	Declare laststate Integer Default 0;
	Declare JobType   Integer Default 0;
	Declare PhaseSeq  Integer Default 0;
  START TRANSACTION;
		
	/* Get Job preLast status */
		SELECT TransactionLog.Phase_ID,TransactionLog.JS_ID
		INTO lastPhase,laststate
		FROM TransactionLog
		WHERE (TransactionLog.Job_ID=FKJobID_Val)
		AND (TransactionLog.JS_ID in (1,2)) /* finished*/
		ORDER BY TransactionLog.TL_ID Desc
		LIMIT 1
		;
		
		/* Get Job Type */
		SELECT Job.JT_ID 
		INTO JobType
		FROM Job
		WHERE Job.Job_ID=FKJobID_Val
		;
		
		/* Get Phase Seq */
		SELECT Phase.Phase_Sequence
		INTO PhaseSeq
		FROM Phase
		WHERE (Phase.Phase_ID=lastPhase)
			AND (Phase.JT_ID=JobType)
		;
		
		
		
		IF (laststate=2) THEN /* finished*/
			
			CALL Phase_getAutoPhase(PhaseSeq,JobType,AutoPhase);
			select AutoPhase;
					
		ELSE
			select lastPhase;
						
		END IF;
		
		
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_getByID`$$
CREATE  PROCEDURE  `DAF02`.`Job_getByID`(JobID_Val		Integer)
BEGIN
	
				SELECT Job.Job_ID,
							Metadata.JobView.Job_External_ID,
							Metadata.JobView.ExtIDType_ID,
							Metadata.JobView.Job_Title,
							Metadata.JobView.Job_Creator,
							Job_Date,
							Metadata.JobView.Job_Info1,
							Metadata.JobView.Job_Info2,
							Metadata.JobView.Job_Info3,
							Job_Path,
							Job_Priority,
							Job_DueDate,
							convert(Metadata.JobView.Job_IdentifyingLob using utf8),
							Batch_ID,
							JT_ID,
							Metadata.JobView.Lang_ID,
							JC_ID,
							TL_ID,
							Storage_ID,
							Job_TimeStamp
			FROM Job	
			inner join Metadata.JobView on Metadata.JobView.Job_ID=Job.Job_ID
			WHERE Job.Job_ID=JobID_Val
			;
	
		
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_getDefaultExtID`$$
CREATE  PROCEDURE  `DAF02`.`Job_getDefaultExtID`(
		JobID_Val		Integer
	)
BEGIN
		/* Get the default ExtID value and ExtID type */
			SELECT Metadata.ExternalIDView.ExtID_Value,
						 Metadata.ExternalID_TypeView.ExtIDType_Name
			FROM Metadata.ExternalID_TypeView
			INNER JOIN Metadata.ExternalIDView
			ON Metadata.ExternalID_TypeView.ExtIDType_ID=Metadata.ExternalIDView.ExtIDType_ID
			WHERE (Metadata.ExternalIDView.Job_ID=JobID_Val)
			 and (Metadata.ExternalIDView.ExtID_isDefault=1)
			LIMIT 1;
			
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_getHistory`$$
CREATE  PROCEDURE  `DAF02`.`Job_getHistory`(
	FKJobID_Val				Integer	
	)
BEGIN
			
			(SELECT   TransactionLog.TL_ID	As TL_ID,
							  TransactionLog.Job_ID		,
								TransactionLog.Phase_ID	,
								TransactionLog.User_ID		,
								TransactionLog.Wrkst_ID	,
								TransactionLog.JS_ID			,
								Metadata.JobView.Job_Title,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								JobStatus.JS_Name,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data
							
			FROM Job
			INNER JOIN TransactionLog
			ON TransactionLog.Job_ID=Job.Job_ID
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and Phase.JT_ID=Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Metadata.JobView 
			ON Metadata.JobView.Job_ID=Job.Job_ID
			WHERE (TransactionLog.Job_ID=FKJobID_Val)
			
			)
			
			UNION 
			
			(SELECT   OldTransactionLog.OTL_ID	As TL_ID	,
							  OldTransactionLog.Job_ID		,
								OldTransactionLog.Phase_ID	,
								OldTransactionLog.User_ID		,
								OldTransactionLog.Wrkst_ID	,
								OldTransactionLog.JS_ID			,
								Metadata.JobView.Job_Title,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								JobStatus.JS_Name,
								OldTransactionLog.OTL_Date as tlDate	,
								OldTransactionLog.OTL_NoOfFiles	,
								OldTransactionLog.OTL_Status_Data
							
			FROM Job
			INNER JOIN OldTransactionLog
			ON OldTransactionLog.Job_ID=Job.Job_ID
			INNER JOIN Phase
			ON (OldTransactionLog.Phase_ID=Phase.Phase_ID and Phase.JT_ID=Job.JT_ID)
			INNER JOIN User
			ON OldTransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON OldTransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON OldTransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Metadata.JobView 
			ON Metadata.JobView.Job_ID=Job.Job_ID
	
			WHERE (OldTransactionLog.Job_ID=FKJobID_Val)
			)
			
			
			/*ORDER BY tlDate desc;*/
			Order By TL_ID Desc;
			
			

	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_getJobs`$$
CREATE  PROCEDURE  `DAF02`.`Job_getJobs`( UserID_Val Integer,
													WsID_Val Integer
												)
BEGIN
Declare allPhasesUser		Integer Default 0;
		Declare allPhasesWS		Integer Default 0;
		Declare tableExists	Integer Default 0;
		/*Check Pool Existence*/
		select count(*) into tableExists FROM information_schema.tables 
		WHERE table_schema = 'DAF02' AND table_name = 'Job_Pool';
		if(tableExists=0)THEN
		call Job_CreatePool();
		END IF;
		
		select User.User_AnyPhase
		into allPhasesUser
		from User where User_ID=UserID_Val;
		
			
		select Workstation.Wrkst_AnyPhase
		into allPhasesWS
		from Workstation where Workstation.Wrkst_ID=WsID_Val;
		

		
		if(allPhasesUser=0)Then
			/*take phases that user can work on, in consideration*/
			select distinct Job_Pool.Job_ID,
						 Metadata.JobView.Job_Title,
						Phase.Phase_Name,
						User.User_Name,
						Metadata.JobView.Job_External_ID ,
						 Metadata.ExternalID_TypeView.ExtIDType_Name,
						-1,
						if ((Workstation_Collection.Coll_ID is not null or Collection.Coll_AnyWorkstation=1) 
						AND (Workstation_Phase.Phase_ID is not null or allPhasesWS=1)
						,WsID_Val,0) as validWS,
						Job.JT_ID,
						Phase.Phase_ID,
						Job_Pool.JS_ID
					 						
			from Job_Pool 
			inner join User on User.User_ID=Job_Pool.User_ID
			inner join Collection on Collection.Coll_ID=Job_Pool.Coll_ID
			inner join Phase on Phase.Phase_ID=Job_Pool.Phase_ID 
			inner join Job on Job.Job_ID=Job_Pool.Job_ID and Job.TL_ID>0
			inner join Metadata.JobView	on Metadata.JobView.Job_ID=Job_Pool.Job_ID
			left outer join Metadata.ExternalID_TypeView on Metadata.JobView.ExtIDType_ID = Metadata.ExternalID_TypeView.ExtIDType_ID
			left outer join Workstation_Collection on Workstation_Collection.Coll_ID=Job_Pool.Coll_ID and Workstation_Collection.Wrkst_ID=WsID_Val
			left outer join Workstation_Phase on Workstation_Phase.Phase_ID=Job_Pool.Phase_ID and Workstation_Phase.Wrkst_ID=WsID_Val
	
			where Job_Pool.Phase_ID>0 
			and  Job_Pool.User_ID in(0 ,UserID_Val)
			and (Collection.Coll_AnyUser=1 or Job_Pool.Coll_ID in (select Coll_ID from User_Collection where User_ID=UserID_Val))
			and (Job_Pool.Phase_ID in (select Phase_ID from User_Phase where User_ID=UserID_Val))
			Order by if(Job_Pool.JS_ID=6 and Job_Pool.User_ID=UserID_Val, 0,1),Job.Job_Priority Desc,Job.Job_DueDate,Job_Pool.Job_ID ;
			
		ELSE
			/*dont filter on phases, this user can work on all phases*/
		select distinct Job_Pool.Job_ID,
						 Metadata.JobView.Job_Title,
						Phase.Phase_Name,
						User.User_Name,
						Metadata.JobView.Job_External_ID ,
						 Metadata.ExternalID_TypeView.ExtIDType_Name,
						-1,
						if ((Workstation_Collection.Coll_ID is not null or Collection.Coll_AnyWorkstation=1) 
						AND (Workstation_Phase.Phase_ID is not null or allPhasesWS=1)
						,WsID_Val,0) as validWS,
						Job.JT_ID,
						Phase.Phase_ID,
						Job_Pool.JS_ID
			
			from Job_Pool 
			inner join User on User.User_ID=Job_Pool.User_ID
			inner join Collection on Collection.Coll_ID=Job_Pool.Coll_ID
			inner join Phase on Phase.Phase_ID=Job_Pool.Phase_ID 
			inner join Job on Job.Job_ID=Job_Pool.Job_ID and Job.TL_ID>0
			inner join Metadata.JobView	on Metadata.JobView.Job_ID=Job_Pool.Job_ID
			left outer join Metadata.ExternalID_TypeView on Metadata.JobView.ExtIDType_ID = Metadata.ExternalID_TypeView.ExtIDType_ID
			left outer join Workstation_Collection on Workstation_Collection.Coll_ID=Job_Pool.Coll_ID and Workstation_Collection.Wrkst_ID=WsID_Val
			left outer join Workstation_Phase on Workstation_Phase.Phase_ID=Job_Pool.Phase_ID and Workstation_Phase.Wrkst_ID=WsID_Val
	
			where Job_Pool.Phase_ID>0 
			and  Job_Pool.User_ID in(0 ,UserID_Val)
			and (Collection.Coll_AnyUser=1 or Job_Pool.Coll_ID in (select Coll_ID from User_Collection where User_ID=UserID_Val))
			Order by if(Job_Pool.JS_ID=6 and Job_Pool.User_ID=UserID_Val, 0,1),Job.Job_Priority Desc,Job.Job_DueDate,Job_Pool.Job_ID ;
		END IF;	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_getLastData`$$
CREATE  PROCEDURE  `DAF02`.`Job_getLastData`(
	FKJobID_Val				Integer	
	)
BEGIN
		
			SELECT    TransactionLog.TL_ID			,
							  TransactionLog.Job_ID		,
								TransactionLog.Phase_ID	,
								TransactionLog.User_ID		,
								TransactionLog.Wrkst_ID	,
								TransactionLog.JS_ID			,
								TransactionLog.TL_Date			,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data
							
			FROM Job
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			WHERE (Job.Job_ID=FKJobID_Val)
			;
		
		
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_GetLastFinishedInfoForPhase`$$
CREATE  PROCEDURE  `DAF02`.`Job_GetLastFinishedInfoForPhase`(
JobID_Val Integer,
PhaseID_Val Integer
)
BEGIN
	SELECT *
	FROM TransactionLog
	WHERE Job_ID = JobID_Val AND Phase_ID = PhaseID_Val AND JS_ID = 2
	ORDER BY TL_ID DESC
	LIMIT 1
	;
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_getLastFinishedStatus`$$
CREATE  PROCEDURE  `DAF02`.`Job_getLastFinishedStatus`(JobID_Val	Integer)
BEGIN


		
		
	 /* Get Job Last status */
		SELECT TransactionLog.TL_ID,
					 TransactionLog.Job_ID,
					 TransactionLog.Phase_ID,
					 TransactionLog.User_ID,
					 TransactionLog.Wrkst_ID,
					 TransactionLog.JS_ID,
					 TransactionLog.TL_Date,
					 TransactionLog.TL_NoOfFiles,
					 TransactionLog.TL_Status_Data
		FROM TransactionLog
		WHERE (Job_ID=JobID_Val)
		  AND (JS_ID=2)
		ORDER BY TL_ID DESC
		LIMIT 1
	;
		

	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_getLastJobPhase_AllStatus`$$
CREATE  PROCEDURE  `DAF02`.`Job_getLastJobPhase_AllStatus`(
FKJobID_Val					Integer,
OUT lastPhaseID Integer
)
BEGIN
/*Last Job Phase associated with all status except PreAssigned*/
Declare LastPhase Integer Default 0;
	
		
	/* Get Job Last status */
		SELECT TransactionLog.Phase_ID
		INTO LastPhase
		FROM Job
		INNER JOIN TransactionLog
		ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
		WHERE (Job.Job_ID=FKJobID_Val)
		FOR UPDATE;
		
		SET lastPhaseID=LastPhase;

	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_getLastJobPhase_BasicStatus`$$
CREATE  PROCEDURE  `DAF02`.`Job_getLastJobPhase_BasicStatus`(
FKJobID_Val					Integer,
OUT lastPhaseID Integer
)
BEGIN
/*Basic Status for Job are Assigned,Started and finished*/
	Declare lastPhase Integer Default 0;
  DECLARE lastJobStatus   Integer Default 0;
	START TRANSACTION;
		
	/* Get Job Last status */
		SELECT TransactionLog.JS_ID, TransactionLog.Phase_ID
		INTO lastJobStatus,lastPhase
		FROM TransactionLog
		INNER JOIN Job
		ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
		WHERE (Job.Job_ID=FKJobID_Val)
		FOR UPDATE;
		
		/*check if upcommingPhase,upcommingUser = null*/
		
		/* change the data of last job record in case of Redirected and Rejected records*/
		IF	(lastJobStatus=4) THEN /*Redirected*/
					/* Find last Finished status record and consider it as the last record of the job*/
						SELECT  TransactionLog.Phase_ID
						INTO  	lastPhase
						FROM 	  TransactionLog
						WHERE  (TransactionLog.Job_ID=FKJobID_Val)
								AND(TransactionLog.JS_ID=2)/*FINISHED STATUS*/
						ORDER BY TransactionLog.TL_ID DESC LIMIT 1;
				
				
				ELSEIF    (lastJobStatus=5) THEN /*Rejected*/
					/* Find last Started status record and consider it as the last record of the job*/
						SELECT  TransactionLog.Phase_ID
						INTO  	lastPhase
						FROM  	TransactionLog
						WHERE  (TransactionLog.Job_ID=FKJobID_Val)
								AND(TransactionLog.JS_ID=1)/*STARTED STATUS*/
						ORDER BY TransactionLog.TL_ID DESC LIMIT 1;
			
		END IF;
		
		SET lastPhaseID=lastPhase;
	
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_getLastPhaseBeforeBackup`$$
CREATE  PROCEDURE  `DAF02`.`Job_getLastPhaseBeforeBackup`(JobID_Val		Integer)
BEGIN
	DECLARE PhaseID Integer Default 0;
	DECLARE TLID Integer Default 0;
	DECLARE JSID Integer Default 0;
	START TRANSACTION;
				
	/*check if last phase is backup and last state is finished*/
	
	SELECT TransactionLog.TL_ID,TransactionLog.Phase_ID,TransactionLog.JS_ID
	INTO TLID,PhaseID,JSID
	FROM TransactionLog
	INNER JOIN Job
	ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
	WHERE Job.Job_ID=JobID_Val
	FOR UPDATE;
	

	IF (PhaseID=1 AND JSID=2)THEN 
	/*get the last finished phase before this one*/
		
		SELECT TransactionLog.TL_ID,TransactionLog.Phase_ID
		FROM TransactionLog
		WHERE (TransactionLog.TL_ID<TLID)
		AND (TransactionLog.Job_ID=JobID_Val)
		AND (TransactionLog.JS_ID =2)
		ORDER BY TransactionLog.TL_ID DESC
		LIMIT 1
		FOR UPDATE;
		
		ELSE
		/*select empty data for exception handling*/
		SELECT TransactionLog.TL_ID,TransactionLog.Phase_ID
		FROM TransactionLog
		WHERE (TransactionLog.TL_ID=-1);
	
	END IF;

	
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_getLastTransactionData`$$
CREATE  PROCEDURE  `DAF02`.`Job_getLastTransactionData`(JobID_Val	Integer)
BEGIN

	if exists (Select * from TransactionLog Where TransactionLog.Job_ID = JobID_Val)
	Then 
	SELECT Job.Job_ID,
					 Job.JT_ID,
					 TransactionLog.TL_ID,
					 TransactionLog.Job_ID,
					 TransactionLog.Phase_ID,
					 TransactionLog.User_ID,
					 TransactionLog.Wrkst_ID,
					 TransactionLog.JS_ID,
					 TransactionLog.TL_Date,
					 TransactionLog.TL_NoOfFiles,
					 TransactionLog.TL_Status_Data
		FROM TransactionLog inner Join Job on TransactionLog.Job_ID = Job.Job_ID
		WHERE Job.Job_ID=JobID_Val And TransactionLog.Phase_ID <> 0 And TransactionLog.Phase_ID <> 1 And TransactionLog.Phase_ID <> 2
		ORDER BY TL_ID DESC
		LIMIT 1;
		
		Else
		
		SELECT Job.Job_ID,
					 Job.JT_ID,
					 OldTransactionLog.OTL_ID as TL_ID,
					 OldTransactionLog.Job_ID,
					 OldTransactionLog.Phase_ID,
					 OldTransactionLog.User_ID,
					 OldTransactionLog.Wrkst_ID,
					 OldTransactionLog.JS_ID,
					 OldTransactionLog.OTL_Date as TL_Date,
					 OldTransactionLog.OTL_NoOfFiles as TL_NoOfFiles,
					 OldTransactionLog.OTL_Status_Data as TL_Status_Data
		FROM OldTransactionLog inner Join Job on OldTransactionLog.Job_ID = Job.Job_ID
		WHERE Job.Job_ID=JobID_Val And OldTransactionLog.Phase_ID <> 0 And OldTransactionLog.Phase_ID <> 1 And OldTransactionLog.Phase_ID <> 2
		ORDER BY OTL_ID DESC
		LIMIT 1;
		
		End If;
		
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_getLastUploadDownloadRec`$$
CREATE  PROCEDURE  `DAF02`.`Job_getLastUploadDownloadRec`(
JobID_Val			Integer,
OUT TLID_Val	Integer,
OUT JSID_Val	Integer
)
BEGIN
	DECLARE TLID Integer Default 0;
	DECLARE JSID Integer Default 0;
	START TRANSACTION;
	/*
	* get the last inserted record in TL for the argumnet job,
	* this record must be one of upload or download status (8,9).
	* it must be noted that both status are not considered as last states so we can't
	* retrieve any of them through the natural join between TL and Job
	* on the field Job.TL_ID, insted we look 4 records > Job.TL_ID
	*/										
	
	SELECT TransactionLog.TL_ID,TransactionLog.JS_ID
	INTO TLID,JSID
	FROM TransactionLog
	INNER JOIN Job
	ON (Job.Job_ID=TransactionLog.Job_ID)
	WHERE (TransactionLog.TL_ID>Job.TL_ID and Job.TL_ID>0)
	AND (TransactionLog.JS_ID in (8,9))
	AND (Job.Job_ID=JobID_Val)
	ORDER BY TransactionLog.TL_ID DESC
	LIMIT 1
	FOR UPDATE;
	
	/*return values*/
	SET TLID_Val=TLID;
	SET JSID_Val=JSID;
	
	
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_getLateJobs`$$
CREATE  PROCEDURE  `DAF02`.`Job_getLateJobs`()
BEGIN
		
	
		SELECT   	 TransactionLog.Job_ID		,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								JobType.JT_Name,
								Collection.Coll_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_Date,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_Status_Data,
								Job.Storage_ID,
								TransactionLog.TL_ID			,
								TransactionLog.Phase_ID	,
								TransactionLog.User_ID		,
								TransactionLog.Wrkst_ID	,
								TransactionLog.JS_ID			,
								TransactionLog.TL_NoOfFiles	,
								 Phase.Phase_Sequence
								
								
							
			FROM Job
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and Job.JT_ID=Phase.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID=Storage.Storage_ID
			inner join JobType on JobType.JT_ID=Job.JT_ID
			inner join Batch on Batch.Batch_ID=Job.Batch_ID
			inner join Collection on Collection.Coll_ID=Batch.Coll_ID
			inner join Metadata.JobView on Metadata.JobView.Job_ID=Job.Job_ID
			
			WHERE (Job.Job_DueDate < NOW())	
			/*exclude done jobs*/
			/*and not (TransactionLog.JS_ID=2 and Phase.Phase_Sequence in (select max(Phase.Phase_Sequence)
																				FROM Phase where Phase.JT_ID=Job.JT_ID)	
					)*/
			group by TransactionLog.Job_ID
			order by Job.Job_DueDate , Metadata.JobView.Job_Title, User.User_Name ,Phase.Phase_Name;

			
			

	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_getMedias`$$
CREATE  PROCEDURE  `DAF02`.`Job_getMedias`(jobID_Val Integer)
BEGIN
Declare OldNew integer default 0;

select Job.TL_ID into OldNew from Job where Job_ID=jobID_Val;
	IF (OldNew=0)Then
		SELECT 	Job_Media.Media_ID,
					Media.Media_BarCode,
					Media.MT_ID,					
					MediaType.MT_Name
		FROM Job_Media
		INNER JOIN Media
		ON Job_Media.Media_ID=Media.Media_ID
		INNER JOIN MediaType
		ON Media.MT_ID=MediaType.MT_ID
		inner Join OldTransactionLog on OldTransactionLog.OTL_ID=Job_Media.TL_ID
		WHERE OldTransactionLog.Job_ID=jobID_Val
		ORDER BY Job_Media.Media_ID, MediaType.MT_ID		;
		ELSE
			SELECT 	Job_Media.Media_ID,
					Media.Media_BarCode,
					Media.MT_ID,					
					MediaType.MT_Name
		FROM Job_Media
		INNER JOIN Media
		ON Job_Media.Media_ID=Media.Media_ID
		INNER JOIN MediaType
		ON Media.MT_ID=MediaType.MT_ID
		inner Join OldTransactionLog on TransactionLog.TL_ID=Job_Media.TL_ID
		WHERE TransactionLog.Job_ID=jobID_Val
		ORDER BY Job_Media.Media_ID, MediaType.MT_ID		;
		END IF;


	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_getNextVersion`$$
CREATE  PROCEDURE  `DAF02`.`Job_getNextVersion`(JobID_Val	Integer)
BEGIN 
	Declare versionCount Integer default 0;
	Declare checkJob Integer default 0;
	Declare versionNum Integer default 1;

	START TRANSACTION;
		/*check job existence*/
		SELECT COUNT(*)
		INTO checkJob
		FROM Job
		WHERE Job.Job_ID=JobID_Val
		FOR UPDATE;
		
		IF (checkJob>0)THEN
					
					/* Get Job Last backed up and finished phase and extarct version value*/
					SELECT 	EXTRACTVALUE(TransactionLog.TL_Status_Data,'/Status/Backup/@Version')+1 
					INTO versionNum
					FROM TransactionLog
					WHERE (TransactionLog.Job_ID=JobID_Val)
						AND (TransactionLog.JS_ID=2)
						AND (TransactionLog.Phase_ID=1 or TransactionLog.Phase_ID=2)
					ORDER BY TL_ID DESC
					LIMIT 1
					FOR UPDATE;
					
					SELECT versionNum;
		ELSE
		/*job is not exist in the system
		* return -1 for error
		*/
		SELECT -1;
			
		END IF;
		
		

	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_getPendingJobs`$$
CREATE  PROCEDURE  `DAF02`.`Job_getPendingJobs`()
BEGIN
	
	
		
		SELECT  		TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								PreviousUserName(TransactionLog.Job_ID,TransactionLog.JS_ID),
								PreviousPhaseName(TransactionLog.Job_ID,TransactionLog.JS_ID),
								User.User_Name,
								Phase.Phase_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Status_Data,							
								TransactionLog.TL_ID			,
							  TransactionLog.Phase_ID	,
								TransactionLog.User_ID		,
								TransactionLog.Wrkst_ID	,
								TransactionLog.JS_ID			,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								Job.Storage_ID,
								PreviousUserID(TransactionLog.Job_ID,TransactionLog.JS_ID),
								PreviousPhaseID(TransactionLog.Job_ID,TransactionLog.JS_ID)
												
			FROM TransactionLog
			INNER JOIN Job
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID=Storage.Storage_ID
					inner join Metadata.JobView on Metadata.JobView.Job_ID=Job.Job_ID
				WHERE
				 (TransactionLog.JS_ID in (4,5))
			Order by TransactionLog.TL_ID  desc;
			

	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_getRedirectedJobs`$$
CREATE  PROCEDURE  `DAF02`.`Job_getRedirectedJobs`()
BEGIN

			
		SELECT  		TransactionLog.TL_ID			,
							  TransactionLog.Job_ID		,
								TransactionLog.Phase_ID	,
								TransactionLog.User_ID		,
								TransactionLog.Wrkst_ID	,
								TransactionLog.JS_ID			,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
							  Metadata.JobView.Job_Title,
								Job.Job_ID,
								Metadata.JobView.ExtIDType_ID,
								Job.Job_Date,
								Job.Job_DueDate,
								Job.Job_Path,
								Job.Job_Priority,
								Metadata.JobView.Job_Title,
								Metadata.JobView.Lang_ID,
								Job.JT_ID,
								Job.Storage_ID,
								Phase.Phase_Name,
								User.User_Name,
								Workstation.Wrkst_Name,
								JobStatus.JS_Name,
								JobType.JT_Name,
								Metadata.LanguageView.Lang_Name,
								Storage.Path
							
			FROM Job
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN JobType
			ON Job.JT_ID =JobType.JT_ID
			inner join Metadata.JobView on 
			Metadata.JobView.Job_ID=Job.Job_ID
			INNER JOIN Metadata.LanguageView
			ON Metadata.JobView.Lang_ID=Metadata.LanguageView.Lang_ID
			INNER JOIN Storage
			ON Job.Storage_ID=Storage.Storage_ID
			
			WHERE
			Job.Job_ID in (SELECT Job_ID From RedirectedJobs)
			Order by tlDate desc;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_getRejectedJobs`$$
CREATE  PROCEDURE  `DAF02`.`Job_getRejectedJobs`()
BEGIN

			
		SELECT  		TransactionLog.TL_ID			,
							  TransactionLog.Job_ID		,
								TransactionLog.Phase_ID	,
								TransactionLog.User_ID		,
								TransactionLog.Wrkst_ID	,
								TransactionLog.JS_ID			,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.JobView.Job_Title,
								Job.Job_ID,
								Metadata.JobView.ExtIDType_ID,
								Job.Job_Date,
								Job.Job_DueDate,
								Job.Job_Path,
								Job.Job_Priority,
								Metadata.JobView.Job_Title,
								Metadata.JobView.Lang_ID,
								Job.JT_ID,
								Job.Storage_ID,
								Phase.Phase_Name,
								User.User_Name,
								Workstation.Wrkst_Name,
								JobStatus.JS_Name,
								JobType.JT_Name,
								Metadata.LanguageView.Lang_Name,
								Storage.Path
							
			FROM Job
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN JobType
			ON Job.JT_ID =JobType.JT_ID
			inner join Metadata.JobView 
			on Metadata.JobView.Job_ID=Job.Job_ID
			INNER JOIN Metadata.LanguageView
			ON Metadata.JobView.Lang_ID= Metadata.LanguageView.Lang_ID
			INNER JOIN Storage
			ON Job.Storage_ID=Storage.Storage_ID
			WHERE
			Job.Job_ID in (SELECT Job_ID From RejectedJobs)
			Order by tlDate desc;
			
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_GetServerPath`$$
CREATE  PROCEDURE  `DAF02`.`Job_GetServerPath`(
		PKJobID_Val		Integer
	)
BEGIN
	
	
				SELECT  Storage.Storage_ID,
								Storage.Path,
								Storage.UserName,
								Storage.PassWord
								
				FROM Storage
				INNER JOIN Job
				ON Job.Storage_ID=Storage.Storage_ID
				WHERE Job.Job_ID=PKJobID_Val
				;
								
																
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_getTextualValues`$$
CREATE  PROCEDURE  `DAF02`.`Job_getTextualValues`(
	JobID_Val				Integer	
	)
Begin
Select Distinct
			Job.Job_ID,
			Collection.Coll_Name, 
			Batch.Batch_Name, 
			Metadata.LanguageView.Lang_Name, 
			Metadata.ExternalID_TypeView.ExtIDType_Name,
			JobType.JT_Name
			from Job Left Outer Join Batch on Job.Batch_ID = Batch.Batch_ID
			left outer join Metadata.JobView on Metadata.JobView.Job_ID=Job.Job_ID
			Left Outer join Metadata.LanguageView on Metadata.JobView.Lang_ID = Metadata.LanguageView.Lang_ID
			Left Outer join Metadata.ExternalID_TypeView on Metadata.JobView.ExtIDType_ID = Metadata.ExternalID_TypeView.ExtIDType_ID
			Left Outer join JobType on Job.JT_ID = JobType.JT_ID
			Left Outer join Collection on Batch.Coll_ID = Collection.Coll_ID
			Where Job.Job_ID = JobID_Val;
End $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_getZips`$$
CREATE  PROCEDURE  `DAF02`.`Job_getZips`(JobID_Val	integer,	Job_Version nvarchar(4) )
BEGIN
	Declare oldNew integer default 0;
	-- Declare folders nvarchar(100) default '';
	
	SELECT Job.TL_ID 
	Into oldNew
	from Job 
	Where Job_ID=JobID_Val;
	
	IF (oldNew=0)Then
		SELECT EXTRACTVALUE(OTL_Status_Data,'/Status/Backup/CompressedFolder/@FolderName'),
					 EXTRACTVALUE(OTL_Status_Data,'/Status/Backup/@Size')
		from OldTransactionLog
		WHERE OldTransactionLog.Job_ID=JobID_Val
		and EXTRACTVALUE(OTL_Status_Data,'/Status/Backup/@Version') = Job_Version;
	ELSE
		SELECT EXTRACTVALUE(TL_Status_Data,'/Status/Backup/CompressedFolder/@FolderName'),
					 EXTRACTVALUE(TL_Status_Data,'/Status/Backup/@Size')
		from TransactionLog
		WHERE TransactionLog.Job_ID=JobID_Val
		and EXTRACTVALUE(TL_Status_Data,'/Status/Backup/@Version') = Job_Version;
	END IF;
	

END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_insertIntoMedia`$$
CREATE  PROCEDURE  `DAF02`.`Job_insertIntoMedia`(mediaType integer, mediaID integer,TLID integer)
BEGIN
	Declare recorded TinyInt(1) default 0;
	START TRANSACTION;		

	/*check if TLID is recorded before with same type of MediaID or not
	* if result = no then insert it
	*/
		
	SELECT if (Count(Media.Media_ID)>=1,1,0) into recorded
	FROM Media
	INNER Join Job_Media
	ON (Media.Media_ID=Job_Media.Media_ID)
	WHERE (Job_Media.TL_ID=TLID)
		and (Media.MT_ID=mediaType);
	
	IF (recorded=0) THEN
		INSERT INTO Job_Media (TL_ID,Media_ID)
										VALUES(TLID,mediaID);
	END IF;
	
	SELECT * 
	FROM Job_Media 
	WHERE (Job_Media.TL_ID=TLID)
	  AND (Job_Media.Media_ID=mediaID);
	
	COMMIT;			
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_IsRePhase`$$
CREATE  PROCEDURE  `DAF02`.`Job_IsRePhase`(
		JobID_Val		Integer,
		PhaseID_Val		Integer		
	)
BEGIN
	
	DECLARE Jtype Integer Default 0 ;
	START TRANSACTION;
			
		/* Get Job type */
		SELECT Job.JT_ID 
		INTO Jtype
		FROM Job 
		WHERE Job.Job_ID=JobID_Val
		;/*X Lock*/
		
	
	SELECT  JobID_Val,User_ID,User_Name,Phase_ID,Phase_Name , TransDate
	FROM 
	(
	  ( SELECT  JobID_Val,OldTransactionLog.User_ID ,User.User_Name,
							OldTransactionLog.Phase_ID ,Phase.Phase_Name,
							OldTransactionLog.OTL_Date as TransDate
				from User
				INNER JOIN OldTransactionLog
				ON OldTransactionLog.User_ID = User.User_ID
				INNER JOIN Phase
				on Phase.Phase_ID=OldTransactionLog.Phase_ID
				where (OldTransactionLog.Phase_ID in (select Phase.Phase_ID from Phase where (Phase.JT_ID=Jtype) and (Phase.Phase_ID=PhaseID_Val)))
				 and (OldTransactionLog.Job_ID=JobID_Val)
				 and (OldTransactionLog.JS_ID=1)
			 
		) 
		UNION
		(	SELECT  JobID_Val,TransactionLog.User_ID,User.User_Name,
							TransactionLog.Phase_ID ,Phase.Phase_Name,
							TransactionLog.TL_Date as TransDate
			from User
			INNER JOIN TransactionLog
			ON TransactionLog.User_ID = User.User_ID
			INNER JOIN Phase
			on Phase.Phase_ID=TransactionLog.Phase_ID
			where (TransactionLog.Phase_ID in (select Phase.Phase_ID from Phase where (Phase.JT_ID=Jtype) and (Phase.Phase_ID=PhaseID_Val)))
				and (TransactionLog.Job_ID=JobID_Val)
				and (TransactionLog.JS_ID=1)
														
															
			)

	)HistoryTable
	
	order by TransDate;
	
																
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_LimitedReadyToArchive`$$
CREATE  PROCEDURE  `DAF02`.`Job_LimitedReadyToArchive`(MediaTypeID Integer, JobCount varchar(20))
BEGIN
	Declare ready2Archive varchar(2000);
	Declare compare Integer default -1;
	--  Select stmt
	set ready2Archive='SELECT  TransactionLog.TL_ID,TransactionLog.Job_ID,0,Job.JT_ID,EXTRACTVALUE(TL_Status_Data,''/Status/Backup/@Version'') as  Version, EXTRACTVALUE(TL_Status_Data,''/Status/Backup/@Size'') as Size,Concat(Job.Job_Path,''_v'',EXTRACTVALUE(TL_Status_Data,''/Status/Backup/@Version'')) as VersionName';
	-- From stmt
  set  ready2Archive=concat(ready2Archive,'	FROM Job	INNER JOIN JobType_MediaType	ON (JobType_MediaType.JT_ID=Job.JT_ID AND JobType_MediaType.MT_ID=',MediaTypeID,')		INNER JOIN TransactionLog		on TransactionLog.Job_ID=Job.Job_ID	');
 	-- if JobCount==all --> select all, otherwise select limit 
	SELECT STRCMP(JobCount,'all') into compare;
	IF (compare=0)THEN
		-- select all
		set  ready2Archive=concat(ready2Archive,' WHERE   ((TransactionLog.Phase_ID=1 or TransactionLog.Phase_ID=2) and TransactionLog.JS_ID=2)	AND (TransactionLog.TL_ID not in 	( SELECT Job_Media.TL_ID	FROM  Job_Media		INNER JOIN Media 	ON Job_Media.Media_ID=Media.Media_ID		INNER Join MediaType ON MediaType.MT_ID=Media.MT_ID  WHERE MediaType.MT_ID=',MediaTypeID,'  )	) 	AND TransactionLog.TL_ID > MaxCheckedOut(TransactionLog.Job_ID)	  ORDER BY Job_ID,TL_ID	;');
	ELSE
		-- select limited
		set  ready2Archive=concat(ready2Archive,' WHERE   ((TransactionLog.Phase_ID=1 or TransactionLog.Phase_ID=2) and TransactionLog.JS_ID=2) and (TransactionLog.TL_ID not in 	( SELECT Job_Media.TL_ID	FROM  Job_Media	WHERE 	Job_Media.Media_ID=2382  )	) 	AND TransactionLog.TL_ID > MaxCheckedOut(TransactionLog.Job_ID)	 	ORDER BY Job_ID,TL_ID	LIMIT ',JobCount,';');
	END IF;
	-- execute prepared stmt
	set @toArchive:=ready2Archive;
	Prepare stmt from @toArchive;
	execute stmt;
	DEALLOCATE PREPARE stmt;


	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_loadAll`$$
CREATE  PROCEDURE  `DAF02`.`Job_loadAll`()
BEGIN
	
		Select 	Job.Job_ID,
							Metadata.JobView.Job_External_ID,
							Metadata.JobView.ExtIDType_ID,
							Metadata.JobView.Job_Title,
							Metadata.JobView.Job_Creator,
							Job_Date,
							Metadata.JobView.Job_Info1,
							Metadata.JobView.Job_Info2,
							Metadata.JobView.Job_Info3,
							Job_Path,
							Job_Priority,
							Job_DueDate,
							Metadata.JobView.Job_IdentifyingLob,
							Batch_ID,
							JT_ID,
							Metadata.JobView.Lang_ID,
							JC_ID,
							TL_ID,
							Storage_ID,
							Job_TimeStamp
			From Job
			inner join Metadata.JobView on Metadata.JobView.Job_ID=Job.Job_ID
		WHERE Job.Job_ID>0;
		
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_MultipleInsertIntoMedia`$$
CREATE  PROCEDURE  `DAF02`.`Job_MultipleInsertIntoMedia`(
	mediaType integer, 
	mediaID integer,
	TL_IDs_Val text,
	delimiterVal char(1)
	)
BEGIN
	Declare recorded TinyInt(1) default 0;
	
	START TRANSACTION;		
	
	CALL SplitIDs(TL_IDs_Val,delimiterVal);	
	
	/*check if TLIDs are recorded before with same type of MediaID or not
	* if result = no then insert them
	*/
	SELECT if (Count(Media.Media_ID)>=1,1,0) into recorded
	FROM Media
	INNER Join Job_Media
	ON (Media.Media_ID=Job_Media.Media_ID)
	WHERE (Job_Media.TL_ID in ( 
				  									SELECT IDVal
														FROM 
														SplittedTempTable
														)
		and (Media.MT_ID=mediaType));

	IF (recorded=0)THEN
	/*all TLs are valid to be recoded into this media type*/
	insert into Job_Media (Job_Media.Media_ID,Job_Media.TL_ID) 
	(select mediaID,IDVal from SplittedTempTable);
			
	SELECT * 
	FROM Job_Media 
	WHERE Job_Media.Media_ID=mediaID;	

	ELSE
	/*dummy data*/
	SELECT * 
	FROM Job_Media 
	WHERE Job_Media.Media_ID=-1;	

	END IF;
		
	
	Drop Temporary Table If Exists `SplittedTempTable`;

	COMMIT;		
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_newOrOld`$$
CREATE  PROCEDURE  `DAF02`.`Job_newOrOld`(jobID_Val Integer)
BEGIN
Declare newJob Integer default 0;
Declare oldJob Integer default 0;
START TRANSACTION;

 	SELECT count(*) 
	INTO newJob
 	FROM TransactionLog
 	WHERE TransactionLog.Job_ID=jobID_Val
	;
	
	SELECT count(*) 
	INTO oldJob
 	FROM OldTransactionLog
 	WHERE OldTransactionLog.Job_ID=jobID_Val
	;
	
	IF (newJob<>0) THEN
	/*job is existed in TL not OTL*/
	/*return 1*/
			SELECT 1;
	
	ELSEIF (oldJob<>0) THEN
		/*job in OTL*/
			SELECT 0;
	ELSE
	   /*exception*/
		 SELECT -1;
				
	END IF;

 COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_PreAssign`$$
CREATE  PROCEDURE  `DAF02`.`Job_PreAssign`(
		FKJobID_Val 				Integer		,			
		FKPhaseID_Val 		  Integer		,
		FKUserID_Val 			  Integer	  ,
		FKWrkstID_Val 			Integer		,
		TLNoOfFiles_Val			Integer 	,
		TLStatusData_Val		Text	,
		TLDate_Val				DateTime
	)
BEGIN
	START TRANSACTION;
		
			
				/*Add Rediect record  */ 
					CALL TransLog_AddWithoutCommit(FKJobID_Val		,
																				 FKPhaseID_Val	,
																			   FKUserID_Val		,
																				 FKWrkstID_Val	,
																				 3							,
																				 TLDate_Val				,
																				 TLNoOfFiles_Val,
																				 TLStatusData_Val
																				);
		SELECT * FROM TransactionLog WHERE Job_ID = FKJobID_Val AND JS_ID = 3;

	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_ReadyToArchive`$$
CREATE  PROCEDURE  `DAF02`.`Job_ReadyToArchive`(MediaTypeID Integer)
BEGIN
	Declare	GUIcheckBox	 TinyInt(1) Default 0;
	
		SELECT  TransactionLog.TL_ID,
						TransactionLog.Job_ID,
						GUIcheckBox,
						Job.JT_ID,
						EXTRACTVALUE(TL_Status_Data,'/Status/Backup/@Version') as  Version, 
						EXTRACTVALUE(TL_Status_Data,'/Status/Backup/@Size') as Size,
						Concat(Job.Job_Path,'_v',EXTRACTVALUE(TL_Status_Data,'/Status/Backup/@Version')) as VersionName
		FROM Job
		INNER JOIN JobType_MediaType
		ON (JobType_MediaType.JT_ID=Job.JT_ID AND JobType_MediaType.MT_ID=MediaTypeID)
		INNER JOIN TransactionLog
		on TransactionLog.Job_ID=Job.Job_ID
		left outer join Job_MaxCheckOut on Job_MaxCheckOut.Job_ID=TransactionLog.Job_ID 
		-- get all jobs that finished backup phase
		WHERE ((TransactionLog.Phase_ID=1 Or TransactionLog.Phase_ID=2) and TransactionLog.JS_ID=2)
		/* execlude all job versions (TL_ID) that already archived on 
		*  any media that belongs to MediaType argument value.
		*  and Backed up record > last check out record
		*/
				AND (TransactionLog.TL_ID not in 
							( SELECT Job_Media.TL_ID
								FROM  Job_Media
								INNER JOIN Media 
								ON Job_Media.Media_ID=Media.Media_ID
									WHERE Media.MT_ID=MediaTypeID
						  )
				)
		 	 -- 	AND TransactionLog.TL_ID > MaxCheckedOut(TransactionLog.Job_ID)
			and if (Job_MaxCheckOut.Job_ID is not null,TransactionLog.TL_ID>Job_MaxCheckOut.TL_ID,true)

				
		ORDER BY  Job_ID ,EXTRACTVALUE(TL_Status_Data,'/Status/Backup/@Size')
		;
		
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_Redirect`$$
CREATE  PROCEDURE  `DAF02`.`Job_Redirect`(
		JobID_Val 				Integer		,			
		PhaseID_Val 		  Integer		,
		UserID_Val 			  Integer	  ,
		NextPhaseID_Val 		  Integer		,
		NextUserID_Val 			  Integer	  ,
		WrkstID_Val 			Integer		,
		TLNoOfFiles_Val			Integer 	,
		FinishTLStatusData_Val		Text		,
		RedirectTLStatusData_Val		Text		,
		AssignTLStatusData_Val		Text		,
		TLDate_Val				DateTime
		
	)
BEGIN
		DECLARE TLrecord  			Integer	Default -1;
		DECLARE permID  					Integer	Default 0;
		Declare TLID_Val Integer default 0;

		DECLARE CONTINUE HANDLER FOR SQLWARNING 
		BEGIN 
				set TLID_Val = 0;
			--  	set permID = 0;
		END;

	START TRANSACTION;
		/*get job last state and make sure it's Start state*/
		
		SELECT Job.TL_ID,TransactionLog.Phase_ID	INTO TLID_Val, PhaseID_Val
		FROM Job	INNER JOIN TransactionLog	ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
		WHERE  (TransactionLog.JS_ID=1)		-- IFF Started
			AND (Job.Job_ID=JobID_Val)
		FOR UPDATE;
		
			-- check if NextUserID_Val is inactive, if yes then assign to auto user
					Select if(User.User_IsActive=0 ,0,NextUserID_Val) into NextUserID_Val from User
					where User.User_ID=NextUserID_Val;
		
		IF (TLID_Val>0) Then/*last job state is started*/
			/* insert finish record in the TL*/
			INSERT INTO TransactionLog (Job_ID,    Phase_ID,    User_ID,    Wrkst_ID,   JS_ID, TL_Date,    TL_NoOfFiles,    TL_Status_Data)
   												values (JobID_Val, PhaseID_Val, UserID_Val, WrkStID_Val, 2,    TLDate_Val, TLNoOfFiles_Val, FinishTLStatusData_Val);
			/*Add Rediect record  */ 
			INSERT INTO TransactionLog (Job_ID,    Phase_ID,        User_ID,        Wrkst_ID,   JS_ID, TL_Date,    TL_NoOfFiles,    TL_Status_Data)
   												values (JobID_Val, NextPhaseID_Val, NextUserID_Val, WrkStID_Val, 4,    ADDTIME(TLDate_Val,'00:00:01'), -1  , RedirectTLStatusData_Val);

			SET TLrecord = Last_Insert_ID();

			
			/*check if user can redirect or not*/
		
				SELECT Permission.Perm_ID INTO permID	
				FROM Permission	INNER JOIN Role_Permission ON Permission.Perm_ID= Role_Permission.Perm_ID
												INNER JOIN User	ON (User.Role_ID = Role_Permission.Role_ID and User.User_IsActive=1) 			
				WHERE (User.User_ID=UserID_Val)
					and Permission.Perm_ID = 7;
				--  AND (Permission.Perm_Description = 'PhaseManager_Redirect');

				IF (permID>0) THEN
					/*assign job to the next phase, next user*/
							INSERT INTO TransactionLog (Job_ID,    Phase_ID,        User_ID,        Wrkst_ID,   JS_ID, TL_Date,    TL_NoOfFiles,    TL_Status_Data)
																	values (JobID_Val, NextPhaseID_Val, NextUserID_Val, WrkStID_Val, 6,    ADDTIME(TLDate_Val,'00:00:02'), -1  , AssignTLStatusData_Val);
							SET TLrecord = Last_Insert_ID();
				END IF;
		
			
		-- Update the Job Table to make it indicate to the Last update record of TL
	 	UPDATE Job 
		SET Job.TL_ID=TLrecord
		WHERE Job.Job_ID=JobID_Val;
					
	END IF;/*start state*/

	SELECT * 
	FROM TransactionLog
	WHERE	TransactionLog.TL_ID=TLrecord;
	COMMIT;
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_Reject`$$
CREATE  PROCEDURE  `DAF02`.`Job_Reject`(
		JobID_Val 				Integer		,			
		NextPhaseID_Val 		  Integer		,
		userID_Val 		   Integer		,
		NextUserID_Val 			  Integer	  ,
		WrkstID_Val 			Integer		,
		TLNoOfFiles_Val			Integer 	,
		RejectedTLStatusData_Val		Text		,
		AssignedTLStatusData_Val		Text		,
		TLDate_Val				DateTime	
		)
BEGIN
		
		DECLARE lastJobRec  			Integer	Default 0;
		DECLARE currentRec  			Integer	Default -1;
		DECLARE permID  					Integer	Default 0;
		
	
		DECLARE CONTINUE HANDLER FOR SQLWARNING 
		BEGIN 
				set lastJobRec = 0;
			END;

		
		/*Check the last state of the job, If it's = Started then processd, else halt*/
			/* Get the Last job status */
			SELECT TransactionLog.TL_ID
			INTO lastJobRec
			FROM Job
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			WHERE (Job.Job_ID=JobID_Val)
			and (TransactionLog.JS_ID=1)
			FOR Update;
			
				-- check if NextUserID_Val is inactive, if yes then assign to auto user
					Select if(User.User_IsActive=0 ,0,NextUserID_Val) into NextUserID_Val from User
					where User.User_ID=NextUserID_Val;
	
			IF (lastJobRec>0) THEN /*Started Job*/
			
				/*Add Reject record  */ 
				INSERT INTO TransactionLog (Job_ID,    Phase_ID,    User_ID,    Wrkst_ID,   JS_ID, TL_Date,    TL_NoOfFiles,    TL_Status_Data)
   												values (JobID_Val, NextPhaseID_Val, NextUserID_Val, WrkstID_Val, 5,    TLDate_Val, TLNoOfFiles_Val, RejectedTLStatusData_Val);
		
				SET currentRec = Last_Insert_ID();
				
				
				/*check if user can reject or not*/
				SELECT Permission.Perm_ID INTO permID	
				FROM Permission	INNER JOIN Role_Permission ON Permission.Perm_ID= Role_Permission.Perm_ID
												INNER JOIN User	ON (User.Role_ID = Role_Permission.Role_ID and User.User_IsActive=1) 			
				WHERE (User.User_ID=userID_Val)
					and Permission.Perm_ID = 8;
					
				IF (permID>0) THEN
						/*assign job to the next phase, next user*/
							INSERT INTO TransactionLog (Job_ID,    Phase_ID,        User_ID,        Wrkst_ID,   JS_ID, TL_Date,    TL_NoOfFiles,    TL_Status_Data)
																	values (JobID_Val, NextPhaseID_Val, NextUserID_Val, WrkStID_Val, 6,    ADDTIME(TLDate_Val,'00:00:01'), -1  , AssignedTLStatusData_Val);
							SET currentRec = Last_Insert_ID();
			 END IF;
		
			/* Update the Job Table to make it indicate to the Last update record of TL*/
					UPDATE Job 
					SET Job.TL_ID=currentRec
					WHERE Job.Job_ID=JobID_Val;
					
			END IF;
			
					
			SELECT * FROM TransactionLog
			WHERE
			TransactionLog.TL_ID=currentRec;
		

	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_RejectForced`$$
CREATE  PROCEDURE  `DAF02`.`Job_RejectForced`(
		FKJobID_Val 				Integer		,			
		FKPhaseID_Val 		  Integer		,
		FKUserID_Val 			  Integer	  ,
		FKWrkstID_Val 			Integer		,
		TLNoOfFiles_Val			Integer 	,
		TLStatusData_Val		Text		,
		TLDate_Val				DateTime
	)
BEGIN
		DECLARE lastJobStatus			Integer	Default 0;
		DECLARE lastJobRec  			Integer	Default 0;
		DECLARE currentRec  			Integer	Default 0;
		START TRANSACTION;
		
		/*Check the last state of the job, If it's = Started then processd, else halt*/
			/* Get the Last job status */
			SELECT TransactionLog.JS_ID,TransactionLog.TL_ID
			INTO lastJobStatus,lastJobRec
			FROM TransactionLog
			INNER JOIN Job
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			WHERE (Job.Job_ID=FKJobID_Val)
			FOR Update;
			
				Select if(User.User_IsActive=0 ,0,FKUserID_Val) into FKUserID_Val from User
					where User.User_ID=FKUserID_Val;
			
				/*Add Reject record  */ 
					CALL TransLog_AddWithoutCommit(FKJobID_Val		,
																				 FKPhaseID_Val	,
																			   FKUserID_Val		,
																				 FKWrkstID_Val	,
																				 5							,
																				 TLDate_Val					,
																				 TLNoOfFiles_Val,
																				 TLStatusData_Val
																				);
			/* Update the Job Table to make it indicate to the Last update record of TL*/
					SET currentRec = Last_Insert_ID();
					UPDATE Job 
					SET Job.TL_ID=currentRec
					WHERE Job.Job_ID=FKJobID_Val;
					
						
					
			SELECT * FROM TransactionLog
			WHERE
			TransactionLog.TL_ID=currentRec;
		
			
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_Start`$$
CREATE  PROCEDURE  `DAF02`.`Job_Start`(
	FKJobID_Val				Integer	,
	user_Val				Integer	,
	phase_Val				Integer	,
	WS_Val				Integer,
	TLStatusData_Val		Text,
	TLDate_Val 	DateTime
	)
BEGIN
		DECLARE lastJobRec  			Integer	Default 0;
		DECLARE currentRec  			Integer	Default -1;
		DECLARE assignedPhaseID  					Integer	Default 0;
		DECLARE assignedWSID  						Integer	Default 0;
		DECLARE assignedAserID  					Integer	Default 0;
		START TRANSACTION;
		/*Check the last state of the job, If it's = assigned then processd, else halt*/
			/* Get the Last job status */
			SELECT TransactionLog.TL_ID,TransactionLog.User_ID,TransactionLog.Wrkst_ID,TransactionLog.Phase_ID
			INTO lastJobRec,assignedAserID,assignedWSID,assignedPhaseID
			FROM TransactionLog
			INNER JOIN Job
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			WHERE (Job.Job_ID=FKJobID_Val)
			and (TransactionLog.JS_ID=6)
			FOR Update;
								
			/*new data for start record must have last data of assigned record*/
			IF ((lastJobRec>0) and (user_Val=assignedAserID) and (WS_Val=assignedWSID)  and (phase_Val=assignedPhaseID) ) THEN /*Assigned Job*/
							/*Add Start record with the data associated with lastJobRec */ 
								
									CALL TransLog_AddWithoutCommit( FKJobID_Val,
																									phase_Val,
																									user_Val,
																									WS_Val,
																									1,/*started status*/
																									TLDate_Val,/*system date*/
																									0,
																									TLStatusData_Val 
																									);				
											
									/* Update the Job Table to make it indicate to the Last update record of TL*/
				
									SET currentRec = Last_Insert_ID();
									UPDATE Job 
									SET Job.TL_ID=currentRec
									WHERE Job.Job_ID=FKJobID_Val;
				
			END IF;
			
					
			SELECT * FROM TransactionLog
			WHERE
			TransactionLog.TL_ID=currentRec;
		
			COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_Update`$$
CREATE  PROCEDURE  `DAF02`.`Job_Update`(
	JobID_Val					   Integer			,
	JobDate_Val 					 DateTime			,
	JobPath_Val 					 nvarchar(200) ,
	JobPriority_Val				 Integer			,
	JobDueDate_Val 				 DateTime			,
	BatchID_Val 				 Integer			,
	JTID_Val             Integer			,
	JCID_Val 						 Integer			,
	TLID_Val						 Integer,
	StorageID_Val					 Integer

)
BEGIN
	START TRANSACTION;
				UPDATE Job  SET   Job_ID				  = JobID_Val						,
													Job_Date					= JobDate_Val						,
													Job_Path					= JobPath_Val						,
													Job_Priority			= JobPriority_Val				,
													Job_DueDate				= JobDueDate_Val				,
													Batch_ID				= BatchID_Val					,
													JT_ID					= JTID_Val						,
													JC_ID					= JCID_Val						,
													TL_ID					= TLID_Val		,
													Storage_ID				=	StorageID_Val				
												
										WHERE  Job_ID	  = JobID_Val;
								
				SELECT * FROM Job WHERE  Job_ID = JobID_Val;										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_Upload`$$
CREATE  PROCEDURE  `DAF02`.`Job_Upload`(
		JobID_Val 				Integer		,			
		PhaseID_Val 		  Integer		,
		UserID_Val 			  Integer	  ,
		WrkstID_Val 			Integer		,
		TLNoOfFiles_Val			Integer 	,
		TLStatusData_Val		Text		,
		TLDate_Val				DateTime
	)
BEGIN
	DECLARE TLID Integer Default -1;	
	START TRANSACTION;	
			
			CALL TransLog_AddWithoutCommit(JobID_Val		,
																		 PhaseID_Val	,
																	   UserID_Val		,
																		 WrkstID_Val	,
																		 8							,
																		 TLDate_Val					,
																		 TLNoOfFiles_Val,
																		 TLStatusData_Val
																		);
		
			SET TLID=Last_Insert_ID();
			SELECT * FROM TransactionLog
			WHERE
			TransactionLog.TL_ID=TLID;
	COMMIT;

END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Job_ValidateUserWSPhase`$$
CREATE  PROCEDURE  `DAF02`.`Job_ValidateUserWSPhase`(
		FKJobID_Val					Integer		,
		FKUserID_Val 			  Integer	  ,
		FKWrkstID_Val 			Integer		,
		FKPhaseID_Val				Integer   
		)
BEGIN
	Declare CollID	  		 Integer Default 0;
	Declare validUserPhase Integer Default 0;
	Declare validWSPhase	 Integer Default 0;
	Declare validUserColl	 Integer Default 0;
	Declare validWSColl 	 Integer Default 0;
	Declare collAnyUser 	 Integer Default 0;
	Declare collAnyWS 	 	 Integer Default 0;
	Declare wsAnyPhase 	 	 Integer Default 0;
	Declare userAnyPhase 	 	 Integer Default 0;
	START TRANSACTION;
	
	/*Get Job Collection */
	SELECT  Collection.Coll_ID,Collection.Coll_AnyUser,Collection.Coll_AnyWorkstation
	INTO CollID,collAnyUser,collAnyWS
	FROM Collection
	INNER JOIN Batch
	ON Batch.Coll_ID = Collection.Coll_ID
	INNER JOIN Job
	ON Job.Batch_ID = Batch.Batch_ID
	WHERE (Job.Job_ID= FKJobID_Val) AND (Collection.Coll_Active=1)
	;
		
	SELECT Workstation.Wrkst_AnyPhase
	INTO wsAnyPhase
	FROM Workstation
	WHERE (Workstation.Wrkst_ID=FKWrkstID_Val)
		AND (Workstation.Wrkst_IsActive=1)
		;
		
	SELECT User.User_AnyPhase
	INTO userAnyPhase
	FROM User
	WHERE (User.User_ID=FKUserID_Val)
		AND (User.User_IsActive=1)
		;
	
	
	SELECT COUNT(*)
	INTO validUserPhase
	FROM User_Phase
	INNER JOIN User
	ON User_Phase.User_ID=User.User_ID
	WHERE (User_Phase.Phase_ID=FKPhaseID_Val)
		AND (User_Phase.User_ID=FKUserID_Val)
		AND (User.User_IsActive=1)
		;
	
		
	SELECT COUNT(*)
	INTO validWSPhase
	FROM Workstation_Phase
	INNER  JOIN Workstation
	ON Workstation_Phase.Wrkst_ID=Workstation.Wrkst_ID
	WHERE (Workstation_Phase.Phase_ID=FKPhaseID_Val)
		AND (Workstation_Phase.Wrkst_ID=FKWrkstID_Val)
		AND (Workstation.Wrkst_IsActive=1)
		;
		
	SELECT COUNT(*)
	INTO validUserColl
	FROM User_Collection
	INNER JOIN Collection
	ON User_Collection.Coll_ID=Collection.Coll_ID
	INNER JOIN User
	ON User_Collection.User_ID=User.User_ID
	WHERE (User_Collection.Coll_ID=CollID)
		AND (User_Collection.User_ID=FKUserID_Val)
		AND (User.User_IsActive=1)
		AND (Collection.Coll_Active=1)
		;
		
		
	SELECT COUNT(*)
	INTO validWSColl
	FROM Workstation_Collection
	INNER JOIN Collection
	ON Workstation_Collection.Coll_ID= Collection.Coll_ID
	INNER JOIN Workstation
	ON Workstation_Collection.Wrkst_ID= Workstation.Wrkst_ID
	WHERE (Workstation_Collection.Coll_ID=CollID)
		AND (Workstation_Collection.Wrkst_ID=FKWrkstID_Val)
		AND (Workstation.Wrkst_IsActive=1)
		AND (Collection.Coll_Active=1)
		;

	
	
IF   ((validUserPhase>0) OR (userAnyPhase=1)) AND
		 ((validWSPhase  >0) OR (wsAnyPhase=1)) AND
		 ((validUserColl >0) OR (collAnyUser=1)) AND
		 ((validWSColl   >0) OR (collAnyWS=1))	THEN
	select 1;
	ELSE
	select 0;
	END IF;
	
	
			
	COMMIT;									
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`JobCondition_Add`$$
CREATE  PROCEDURE  `DAF02`.`JobCondition_Add`(
		JCName_Val 					 nvarchar(50) ,			
		JCDescription_Val 		 Text		
)
BEGIN
	START TRANSACTION;
				INSERT INTO JobCondition (JC_Name 		,
													 				JC_Description			
																	)
									
													values (JCName_Val	,
																	JCDescription_Val
																	);			
														
				SELECT * FROM JobCondition WHERE JC_ID=Last_Insert_ID();										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`JobCondition_Delete`$$
CREATE  PROCEDURE  `DAF02`.`JobCondition_Delete`(
		PKJCID_Val		Integer
	)
BEGIN
	START TRANSACTION;
				DELETE FROM JobCondition	WHERE JC_ID=PKJCID_Val;
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`JobCondition_getByID`$$
CREATE  PROCEDURE  `DAF02`.`JobCondition_getByID`(
		PKJCID_Val		Integer
	)
BEGIN
	
	SELECT * FROM JobCondition	WHERE JC_ID=PKJCID_Val;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`JobCondition_loadAll`$$
CREATE  PROCEDURE  `DAF02`.`JobCondition_loadAll`()
BEGIN
	
	SELECT * FROM JobCondition ;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`JobCondition_Update`$$
CREATE  PROCEDURE  `DAF02`.`JobCondition_Update`(
		PKJCID_Val					   Integer      ,
		JCName_Val 						 nvarchar(50)  ,			
		JCDescription_Val 		 Text	
)
BEGIN
	START TRANSACTION;
				UPDATE JobCondition  SET JC_ID 			=	PKJCID_Val			,
																 JC_Name				= JCName_Val		  ,
													       JC_Description =	JCDescription_Val		 
												
															WHERE JC_ID= PKJCID_Val;
								
				SELECT * FROM JobCondition WHERE JC_ID=PKJCID_Val;										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`JobStatus_Add`$$
CREATE  PROCEDURE  `DAF02`.`JobStatus_Add`(
		JSName_Val				nvarchar(50),
		JSDescription_Val Text
 )
BEGIN
	START TRANSACTION;
				INSERT INTO JobStatus (JS_Name			,
															 JS_Description
															) 
										values (JSName_Val	,
														JSDescription_Val
														);			
				SELECT * FROM JobStatus WHERE JS_ID=Last_Insert_ID();										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`JobStatus_Delete`$$
CREATE  PROCEDURE  `DAF02`.`JobStatus_Delete`(
		PKJSID_Val		Integer
	)
BEGIN
	START TRANSACTION;
				DELETE FROM JobStatus	WHERE JS_ID=PKJSID_Val;
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`JobStatus_getByID`$$
CREATE  PROCEDURE  `DAF02`.`JobStatus_getByID`(
		PKJSID_Val		Integer
	)
BEGIN
	
	SELECT * FROM JobStatus	WHERE JS_ID=PKJSID_Val;
		
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`JobStatus_loadAll`$$
CREATE  PROCEDURE  `DAF02`.`JobStatus_loadAll`()
BEGIN
	
	SELECT * FROM JobStatus ;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`JobStatus_loadFinalStates`$$
CREATE  PROCEDURE  `DAF02`.`JobStatus_loadFinalStates`()
BEGIN
	
	SELECT JobStatus.JS_ID,
				 JobStatus.JS_Name
	FROM JobStatus
	WHERE JobStatus.JS_ID in (1,2,4,5,6);
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`JobStatus_Update`$$
CREATE  PROCEDURE  `DAF02`.`JobStatus_Update`(
		PKJSID_Val					   Integer      ,
		JSName_Val						 nvarchar(50)	,
		JSDescription_Val			 Text  			
	)
BEGIN
	START TRANSACTION;
				UPDATE JobStatus  SET  JS_ID		 =	PKJSID_Val		    ,
														JS_Name				 = JSName_Val		 	    ,
														JS_Description = JSDescription_Val
												
												WHERE  JS_ID =	PKJSID_Val;
								
				SELECT * FROM JobStatus WHERE  JS_ID	=	PKJSID_Val;										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`JobType_Add`$$
CREATE  PROCEDURE  `DAF02`.`JobType_Add`(
		JTName_Val 						 nvarchar(50) ,			
		JTDescription_Val 		 Text				 ,
		JTLifeTime_Val 			   Integer		 ,
		JTNamingConvention_Val nvarchar(200)
)
BEGIN
	Declare JobType Integer Default 0;
	START TRANSACTION;
				INSERT INTO JobType (JT_Name 				,
														 JT_Description	,
													   JT_LifeTime		,
													   JT_NamingConvention
														)
									
										values (JTName_Val,
														JTDescription_Val,
														JTLifeTime_Val,
														JTNamingConvention_Val														
														);			
					
					SET JobType=Last_Insert_ID();	
				/* insert phase=0 in phase table indicating to Auto phase related to this job type*/
				
					INSERT INTO Phase (Phase_ID								,
													Phase_Name,
													 	 Phase_Sequence 				,
													   Phase_MaxPeriod				,
													   Phase_Description			,
													   Phase_XMLDescription		,
													   JT_ID
													 )
									
										values (0				,
													'Auto',
														0				,
														0				,
														'Auto'	,
														''		,
														JobType
														);			
														
					UPDATE Phase set Phase_ID=0 where (JT_ID=JobType) and (Phase_ID=Last_Insert_ID());
					
					/* insert phase=1 in phase table indicating to QuickBackup phase related to this job type*/
					
					INSERT INTO Phase (Phase_ID								,
													Phase_Name,
													 	 Phase_Sequence 				,
													   Phase_MaxPeriod				,
													   Phase_Description			,
													   Phase_XMLDescription		,
													   JT_ID
													 )
									
										values (1				,
													'Quick Backup'	,
														10000				,
														3				,
														'Quick Backup'	,
														'<Phase Name="QuickBackup"><PrePhase></PrePhase><PostPhase><ReflectionCall Method="org.bibalex.daf.reflectioncalls.BackupPhase.applyQuickBackupActions" /></PostPhase></Phase>'		,
														JobType
														);			
														
					UPDATE Phase set Phase_ID=1 where (JT_ID=JobType) and (Phase_ID=Last_Insert_ID());
					
					/* insert phase=2 in phase table indicating to Backup phase related to this job type*/
					
					INSERT INTO Phase (Phase_ID								,
													Phase_Name,
													 	 Phase_Sequence 				,
													   Phase_MaxPeriod				,
													   Phase_Description			,
													   Phase_XMLDescription		,
													   JT_ID
													 )
									
										values (2				,
													'Backup'	,
														10000				,
														3				,
														'Backup'	,
														'<Phase Name="Backup"><PrePhase></PrePhase><PostPhase><ReflectionCall Method="org.bibalex.daf.reflectioncalls.BackupPhase.applyBackupActions" /></PostPhase></Phase>'		,
														JobType
														);			
														
					UPDATE Phase set Phase_ID=2 where (JT_ID=JobType) and (Phase_ID=Last_Insert_ID());	
														
														
				SELECT * FROM JobType WHERE JT_ID=JobType;								
			COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`JobType_Delete`$$
CREATE  PROCEDURE  `DAF02`.`JobType_Delete`(
		PKJTID_Val		Integer
	)
BEGIN
	START TRANSACTION;
				DELETE FROM JobType	WHERE JT_ID=PKJTID_Val;
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`JobType_DeleteCascade`$$
CREATE  PROCEDURE  `DAF02`.`JobType_DeleteCascade`(
		PKJTID_Val		Integer
	)
BEGIN
	START TRANSACTION;
				
									
				DELETE FROM User_Phase
				WHERE	User_Phase.Phase_ID in (SELECT Phase.Phase_ID FROM Phase WHERE Phase.JT_ID=PKJTID_Val);
				
				DELETE FROM Workstation_Phase 
				WHERE	Workstation_Phase.Phase_ID in (SELECT Phase.Phase_ID FROM Phase WHERE Phase.JT_ID=PKJTID_Val);
				
				DELETE FROM Phase	WHERE JT_ID=PKJTID_Val;
				
				DELETE FROM JobType	WHERE JT_ID=PKJTID_Val;
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`JobType_deleteMediaType`$$
CREATE  PROCEDURE  `DAF02`.`JobType_deleteMediaType`(
		JTID_Val 					 Integer ,			
		MTID_Val			     Integer 	
	)
BEGIN
	START TRANSACTION;
	
			DELETE FROM JobType_MediaType	
			WHERE (JobType_MediaType.JT_ID=JTID_Val) 
		  	AND (JobType_MediaType.MT_ID=MTID_Val);
				
			SELECT JTID_Val,MTID_Val;
	
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`JobType_getAllPhases`$$
CREATE  PROCEDURE  `DAF02`.`JobType_getAllPhases`(
		PKJobType_Val		Integer
	)
BEGIN
	
		
	SELECT  Phase.Phase_ID,
					Phase.Phase_Sequence,
					Phase.Phase_MaxPeriod,
					Phase.Phase_Description,
					Phase.Phase_XMLDescription,
					Phase.JT_ID,
					Phase.Phase_Name
	FROM JobType
	INNER JOIN Phase
	ON Phase.JT_ID=JobType.JT_ID
	WHERE JobType.JT_ID=PKJobType_Val
	;
							

	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`JobType_getAllSeqPhases`$$
CREATE  PROCEDURE  `DAF02`.`JobType_getAllSeqPhases`(
		PKJobType_Val		Integer
	)
BEGIN
	
	
		
	SELECT  Phase.Phase_ID,
					Phase.Phase_Name,
					Phase.Phase_Sequence,
					Phase.Phase_MaxPeriod,
					Phase.Phase_Description,
					Phase.Phase_XMLDescription,
					Phase.JT_ID
					
	FROM Phase
	INNER JOIN JobType
	ON Phase.JT_ID=JobType.JT_ID
	WHERE (JobType.JT_ID=PKJobType_Val)
	AND (Phase.Phase_Sequence<>10000) 
	AND (Phase.Phase_ID<>0)
	
	order by Phase.Phase_Sequence 
	
	;
								
																

	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`JobType_getAvailablePhases`$$
CREATE  PROCEDURE  `DAF02`.`JobType_getAvailablePhases`(jobTypeVal Integer)
BEGIN
	
				SELECT  Phase.Phase_ID,
								Phase.Phase_Name,
								Phase.Phase_Sequence,
								Phase.Phase_MaxPeriod,
								Phase.Phase_Description,
								Phase.Phase_XMLDescription,
								Phase.JT_ID
				FROM Phase 
				WHERE 
				(Phase.JT_ID=jobTypeVal) 
				and (Phase.Phase_ID<>0) 
				and (Phase.Phase_Sequence=10000)
				order by Phase.Phase_Name	;

	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`JobType_getByID`$$
CREATE  PROCEDURE  `DAF02`.`JobType_getByID`(
		PKJTID_Val		Integer
	)
BEGIN
	
	SELECT * FROM JobType	WHERE JT_ID=PKJTID_Val;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`JobType_getFirstPhase`$$
CREATE  PROCEDURE  `DAF02`.`JobType_getFirstPhase`(
		PKJobType_Val		Integer
	)
BEGIN
	
	
		
	SELECT  Phase.Phase_ID,
					Phase.Phase_Name,
					Phase.Phase_Sequence,
					Phase.Phase_MaxPeriod,
					Phase.Phase_Description,
					Phase.Phase_XMLDescription,
					Phase.JT_ID
					
	FROM Phase
	WHERE (Phase.JT_ID=PKJobType_Val)
	AND (Phase.Phase_Sequence<>10000) 
	AND (Phase.Phase_ID<>0) 
	order by Phase.Phase_Sequence 
	limit 1
	
	;
								
																
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`JobType_getMediaTypes`$$
CREATE  PROCEDURE  `DAF02`.`JobType_getMediaTypes`(JTID Integer )
BEGIN
	
				
			SELECT  MediaType.MT_ID,
							MediaType.MT_Name,
							MediaType.MT_Size							
				FROM MediaType
				Inner Join JobType_MediaType 
				ON MediaType.MT_ID = JobType_MediaType.MT_ID
				WHERE (JobType_MediaType.JT_ID=JTID)
				 ;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`JobType_getNotAutoPhases`$$
CREATE  PROCEDURE  `DAF02`.`JobType_getNotAutoPhases`(
		JobType_Val		Integer
	)
BEGIN
	
	
		
	SELECT  Phase.Phase_ID,
					Phase.Phase_Sequence,
					Phase.Phase_MaxPeriod,
					Phase.Phase_Description,
					Phase.Phase_XMLDescription,
					Phase.JT_ID,
					Phase.Phase_Name
	FROM JobType
	INNER JOIN Phase
	ON Phase.JT_ID=JobType.JT_ID
	WHERE (JobType.JT_ID=JobType_Val)
	AND (Phase.Phase_ID>0)
	order by Phase.Phase_Sequence
	;
								

	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`JobType_loadAll`$$
CREATE  PROCEDURE  `DAF02`.`JobType_loadAll`()
BEGIN
	
	SELECT * FROM JobType
	WHERE JobType.JT_ID>0;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`JobType_Update`$$
CREATE  PROCEDURE  `DAF02`.`JobType_Update`(
		PKJTID_Val						Integer			 ,
		JTName_Val 						 nvarchar(50) ,			
		JTDescription_Val 		 Text				 ,
		JTLifeTime_Val 			   Integer		 ,
		JTNamingConvention_Val nvarchar(200)
)
BEGIN
	START TRANSACTION;
				UPDATE JobType  SET JT_ID=PKJTID_Val													,
														JT_Name= JTName_Val													,
													  JT_Description	=JTDescription_Val					,
													  JT_LifeTime=JTLifeTime_Val									,
													  JT_NamingConvention=JTNamingConvention_Val  
												
												WHERE JT_ID= PKJTID_Val;
								
				SELECT * FROM JobType WHERE JT_ID=PKJTID_Val;										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`JobType_updateMediaType`$$
CREATE  PROCEDURE  `DAF02`.`JobType_updateMediaType`(
		JTID_Val 					 Integer ,			
		MTID_Val			     Integer 
		)
BEGIN
	START TRANSACTION;
	
			DELETE FROM JobType_MediaType	
			WHERE (JobType_MediaType.JT_ID=JTID_Val) 
		  	AND (JobType_MediaType.MT_ID=MTID_Val);
				
			INSERT INTO JobType_MediaType (JT_ID,MT_ID)
														 VALUES (JTID_Val,MTID_Val);
			
			SELECT * FROM JobType_MediaType
			WHERE (JobType_MediaType.JT_ID=JTID_Val) 
		  	AND (JobType_MediaType.MT_ID=MTID_Val);
		
							
	
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`JobType_updateMediaTypes`$$
CREATE  PROCEDURE  `DAF02`.`JobType_updateMediaTypes`(
		JTID_Val 					 Integer ,			
		mediaTypesVal			 nvarchar(500),
		delimiterVal			 char(1)
	)
BEGIN
	START TRANSACTION;
			DELETE FROM JobType_MediaType	
			WHERE (JobType_MediaType.JT_ID=JTID_Val);
			
			CALL SplitIDs(mediaTypesVal,delimiterVal);
			INSERT INTO JobType_MediaType (JT_ID,MT_ID) 
  										( SELECT   JTID_Val,IDVal
												FROM SplittedTempTable
											);											
				
		Drop Temporary Table If Exists `SplittedTempTable`;
		
		SELECT * FROM JobType_MediaType 
		WHERE (JobType_MediaType.JT_ID=JTID_Val);
										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`JobType_updatePhasesSeq`$$
CREATE  PROCEDURE  `DAF02`.`JobType_updatePhasesSeq`(
		JTID_Val 					 Integer ,			
		phasesVal						 nvarchar(500),
		delimiterVal				 char(1)
	)
BEGIN
	Declare phaseID Integer Default 0;
	Declare totalCount Integer Default 0;
	Declare counter Integer Default 1;
	Declare cur Cursor FOR 
			SELECT IDVal
			FROM SplittedTempTable
			FOR UPDATE;

	START TRANSACTION;
			CALL SplitIDs(phasesVal,delimiterVal);
			
			SELECT count(IDVal) INTO totalCount
			FROM SplittedTempTable
			;
		
			UPDATE Phase Set Phase.Phase_Sequence=10000
			WHERE  (Phase.JT_ID=JTID_Val) AND (Phase.Phase_ID<>0) ;
			
			IF (totalCount>0) THEN
				OPEN cur;
				REPEAT
					FETCH cur INTO phaseID;
					
						UPDATE Phase Set Phase.Phase_Sequence=counter
						WHERE (Phase.Phase_ID=phaseID)
						AND (Phase.JT_ID=JTID_Val);
						
						SET counter = counter + 1;
			UNTIL  counter > totalCount
			END REPEAT;
			CLOSE cur;
			END IF;
			
			
				
						
		Drop Temporary Table If Exists `SplittedTempTable`;
		
		SELECT * FROM Phase 
		WHERE (Phase.JT_ID=JTID_Val);
										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Language_getByID`$$
CREATE  PROCEDURE  `DAF02`.`Language_getByID`(
		LangID_Val		Integer
	)
BEGIN
	
	SELECT * FROM Metadata.LanguageView	WHERE Metadata.LanguageView.Lang_ID=LangID_Val;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Language_loadAll`$$
CREATE  PROCEDURE  `DAF02`.`Language_loadAll`()
BEGIN
	
	SELECT * FROM Metadata.LanguageView;
	
	
END $$





DROP FUNCTION IF EXISTS `DAF02`.`MaxCheckedOut`$$
CREATE  FUNCTION  `DAF02`.`MaxCheckedOut`(JobTypeID_Val Integer
							) RETURNS int(11)
BEGIN
/* This function returns the last checked out entry for JobTypeID_Val
*/
  Declare Cnt Integer default -1;
	
	SELECT ifnull(max(TransactionLog.TL_ID),-1)
	into Cnt
	FROM TransactionLog
	WHERE 
	(TransactionLog.Job_ID=JobTypeID_Val)
	and (TransactionLog.JS_ID=7);
	
	RETURN (Cnt);
END;

 $$





DROP PROCEDURE IF EXISTS `DAF02`.`Media_BatchDeleteCascade`$$
CREATE  PROCEDURE  `DAF02`.`Media_BatchDeleteCascade`(
mediaIDsVal					 nvarchar(500),
delimiterVal				 char(1)
)
BEGIN
START TRANSACTION;	

	CALL SplitIDs(mediaIDsVal,delimiterVal);

  DELETE FROM Job_Media WHERE Job_Media.Media_ID in (
																											SELECT IDVal
																											FROM 
																											SplittedTempTable
																											);
																											
		DELETE FROM Media WHERE Media.Media_ID  in (
																								SELECT IDVal
																								FROM 
																								SplittedTempTable
																							);

	/*select dummy data*/
	SELECT * 	FROM Media ;
	
	
	Drop Temporary Table If Exists `SplittedTempTable`;

COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Media_CheckJobsInsertion`$$
CREATE  PROCEDURE  `DAF02`.`Media_CheckJobsInsertion`(
	mediaType integer, 
	TL_IDs_Val text,
	delimiterVal char(1)
	)
BEGIN
	/*check if TLID is recorded before with same type of Media or not
	* if result = no then insert it
	*/
	Declare recorded TinyInt(1) default 0;
	CALL SplitIDs(TL_IDs_Val,delimiterVal);
	
	SELECT if (Count(Media.Media_ID)>=1,1,0) into recorded
	FROM Media
	INNER Join Job_Media
	ON (Media.Media_ID=Job_Media.Media_ID)
	WHERE (Job_Media.TL_ID in ( 
				  									SELECT IDVal
														FROM 
														SplittedTempTable
														)
		and (Media.MT_ID=mediaType));
	
	Drop Temporary Table If Exists `SplittedTempTable`;
		
	IF ( recorded = 0 )THEN
		select 1;
	ELSE
		select -1;
	END IF;
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Media_CheckRecordExistance`$$
CREATE  PROCEDURE  `DAF02`.`Media_CheckRecordExistance`(mediaType integer, mediaID integer,TLID integer)
BEGIN
	Declare recorded TinyInt(1) default 0;
	
	/*check if TLID is recorded before with same type of MediaID or not
	* if result = no select 1 else select 0
	*/
		
	SELECT if (Count(Media.Media_ID)>=1,1,0) into recorded
	FROM Media
	INNER Join Job_Media
	ON (Media.Media_ID=Job_Media.Media_ID)
	WHERE (Job_Media.TL_ID=TLID)
		and (Media.MT_ID=mediaType);
	
	IF ( recorded <> 0 )THEN
		select 1;
	ELSE
		select -1;
	END IF;
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Media_ConfirmDeletion`$$
CREATE  PROCEDURE  `DAF02`.`Media_ConfirmDeletion`(
mediaIDsVal					 nvarchar(500),
delimiterVal				 char(1)
)
BEGIN
START TRANSACTION;	

	CALL SplitIDs(mediaIDsVal,delimiterVal);
	/*Media_DelConfirm =1 means media confirmed otherwise Media_DelConfirm=0*/
	Update Media set Media.Media_DelConfirm=1
							 WHERE Media.Media_ID in (
																				SELECT IDVal
																				FROM 
																				SplittedTempTable
																				);
	
	
	SELECT * 
	FROM Media 
	WHERE Media.Media_ID in (
														SELECT IDVal
														FROM 
														SplittedTempTable
													)
	;
	
	Drop Temporary Table If Exists `SplittedTempTable`;

COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Media_DeConfirmDeletion`$$
CREATE  PROCEDURE  `DAF02`.`Media_DeConfirmDeletion`(
mediaIDsVal					 nvarchar(500),
delimiterVal				 char(1)
)
BEGIN
START TRANSACTION;	

	CALL SplitIDs(mediaIDsVal,delimiterVal);
	/*Media_DelConfirm =1 means media confirmed otherwise Media_DelConfirm=0*/
	Update Media set Media.Media_DelConfirm=0
							 WHERE Media.Media_ID in (
																				SELECT IDVal
																				FROM 
																				SplittedTempTable
																				);
	
	
	SELECT * 
	FROM Media 
	WHERE Media.Media_ID in (
														SELECT IDVal
														FROM 
														SplittedTempTable
													)
	;
	
	Drop Temporary Table If Exists `SplittedTempTable`;

COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Media_DeleteCascade`$$
CREATE  PROCEDURE  `DAF02`.`Media_DeleteCascade`(MediaID  Integer)
BEGIN
	START TRANSACTION;
				
				DELETE FROM Job_Media WHERE Job_Media.Media_ID= MediaID;
				DELETE FROM Media WHERE Media.Media_ID=MediaID;
				
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Media_DeleteJob`$$
CREATE  PROCEDURE  `DAF02`.`Media_DeleteJob`(MediaID  Integer, TLID Integer)
BEGIN
	START TRANSACTION;
				
				DELETE FROM Job_Media
				WHERE(Job_Media.Media_ID= MediaID)
					AND(Job_Media.TL_ID=TLID);
				
				SELECT * FROM TransactionLog WHERE TransactionLog.TL_ID=TLID;
				
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Media_getAllNotConfirmed`$$
CREATE  PROCEDURE  `DAF02`.`Media_getAllNotConfirmed`()
BEGIN
DECLARE checkBoxGUI TinyInt(1) Default 0;

	
	/*Media_DelConfirm =1 means media confirmed otherwise Media_DelConfirm=0*/
	SELECT Media.Media_ID,
		   checkBoxGUI,
		   Media.Media_BarCode,
			User.User_Name,
			Workstation.Wrkst_Name
	FROM Media 
	inner join Workstation on Workstation.Wrkst_ID=Media.Wrkst_ID
	inner join User on User.User_ID=Media.user_ID
	WHERE Media.Media_DelConfirm=0
	;

	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Media_getByBarcode`$$
CREATE  PROCEDURE  `DAF02`.`Media_getByBarcode`(MediaBarcode_Val		varchar(50))
BEGIN
	
	SELECT * FROM Media	WHERE Media.Media_BarCode=MediaBarcode_Val;
				
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Media_getByID`$$
CREATE  PROCEDURE  `DAF02`.`Media_getByID`(MediaID_Val		Integer)
BEGIN
	
	SELECT * FROM Media	WHERE Media.Media_ID=MediaID_Val;
				

	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Media_getJobFolderNames`$$
CREATE  PROCEDURE  `DAF02`.`Media_getJobFolderNames`(mediaID_Val			Integer)
BEGIN
	
	

				SELECT Job_Media.TL_ID,
							 TransactionLog.Job_ID,
							 Metadata.JobView.Job_Title,
							 EXTRACTVALUE(TransactionLog.TL_Status_Data,'/Status/Backup/@Version') as  Version,
							 Concat(Job.Job_Path,'_v',EXTRACTVALUE(TransactionLog.TL_Status_Data,'/Status/Backup/@Version')) as FolderName
				FROM Job_Media
				INNER JOIN TransactionLog
				ON Job_Media.TL_ID=TransactionLog.TL_ID
				INNER JOIN Job
				ON TransactionLog.Job_ID=Job.Job_ID
				inner join Metadata.JobView 
				on Metadata.JobView.Job_ID=Job.Job_ID
				WHERE Job_Media.Media_ID=mediaID_Val
				ORDER BY Metadata.JobView.Job_Title,Version	;
				

END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Media_getJobs`$$
CREATE  PROCEDURE  `DAF02`.`Media_getJobs`(mediaID_Val		Integer)
BEGIN
	DECLARE checkBoxGUI TinyInt(1) Default 0;
	
	SELECT  distinct TransactionLog.Job_ID,
										checkBoxGUI,
									Metadata.JobView.Job_Title
	FROM Job_Media
	INNER JOIN TransactionLog
	ON Job_Media.TL_ID=TransactionLog.TL_ID
	INNER JOIN Job
	ON TransactionLog.Job_ID=Job.Job_ID
	inner join Metadata.JobView 
	on Metadata.JobView.Job_ID=Job.Job_ID
		
	WHERE Job_Media.Media_ID=mediaID_Val
	ORDER BY Metadata.JobView.Job_Title	;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Media_getNewItem`$$
CREATE  PROCEDURE  `DAF02`.`Media_getNewItem`(
MTID_Val						Integer,
Location 						varchar(50),
UserID							Integer,
WrkstID            Integer
)
BEGIN

Declare MediaFTP		varchar(100) default '' ;
Declare newBarcode	varchar(50) default '' ;
Declare oldBarcode  Integer default 0;

START TRANSACTION;
	
				/*If the media type were online storage (MTID=1) then the barcode will be the ftp path */
				IF (MTID_Val=1) THEN
					/*IF the last record barcode (ftp) is the same ftp path of the media type
					* then there is no need to get new instance of media type
					* else, create new instance of media type with the new ftp path as its barcode
					*/
									
					/*get media type ftp path*/
						SELECT Storage.Path
						INTO MediaFTP
						FROM Storage
						INNER JOIN MediaType
						ON MediaType.Storage_ID=Storage.Storage_ID
						WHERE MediaType.MT_ID=MTID_Val;
					
						/*check if MediaFTP already exist befire or not*/
						SELECT COUNT(*) INTO oldBarcode
						FROM Media 
						WHERE (Media.MT_ID=1)
							AND (Media.Media_BarCode=MediaFTP)
						FOR UPDATE;
					
						/*oldBarcode=0 means this barcodeis not existed*/
					IF (oldBarcode=0)THEN
							/*get new instance*/
							set newBarcode=MediaFTP;
							
							/*insert the media instance and set confirm media deletion=1.
							* setting confirmation field because the absence of human interaction, so the system
							* maintains the folder movement internally.
							* in case the folder were not mved successfully the databasse will roll back the record
							*/
							INSERT INTO Media (Media_BarCode,Media_Location,MT_ID,Media_DelConfirm,User_ID,Wrkst_ID)
									values(newBarcode,Location,MTID_Val,1,UserID,WrkstID);
		
																	
						END IF;
						
						
				/*if media type <>1*/					
				ELSE
					
					/*BarCode Format Will Be (MediaTypeAbb + 6 digit as ID)*/
						/*get the last barcode of this media type*/
					call Media_getNextBarcode(MTID_Val,newBarcode);
								
					/*insert the instance of media without setting the deletion confirmation*/	
						INSERT INTO Media (Media_BarCode,Media_Location,MT_ID,User_ID,Wrkst_ID)
									 values(newBarcode,Location,MTID_Val,UserID,WrkstID);
								
							
				END IF;/*if media type =1*/
			
				
							
		/*IF the value of newBarcode was set then insert new media instance*/		
		IF (LENGTH(newBarcode)<>0) THEN
			
			SELECT  Media.Media_ID,
							Media.Media_BarCode,
							Media.Media_Location,
							Media.MT_ID,
							Media.Media_DelConfirm,
							Media.Media_TimeStamp,
							Media.User_ID,
							Media.Wrkst_ID,
							MediaType.MT_Size	
			 FROM Media 
			 Inner Join MediaType 
			 On Media.MT_ID = MediaType.MT_ID
			 WHERE Media.Media_ID=Last_Insert_ID();
				
		ELSE
			
		/*if media type = 1 and newBarcode was not set then   
		 *get the last instance of the online media storage 
		*/
   SELECT Media.Media_ID,
					Media.Media_BarCode,
					Media.Media_Location,
					Media.MT_ID,
					Media.Media_DelConfirm,
					Media.Media_TimeStamp,
					Media.User_ID,
					Media.Wrkst_ID,
					MediaType.MT_Size					
		FROM Media 
		Inner Join MediaType 
		On Media.MT_ID = MediaType.MT_ID
		WHERE (Media.MT_ID=1) AND (Media.Media_BarCode=MediaFTP) LIMIT 1 ;
	
		END IF;
	
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Media_getNextBarcode`$$
CREATE  PROCEDURE  `DAF02`.`Media_getNextBarcode`(MTID_Val	 integer, OUT nextBarcode  varchar(50))
BEGIN
	Declare MT_abb varchar(4) default '';
	Declare NewID	integer(6) ZEROFILL default 0 ;

		/*Get last barcode value*/
		SELECT MediaType.MT_LastBarcode+1 , MediaType.MT_Abbreviation
		INTO NewID,MT_abb
		FROM MediaType
		WHERE MediaType.MT_ID=MTID_Val
		FOR UPDATE;
		
		/*update new barcode*/
		UPDATE MediaType set MediaType.MT_LastBarcode=NewID
		WHERE MediaType.MT_ID=MTID_Val;
		
		SET nextBarcode = concat(MT_abb,NewID);

END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Media_recordCheck`$$
CREATE  PROCEDURE  `DAF02`.`Media_recordCheck`(mediaID integer,jobID integer,version_Val integer)
BEGIN
	Declare oldNew integer default 0;
	
	SELECT Job.TL_ID 
	Into oldNew
	from Job 
	Where Job_ID=jobID;
	
	IF (oldNew=0)Then
		Select OldTransactionLog.OTL_ID
			From 	 OldTransactionLog	
			Where (OldTransactionLog.Phase_ID=1 Or OldTransactionLog.Phase_ID=2)
			And OldTransactionLog.JS_ID=2
			And OldTransactionLog.Job_ID=jobID
			And EXTRACTVALUE(OTL_Status_Data,'/Status/Backup/@Version')=version_Val;
	ELSE
		Select TransactionLog.TL_ID
			From 	 TransactionLog	
			Where (TransactionLog.Phase_ID=1 or TransactionLog.Phase_ID=2)
			And TransactionLog.JS_ID=2
			And TransactionLog.Job_ID=jobID
			And EXTRACTVALUE(TL_Status_Data,'/Status/Backup/@Version')=version_Val;
		END IF;

	
	
	END $$





DROP PROCEDURE IF EXISTS `DAF02`.`MediaType_Add`$$
CREATE  PROCEDURE  `DAF02`.`MediaType_Add`(
		MediaTypeName_Val 			 varchar(50) ,			
		MediaTypeSize_Val 			 Float,
		MediaTypeStorage_Val		 Integer,
		MediaTypeAbb_Val 			 varchar(4) ,
		MediaTypeBarcode_Val		 Integer
	)
BEGIN
	START TRANSACTION;
			/*
			* If storage ID <0 then don't insert storage ID.
			* this action taken with all medias except online media 
			*/
			
			IF (MediaTypeStorage_Val<0) THEN
			
				INSERT INTO MediaType (MT_Name 		,
																MT_Size ,
																MT_Abbreviation,
																MT_LastBarcode
																)
												values (MediaTypeName_Val,
																MediaTypeSize_Val,
																MediaTypeAbb_Val,
																MediaTypeBarcode_Val
															);			
			ELSE
				INSERT INTO MediaType (MT_Name 		,
																MT_Size,
																MT_Abbreviation,
																MT_LastBarcode,
																Storage_ID
																)
												values (MediaTypeName_Val,
																MediaTypeSize_Val,
																MediaTypeAbb_Val,
																MediaTypeBarcode_Val,
																MediaTypeStorage_Val
															);			
			END IF;
				
														
				SELECT * FROM MediaType WHERE MT_ID=Last_Insert_ID();									
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`MediaType_DeleteCascade`$$
CREATE  PROCEDURE  `DAF02`.`MediaType_DeleteCascade`(MediaTypID_Val  Integer)
BEGIN
	START TRANSACTION;
				
				DELETE FROM JobType_MediaType WHERE JobType_MediaType.MT_ID=MediaTypID_Val;
				DELETE FROM Workstation_MediaType WHERE Workstation_MediaType.MT_ID=MediaTypID_Val;
				DELETE FROM Job_Media WHERE Job_Media.Media_ID in (SELECT	Media_ID FROM Media
																													 WHERE Media.MT_ID=MediaTypID_Val
																													);
																													
				DELETE FROM Media WHERE Media.MT_ID=MediaTypID_Val;
				DELETE FROM MediaType WHERE MediaType.MT_ID=MediaTypID_Val;
   COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`MediaType_getCredentials`$$
CREATE  PROCEDURE  `DAF02`.`MediaType_getCredentials`(MTID Integer)
BEGIN
				
				SELECT Storage.Path,
							 Storage.UserName,
							 Storage.PassWord
				FROM Storage
				INNER JOIN MediaType
				ON Storage.Storage_ID=MediaType.Storage_ID
				WHERE MediaType.MT_ID=MTID
				;

	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`MediaType_getCredentialsByIP`$$
CREATE  PROCEDURE  `DAF02`.`MediaType_getCredentialsByIP`(IP_Val		varchar(100))
BEGIN
	
				SELECT Storage.UserName,
							 Storage.PassWord
				FROM Storage
				WHERE Storage.Path=IP_Val
				;

	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`MediaType_loadAll`$$
CREATE  PROCEDURE  `DAF02`.`MediaType_loadAll`()
BEGIN
			
	SELECT * FROM MediaType;

	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`MediaType_Update`$$
CREATE  PROCEDURE  `DAF02`.`MediaType_Update`(
		MediaTypID_Val  				 Integer,
		MediaTypeName_Val 			 varchar(50) ,			
		MediaTypeSize_Val 			 Float,
		MediaTypeStorage_Val		 Integer,
		MediaTypeAbb_Val 			 varchar(4),
		MediaTypeBarcode_Val		 Integer
	)
BEGIN
	START TRANSACTION;
		/*
			* If storage ID <0 then don't update storage ID.
			* this action taken with all medias except online media 
			*/
		IF (MediaTypeStorage_Val<0) THEN		
			
				UPDATE MediaType SET   MT_Name=MediaTypeName_Val,
														   MT_Size=MediaTypeSize_Val,
														   MT_Abbreviation=MediaTypeAbb_Val,
															 MT_LastBarcode=MediaTypeBarcode_Val
										 		 WHERE MT_ID=MediaTypID_Val;
		ELSE
			
			UPDATE MediaType SET   MT_Name=MediaTypeName_Val,
														 MT_Size=MediaTypeSize_Val,
														 MT_Abbreviation=MediaTypeAbb_Val,
														 MT_LastBarcode=MediaTypeBarcode_Val,
  													 Storage_ID=MediaTypeStorage_Val
											 WHERE MT_ID=MediaTypID_Val;
		END IF;
		
				SELECT * FROM MediaType WHERE MT_ID=MediaTypID_Val;										
	
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`OldTransLog_getByID`$$
CREATE  PROCEDURE  `DAF02`.`OldTransLog_getByID`( OTLID			Integer	)
BEGIN
	
		Select 	* 
		From OldTransactionLog
		WHERE OldTransactionLog.OTL_ID=OTLID;
			
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`OperatingSystem_Add`$$
CREATE  PROCEDURE  `DAF02`.`OperatingSystem_Add`(
		OSName_Val	nvarchar(50)
 )
BEGIN
	START TRANSACTION;
				INSERT INTO OperatingSystem (OS_Name) values (OSName_Val);			
				SELECT * FROM OperatingSystem WHERE OS_ID=Last_Insert_ID();										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`OperatingSystem_Delete`$$
CREATE  PROCEDURE  `DAF02`.`OperatingSystem_Delete`(
		PKOSID_Val		Integer
	)
BEGIN
	START TRANSACTION;
				DELETE FROM OperatingSystem	WHERE OS_ID=PKOSID_Val;
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`OperatingSystem_getByID`$$
CREATE  PROCEDURE  `DAF02`.`OperatingSystem_getByID`(
		PKOSID_Val		Integer
	)
BEGIN
	
	SELECT * FROM OperatingSystem	WHERE OS_ID=PKOSID_Val;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`OperatingSystem_loadAll`$$
CREATE  PROCEDURE  `DAF02`.`OperatingSystem_loadAll`()
BEGIN

	SELECT * FROM OperatingSystem ;

	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`OperatingSystem_Update`$$
CREATE  PROCEDURE  `DAF02`.`OperatingSystem_Update`(
		PKOSID_Val					   Integer      ,
		OSName_Val 					   nvarchar(50)  			
	)
BEGIN
	START TRANSACTION;
				UPDATE OperatingSystem  SET  OS_ID	=	PKOSID_Val		 ,
																 		 OS_Name	= OSName_Val		 
												
																WHERE OS_ID	=	PKOSID_Val;
								
				SELECT * FROM OperatingSystem WHERE OS_ID	=	PKOSID_Val;										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Owner_getByID`$$
CREATE  PROCEDURE  `DAF02`.`Owner_getByID`(
		ownerID_Val		Integer
	)
BEGIN
	
	SELECT  Metadata.OwnerView.Own_ID,
					Metadata.OwnerView.Own_Name,
					Metadata.OwnerView.Own_Abbreviation,
					Metadata.OwnerView.Own_Comment,
					Metadata.OwnerView.Own_TimeStamp
	FROM Metadata.OwnerView	WHERE Metadata.OwnerView.Own_ID=ownerID_Val;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Owner_loadAll`$$
CREATE  PROCEDURE  `DAF02`.`Owner_loadAll`()
BEGIN
	Select Own_ID,Own_Name,Own_Abbreviation,Own_Comment,Own_TimeStamp from Metadata.OwnerView;
	
END $$





DROP FUNCTION IF EXISTS `DAF02`.`PendingJobsAlotCnt`$$
CREATE  FUNCTION  `DAF02`.`PendingJobsAlotCnt`(
							JobTypeID_Val Integer,
							PhaseID_Val Integer
							) RETURNS int(11)
BEGIN
/* This function returns the number of Jobs visited Phase PhaseID_Val more than once
		and currently Pending in this Phase.
*/

  Declare Cnt Integer default 0;
	
	select count(JobPhaseVisitedTimes.Job_ID) into Cnt
	from JobPhaseVisitedTimes inner join TransactionLog on JobPhaseVisitedTimes.TL_ID = TransactionLog.TL_ID
														inner join Phase on TransactionLog.Phase_ID = Phase.Phase_ID
	where JobPhaseVisitedTimes.JT_ID = JobTypeID_Val
		and JobPhaseVisitedTimes.Phase_ID = PhaseID_Val
		and TransactionLog.JS_ID in (4,5,6) /*Currently Assigned, rejected and redirectedJobs*/
		and TransactionLog.Phase_ID = PhaseID_Val
		and Phase.JT_ID = JobTypeID_Val;
		
	RETURN (Cnt);
END;

 $$





DROP FUNCTION IF EXISTS `DAF02`.`PendingJobsCnt`$$
CREATE  FUNCTION  `DAF02`.`PendingJobsCnt`(
							JobTypeID_Val Integer,
							PhaseID_Val Integer
							) RETURNS int(11)
BEGIN
  Declare Cnt Integer default 0;
	
	select count(Job.Job_ID) into Cnt
	from Job inner join TransactionLog on (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
						inner join Phase on (Phase.Phase_ID = TransactionLog.Phase_ID and Phase.JT_ID=Job.JT_ID)
	where TransactionLog.JS_ID in (	6,	/*Assign*/
																	4,	/*Redirected*/
																	5)	/*Rejected*/
				and TransactionLog.Phase_ID = PhaseID_Val
				and Phase.JT_ID = JobTypeID_Val;
	RETURN (Cnt);
END;

 $$





DROP PROCEDURE IF EXISTS `DAF02`.`Permission_Add`$$
CREATE  PROCEDURE  `DAF02`.`Permission_Add`(
		PermDescription_Val	Text
 )
BEGIN
	START TRANSACTION;
				INSERT INTO Permission (Perm_Description) 
												values (PermDescription_Val);			
				SELECT * FROM Permission WHERE Perm_ID=Last_Insert_ID();										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Permission_Delete`$$
CREATE  PROCEDURE  `DAF02`.`Permission_Delete`(
		PKPermID_Val		Integer
	)
BEGIN
	START TRANSACTION;
				DELETE FROM Permission	WHERE Perm_ID=PKPermID_Val;
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Permission_getByID`$$
CREATE  PROCEDURE  `DAF02`.`Permission_getByID`(
		PKPermID_Val		Integer
	)
BEGIN
	
	SELECT * FROM Permission	WHERE Perm_ID=PKPermID_Val;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Permission_loadAll`$$
CREATE  PROCEDURE  `DAF02`.`Permission_loadAll`()
BEGIN
	
	SELECT * FROM Permission ;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Permission_Update`$$
CREATE  PROCEDURE  `DAF02`.`Permission_Update`(
		PKPermID_Val					   Integer      ,
		PermDescription_Val			 Text	
	)
BEGIN
	START TRANSACTION;
				UPDATE Permission  SET  Perm_ID			 =	PKPermID_Val	 ,
																Perm_Description = PermDescription_Val
												
													 WHERE  Perm_ID =	PKPermID_Val;
								
				SELECT * FROM Permission WHERE  Perm_ID = PKPermID_Val;										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Phase_Add`$$
CREATE  PROCEDURE  `DAF02`.`Phase_Add`(
		PhaseSequence_Val	 			Integer	,
		PhaseMaxPeriod_Val 			Integer	,
		PhaseDescription_Val 		Text		,
		PhaseName_Val 		nvarchar(50)		,
		PhaseXMLDescription_Val Text		,
		FKJTID_Val 							Integer
)
BEGIN
	START TRANSACTION;
				INSERT INTO Phase (Phase_Name,
													Phase_Sequence 				,
													 Phase_MaxPeriod				,
													 Phase_Description			,
													 Phase_XMLDescription		,
													 JT_ID
													 )
									
										values (PhaseName_Val,
														PhaseSequence_Val				,
														PhaseMaxPeriod_Val			,
														PhaseDescription_Val		,
														PhaseXMLDescription_Val	,
														FKJTID_Val
														);			
														
				SELECT * FROM Phase WHERE Phase_ID=Last_Insert_ID();										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Phase_Delete`$$
CREATE  PROCEDURE  `DAF02`.`Phase_Delete`(
		PKPhaseID_Val		Integer,
		JobType_Val		Integer
	)
BEGIN
	START TRANSACTION;
				DELETE FROM Phase	WHERE (Phase_ID=PKPhaseID_Val) AND (JT_ID=JobType_Val);
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Phase_DeleteCascade`$$
CREATE  PROCEDURE  `DAF02`.`Phase_DeleteCascade`(
		PKPhase_Val		Integer,
		JT_Val		Integer
	)
BEGIN
	START TRANSACTION;
				
				DELETE FROM Reason WHERE Reason.Phase_ID=PKPhase_Val;
				DELETE FROM User_Phase WHERE User_Phase.Phase_ID=PKPhase_Val;
				DELETE FROM Workstation_Phase WHERE Workstation_Phase.Phase_ID=PKPhase_Val;
				DELETE FROM Phase	WHERE Phase_ID= PKPhase_Val and (JT_ID=JT_Val);
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Phase_getAllUsers`$$
CREATE  PROCEDURE  `DAF02`.`Phase_getAllUsers`(
FKPhase_Val			Integer
)
BEGIN
/*Get all valid users related to this job
 * this result is just listing of valid users in this job
 * without specifying which phase of the job
*/
	
		
	
	SELECT distinct User.User_ID		,
				 User.User_Name			,
				 User.User_Password	,
				 User.User_AnyPhase	,
				 User.User_MaxJobs 	,
				 User.User_IsActive ,
				 User.Role_ID,
				 User.User_isLDAP
	FROM User
	where  (User.User_AnyPhase = 1 ) AND (User.User_IsActive = 1)
	
	UNION
	
	
	SELECT distinct User.User_ID		,
				 User.User_Name			,
				 User.User_Password	,
				 User.User_AnyPhase	,
				 User.User_MaxJobs 	,
				 User.User_IsActive ,
				 User.Role_ID,
				 User.User_isLDAP
	FROM User
	INNER JOIN User_Phase
	ON User.User_ID=User_Phase.User_ID
	WHERE (User_Phase.Phase_ID=FKPhase_Val)	AND (User.User_IsActive = 1)	
	
	ORDER BY User_Name
	
	;
	
	

	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Phase_getAutoPhase`$$
CREATE  PROCEDURE  `DAF02`.`Phase_getAutoPhase`(
PhaseSeq			Integer,
JobType				Integer,
OUT AutoPhase	Integer
)
BEGIN
	DECLARE Counter Integer Default 0;
	
	
				/* check at first the count of next phases in the sequence
					 * if count > 0 then proceed 
					 * Else return 0 which means this is the last phase
					*/
					SELECT COUNT(Phase_ID)
					INTO Counter
					FROM Phase
					WHERE (JT_ID=JobType)
						AND (Phase_Sequence > PhaseSeq)
						AND (Phase_Sequence <> 10000)
						;
						
					IF (Counter > 0 ) THEN
						/* Get the next phase  */
								SELECT Phase_ID
								INTO AutoPhase
								FROM Phase
								WHERE (JT_ID=JobType)
								  AND (Phase_Sequence > PhaseSeq)
								  AND (Phase_Sequence <> 10000)
								ORDER By Phase_Sequence
								LIMIT 1
								;
						
					ELSE 
						    SET AutoPhase=0;/* This is Last Phase*/
					END IF;
								
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Phase_getAutoPhaseValue`$$
CREATE  PROCEDURE  `DAF02`.`Phase_getAutoPhaseValue`(
FKJobID_Val					Integer,
OUT prelastPhaseID  Integer,
OUT prelastPhaseSeq Integer
)
BEGIN
	Declare lastPhase Integer Default 0;
	Declare AutoPhase Integer Default 0;
	Declare AutoPhaseSeq Integer Default 0;
	Declare laststate Integer Default 0;
	Declare JobType   Integer Default 0;
	Declare PhaseSeq  Integer Default 0;
 
		
	/* Get Job preLast status */
		SELECT TransactionLog.Phase_ID,TransactionLog.JS_ID
		INTO lastPhase,laststate
		FROM TransactionLog
		WHERE (TransactionLog.Job_ID=FKJobID_Val)
		AND (TransactionLog.JS_ID in (6,2)) /*  assigned or finished*/
		ORDER BY TransactionLog.TL_ID Desc
		LIMIT 1
		;
		
		/* Get Job Type */
		SELECT Job.JT_ID 
		INTO JobType
		FROM Job
		WHERE Job.Job_ID=FKJobID_Val
		;
		
		/* Get Phase Seq */
		SELECT Phase.Phase_Sequence
		INTO PhaseSeq
		FROM Phase
		WHERE (Phase.Phase_ID=lastPhase)
			AND (Phase.JT_ID=JobType)
		;
		
		IF (laststate=2) THEN /* finished*/
			
			CALL Phase_getAutoPhase(PhaseSeq,JobType,AutoPhase);
			SET prelastPhaseID=AutoPhase;
					
		ELSE
			SET prelastPhaseID=lastPhase;
						
		END IF;
		
				
		 SELECT Phase.Phase_Sequence
			INTO AutoPhaseSeq
			FROM Phase
			WHERE (Phase.Phase_ID=prelastPhaseID)
			AND (Phase.JT_ID=JobType)
			;
	
		SET prelastPhaseSeq=AutoPhaseSeq;
	

	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Phase_getByID`$$
CREATE  PROCEDURE  `DAF02`.`Phase_getByID`(
		PKPhaseID_Val		Integer,
		JobType_Val			Integer
	)
BEGIN
	
	SELECT * FROM Phase	WHERE (Phase_ID=PKPhaseID_Val) AND (JT_ID=JobType_Val);
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Phase_getByName`$$
CREATE  PROCEDURE  `DAF02`.`Phase_getByName`(PhaseName_Val		VARCHAR(50)	)
BEGIN
	
				SELECT Phase.Phase_ID, Phase.JT_ID FROM Phase	
				WHERE (lower(Phase.Phase_Name)= lower(PhaseName_Val))
				LIMIT 1;

	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Phase_getFinishedJobs`$$
CREATE  PROCEDURE  `DAF02`.`Phase_getFinishedJobs`(
JobType_Val		Integer,
PhaseID_Val		Integer,
CollID_Val		Integer,
BatchID_Val		Integer
)
BEGIN
		
	
		/*get the finished jobs for this phase*/
		/*test if the collection, batch filter are used or not
		* there are 4 combinations (2^2) 0 0 ,0 1 ,1 0 , 1 1 
		*/
		IF (CollID_Val>-1 AND BatchID_Val>-1) THEN
			/*first case: the 2 values <> any*/
			SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
								
							
			FROM Job
			INNER JOIN Job_Collection on (Job.Job_ID= Job_Collection.Job_ID and Job_Collection.Coll_ID=CollID_Val)
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
	
		
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID=2)
				AND (Job.Batch_ID=BatchID_Val);

		ELSEIF (CollID_Val>-1 AND BatchID_Val=-1) THEN
			/*second case: only batch value = any*/	
					SELECT  TransactionLog.Job_ID,
								 Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
								
							
			FROM Job
			INNER JOIN Job_Collection on (Job.Job_ID= Job_Collection.Job_ID and Job_Collection.Coll_ID=CollID_Val)
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
	
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID=2);
				

		ELSEIF (CollID_Val=-1 AND BatchID_Val>-1) THEN
			/*third case: only collection value = any*/
					SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
								
							
			FROM Job
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
	
	
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID=2)
				AND (Job.Batch_ID=BatchID_Val);

		ELSEIF (CollID_Val=-1 AND BatchID_Val=-1) THEN
			/*fourth case: both values = any*/
			SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
								
							
			FROM Job
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
	
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID=2);

		 END IF;
	
							
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Phase_getFinishedJobsMoreThanOnce`$$
CREATE  PROCEDURE  `DAF02`.`Phase_getFinishedJobsMoreThanOnce`(
JobType_Val		Integer,
PhaseID_Val		Integer,
CollID_Val		Integer,
BatchID_Val		Integer
)
BEGIN
		
	
			
		/*get the finished jobs for this phase*/
		/*test if the collection, batch filter are used or not
		* there are 4 combinations (2^2) 0 0 ,0 1 ,1 0 , 1 1 
		*/
		IF (CollID_Val>-1 AND BatchID_Val>-1) THEN
			/*first case: the 2 values <> any*/
			SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN Job_Collection on (Job.Job_ID= Job_Collection.Job_ID and Job_Collection.Coll_ID=CollID_Val)
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
	
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID=2)
				AND(RevisitingTimes(TransactionLog.Job_ID,PhaseID_Val,JobType_Val)>1)	
				AND (Job.Batch_ID=BatchID_Val);

		ELSEIF (CollID_Val>-1 AND BatchID_Val=-1) THEN
			/*second case: only batch value = any*/	
			SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN Job_Collection on (Job.Job_ID= Job_Collection.Job_ID and Job_Collection.Coll_ID=CollID_Val)
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
	
	
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID=2)
				AND(RevisitingTimes(TransactionLog.Job_ID,PhaseID_Val,JobType_Val)>1)	;

		ELSEIF (CollID_Val=-1 AND BatchID_Val>-1) THEN
			/*third case: only collection value = any*/
			SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
	
	
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID=2)
				AND(RevisitingTimes(TransactionLog.Job_ID,PhaseID_Val,JobType_Val)>1)	
				AND (Job.Batch_ID=BatchID_Val);

		ELSEIF (CollID_Val=-1 AND BatchID_Val=-1) THEN
			/*fourth case: both values = any*/
			SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
	
	
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID=2)
				AND(RevisitingTimes(TransactionLog.Job_ID,PhaseID_Val,JobType_Val)>1)		;

		 END IF;

	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Phase_getFinishedJobsOnce`$$
CREATE  PROCEDURE  `DAF02`.`Phase_getFinishedJobsOnce`(
JobType_Val		Integer,
PhaseID_Val		Integer,
CollID_Val		Integer,
BatchID_Val		Integer
)
BEGIN
		/*get the finished jobs for this phase*/
		/*test if the collection, batch filter are used or not
		* there are 4 combinations (2^2) 0 0 ,0 1 ,1 0 , 1 1 
		*/
		IF (CollID_Val>-1 AND BatchID_Val>-1) THEN
			/*first case: the 2 values <> any*/
			SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,							
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN Job_Collection on (Job.Job_ID= Job_Collection.Job_ID and Job_Collection.Coll_ID=CollID_Val)
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
	
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID=2)
			  AND(RevisitingTimes(TransactionLog.Job_ID,PhaseID_Val,JobType_Val)=1)
			  AND (Job.Batch_ID=BatchID_Val);

			
		ELSEIF (CollID_Val>-1 AND BatchID_Val=-1) THEN
			/*second case: only batch value = any*/	
				SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,							
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN Job_Collection on (Job.Job_ID= Job_Collection.Job_ID and Job_Collection.Coll_ID=CollID_Val)
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
	
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID=2)
			  AND(RevisitingTimes(TransactionLog.Job_ID,PhaseID_Val,JobType_Val)=1)	  ;

			
		ELSEIF (CollID_Val=-1 AND BatchID_Val>-1) THEN
			/*third case: only collection value = any*/
				SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,							
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
	
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID=2)
			  AND(RevisitingTimes(TransactionLog.Job_ID,PhaseID_Val,JobType_Val)=1)
			  AND (Job.Batch_ID=BatchID_Val);

			
		ELSEIF (CollID_Val=-1 AND BatchID_Val=-1) THEN
			/*fourth case: both values = any*/
			SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,							
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
	
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID=2)
			 AND(RevisitingTimes(TransactionLog.Job_ID,PhaseID_Val,JobType_Val)=1);

			
		 END IF;
					
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Phase_getLastUser`$$
CREATE  PROCEDURE  `DAF02`.`Phase_getLastUser`(
		JobID_Val 				Integer		,		
		PhaseID_Val				Integer,
		JSID_Val					Integer
)
BEGIN
						
				SELECT TransactionLog.User_ID
				FROM Job
				INNER JOIN Phase ON (Job.JT_ID =Phase.JT_ID)
				INNER JOIN TransactionLog ON (TransactionLog.Job_ID=Job.Job_ID and Job.TL_ID>0 and TransactionLog.Phase_ID=Phase.Phase_ID)
				WHERE TransactionLog.Phase_ID=PhaseID_Val and Job.Job_ID=JobID_Val and TransactionLog.JS_ID=JSID_Val
				ORDER BY TransactionLog.TL_ID DESC
				LIMIT 1;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Phase_getNext_PreAssigned_SeqPhaseUser`$$
CREATE  PROCEDURE  `DAF02`.`Phase_getNext_PreAssigned_SeqPhaseUser`(
	currJob 				Integer,
	currSeq 				Integer,
	currJobType 		Integer,
	OUT NextPhase1  Integer,
	OUT NextSeq1    Integer,
	OUT NextUser1    Integer,
	OUT NextTLrec		Integer
	)
BEGIN
Declare nextPhase 				Integer;
Declare nextUser 			  	Integer;
Declare User_Val 			  	Integer Default 0;
Declare nextTL 						Integer;
Declare TLrec_Val					Integer Default 0;
Declare nextSeq 					Integer;
Declare totalCount 				Integer Default 0;
Declare counter 					Integer Default 1;
Declare Min_Val 					Integer Default 0;
Declare ActualPhase 			Integer Default 0;
Declare done							Integer Default 0;
Declare cur Cursor FOR 
			SELECT Phase.Phase_ID,Phase.Phase_Sequence,TransactionLog.User_ID,TransactionLog.TL_ID
			FROM Phase
			INNER JOIN TransactionLog
			ON Phase.Phase_ID=TransactionLog.Phase_ID
			WHERE (TransactionLog.JS_ID=3)/*PreAssigned status=3*/
				 AND(TransactionLog.Job_ID=currJob)
				 AND (Phase.JT_ID=currJobType)
				 AND (Phase_Sequence>currSeq)
				 AND (Phase_Sequence<>10000)/*vaild phases not included*/
				ORDER BY TransactionLog.TL_ID Desc
				;
			   
					
START TRANSACTION;
		/* Get the result set count*/
		SELECT count(Phase.Phase_ID) INTO totalCount
		FROM Phase
		INNER JOIN TransactionLog
		ON Phase.Phase_ID=TransactionLog.Phase_ID
		WHERE (TransactionLog.JS_ID=3)/*PreAssigned status=3*/
		 	 AND(TransactionLog.Job_ID=currJob)
		   AND (Phase.JT_ID=currJobType)
			 AND (Phase_Sequence>currSeq)
			 AND (Phase_Sequence<>10000)
			;
						
		IF (totalCount<=0) THEN
				SET ActualPhase = 0;
				SET Min_Val  = 0;
				SET TLrec_Val= 0;
				SET User_Val = 0;
		ELSE
			/* find the minimum seq*/
			SET Min_Val=1000;
			OPEN cur;
			REPEAT
					FETCH cur INTO nextPhase, nextSeq,nextUser, nextTL;
						IF nextSeq < Min_Val Then
								SET Min_Val = nextSeq;
								SET ActualPhase=nextPhase;
								SET TLrec_Val=nextTL;
								SET User_Val = nextUser;
						END IF;
				
				SET counter = counter + 1;
			
			UNTIL  counter > totalCount
			END REPEAT;
			CLOSE cur;
		
		END IF;
		
			SET NextPhase1 = ActualPhase;	
			SET NextSeq1   = Min_Val;
			SET NextTLrec  = TLrec_Val;
			SET NextUser1  = User_Val;
		


	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Phase_getNextSeqPhase`$$
CREATE  PROCEDURE  `DAF02`.`Phase_getNextSeqPhase`(
	PhaseID					Integer,
	JobType 		Integer
	)
BEGIN
Declare phaseSeq Integer Default -1;

START TRANSACTION;
		/* Get the phase sequence*/
		SELECT Phase.Phase_Sequence
		INTO phaseSeq
		FROM Phase
		Where (Phase.JT_ID=JobType)
			 AND (Phase.Phase_ID=PhaseID)
		;
						
		/* Get the phase havingh sequence =  phaseSeq + 1*/
		
		IF (phaseSeq  <> -1) THEN
				
				SELECT  Phase.Phase_ID,
								Phase.Phase_Name,
								Phase.Phase_Sequence,
								Phase.Phase_MaxPeriod,
								Phase.Phase_Description,
								Phase.Phase_XMLDescription,
								Phase.JT_ID
				FROM Phase
				Where (Phase.JT_ID=JobType)
					AND (Phase.Phase_Sequence=phaseSeq+1);
			
			ELSE
			/*Select dummy data*/
			SELECT  Phase.Phase_ID,
								Phase.Phase_Name,
								Phase.Phase_Sequence,
								Phase.Phase_MaxPeriod,
								Phase.Phase_Description,
								Phase.Phase_XMLDescription,
								Phase.JT_ID
				FROM Phase
				Where (Phase.JT_ID=JobType)
					AND (Phase.Phase_Sequence=-1)	;
				
	END IF;


	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Phase_getPendingJobs`$$
CREATE  PROCEDURE  `DAF02`.`Phase_getPendingJobs`(
JobType_Val		Integer,
PhaseID_Val		Integer,
CollID_Val		Integer,
BatchID_Val		Integer
)
BEGIN
			
		/*get the pending jobs for this phase*/
		
		/*test if the collection, batch filter are used or not
		* there are 4 combinations (2^2) 0 0 ,0 1 ,1 0 , 1 1 
		*/
		IF (CollID_Val>-1 AND BatchID_Val>-1) THEN
			/*first case: the 2 values <> any*/
			SELECT  TransactionLog.Job_ID,
								 Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN Job_Collection on (Job.Job_ID= Job_Collection.Job_ID and Job_Collection.Coll_ID=CollID_Val)
				INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON ( TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
	
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID in (4,5,6))
				AND (Job.Batch_ID=BatchID_Val);
			
		ELSEIF (CollID_Val>-1 AND BatchID_Val=-1) THEN
			/*second case: only batch value = any*/	
			
			SELECT  TransactionLog.Job_ID,
								 Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN Job_Collection on (Job.Job_ID= Job_Collection.Job_ID and Job_Collection.Coll_ID=CollID_Val)
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON ( TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
	
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID in (4,5,6))				;
			
		ELSEIF (CollID_Val=-1 AND BatchID_Val>-1) THEN
			/*third case: only collection value = any*/
			
			SELECT  TransactionLog.Job_ID,
								 Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON ( TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
	
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID in (4,5,6))
				AND (Job.Batch_ID=BatchID_Val);
		ELSEIF (CollID_Val=-1 AND BatchID_Val=-1) THEN
			/*fourth case: both values = any*/
			
			SELECT  TransactionLog.Job_ID,
								 Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON ( TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
	
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID in (4,5,6))		;
		
	 END IF;

								
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Phase_getPendingJobsMoreThanOnce`$$
CREATE  PROCEDURE  `DAF02`.`Phase_getPendingJobsMoreThanOnce`(
JobType_Val		Integer,
PhaseID_Val		Integer,
CollID_Val		Integer,
BatchID_Val		Integer
)
BEGIN
			
		/*get the pending jobs for this phase*/
		 /*test if the collection, batch filter are used or not
		* there are 4 combinations (2^2) 0 0 ,0 1 ,1 0 , 1 1 
		*/
		IF (CollID_Val>-1 AND BatchID_Val>-1) THEN
			/*first case: the 2 values <> any*/
			SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN Job_Collection on (Job.Job_ID= Job_Collection.Job_ID and Job_Collection.Coll_ID=CollID_Val)
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID in (4,5,6))
				AND(RevisitingTimes(TransactionLog.Job_ID,PhaseID_Val,JobType_Val)>0)
				AND (Job.Batch_ID=BatchID_Val);
								
		ELSEIF (CollID_Val>-1 AND BatchID_Val=-1) THEN
			/*second case: only batch value = any*/	
			SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN Job_Collection on (Job.Job_ID= Job_Collection.Job_ID and Job_Collection.Coll_ID=CollID_Val)
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID in (4,5,6))
				AND(RevisitingTimes(TransactionLog.Job_ID,PhaseID_Val,JobType_Val)>0);
				
		ELSEIF (CollID_Val=-1 AND BatchID_Val>-1) THEN
			/*third case: only collection value = any*/
			SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID in (4,5,6))
				AND(RevisitingTimes(TransactionLog.Job_ID,PhaseID_Val,JobType_Val)>0)
				AND (Job.Batch_ID=BatchID_Val);
				
		ELSEIF (CollID_Val=-1 AND BatchID_Val=-1) THEN
			/*fourth case: both values = any*/
			SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID in (4,5,6))
				AND(RevisitingTimes(TransactionLog.Job_ID,PhaseID_Val,JobType_Val)>0);
		
		END IF;
		
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Phase_getPendingJobsOnce`$$
CREATE  PROCEDURE  `DAF02`.`Phase_getPendingJobsOnce`(
JobType_Val		Integer,
PhaseID_Val		Integer,
CollID_Val		Integer,
BatchID_Val		Integer
)
BEGIN
		

	 	/*get the pending jobs for this phase*/
		/*test if the collection, batch filter are used or not
		* there are 4 combinations (2^2) 0 0 ,0 1 ,1 0 , 1 1 
		*/
		IF (CollID_Val>-1 AND BatchID_Val>-1) THEN
			/*first case: the 2 values <> any*/
				SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN Job_Collection on (Job.Job_ID= Job_Collection.Job_ID and Job_Collection.Coll_ID=CollID_Val)
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID in (4,5,6))
				AND(RevisitingTimes(TransactionLog.Job_ID,PhaseID_Val,JobType_Val)=0)	
				AND (Job.Batch_ID=BatchID_Val);
				
		ELSEIF (CollID_Val>-1 AND BatchID_Val=-1) THEN
			/*second case: only batch value = any*/	
				SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN Job_Collection on (Job.Job_ID= Job_Collection.Job_ID and Job_Collection.Coll_ID=CollID_Val)
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID in (4,5,6))
				AND(RevisitingTimes(TransactionLog.Job_ID,PhaseID_Val,JobType_Val)=0);
				
		ELSEIF (CollID_Val=-1 AND BatchID_Val>-1) THEN
			/*third case: only collection value = any*/
				SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID in (4,5,6))
				AND(RevisitingTimes(TransactionLog.Job_ID,PhaseID_Val,JobType_Val)=0)	
				AND (Job.Batch_ID=BatchID_Val);
		
		ELSEIF (CollID_Val=-1 AND BatchID_Val=-1) THEN
			/*fourth case: both values = any*/
				SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID in (4,5,6))
				AND(RevisitingTimes(TransactionLog.Job_ID,PhaseID_Val,JobType_Val)=0)	;
		 END IF;
			
						
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Phase_getProcessingJobs`$$
CREATE  PROCEDURE  `DAF02`.`Phase_getProcessingJobs`(
JobType_Val		Integer,
PhaseID_Val		Integer,
CollID_Val		Integer,
BatchID_Val		Integer
)
BEGIN
			
		/*get the processing jobs for this phase*/
		/*test if the collection, batch filter are used or not
		* there are 4 combinations (2^2) 0 0 ,0 1 ,1 0 , 1 1 
		*/
		IF (CollID_Val>-1 AND BatchID_Val>-1) THEN
			/*first case: the 2 values <> any*/
			SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
							
			FROM Job
			INNER JOIN Job_Collection on (Job.Job_ID= Job_Collection.Job_ID and Job_Collection.Coll_ID=CollID_Val)
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID =1)
				AND (Job.Batch_ID=BatchID_Val);
				
		ELSEIF (CollID_Val>-1 AND BatchID_Val=-1) THEN
			/*second case: only batch value = any*/	
				SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
							
			FROM Job
			INNER JOIN Job_Collection on (Job.Job_ID= Job_Collection.Job_ID and Job_Collection.Coll_ID=CollID_Val)
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID =1)	;
				
		ELSEIF (CollID_Val=-1 AND BatchID_Val>-1) THEN
			/*third case: only collection value = any*/
			SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
							
			FROM Job
	  	INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID =1)
				AND (Job.Batch_ID=BatchID_Val);
				
		ELSEIF (CollID_Val=-1 AND BatchID_Val=-1) THEN
			/*fourth case: both values = any*/
			SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
							
			FROM Job
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID =1);
		
		END IF;
		
								
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Phase_getProcessingJobsMoreThanOnce`$$
CREATE  PROCEDURE  `DAF02`.`Phase_getProcessingJobsMoreThanOnce`(
JobType_Val		Integer,
PhaseID_Val		Integer,
CollID_Val		Integer,
BatchID_Val		Integer
)
BEGIN
					
		/*get the processing jobs for this phase*/
		/*test if the collection, batch filter are used or not
		* there are 4 combinations (2^2) 0 0 ,0 1 ,1 0 , 1 1 
		*/
		IF (CollID_Val>-1 AND BatchID_Val>-1) THEN
			/*first case: the 2 values <> any*/
				SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN Job_Collection on (Job.Job_ID= Job_Collection.Job_ID and Job_Collection.Coll_ID=CollID_Val)
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID =1)
			  AND(RevisitingTimes(TransactionLog.Job_ID,PhaseID_Val,JobType_Val)>0)
			  AND (Job.Batch_ID=BatchID_Val);
			

		ELSEIF (CollID_Val>-1 AND BatchID_Val=-1) THEN
			/*second case: only batch value = any*/	
				SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN Job_Collection on (Job.Job_ID= Job_Collection.Job_ID and Job_Collection.Coll_ID=CollID_Val)
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID =1)
			  AND(RevisitingTimes(TransactionLog.Job_ID,PhaseID_Val,JobType_Val)>0)	 ;
			

		ELSEIF (CollID_Val=-1 AND BatchID_Val>-1) THEN
			/*third case: only collection value = any*/
					SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID =1)
			  AND(RevisitingTimes(TransactionLog.Job_ID,PhaseID_Val,JobType_Val)>0)
			  AND (Job.Batch_ID=BatchID_Val);
			

		ELSEIF (CollID_Val=-1 AND BatchID_Val=-1) THEN
			/*fourth case: both values = any*/
				SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID =1)
			 AND(RevisitingTimes(TransactionLog.Job_ID,PhaseID_Val,JobType_Val)>0);
			

			
		 END IF;
		
								
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Phase_getProcessingJobsOnce`$$
CREATE  PROCEDURE  `DAF02`.`Phase_getProcessingJobsOnce`(
JobType_Val		Integer,
PhaseID_Val		Integer,
CollID_Val		Integer,
BatchID_Val		Integer
)
BEGIN
		

			
		/*get the processing jobs for this phase*/
		/*test if the collection, batch filter are used or not
		* there are 4 combinations (2^2) 0 0 ,0 1 ,1 0 , 1 1 
		*/
		IF (CollID_Val>-1 AND BatchID_Val>-1) THEN
			/*first case: the 2 values <> any*/
		SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN Job_Collection on (Job.Job_ID= Job_Collection.Job_ID and Job_Collection.Coll_ID=CollID_Val)
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID =1)
			  AND(RevisitingTimes(TransactionLog.Job_ID,PhaseID_Val,JobType_Val)=0)
				AND (Job.Batch_ID=BatchID_Val);
				
		ELSEIF (CollID_Val>-1 AND BatchID_Val=-1) THEN
			/*second case: only batch value = any*/	
			SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN Job_Collection on (Job.Job_ID= Job_Collection.Job_ID and Job_Collection.Coll_ID=CollID_Val)
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID =1)
			  AND(RevisitingTimes(TransactionLog.Job_ID,PhaseID_Val,JobType_Val)=0);
		
		ELSEIF (CollID_Val=-1 AND BatchID_Val>-1) THEN
			/*third case: only collection value = any*/
			SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID =1)
			  AND(RevisitingTimes(TransactionLog.Job_ID,PhaseID_Val,JobType_Val)=0)
				AND (Job.Batch_ID=BatchID_Val);
		
		ELSEIF (CollID_Val=-1 AND BatchID_Val=-1) THEN
			/*fourth case: both values = any*/
			SELECT  TransactionLog.Job_ID,
								Metadata.JobView.Job_Title,
								Job.Job_Path,
								JobStatus.JS_Name,
								User.User_Name,
								Phase.Phase_Name,
								Workstation.Wrkst_Name,
								Storage.Path,
								Job.Job_Priority,
								Job.Job_DueDate,
								TransactionLog.TL_Date	as tlDate		,
								TransactionLog.TL_NoOfFiles	,
								TransactionLog.TL_Status_Data,
								Metadata.ExternalID_TypeView.ExtIDType_Name
							
			FROM Job
			INNER JOIN TransactionLog
			ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
			INNER JOIN Phase
			ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
			INNER JOIN User
			ON TransactionLog.User_ID=User.User_ID
			INNER JOIN Workstation
			ON TransactionLog.Wrkst_ID=Workstation.Wrkst_ID
			INNER JOIN JobStatus
			ON TransactionLog.JS_ID =JobStatus.JS_ID
			INNER JOIN Storage
			ON Job.Storage_ID = Storage.Storage_ID
			INNER JOIN Metadata.JobView
			ON Metadata.JobView.Job_ID=Job.Job_ID
			LEFT OUTER JOIN Metadata.ExternalID_TypeView
			ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
			
			WHERE (TransactionLog.Phase_ID=PhaseID_Val)
				AND (Job.JT_ID=JobType_Val)
				AND (TransactionLog.JS_ID =1)
			  AND(RevisitingTimes(TransactionLog.Job_ID,PhaseID_Val,JobType_Val)=0);
		
		END IF;
		
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Phase_isLastPhase`$$
CREATE  PROCEDURE  `DAF02`.`Phase_isLastPhase`(
PhaseID_Val Integer,
JobTypeID_Val Integer
)
BEGIN
  Declare phaseSequence Integer Default -1;
  Declare maxSequence Integer Default -1;
	
  SELECT Phase_Sequence
  INTO phaseSequence
	FROM Phase
	WHERE Phase_ID = PhaseID_Val AND JT_ID = JobTypeID_Val;

  IF (phaseSequence = 10000) Then
    SELECT 1;
  ELSE
    SELECT MAX(Phase_Sequence)
    INTO maxSequence
    FROM Phase
    WHERE JT_ID = JobTypeID_Val AND Phase_Sequence <> 10000;

    IF (phaseSequence = maxSequence) THEN
      SELECT 1;
    ELSE
      SELECT 0;
    END IF;

  END IF;
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Phase_loadAll`$$
CREATE  PROCEDURE  `DAF02`.`Phase_loadAll`()
BEGIN
	
	SELECT * FROM Phase ;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Phase_loadAll_forJobType`$$
CREATE  PROCEDURE  `DAF02`.`Phase_loadAll_forJobType`(jobTypeVal Integer)
BEGIN
	
				SELECT *
				FROM Phase 
				WHERE 
				(Phase.JT_ID=jobTypeVal) 
				and (Phase.Phase_ID<>0) 
				order by Phase.Phase_Sequence	;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Phase_loadSpecial`$$
CREATE  PROCEDURE  `DAF02`.`Phase_loadSpecial`()
BEGIN
	
	SELECT  Phase.Phase_ID,
					if(Phase.Phase_ID<=2,Phase.Phase_Name,concat(JobType.JT_Name,":",Phase.Phase_Name)) ,
					if(Phase.Phase_ID<=2,-2,Phase.JT_ID)
					
	FROM Phase 
	INNER Join JobType on JobType.JT_ID=Phase.JT_ID
	 group by Phase.Phase_ID;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Phase_Update`$$
CREATE  PROCEDURE  `DAF02`.`Phase_Update`(
		PKPhaseID_Val				   Integer  ,
		PhaseSequence_Val	 			Integer	,
		PhaseMaxPeriod_Val 			Integer	,
		PhaseName_Val 		Text		,
		PhaseDescription_Val 		Text		,
		PhaseXMLDescription_Val Text		,
		FKJTID_Val 							Integer
)
BEGIN
	START TRANSACTION;
				UPDATE Phase  SET   Phase_ID						=	PKPhaseID_Val						,
									Phase_Name=PhaseName_Val,
														Phase_Sequence				= PhaseSequence_Val		  	,
													  Phase_MaxPeriod 			=	PhaseMaxPeriod_Val		  ,
													  Phase_Description 		=	PhaseDescription_Val  	,
													  Phase_XMLDescription 	= PhaseXMLDescription_Val ,
													  JT_ID							= FKJTID_Val
												
												WHERE (Phase_ID= PKPhaseID_Val) and (JT_ID=FKJTID_Val);
								
				SELECT * FROM Phase WHERE (Phase_ID= PKPhaseID_Val) and (JT_ID=FKJTID_Val);										
	COMMIT;
	
END $$





DROP FUNCTION IF EXISTS `DAF02`.`PreviousPhaseID`$$
CREATE  FUNCTION  `DAF02`.`PreviousPhaseID`(
							CurJobID_Val Integer,
							CurStatus_Val Integer
							) RETURNS int(11)
BEGIN
/*
This function is to get the pevious Phase of a Rejected Job
or Redirected Job 
*/
  Declare PhaseID integer default 0;
	
		IF (CurStatus_Val = 4) THEN
		/*It is a REDIRECTED Job and we need to get the last Finish*/

		Select Phase.Phase_ID into PhaseID
		From TransactionLog 
		INNER JOIN Job
		ON  TransactionLog.Job_ID=Job.Job_ID
		INNER	JOIN Phase 
		ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
		Where TransactionLog.Job_ID = CurJobID_Val
			and TransactionLog.JS_ID = 2 	/*Finished*/
		order by TransactionLog.TL_ID  desc
		limit 1;
		
	END IF;
	
	IF (CurStatus_Val = 5) THEN
		/*It is a REJECTED Job and we need to get the last Start*/
			Select Phase.Phase_ID into PhaseID
		From TransactionLog 
		INNER JOIN Job
		ON  TransactionLog.Job_ID=Job.Job_ID
		INNER	JOIN Phase 
		ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
		Where TransactionLog.Job_ID = CurJobID_Val
			and TransactionLog.JS_ID = 1 	/*Started*/
		order by TransactionLog.TL_ID  desc
		limit 1;
	END IF;
	RETURN PhaseID;
END;

 $$





DROP FUNCTION IF EXISTS `DAF02`.`PreviousPhaseName`$$
CREATE  FUNCTION  `DAF02`.`PreviousPhaseName`(
							CurJobID_Val Integer,
							CurStatus_Val Integer
							) RETURNS varchar(100) CHARSET latin1
BEGIN
/*
This function is to get the pevious Phase of a Rejected Job
or Redirected Job 
*/
  Declare PhaseName nvarchar (100);
	
		IF (CurStatus_Val = 4) THEN
		/*It is a REDIRECTED Job and we need to get the last Finish*/

		Select Phase.Phase_Name into PhaseName
		From TransactionLog 
		INNER JOIN Job
		ON  TransactionLog.Job_ID=Job.Job_ID
		INNER	JOIN Phase 
		ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
		Where TransactionLog.Job_ID = CurJobID_Val
			and TransactionLog.JS_ID = 2 	/*Finished*/
		order by TransactionLog.TL_ID desc
		limit 1;
		
	END IF;
	
	IF (CurStatus_Val = 5) THEN
		/*It is a REJECTED Job and we need to get the last Start*/
			Select Phase.Phase_Name into PhaseName
		From TransactionLog 
		INNER JOIN Job
		ON  TransactionLog.Job_ID=Job.Job_ID
		INNER	JOIN Phase 
		ON (TransactionLog.Phase_ID=Phase.Phase_ID and  Phase.JT_ID = Job.JT_ID)
		Where TransactionLog.Job_ID = CurJobID_Val
			and TransactionLog.JS_ID = 1 	/*Started*/
		order by TransactionLog.TL_ID desc
		limit 1;
	END IF;
	RETURN PhaseName;
END;

 $$





DROP FUNCTION IF EXISTS `DAF02`.`PreviousUserID`$$
CREATE  FUNCTION  `DAF02`.`PreviousUserID`(
							CurJobID_Val Integer,
							CurStatus_Val Integer
							) RETURNS int(11)
BEGIN
/*
This function is to get the pevious User of a Rejected Job
or Redirected Job 
*/

  Declare PUserID integer default 0;
	
		IF (CurStatus_Val = 4) THEN
		/*It is a REDIRECTED Job and we need to get the last Finish*/

		Select User.User_ID into PUserID
		From TransactionLog inner join User on TransactionLog.User_ID = User.User_ID					
		Where TransactionLog.Job_ID = CurJobID_Val
			and TransactionLog.JS_ID = 2 	/*Finished*/
		order by TransactionLog.TL_ID  desc
		limit 1;
		
	END IF;
	
	IF (CurStatus_Val = 5) THEN
		/*It is a REJECTED Job and we need to get the last Start*/
		Select  User.User_ID into PUserID
		From TransactionLog inner join User on TransactionLog.User_ID = User.User_ID
		Where TransactionLog.Job_ID = CurJobID_Val
			and TransactionLog.JS_ID = 1 	/*Started*/
		order by TransactionLog.TL_ID  desc
		limit 1;
			
	END IF;


	RETURN PUserID;
END;

 $$





DROP FUNCTION IF EXISTS `DAF02`.`PreviousUserName`$$
CREATE  FUNCTION  `DAF02`.`PreviousUserName`(
							CurJobID_Val Integer,
							CurStatus_Val Integer
							) RETURNS varchar(100) CHARSET latin1
BEGIN
/*
This function is to get the pevious User of a Rejected Job
or Redirected Job 
*/

  Declare PUserName nvarchar (100);
	
		IF (CurStatus_Val = 4) THEN
		/*It is a REDIRECTED Job and we need to get the last Finish*/

		Select User.User_Name into PUserName
		From TransactionLog inner join User on TransactionLog.User_ID = User.User_ID					
		Where TransactionLog.Job_ID = CurJobID_Val
			and TransactionLog.JS_ID = 2 	/*Finished*/
		order by TransactionLog.TL_ID  desc
		limit 1;
		
	END IF;
	
	IF (CurStatus_Val = 5) THEN
		/*It is a REJECTED Job and we need to get the last Start*/
		Select  User.User_Name into PUserName
		From TransactionLog inner join User on TransactionLog.User_ID = User.User_ID
		Where TransactionLog.Job_ID = CurJobID_Val
			and TransactionLog.JS_ID = 1 	/*Started*/
		order by TransactionLog.TL_ID  desc
		limit 1;
			
	END IF;


	RETURN PUserName;
END;

 $$





DROP FUNCTION IF EXISTS `DAF02`.`ProcessingJobsAlotCnt`$$
CREATE  FUNCTION  `DAF02`.`ProcessingJobsAlotCnt`(
							JobTypeID_Val Integer,
							PhaseID_Val Integer
							) RETURNS int(11)
BEGIN
/* This function returns the number of Job visited Phase PhaseID_Val more than once
		and currently Process in this Phase.
*/
  Declare Cnt Integer default 0;
	
	select count(JobPhaseVisitedTimes.Job_ID) into Cnt
	from JobPhaseVisitedTimes inner join TransactionLog on JobPhaseVisitedTimes.TL_ID = TransactionLog.TL_ID
														inner join Phase on TransactionLog.Phase_ID = Phase.Phase_ID 
	where JobPhaseVisitedTimes.JT_ID = JobTypeID_Val
		and JobPhaseVisitedTimes.Phase_ID = PhaseID_Val
		and TransactionLog.JS_ID = 1 /*Currently Started Jobs*/
		and TransactionLog.Phase_ID = PhaseID_Val
		and Phase.JT_ID = JobTypeID_Val;
		
	RETURN (Cnt);
END;

 $$





DROP FUNCTION IF EXISTS `DAF02`.`ProcessingJobsCnt`$$
CREATE  FUNCTION  `DAF02`.`ProcessingJobsCnt`(
							JobTypeID_Val Integer,
							PhaseID_Val Integer
							) RETURNS int(11)
BEGIN
  Declare Cnt Integer default 0;
	
	select count(Job.Job_ID) into Cnt
	from Job inner join TransactionLog on (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
						inner join Phase on (Phase.Phase_ID = TransactionLog.Phase_ID and Phase.JT_ID=Job.JT_ID)
	where TransactionLog.JS_ID =	1	/*Started*/
				and TransactionLog.Phase_ID = PhaseID_Val
				and Phase.JT_ID = JobTypeID_Val;
	RETURN (Cnt);
END;

 $$





DROP PROCEDURE IF EXISTS `DAF02`.`Project_getByID`$$
CREATE  PROCEDURE  `DAF02`.`Project_getByID`(
		PrjID_Val		Integer
	)
BEGIN
	
	SELECT  Metadata.ProjectView.Prj_ID,
					Metadata.ProjectView.Prj_Name,
					Metadata.ProjectView.Prj_Abbreviation,
					Metadata.ProjectView.Prj_Comment,
					Metadata.ProjectView.Prj_TimeStamp
	FROM Metadata.ProjectView	WHERE Metadata.ProjectView.Prj_ID=PrjID_Val;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Project_loadAll`$$
CREATE  PROCEDURE  `DAF02`.`Project_loadAll`()
BEGIN
	Select Prj_ID,Prj_Name,Prj_Abbreviation,Prj_Comment,Prj_TimeStamp from Metadata.ProjectView;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Reason_Add`$$
CREATE  PROCEDURE  `DAF02`.`Reason_Add`(
		ReasonName_Val 					nvarchar(50) ,			
		ReasonDesc_Val 					nvarchar(1000),
		PhaseID_Val			  			Integer	
		)
BEGIN
	START TRANSACTION;
				INSERT INTO Reason (Reason_Name,Reason_Description,Phase_ID)
										VALUES (ReasonName_Val,ReasonDesc_Val,PhaseID_Val);	
				SELECT *
				FROM Reason 
				WHERE Reason.Reason_ID=Last_Insert_ID();
				
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Reason_Delete`$$
CREATE  PROCEDURE  `DAF02`.`Reason_Delete`(ReasonID_Val		Integer)
BEGIN
	START TRANSACTION;
				DELETE FROM Reason WHERE Reason.Reason_ID=ReasonID_Val;
				SELECT * FROM Reason;
				
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Reason_getByID`$$
CREATE  PROCEDURE  `DAF02`.`Reason_getByID`(	ReasonID_Val		Integer)
BEGIN
	
				SELECT Reason.Reason_ID,
							 Reason.Reason_Name,
							 Reason.Reason_Description,
							 Reason.Phase_ID
				FROM Reason WHERE Reason.Reason_ID=ReasonID_Val;
																
		
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Reason_getByPhase`$$
CREATE  PROCEDURE  `DAF02`.`Reason_getByPhase`(
		PhaseID_Val		Integer
	)
BEGIN
	
				SELECT Reason_ID,
							 Reason_Name,
							 Reason_Description,
							 Phase_ID
				FROM Reason WHERE Phase_ID=PhaseID_Val;
																
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Reason_loadAll`$$
CREATE  PROCEDURE  `DAF02`.`Reason_loadAll`()
BEGIN
				
				SELECT *
				FROM Reason ;
				
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Reason_Update`$$
CREATE  PROCEDURE  `DAF02`.`Reason_Update`(
		ReasonID_Val			  		Integer,
		ReasonName_Val 					nvarchar(50) ,			
		ReasonDesc_Val 					nvarchar(1000)
		)
BEGIN
	START TRANSACTION;
				
				UPDATE Reason SET Reason_Name=ReasonName_Val,
													Reason_Description=ReasonDesc_Val
				WHERE Reason.Reason_ID=ReasonID_Val;
												
				SELECT *
				FROM Reason 
				WHERE Reason.Reason_ID=ReasonID_Val;
				
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Report_Add`$$
CREATE PROCEDURE `DAF02`.`Report_Add`(
		ReportName_Val 					 varchar(100) ,			
		ReportDate_Val 					 DateTime			,
		ReportDescription_Val 		 nvarchar(600),
		UserID_Val 						 	 Integer      ,
		ReportQuery_Val					text
)
BEGIN
	START TRANSACTION;
				INSERT INTO Reports (Report_Name 		,
													 Report_Date			,
													 Report_Description	,
													 User_ID			,
													 Report_Query
													 )
									
										values (ReportName_Val,
														ReportDate_Val,
														ReportDescription_Val,
														UserID_Val,
														ReportQuery_Val
														);			
														
				SELECT * FROM Reports WHERE Report_ID=Last_Insert_ID();										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Report_Delete`$$
CREATE  PROCEDURE  `DAF02`.`Report_Delete`(ReportID_Val  Integer )
BEGIN
	START TRANSACTION;
			DELETE  FROM Reports WHERE Report_ID=ReportID_Val;										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Report_ExecuteStmt`$$
CREATE  PROCEDURE  `DAF02`.`Report_ExecuteStmt`(ReportID Integer)
BEGIN
	START TRANSACTION;
		select @a:=Reports.Report_Query from Reports where Reports.Report_ID=ReportID;
		Prepare stmt from @a;
		execute stmt;
		DEALLOCATE PREPARE stmt;

	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Report_ExecuteStringStmt`$$
CREATE  PROCEDURE  `DAF02`.`Report_ExecuteStringStmt`(queryString nvarchar(1000))
BEGIN
	START TRANSACTION;
		select @a:=queryString;
		Prepare stmt from @a;
		execute stmt;
		DEALLOCATE PREPARE stmt;

	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Report_LoadAttrNames`$$
CREATE  PROCEDURE  `DAF02`.`Report_LoadAttrNames`(
		attributesVal						 nvarchar(500),
		delimiterVal				 char(1)
	)
BEGIN

				
			CALL SplitIDs(attributesVal,delimiterVal);
			SELECT Attributes.Attribute_Name 
			FROM 	Attributes
			WHERE Attributes.Attribute_ID in(SELECT * FROM SplittedTempTable);
		Drop Temporary Table If Exists `SplittedTempTable`;
		
										
		
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Reports_loadAll`$$
CREATE  PROCEDURE  `DAF02`.`Reports_loadAll`()
BEGIN

				SELECT Reports.Report_ID,
				Reports.Report_Name,
				User.User_Name ,
				Reports.Report_Date,
				Reports.Report_Description ,
				Reports.Report_Query
				
				FROM Reports 
				INNER JOIN User
				ON Reports.User_ID=User.User_ID;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Reports_loadAttributes`$$
CREATE  PROCEDURE  `DAF02`.`Reports_loadAttributes`()
BEGIN
	
				SELECT Attributes.Attribute_ID,
							Attributes.Attribute_Caption,
							Attributes.Attribute_Name
				from Attributes ORDER BY Attributes.Attribute_Caption;
	
	
END $$





DROP FUNCTION IF EXISTS `DAF02`.`retrieveJobComment`$$
CREATE  FUNCTION  `DAF02`.`retrieveJobComment`(selectedJob_ID integer,
																	 Jtype 					integer,
																	 selectedPhase_ID integer,
																	 js_ID 						integer,
																	 phaseName_Val varchar(100)
																		) RETURNS varchar(500) CHARSET latin1
BEGIN
  DECLARE autoPhase_Name Varchar(50) ;
	DECLARE phaseSeq Integer Default 0 ;
	DECLARE phaseComment Varchar(500) Default'';
	DECLARE phaseHistoryCount Integer Default 0 ;
	
							
								IF (js_ID=2) THEN
										/*for finished jobs get the next phase*/
										SELECT Phase.Phase_Sequence 
										INTO phaseSeq
										FROM Phase 
										WHERE (Phase.Phase_ID=selectedPhase_ID AND Phase.JT_ID=Jtype);
										
										CALL Phase_getAutoPhase(phaseSeq,Jtype,@AutoPhase);
									
										IF (@AutoPhase<>0) THEN
													-- get Auto Phase name
													SELECT Phase.Phase_Name 
													INTO autoPhase_Name
													FROM Phase
													WHERE (Phase.Phase_ID=@AutoPhase) AND (Phase.JT_ID=Jtype) ;
													
													SET phaseComment=concat('Next Phase is: ',autoPhase_Name,', and re-visited ');
																																				
													ELSE
													/*auto phase = 0*/
													SET phaseComment='No next phases';
										END IF;
										
								ELSEIF (js_ID=6) THEN
									/*assigned jobs*/
									SET phaseComment=concat('The assigned Phase is: ',phaseName_Val,' and re-visited ');
									
								
								END IF;/*finished*/
								
								
								IF ((js_ID=2 AND @AutoPhase<>0 ) OR (js_ID=6)) THEN
										SET phaseComment= concat(phaseComment,isReCount(selectedPhase_ID,selectedJob_ID,1),' time(s)');						
								END IF;

											 
				
	RETURN phaseComment;
END;

 $$





DROP FUNCTION IF EXISTS `DAF02`.`RevisitingTimes`$$
CREATE  FUNCTION  `DAF02`.`RevisitingTimes`(
							JobID_Val Integer,
							PhaseID_Val Integer,
							JobTypeID_Val Integer
							) RETURNS int(11)
BEGIN
/*
This function is to get the number of times that a Job visited a Phase 
*/

  Declare VisitCnt Integer default 0;
	
	
	select count(TransactionLog.TL_ID) into VisitCnt
	from TransactionLog /*inner join Phase on TransactionLog.Phase_ID = Phase.Phase_ID*/
	where 
		TransactionLog.Job_ID = JobID_Val
		and TransactionLog.Phase_ID = PhaseID_Val
		and TransactionLog.JS_ID =2;	/*Finished only, since a Job is considered visiting a Phase iff it is finished in it*/
		
		/*and Phase.JT_ID = JobTypeID_Val;*/
		
	RETURN VisitCnt;
	
END;

 $$





DROP PROCEDURE IF EXISTS `DAF02`.`Role_Add`$$
CREATE  PROCEDURE  `DAF02`.`Role_Add`(
		RoleDescription_Val   Text 			
	 )
BEGIN
	START TRANSACTION;
				INSERT INTO Role (Role_Description)
										values (RoleDescription_Val);			
														
				SELECT * FROM Role WHERE Role_ID=Last_Insert_ID();										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Role_Delete`$$
CREATE  PROCEDURE  `DAF02`.`Role_Delete`(
		PKRoleID_Val		Integer
	)
BEGIN
	START TRANSACTION;
		DELETE FROM Role	WHERE Role_ID=PKRoleID_Val;
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Role_DeleteCascade`$$
CREATE  PROCEDURE  `DAF02`.`Role_DeleteCascade`(
		PKRoleID_Val		Integer
	)
BEGIN
	Declare User_ID_Var Integer Default -1;
	START TRANSACTION;	
		Select User_ID Into User_ID_Var From User Where Role_ID = PKRoleID_Val Limit 1;
		If (User_ID_Var = -1)			
		Then
			DELETE FROM Role_Permission	
			WHERE Role_Permission.Role_ID = PKRoleID_Val;			
			DELETE FROM Role WHERE Role_ID = PKRoleID_Val;
		Else
			-- To throw the exception
			DELETE FROM Role WHERE Role_ID = PKRoleID_Val;
		END IF;
	COMMIT;
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Role_getByID`$$
CREATE  PROCEDURE  `DAF02`.`Role_getByID`(
		PKRoleID_Val		Integer
	)
BEGIN

		SELECT * FROM Role	WHERE Role_ID=PKRoleID_Val;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Role_getPermissions`$$
CREATE  PROCEDURE  `DAF02`.`Role_getPermissions`(
		PKRoleID_Val		Integer
	)
BEGIN
	
		
				SELECT Permission.Perm_ID,Permission.Perm_Description FROM Permission
				INNER JOIN Role_Permission
				ON Permission.Perm_ID= Role_Permission.Perm_ID
				WHERE Role_Permission.Role_ID=PKRoleID_Val;
								
																
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Role_getUsers`$$
CREATE  PROCEDURE  `DAF02`.`Role_getUsers`(
		RoleID_Val		Integer
	)
BEGIN
	
				
				SELECT User.User_ID		,
							 User_Name		,
							 User_Password,
							 User_AnyPhase,
							 User_MaxJobs ,
							 User_IsActive,
							 Role_ID,
							 User_isLDAP
				FROM User
				Where Role_ID = RoleID_Val;											

END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Role_loadAll`$$
CREATE  PROCEDURE  `DAF02`.`Role_loadAll`()
BEGIN

	SELECT * FROM Role ;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Role_Permission_Add`$$
CREATE  PROCEDURE  `DAF02`.`Role_Permission_Add`(
		RoleID_Val 					 Integer ,			
		PermID_Val 					 Integer			
	)
BEGIN
	START TRANSACTION;
				INSERT INTO Role_Permission (Role_ID 		,
													 					 Perm_ID
													 					)
									  				values (RoleID_Val	,
																		PermID_Val
																		);			
														
				SELECT * FROM Role_Permission 
				WHERE (Role_Permission.Role_ID=RoleID_Val)
					 AND(Role_Permission.Perm_ID=PermID_Val);										
COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Role_Permission_Delete`$$
CREATE  PROCEDURE  `DAF02`.`Role_Permission_Delete`(
		RoleID_Val 					 Integer ,			
		PermID_Val 					 Integer			
	)
BEGIN
	START TRANSACTION;
				DELETE FROM Role_Permission	
				WHERE (Role_Permission.Role_ID=RoleID_Val)
					AND (Role_Permission.Perm_ID=PermID_Val);
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Role_Permissions_DeleteRole`$$
CREATE  PROCEDURE  `DAF02`.`Role_Permissions_DeleteRole`(
		RoleID_Val 					 Integer 
		)
BEGIN
	START TRANSACTION;
				DELETE FROM Role_Permission	
				WHERE (Role_Permission.Role_ID=RoleID_Val);
					
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Role_Update`$$
CREATE  PROCEDURE  `DAF02`.`Role_Update`(
		PKRoleID_Val  				Integer,
		RoleDescription_Val   Text 	
)
BEGIN
	START TRANSACTION;
				UPDATE Role  SET  Role_ID				=	PKRoleID_Val				 ,
													Role_Description	= RoleDescription_Val	 
												
													WHERE Role_ID= PKRoleID_Val;
								
				SELECT * FROM Role WHERE Role_ID=PKRoleID_Val;										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Role_updatePermissions`$$
CREATE  PROCEDURE  `DAF02`.`Role_updatePermissions`(
		RoleID_Val 					 Integer ,			
		PermVals 						 nvarchar(500),
		delimiterVal				 char(1)
	)
BEGIN
	START TRANSACTION;
			CALL Role_Permissions_DeleteRole(RoleID_Val);
			CALL SplitIDs(PermVals,delimiterVal);
			INSERT INTO Role_Permission 
  										( SELECT   RoleID_Val,IDVal 
												FROM SplittedTempTable
											);											
				
		Drop Temporary Table If Exists `SplittedTempTable`;
		
		SELECT * FROM Role_Permission 
		WHERE (Role_Permission.Role_ID=RoleID_Val);
										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`SimpleSearch`$$
CREATE  PROCEDURE `DAF02`.`SimpleSearch`(
collID integer,
langID integer,
jobTypeID integer,
extTypeID integer,
jobID		integer,
jobExtID  nvarchar(200),
jobCreator  nvarchar(200),
jobTitle  nvarchar(500),
jobIDandOr nvarchar(10),
extIDandOr nvarchar(10),
craetorandOr nvarchar(10),
jobTypeandOr nvarchar(10),
collandOr nvarchar(10),
langandOr nvarchar(10),
extTypeandOr nvarchar(10),
OldOrNew		integer,
statusID	integer,
saveReport	integer,
selectStatement  nvarchar(2000)

)
BEGIN
Declare selectStmt nvarchar(500);
Declare FromStmt nvarchar(1000);
Declare WhereStmt nvarchar(2000) ;
Declare orderStmt nvarchar(100) ;

	-- initialize where clause	
	SET WhereStmt=' WHERE (1=1) ';
	 -- initialize select caluse
  if (saveReport=0) THEN
	SET selectStmt ='SELECT Job.Job_ID,Metadata.JobView.Job_Title,Metadata.JobView.Job_Creator,Metadata.JobView.Job_External_ID,Metadata.ExternalID_TypeView.ExtIDType_Name,Metadata.LanguageView.Lang_Name,Collection.Coll_Name,JobType.JT_Name,Job.TL_ID ';
	 -- initialize from clause
	SET FromStmt=' FROM Job inner join Metadata.JobView on Metadata.JobView.Job_ID=Job.Job_ID LEFT OUTER JOIN Metadata.ExternalID_TypeView ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID';
	SET FromStmt=concat(FromStmt,' INNER JOIN Batch ON Job.Batch_ID=Batch.Batch_ID INNER JOIN Collection ON Batch.Coll_ID=Collection.Coll_ID INNER JOIN Metadata.LanguageView ON Metadata.JobView.Lang_ID=Metadata.LanguageView.Lang_ID');
	SET FromStmt=concat(FromStmt,' INNER JOIN JobType ON Job.JT_ID=JobType.JT_ID ');

	ELSE 
	/*from report builder */
	set selectStmt=selectStatement;
		 -- initialize from clause
	SET FromStmt=' FROM Job inner join Metadata.JobView on Metadata.JobView.Job_ID=Job.Job_ID LEFT OUTER JOIN Metadata.ExternalID_TypeView ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID';
	SET FromStmt=concat(FromStmt,' INNER JOIN Batch ON Job.Batch_ID=Batch.Batch_ID INNER JOIN Collection ON Batch.Coll_ID=Collection.Coll_ID INNER JOIN Metadata.LanguageView ON Metadata.JobView.Lang_ID=Metadata.LanguageView.Lang_ID');
	SET FromStmt=concat(FromStmt,' INNER JOIN JobType ON Job.JT_ID=JobType.JT_ID ');
	SET FromStmt=concat(FromStmt,' inner join Metadata.InChargeView on Metadata.InChargeView.Icg_ID=Collection.Icg_ID ');
	SET FromStmt=concat(FromStmt,' inner join Metadata.OwnerView on Metadata.OwnerView.Own_ID=Collection.Own_ID ');
	SET FromStmt=concat(FromStmt,' inner join Metadata.ProjectView on Metadata.ProjectView.Prj_ID=Collection.Prj_ID ');
	SET FromStmt=concat(FromStmt,' inner join Storage on Storage.Storage_ID = Job.Storage_ID ');
		IF (OldOrNew=1 and statusID>-1 )THEN
			SET FromStmt=concat(FromStmt,' inner join TransactionLog on TransactionLog.TL_ID=Job.TL_ID and Job.TL_ID>0 and TransactionLog.JS_ID= ',statusID);
	
		END IF;

	END IF;
 	-- initialize from clause
	-- 0 old Job
	-- 1 new Job
	-- otherwise Any Job
	IF (OldOrNew=0)Then
	-- old
		SET WhereStmt=' where Job.TL_ID=0 ' ;
	ELSEIF (OldOrNew=1) THEN
	-- new
		SET WhereStmt=' where Job.TL_ID>0 ' ;
	
	ELSE
	-- Any
	SET WhereStmt=' where (1=1) ' ;
	END IF;
		

-- set where clause (independent of New or Old job)
IF (Length(jobTitle)>0) Then
	SET WhereStmt = concat(WhereStmt,' AND  Metadata.JobView.Job_Title like ("%',jobTitle,'%")');
END IF;

IF (collID>-1) Then
	SET WhereStmt = concat(WhereStmt,' ',collandOr,' Collection.Coll_ID = ',collID);
END IF;

IF (langID>-1) Then
	SET WhereStmt = concat(WhereStmt,' ',langandOr,' Metadata.LanguageView.Lang_ID = ',langID);
END IF;

IF (jobTypeID>-1) Then
	SET WhereStmt = concat(WhereStmt,' ',jobTypeandOr,' JobType.JT_ID = ',jobTypeID);
END IF;

IF (extTypeID>-1) Then
	SET WhereStmt = concat(WhereStmt,' ',extTypeandOr,' Metadata.ExternalID_TypeView.ExtIDType_ID = ',extTypeID);
END IF;

IF (jobID>-1) Then
	SET WhereStmt = concat(WhereStmt,' ',jobIDandOr,' Job.Job_ID = ',jobID);
END IF;

IF (Length(jobExtID)>0) Then
	SET WhereStmt = concat(WhereStmt,' ',extIDandOr,'  Metadata.JobView.Job_External_ID = ("',jobExtID,'")');
END IF;

IF (Length(jobCreator)>0) Then
	SET WhereStmt = concat(WhereStmt,' ',craetorandOr,'  Metadata.JobView.Job_Creator like ("%',jobCreator,'%")');
END IF;

set orderStmt=' Order by Job.Job_ID ';
select @a:=concat(selectStmt,FromStmt,WhereStmt,orderStmt);
if (saveReport=0) THEN
-- execute the query
Prepare stmt from @a;
execute stmt;
DEALLOCATE PREPARE stmt;
END IF;
	
	

END $$





DROP PROCEDURE IF EXISTS `DAF02`.`SplitIDs`$$
CREATE  PROCEDURE  `DAF02`.`SplitIDs`(in stringToSplit text,in delimiter char(1))
BEGIN

DECLARE ResponseLength INT;
DECLARE ResponseStart INT;
DECLARE Marker INT;
DECLARE Previous INT;

CREATE Temporary TABLE if not exists `SplittedTempTable` (
  `IDVal` int(11) unsigned NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

SET ResponseLength = LENGTH(stringToSplit);
SET Marker = 0;
SET ResponseStart = LOCATE(delimiter, stringToSplit, ResponseStart);
SET Marker = ResponseStart;
SET Previous = 1;
SET ResponseStart = ResponseStart + 1;

IF (ResponseLength > 0)	Then
	WHILE (ResponseStart < ResponseLength) DO
		IF((ResponseStart = LOCATE(delimiter, stringToSplit, ResponseStart))!=0) Then
			Set Marker = ResponseStart;
			Insert into SplittedTempTable VALUES (CAST(SUBSTRING(stringToSplit,Previous,Marker-Previous) as UNSIGNED));
			Set Previous = ResponseStart+1;
		END IF;
		Set ResponseStart = ResponseStart + 1;
	END WHILE;
	Insert into SplittedTempTable VALUES (CAST(SUBSTRING(stringToSplit,Previous,ResponseStart-Marker) as UNSIGNED));
END IF;
/*Select * from SplittedTempTable;*/

/*Drop Temporary Table If Exists `SplittedTempTable`;*/

END $$





DROP PROCEDURE IF EXISTS `DAF02`.`SplitIDsForOTL`$$
CREATE  PROCEDURE  `DAF02`.`SplitIDsForOTL`(in stringToSplit text,in delimiter char(1))
BEGIN

DECLARE ResponseLength INT;
DECLARE ResponseStart INT;
DECLARE Marker INT;
DECLARE Previous INT;

CREATE Temporary TABLE if not exists `SplittedTempTableOTL` (
  `IDVal` int(11) unsigned NOT NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

SET ResponseLength = LENGTH(stringToSplit);
SET Marker = 0;
SET ResponseStart = LOCATE(delimiter, stringToSplit, ResponseStart);
SET Marker = ResponseStart;
SET Previous = 1;
SET ResponseStart = ResponseStart + 1;

IF (ResponseLength > 0)	Then
	WHILE (ResponseStart < ResponseLength) DO
		IF((ResponseStart = LOCATE(delimiter, stringToSplit, ResponseStart))!=0) Then
			Set Marker = ResponseStart;
			Insert into SplittedTempTableOTL VALUES (CAST(SUBSTRING(stringToSplit,Previous,Marker-Previous) as UNSIGNED));
			Set Previous = ResponseStart+1;
		END IF;
		Set ResponseStart = ResponseStart + 1;
	END WHILE;
	Insert into SplittedTempTableOTL VALUES (CAST(SUBSTRING(stringToSplit,Previous,ResponseStart-Marker) as UNSIGNED));
END IF;
/*Select * from SplittedTempTableOTL;*/

/*Drop Temporary Table If Exists `SplittedTempTableOTL`;*/

END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Storage_Add`$$
CREATE  PROCEDURE  `DAF02`.`Storage_Add`(
		Path_Val 					    varchar(100) ,			
		UserName_Val 					varchar(50) ,			
		PassWord_Val					varchar(50)
)
BEGIN
	START TRANSACTION;
				INSERT INTO Storage (Path 		,
													   UserName	,
													   PassWord
													 )
									
										values (Path_Val,
														UserName_Val,
														PassWord_Val
														);			
														
				SELECT * FROM Storage WHERE Storage_ID=Last_Insert_ID();										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Storage_Delete`$$
CREATE  PROCEDURE  `DAF02`.`Storage_Delete`(
		StorageID_Val		Integer
	)
BEGIN
	START TRANSACTION;
				DELETE FROM Storage	WHERE Storage.Storage_ID=StorageID_Val;
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Storage_getByID`$$
CREATE  PROCEDURE  `DAF02`.`Storage_getByID`(
		StorageID_Val		Integer
	)
BEGIN
	
				SELECT * FROM Storage	WHERE Storage.Storage_ID=StorageID_Val;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Storage_loadAll`$$
CREATE  PROCEDURE  `DAF02`.`Storage_loadAll`()
BEGIN
	
		SELECT * FROM Storage;
										
		
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Storage_Update`$$
CREATE  PROCEDURE  `DAF02`.`Storage_Update`(
		StorageID_Val					integer,
		Path_Val 					    varchar(100) ,			
		UserName_Val 					varchar(50) ,			
		PassWord_Val					varchar(50)
)
BEGIN
	START TRANSACTION;
				update Storage set Path =Path_Val	,
													 UserName=UserName_Val	,
													 PassWord=PassWord_Val
				where Storage.Storage_ID=	StorageID_Val	;						 
									
				SELECT * FROM Storage WHERE Storage_ID=StorageID_Val;										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`TransLog_AddWithoutCommit`$$
CREATE  PROCEDURE  `DAF02`.`TransLog_AddWithoutCommit`(
		FKJobID_Val 				Integer		,			
		FKPhaseID_Val 		  Integer		,
		FKUserID_Val 			  Integer	  ,
		FKWrkstID_Val 			Integer		,
		FKJSID_Val					Integer		,
		TLDate_Val					DateTime	,
		TLNoOfFiles_Val 		Integer		,
		TLStatusData_Val		Text				
		
)
BEGIN
	
				INSERT INTO TransactionLog (Job_ID			,
																		Phase_ID		,
																	  User_ID		,
																		Wrkst_ID		,
																		JS_ID			,
																		TL_Date				,
																		TL_NoOfFiles	,
																		TL_Status_Data																			
																 	  )
				
											 			values  (FKJobID_Val	  ,
																 		 FKPhaseID_Val	,
																 		 FKUserID_Val		,
																     FKWrkstID_Val	,
																 		 FKJSID_Val			,
																 		 TLDate_Val			,
																  	 TLNoOfFiles_Val,
																 		 TLStatusData_Val				
																		 );
																			
							
												
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`TransLog_AddWithoutCommitWithSelect`$$
CREATE  PROCEDURE  `DAF02`.`TransLog_AddWithoutCommitWithSelect`(
		FKJobID_Val 				Integer		,			
		FKPhaseID_Val 		  Integer		,
		FKUserID_Val 			  Integer	  ,
		FKWrkstID_Val 			Integer		,
		FKJSID_Val					Integer		,
		TLDate_Val					DateTime	,
		TLNoOfFiles_Val 		Integer		,
		TLStatusData_Val		Text				
		
)
BEGIN
	
				INSERT INTO TransactionLog (Job_ID			,
																		Phase_ID		,
																	  User_ID		,
																		Wrkst_ID		,
																		JS_ID			,
																		TL_Date				,
																		TL_NoOfFiles	,
																		TL_Status_Data																			
																 	  )
				
											 			values  (FKJobID_Val	  ,
																 		 FKPhaseID_Val	,
																 		 FKUserID_Val		,
																     FKWrkstID_Val	,
																 		 FKJSID_Val			,
																 		 TLDate_Val			,
																  	 TLNoOfFiles_Val,
																 		 TLStatusData_Val				
																		 );
				SELECT * FROM TransactionLog WHERE TransactionLog.TL_ID= Last_Insert_ID();
							
												
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`TransLog_getByID`$$
CREATE  PROCEDURE  `DAF02`.`TransLog_getByID`( TLID	Integer	)
BEGIN

		
	SELECT 	TransactionLog.TL_ID,
					TransactionLog.Job_ID,
					TransactionLog.Phase_ID,
					TransactionLog.User_ID,
					TransactionLog.Wrkst_ID,
					TransactionLog.JS_ID,
					TransactionLog.TL_Date,
					TransactionLog.TL_NoOfFiles,
					TransactionLog.TL_Status_Data,
					User.User_Name,
					Phase.Phase_Name,
					JobStatus.JS_Name
	FROM Phase
	INNER JOIN TransactionLog
	ON Phase.Phase_ID=TransactionLog.Phase_ID
	INNER JOIN JobStatus
	ON JobStatus.JS_ID=TransactionLog.JS_ID
	INNER JOIN User
	ON User.User_ID=TransactionLog.User_ID
	WHERE TransactionLog.TL_ID=TLID;

	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`TransLog_UpdateWithoutCommit`$$
CREATE  PROCEDURE  `DAF02`.`TransLog_UpdateWithoutCommit`(
		PKTLID_Val					Integer   ,			
		FKJobID_Val 				Integer		,			
		FKPhaseID_Val 		  Integer		,
		FKUserID_Val 			  Integer	  ,
		FKWrkstID_Val 			Integer		,
		FKJSID_Val					Integer		,
		TLDate_Val					DateTime	,
		TLNoOfFiles_Val 		Integer		,
		TLStatusData_Val		Text				
		
)
BEGIN
	
				UPDATE  TransactionLog SET Job_ID	 =FKJobID_Val					,
																		Phase_ID=FKPhaseID_Val				,
																	  User_ID =FKUserID_Val					,
																		Wrkst_ID=FKWrkstID_Val			,
																		JS_ID	 =FKJSID_Val						,
																		TL_Date		 =TLDate_Val						,
																		TL_NoOfFiles	=TLNoOfFiles_Val	,
																		TL_Status_Data=TLStatusData_Val																			
																 	 
				WHERE TL_ID=PKTLID_Val;
																			
							
												
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_Add`$$
CREATE  PROCEDURE  `DAF02`.`User_Add`(
		UserName_Val   					nvarchar(50)	,
		UserPassword_Val 				nvarchar(50)	,
		UserAnyPhase_Val 				TinyInt(1)	,
		UserMaxJobs_Val 				Integer			,
		UserIsActive_Val				TinyInt(1)	,
		FKRoleID_Val						Integer	,			
		UserIsLDAP				TinyInt(1)	
		
	 )
BEGIN
	START TRANSACTION;
				INSERT INTO User (User_Name				,
													User_Password		,
													User_AnyPhase		,
													User_MaxJobs		,
													User_IsActive		,
													Role_ID,
													User_isLDAP									
								   			  )
									values (UserName_Val		 ,
													UserPassword_Val ,
													UserAnyPhase_Val ,
													UserMaxJobs_Val	 ,
													UserIsActive_Val ,
													FKRoleID_Val								,
													UserIsLDAP
													);			
														
				SELECT * FROM User WHERE User_ID=Last_Insert_ID();										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_DBAuthenticate`$$
CREATE  PROCEDURE  `DAF02`.`User_DBAuthenticate`(
		UserName_Val		 nvarchar(50),
		UserPassword_Val nvarchar(50)
		)
BEGIN
	Declare userCount Integer Default 0 ;
	
				SELECT COUNT(User_ID) into userCount FROM User	
				WHERE (User_Name= UserName_Val)
					and (User_Password=UserPassword_Val);
				
				IF (userCount > 0) THEN
					Select 1;
				ELSE
					Select 0;
				END IF;
					
		
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_Delete`$$
CREATE  PROCEDURE  `DAF02`.`User_Delete`(
		PKUserID_Val		Integer
	)
BEGIN
	START TRANSACTION;
				DELETE FROM User	WHERE User_ID= PKUserID_Val;
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_DeleteCascade`$$
CREATE  PROCEDURE  `DAF02`.`User_DeleteCascade`(
		PKUserID_Val		Integer
	)
BEGIN
	START TRANSACTION;
				
				DELETE FROM User_Collection WHERE User_Collection.User_ID=PKUserID_Val;
				DELETE FROM User_Phase WHERE User_Phase.User_ID=PKUserID_Val;
				DELETE FROM User	WHERE User_ID= PKUserID_Val;
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_getAnyPhaseUsers`$$
CREATE  PROCEDURE  `DAF02`.`User_getAnyPhaseUsers`()
BEGIN

 SELECT * FROM User	WHERE User.User_AnyPhase=1	;

	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_getAssignedJobs`$$
CREATE  PROCEDURE  `DAF02`.`User_getAssignedJobs`(
		FKUserID_Val 			  Integer	 
		)
BEGIN
		START TRANSACTION;
	
	CALL User_prepareAssignedJobs(FKUserID_Val);
		
	SELECT TransactionLog.TL_ID		,
				 TransactionLog.Job_ID		,
				 TransactionLog.JS_ID				,
				 TransactionLog.Phase_ID		,
			   Metadata.JobView.Job_Title							,
				 Phase.Phase_Name						,	
				 JobStatus.JS_Name					,
				 TransactionLog.TL_Date			,
				 TransactionLog.TL_NoOfFiles,
				 TransactionLog.TL_Status_Data
			   
	FROM TransactionLog
	INNER JOIN Job
	ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
	INNER JOIN Phase
	ON (TransactionLog.Phase_ID = Phase.Phase_ID  and  Phase.JT_ID = Job.JT_ID)
	INNER JOIN JobStatus
	ON TransactionLog.JS_ID = JobStatus.JS_ID
	INNER JOIN Metadata.JobView
	ON Metadata.JobView.Job_ID=Job.Job_ID
	
	WHERE (TransactionLog.User_ID=FKUserID_Val)
		AND (TransactionLog.JS_ID=6) AND (TransactionLog.Phase_ID<>0)
		ORDER BY Job.Job_Priority DESC, TransactionLog.TL_Date DESC
	;
	
COMMIT;									
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_getByID`$$
CREATE  PROCEDURE  `DAF02`.`User_getByID`(
		PKUserID_Val		Integer
	)
BEGIN

	SELECT * FROM User	WHERE User_ID= PKUserID_Val;

	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_getByName`$$
CREATE  PROCEDURE  `DAF02`.`User_getByName`(
		UserName_Val		nvarchar(50)
	)
BEGIN
	
	SELECT * FROM User	WHERE User_Name= UserName_Val;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_getCollections`$$
CREATE  PROCEDURE  `DAF02`.`User_getCollections`(
		UserID_Val		 	Integer
		)
BEGIN
	
			SELECT  Collection.Coll_ID           ,
							Collection.Coll_Name	          ,
							Collection.Coll_Abbreviation		  ,
							Collection.Coll_DefaultPath	  	,
							Collection.Coll_Priority				,
							Collection.Coll_AnyUser			  	,
							Collection.Coll_AnyWorkstation	,
							Collection.Coll_Active					,
							Collection.Coll_Comment			  	,
							Collection.Own_ID,
							Collection.Prj_ID,
							Collection.Icg_ID
							
				FROM Collection
				INNER JOIN User_Collection
				ON Collection.Coll_ID= User_Collection.Coll_ID
				WHERE (User_Collection.User_ID=UserID_Val)
				;
				

	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_getHistory`$$
CREATE  PROCEDURE  `DAF02`.`User_getHistory`(
		FKUserID_Val		Integer
	)
BEGIN

		SELECT * FROM TransactionLog	WHERE User_ID= FKUserID_Val;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_getPermissions`$$
CREATE  PROCEDURE  `DAF02`.`User_getPermissions`(
		PKUserID_Val		Integer
	)
BEGIN

	Select Perm_ID, GetPermissionTree(Perm_ID) as Perm_Description from User 
	Inner Join Role On User.Role_ID = Role.Role_ID 
	Inner Join Role_Permission on Role_Permission.Role_ID = Role.Role_ID
	Where User.User_ID = PKUserID_Val;
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_getPhases`$$
CREATE  PROCEDURE  `DAF02`.`User_getPhases`(
		UserID_Val		 	Integer
		)
BEGIN
	Declare anyPhase Integer Default 0;
	START TRANSACTION;
			
			SELECT User.User_AnyPhase
			INTO anyPhase
			FROM User
			WHERE User.User_ID=UserID_Val;
	
		IF (anyPhase=0) THEN
			SELECT  Phase.Phase_ID			,
							Phase.Phase_Sequence 	,
							Phase_MaxPeriod				,
							Phase_Description			,
							Phase_XMLDescription	,
							JT_ID,
							Phase_Name
							
				FROM Phase
				INNER JOIN User_Phase
				ON Phase.Phase_ID= User_Phase.Phase_ID
				WHERE (User_Phase.User_ID=UserID_Val) 
				;
			
			ELSE
				SELECT  Phase.Phase_ID			,
							Phase.Phase_Sequence 	,
							Phase_MaxPeriod				,
							Phase_Description			,
							Phase_XMLDescription	,
							JT_ID,
							Phase_Name
							
				FROM Phase
				where (Phase.Phase_ID<>0) ;
			
			
		END IF;
				
					
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_getPhasesSpecial`$$
CREATE  PROCEDURE  `DAF02`.`User_getPhasesSpecial`(
		UserID_Val		 	Integer
		)
BEGIN
	Declare anyPhase Integer Default 0;
	START TRANSACTION;
			
			SELECT User.User_AnyPhase
			INTO anyPhase
			FROM User
			WHERE User.User_ID=UserID_Val;
	
		IF (anyPhase=0) THEN
			SELECT  Phase.Phase_ID			,
							Phase.Phase_Sequence 	,
							Phase_MaxPeriod				,
							Phase_Description			,
							Phase_XMLDescription	,
							Phase.JT_ID,
							concat(JobType.JT_Name,":",Phase.Phase_Name)
							
				FROM JobType
				INNER JOIN Phase
				On Phase.JT_ID=JobType.JT_ID
				INNER JOIN User_Phase
				ON Phase.Phase_ID= User_Phase.Phase_ID
				WHERE (User_Phase.User_ID=UserID_Val) 
				;
			
			ELSE
				SELECT  Phase.Phase_ID			,
							Phase.Phase_Sequence 	,
							Phase_MaxPeriod				,
							Phase_Description			,
							Phase_XMLDescription	,
							Phase.JT_ID,
							concat(JobType.JT_Name,":",Phase.Phase_Name)
							
				FROM Phase
				INNER JOIN JobType
				On Phase.JT_ID=JobType.JT_ID
				where (Phase.Phase_ID<>0) ;
			
			
		END IF;
				
					
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_getRateAllJobs`$$
CREATE  PROCEDURE  `DAF02`.`User_getRateAllJobs`(
JobType_Val					Integer,
userID_Val					Integer,
fromDate 						DateTime,
toDate							DateTime
)
begin
		
		-- All Done for the User
		select PhaseID, sum(TLID),Phase.Phase_Sequence
		from
		((
		select TransactionLog.Phase_ID as PhaseID ,count(TransactionLog.TL_ID) as TLID
		from TransactionLog 
		where TransactionLog.JS_ID = 2
		and TransactionLog.User_ID = userID_Val
		and TransactionLog.TL_Date >= fromDate
		and TransactionLog.TL_Date < toDate
		group by PhaseID
		)
		union
		
		(
		select OldTransactionLog.Phase_ID as PhaseID ,count(OldTransactionLog.OTL_ID) as TLID
		from OldTransactionLog 
		where OldTransactionLog.JS_ID = 2
		and OldTransactionLog.User_ID = userID_Val
		and OldTransactionLog.OTL_Date >= fromDate
		and OldTransactionLog.OTL_Date < toDate
		group by PhaseID
		)) AllLog inner join Phase on AllLog.PhaseID = Phase.Phase_ID
		where Phase.JT_ID = JobType_Val
		group by Phase.Phase_Name
		order by Phase.Phase_Sequence;

end $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_getRateJobs`$$
CREATE  PROCEDURE  `DAF02`.`User_getRateJobs`(
JobType_Val					Integer,
phaseID_Val					Integer,
userID_Val					Integer,
fromDate 						DateTime,
toDate							DateTime,
bookLevel						Integer
)
BEGIN

					IF (bookLevel=1) THEN
									(	SELECT Job.Job_ID,	Metadata.JobView.Job_Title,max(TransactionLog.TL_NoOfFiles) as filesNum,	TransactionLog.TL_Date as TransactionDate,count(TransactionLog.TL_ID) as jobCount
									FROM Job
									INNER JOIN TransactionLog
									ON Job.Job_ID=TransactionLog.Job_ID
									INNER JOIN Phase
									ON (Phase.Phase_ID=TransactionLog.Phase_ID and Phase.JT_ID=Job.JT_ID)
									INNER JOIN Metadata.JobView
									ON Metadata.JobView.Job_ID=Job.Job_ID
		
									WHERE (TransactionLog.JS_ID=2 ) 
										AND (TransactionLog.User_ID =userID_Val)
										AND (TransactionLog.Phase_ID = phaseID_Val)
										AND (Job.JT_ID=JobType_Val) 
									and TransactionLog.TL_Date >= fromDate
									and TransactionLog.TL_Date < toDate
										group by Job.Job_ID ,TransactionLog.Phase_ID,TransactionLog.User_ID
									
									)
						UNION	
									( SELECT Job.Job_ID,	Metadata.JobView.Job_Title,max(OldTransactionLog.OTL_NoOfFiles) as filesNum,OldTransactionLog.OTL_Date as TransactionDate ,count(OldTransactionLog.OTL_ID) as jobCount
										FROM Job
										INNER JOIN OldTransactionLog
										ON Job.Job_ID=OldTransactionLog.Job_ID
										INNER JOIN Phase
										ON (Phase.Phase_ID=OldTransactionLog.Phase_ID and Phase.JT_ID=Job.JT_ID)
										INNER JOIN Metadata.JobView
										ON Metadata.JobView.Job_ID=Job.Job_ID
												WHERE (OldTransactionLog.JS_ID=2 ) 
											AND (OldTransactionLog.User_ID =userID_Val)
											AND (OldTransactionLog.Phase_ID = phaseID_Val)
											AND (Job.JT_ID=JobType_Val) 
										and OldTransactionLog.OTL_Date >= fromDate
										and OldTransactionLog.OTL_Date < toDate
											group by Job.Job_ID,OldTransactionLog.Phase_ID,OldTransactionLog.User_ID
							
									) 
							
			
							order by 	TransactionDate;
					
					ELSE
										(	SELECT Job.Job_ID,	Metadata.JobView.Job_Title,max(TransactionLog.TL_NoOfFiles) as filesNum,	TransactionLog.TL_Date as TransactionDate,count(TransactionLog.TL_ID) as jobCount
										FROM Job
										INNER JOIN TransactionLog
										ON Job.Job_ID=TransactionLog.Job_ID
										INNER JOIN Phase
										ON (Phase.Phase_ID=TransactionLog.Phase_ID and Phase.JT_ID=Job.JT_ID)
									  INNER JOIN Metadata.JobView
										ON Metadata.JobView.Job_ID=Job.Job_ID
										WHERE (TransactionLog.JS_ID=2 ) 
											AND (TransactionLog.User_ID =userID_Val)
											AND (TransactionLog.Phase_ID = phaseID_Val)
											AND (Job.JT_ID=JobType_Val) 
											group by Job.Job_ID,TransactionLog.Phase_ID,TransactionLog.User_ID
											Having if((min(TransactionLog.TL_Date)>=fromDate AND min(TransactionLog.TL_Date)<=toDate),True,False) 
										)
							UNION	
										( SELECT Job.Job_ID,	Metadata.JobView.Job_Title,max(OldTransactionLog.OTL_NoOfFiles) as filesNum,OldTransactionLog.OTL_Date as TransactionDate ,count(OldTransactionLog.OTL_ID) as jobCount
											FROM Job
											INNER JOIN OldTransactionLog
											ON Job.Job_ID=OldTransactionLog.Job_ID
											INNER JOIN Phase
											ON (Phase.Phase_ID=OldTransactionLog.Phase_ID and Phase.JT_ID=Job.JT_ID)
											INNER JOIN Metadata.JobView
									  	ON Metadata.JobView.Job_ID=Job.Job_ID
													WHERE (OldTransactionLog.JS_ID=2 ) 
												AND (OldTransactionLog.User_ID =userID_Val)
												AND (OldTransactionLog.Phase_ID = phaseID_Val)
												AND (Job.JT_ID=JobType_Val) 
														group by Job.Job_ID,OldTransactionLog.Phase_ID,OldTransactionLog.User_ID
												Having if((min(OldTransactionLog.OTL_Date)>=fromDate AND min(OldTransactionLog.OTL_Date)<=toDate),True,False) 
										) 
								
					
								order by 	TransactionDate;
				
					END IF;
				
	

	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_getRateReDoJobs`$$
CREATE  PROCEDURE  `DAF02`.`User_getRateReDoJobs`(
JobType_Val					Integer,
userID_Val					Integer,
fromDate 						DateTime,
toDate							DateTime
)
begin
				select PhaseID, sum(JobCnt), Phase.Phase_Sequence
				from
				(select count(T1.TL_ID) as JobCnt, T1.Phase_ID as PhaseID
				from TransactionLog T1 
				where T1.JS_ID = 2
				and T1.TL_Date >= fromDate
				and T1.TL_Date < toDate
				and T1.User_ID = userID_Val
				and ((T1.User_ID <> (select TransactionLog.User_ID
														from TransactionLog
														where TransactionLog.TL_ID = (select max(TransactionLog.TL_ID)
															from TransactionLog
															where TransactionLog.JS_ID = 2
															and TransactionLog.Job_ID = T1.Job_ID
															and TransactionLog.Phase_ID = T1.Phase_ID
															)
														) -- LASTUSER
				
				and (select count(TransactionLog.TL_ID)
					from TransactionLog
					where TransactionLog.Job_ID = T1.Job_ID
					and TransactionLog.Phase_ID = T1.Phase_ID
					and TransactionLog.JS_ID = 2
					) > 1)
				or ((select count(TransactionLog.TL_ID)
					from TransactionLog
					where TransactionLog.Job_ID = T1.Job_ID
					and TransactionLog.Phase_ID = T1.Phase_ID
					and TransactionLog.JS_ID = 2
					and TransactionLog.User_ID = T1.User_ID
					) > 1
					and T1.TL_ID <> (	-- Do not count first time with the user
														select min(TransactionLog.TL_ID)
														from TransactionLog
														where TransactionLog.JS_ID = 2
														and TransactionLog.Job_ID = T1.Job_ID
														and TransactionLog.Phase_ID = T1.Phase_ID
														and TransactionLog.User_ID = T1.User_ID
					)
					))
				group by PhaseID
				union
				(
				select count(T1.OTL_ID) as JobCnt, T1.Phase_ID as PhaseID
				from OldTransactionLog T1 
				where T1.JS_ID = 2
				and T1.OTL_Date >= fromDate
				and T1.OTL_Date < toDate
				and T1.User_ID = userID_Val
				and ((T1.User_ID <> (select OldTransactionLog.User_ID
														from OldTransactionLog
														where OldTransactionLog.OTL_ID = (select max(OldTransactionLog.OTL_ID)
															from OldTransactionLog
															where OldTransactionLog.JS_ID = 2
															and OldTransactionLog.Job_ID = T1.Job_ID
															and OldTransactionLog.Phase_ID = T1.Phase_ID
															)
														) -- LASTUSER
				
				and (select count(OldTransactionLog.OTL_ID)
					from OldTransactionLog
					where OldTransactionLog.Job_ID = T1.Job_ID
					and OldTransactionLog.Phase_ID = T1.Phase_ID
					and OldTransactionLog.JS_ID = 2
					) > 1)
				or ((select count(OldTransactionLog.OTL_ID)
					from OldTransactionLog
					where OldTransactionLog.Job_ID = T1.Job_ID
					and OldTransactionLog.Phase_ID = T1.Phase_ID
					and OldTransactionLog.JS_ID = 2
					and OldTransactionLog.User_ID = T1.User_ID
					) > 1
					and T1.OTL_ID <> (	-- Do not count first time with the user
														select min(OldTransactionLog.OTL_ID)
														from OldTransactionLog
														where OldTransactionLog.JS_ID = 2
														and OldTransactionLog.Job_ID = T1.Job_ID
														and OldTransactionLog.Phase_ID = T1.Phase_ID
														and OldTransactionLog.User_ID = T1.User_ID
					)
					))
				group by PhaseID
				)) AllLog inner join Phase on Phase.Phase_ID = PhaseID
				where Phase.JT_ID = JobType_Val
				group by Phase.Phase_Name
				order by Phase.Phase_Sequence;

end $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_getRole`$$
CREATE  PROCEDURE  `DAF02`.`User_getRole`(
		UserID_Val		 	Integer
		)
BEGIN

			SELECT User.Role_ID,
							Role.Role_Description
						
				FROM Role
				INNER JOIN User
				ON User.Role_ID= Role.Role_ID
				WHERE (User.User_ID=UserID_Val)
				;
				
				
					

	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_getStartedJobs`$$
CREATE  PROCEDURE  `DAF02`.`User_getStartedJobs`(UserID_Val 	Integer	)
BEGIN
	
	SELECT TransactionLog.TL_ID				,
				 TransactionLog.Job_ID			,
				 TransactionLog.JS_ID				,
				 TransactionLog.Phase_ID		,
			   Metadata.JobView.Job_Title							,
				 Phase.Phase_Name						,	
				 JobStatus.JS_Name					,
				 TransactionLog.TL_Date			,
				 TransactionLog.TL_NoOfFiles,
				 TransactionLog.TL_Status_Data,
				 Job.JT_ID,
				 isReCount(TransactionLog.Phase_ID,TransactionLog.Job_ID,1), /*get started jobs (started before)*/
				 Metadata.JobView.Job_External_ID,
				 Metadata.ExternalID_TypeView.ExtIDType_Name
	FROM Job 
	INNER JOIN TransactionLog
	ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
	INNER Join Phase
	ON (TransactionLog.Phase_ID = Phase.Phase_ID  and  Phase.JT_ID = Job.JT_ID)
	INNER JOIN JobStatus
	ON TransactionLog.JS_ID = JobStatus.JS_ID
	INNER JOIN Metadata.JobView
	ON Metadata.JobView.Job_ID=Job.Job_ID
	LEFT OUTER JOIN Metadata.ExternalID_TypeView
	ON Metadata.JobView.ExtIDType_ID=Metadata.ExternalID_TypeView.ExtIDType_ID
	WHERE (TransactionLog.User_ID=UserID_Val)
		AND (TransactionLog.JS_ID=1) /*started jobs*/
		ORDER BY TransactionLog.TL_ID DESC
		
		;
			
			
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_hasAdminAccess`$$
CREATE  PROCEDURE  `DAF02`.`User_hasAdminAccess`(
		UserID_Val		 	Integer
			)
BEGIN
	Declare roleID Integer Default 0 ;
	Declare permCount Integer Default 0 ;
	START TRANSACTION;
			SELECT Role_ID into roleID FROM User	WHERE User_ID= UserID_Val;	
			
				SELECT count(Permission.Perm_ID)
				INTO permCount
				FROM Permission
				INNER JOIN Role_Permission
				ON Permission.Perm_ID= Role_Permission.Perm_ID
				WHERE (Role_Permission.Role_ID=roleID)
				  AND (Permission.Perm_Description like 'Admin%')
				;
				
				IF (permCount>0) THEN
				Select 1;
				else
				Select 0;
				END IF;
				
					
	COMMIT;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_hasArchiveAccess`$$
CREATE  PROCEDURE  `DAF02`.`User_hasArchiveAccess`(
		UserID_Val		 	Integer
			)
BEGIN
	Declare roleID Integer Default 0 ;
	Declare permCount Integer Default 0 ;
	START TRANSACTION;
			SELECT Role_ID into roleID FROM User	WHERE User_ID= UserID_Val;	
			
				SELECT count(Permission.Perm_ID)
				INTO permCount
				FROM Permission
				INNER JOIN Role_Permission
				ON Permission.Perm_ID= Role_Permission.Perm_ID
				WHERE (Role_Permission.Role_ID=roleID)
				  AND (Permission.Perm_Description like 'Archive_%')
				;
				
				IF (permCount>0) THEN
				Select 1;
				else
				Select 0;
				END IF;
				
					
	COMMIT;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_hasCheckInAccess`$$
CREATE  PROCEDURE  `DAF02`.`User_hasCheckInAccess`(
		UserID_Val		 	Integer
			)
BEGIN
	Declare roleID Integer Default 0 ;
	Declare permCount Integer Default 0 ;
	START TRANSACTION;
			SELECT Role_ID into roleID FROM User	WHERE User_ID= UserID_Val;	
			
				SELECT count(Permission.Perm_ID)
				INTO permCount
				FROM Permission
				INNER JOIN Role_Permission
				ON Permission.Perm_ID= Role_Permission.Perm_ID
				WHERE (Role_Permission.Role_ID=roleID)
				  AND (Permission.Perm_Description like 'CheckIn%')
				;
				
				IF (permCount>0) THEN
				Select 1;
				else
				Select 0;
				END IF;
				
					
	COMMIT;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_hasPermission`$$
CREATE  PROCEDURE  `DAF02`.`User_hasPermission`(
		UserID_Val		 	Integer,
		PermissionID_Val Integer
		)
BEGIN
	Declare roleID Integer Default 0 ;
	Declare permCount Integer Default 0 ;
	START TRANSACTION;
			SELECT Role_ID into roleID FROM User	WHERE User_ID= UserID_Val;	
			
				SELECT count(Perm_ID)
				INTO permCount
				FROM Permission
				INNER JOIN Role_Permission
				ON Permission.Perm_ID= Role_Permission.Perm_ID
				WHERE (Role_Permission.Role_ID=roleID)
				  AND (Permission.Perm_ID=PermissionID_Val)
				;
				
				IF (permCount>0) THEN
				Select 1;
				else
				Select 0;
				END IF;
				
					
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_hasPermissionString`$$
CREATE  PROCEDURE  `DAF02`.`User_hasPermissionString`(
		UserID_Val		 	Integer,
		Permission_Val  varchar(100)
		)
BEGIN
	Declare roleID Integer Default 0 ;
	Declare permCount Integer Default 0 ;
	START TRANSACTION;
			SELECT Role_ID into roleID FROM User	WHERE User_ID= UserID_Val;	
			
				SELECT count(Permission.Perm_ID)
				INTO permCount
				FROM Permission
				INNER JOIN Role_Permission
				ON Permission.Perm_ID= Role_Permission.Perm_ID
				WHERE (Role_Permission.Role_ID=roleID)
				  AND (Permission.Perm_Description like Permission_Val)
				;
				
				IF (permCount>0) THEN
				Select 1;
				else
				Select 0;
				END IF;
				
					
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_hasPhaseManagerAccess`$$
CREATE  PROCEDURE  `DAF02`.`User_hasPhaseManagerAccess`(
		UserID_Val		 	Integer
			)
BEGIN
	Declare roleID Integer Default 0 ;
	Declare permCount Integer Default 0 ;
	START TRANSACTION;
			SELECT Role_ID into roleID FROM User	WHERE User_ID= UserID_Val;	
			
				SELECT count(Permission.Perm_ID)
				INTO permCount
				FROM Permission
				INNER JOIN Role_Permission
				ON Permission.Perm_ID= Role_Permission.Perm_ID
				WHERE (Role_Permission.Role_ID=roleID)
				  AND (Permission.Perm_Description like 'PhaseManager%')
				;
				
				IF (permCount>0) THEN
				Select 1;
				else
				Select 0;
				END IF;
				
					
	COMMIT;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_hasReportAccess`$$
CREATE  PROCEDURE  `DAF02`.`User_hasReportAccess`(
		UserID_Val		 	Integer
			)
BEGIN
	Declare roleID Integer Default 0 ;
	Declare permCount Integer Default 0 ;
	START TRANSACTION;
			SELECT Role_ID into roleID FROM User	WHERE User_ID= UserID_Val;	
			
				SELECT count(Permission.Perm_ID)
				INTO permCount
				FROM Permission
				INNER JOIN Role_Permission
				ON Permission.Perm_ID= Role_Permission.Perm_ID
				WHERE (Role_Permission.Role_ID=roleID)
				  AND (Permission.Perm_Description like 'Report%')
				;
				
				IF (permCount>0) THEN
				Select 1;
				else
				Select 0;
				END IF;
				
					
	COMMIT;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_loadAll`$$
CREATE  PROCEDURE  `DAF02`.`User_loadAll`()
BEGIN

	SELECT * FROM User ;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_loadAllActive`$$
CREATE  PROCEDURE  `DAF02`.`User_loadAllActive`()
BEGIN
	
				SELECT  User.User_ID,
								User.User_Name,
								Role.Role_Description,
								User.User_MaxJobs,
								User.User_AnyPhase,
								User.User_IsActive,
								User.User_isLDAP,
								User.User_Password,
								User.Role_ID
								
				FROM Role
				INNER JOIN User
				ON User.Role_ID=Role.Role_ID
				WHERE (User_IsActive = 1) and (User.User_Name<>'Auto')
				order by User.User_Name ;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_loadAllGUI`$$
CREATE  PROCEDURE  `DAF02`.`User_loadAllGUI`()
BEGIN
	
				SELECT  User.User_ID,
								User.User_Name,
								Role.Role_Description,
								User.User_MaxJobs,
								User.User_AnyPhase,
								User.User_IsActive,
								User.User_isLDAP,
								User.User_Password,
								User.Role_ID
								
				FROM Role
				INNER JOIN User
				ON User.Role_ID=Role.Role_ID
				WHERE User.User_Name<>'Auto'
				order by User.User_Name;
								

	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_NameDBAuthenticate`$$
CREATE  PROCEDURE  `DAF02`.`User_NameDBAuthenticate`(
		UserName_Val		 nvarchar(50)
			)
BEGIN
	Declare userCount Integer Default 0 ;
	START TRANSACTION;
				SELECT COUNT(User_ID) into userCount FROM User	
				WHERE (User_Name= UserName_Val);
									
				IF (userCount > 0) THEN
					Select 1;
				ELSE
					Select 0;
				END IF;
					
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_prepareAssignedJobs`$$
CREATE  PROCEDURE  `DAF02`.`User_prepareAssignedJobs`(
		FKUserID_Val 			  Integer
		)
BEGIN
	Declare jobCount Integer Default 0;
	Declare insertedID Integer Default 0;
	Declare NextAutoPhase Integer Default 0;
	Declare Counter  Integer Default 1;
	Declare	TLID		 Integer Default 0;
	Declare	JobID		 Integer Default 0;
	Declare	JSID		 Integer Default 0;
	Declare	PhaseID	 Integer Default 0;
	Declare	WSID		 Integer Default 0;
	Declare	TLDate	 DateTime;
	Declare	NoFiles	 Integer Default 0;
	Declare	Status	 Text;
	Declare	ValidComb	Integer Default 0;
	
	Declare cur Cursor FOR 
	SELECT TransactionLog.TL_ID		,
				 TransactionLog.Job_ID		,
				 TransactionLog.JS_ID		,
				 TransactionLog.Phase_ID	,
				 TransactionLog.TL_Date			,
				 TransactionLog.TL_NoOfFiles,
				 TransactionLog.TL_Status_Data,
			   TransactionLog.Wrkst_ID
	FROM TransactionLog
	INNER JOIN Job
	ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
	WHERE (TransactionLog.User_ID=FKUserID_Val)
		AND (TransactionLog.JS_ID=6)
		ORDER BY Job.Job_Priority DESC, TransactionLog.TL_Date DESC
		;
		
	START TRANSACTION;
	
	SELECT COUNT(TransactionLog.TL_ID)
	INTO jobCount
	FROM TransactionLog
	INNER JOIN Job
	ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
	WHERE (TransactionLog.User_ID=FKUserID_Val)
	  AND (TransactionLog.JS_ID=6)
		;
		
IF (jobCount>0) THEN
		
		

	OPEN cur;
			REPEAT
					FETCH cur INTO TLID,JobID,JSID,PhaseID,TLDate,NoFiles,Status,WSID;
						SET NextAutoPhase=0;
						IF (PhaseID=0) Then /* Auto phase*/
							/* Get the value of auto phase
							* this can be done by searching for last Started or Finished state for this job
							* If finished then we need to get the next
							* if started then we will take the same date
							*/
							CALL Phase_getAutoPhaseValue(JobID,NextAutoPhase,@NextSeq);
							IF (NextAutoPhase<>0) THEN
							
									 CALL TransLog_UpdateWithoutCommit(TLID,
																									JobID					,
																									NextAutoPhase	,
																									FKUserID_Val	,
																									WSID	,
																									6							,
																									NOW() 				,
																									NoFiles				,
																									Status				
																									);
																						
									/* Update the last job status to refer to this inserted record as last record*/
								
									UPDATE Job 
									SET Job.TL_ID=TLID
									WHERE Job.Job_ID=JobID;
									
										
							END IF;/* NextAutoPhase<>0 */
							
																									
					END IF;/* Phase = 0 */
									
		      	SET Counter = Counter + 1;
			
			 UNTIL  ((Counter > jobCount))
			END REPEAT;
	CLOSE cur;


END IF;
				
	COMMIT;									
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_Update`$$
CREATE  PROCEDURE  `DAF02`.`User_Update`(
		PKUserID_Val		  			Integer		  ,
		UserName_Val   					nvarchar(50)	,
		UserPassword_Val 				nvarchar(50)	,
		UserAnyPhase_Val 				TinyInt(1)	,
		UserMaxJobs_Val 				Integer			,
		UserIsActive_Val				TinyInt(1)	,
		FKRoleID_Val						Integer	,
		UserIsLDAP				TinyInt(1)				
	)
BEGIN
	START TRANSACTION;
				UPDATE User  SET  	User_ID		= PKUserID_Val		 ,
														User_Name			= UserName_Val 		 ,
														User_Password = UserPassword_Val ,
														User_AnyPhase	= UserAnyPhase_Val ,
														User_MaxJobs	= UserMaxJobs_Val	 ,
														User_IsActive	= UserIsActive_Val ,
														Role_ID		= FKRoleID_Val	,							 
														User_isLDAP= UserIsLDAP
																	
												
										  WHERE User_ID= PKUserID_Val;
								
				SELECT * FROM User WHERE User_ID=PKUserID_Val;										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`User_updatePhases`$$
CREATE  PROCEDURE  `DAF02`.`User_updatePhases`(
		userID_Val 					 Integer ,			
		phasesVal						 nvarchar(500),
		delimiterVal				 char(1)
	)
BEGIN
	START TRANSACTION;
			DELETE FROM User_Phase	
			WHERE (User_Phase.User_ID=userID_Val);
			
			CALL SplitIDs(phasesVal,delimiterVal);
			INSERT INTO User_Phase (User_ID,Phase_ID) 
  										( SELECT   userID_Val,IDVal
												FROM SplittedTempTable
												WHERE IDVal not in (1,2)
											);											
				
		IF (1 in (select IDVal from SplittedTempTable) )THEN
				INSERT INTO User_Phase (User_ID,Phase_ID) values (userID_Val,1);
		END IF;
		
			IF (2 in (select IDVal from SplittedTempTable) )THEN
				INSERT INTO User_Phase (User_ID,Phase_ID) values (userID_Val,2);
		END IF;
		
		Drop Temporary Table If Exists `SplittedTempTable`;
		
		SELECT * FROM User_Phase 
		WHERE (User_Phase.User_ID=userID_Val);
										
	COMMIT;
	
	
END $$




DROP PROCEDURE IF EXISTS `DAF02`.`User_ValidateLimit`$$
CREATE  PROCEDURE  `DAF02`.`User_ValidateLimit`(
currUser				Integer,
OUT Valid	TinyInt(1)
)
BEGIN
	Declare Started  Integer Default 0;
  Declare MaxLimit Integer Default 0;
	Declare Rejected Integer Default 0;
		
	START TRANSACTION;
	
								/*Get Started Jobs Count*/
						SELECT COUNT(TransactionLog.TL_ID)
						INTO Started
						FROM Job
						INNER JOIN TransactionLog
						ON (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
						WHERE (JS_ID= 1)
							AND (User_ID= currUser)
							;
										
						/* Get Max Limit */
						SELECT User_MaxJobs
						INTO MaxLimit
						FROM User
						WHERE (User_ID= currUser) AND (User_IsActive=1)
						;
						
						IF (MaxLimit > Started) Then
							SET Valid=1;
						ELSE
							SET Valid=0;
						END IF;
					
	COMMIT;
	
END $$


DROP PROCEDURE IF EXISTS `DAF02`.`Job_CreatePool` $$
CREATE  PROCEDURE `DAF02`.`Job_CreatePool`()
BEGIN

/*Create Job_Pool*/
	DROP TABLE IF EXISTS Job_Pool;
	CREATE TABLE   Job_Pool(
	`Job_ID` int(10) unsigned NOT NULL,
	`Coll_ID` int(10) unsigned NOT NULL,
	`JS_ID` int(10) unsigned NOT NULL,
	`Phase_ID` int(10) unsigned NOT NULL,
	`User_ID` int(10) unsigned NOT NULL,
		KEY `Job_ID` (`Job_ID`),
		KEY `Coll_ID` (`Coll_ID`),
		KEY `JS_ID` (`JS_ID`),
		KEY `Phase_ID` (`Phase_ID`),
		KEY `User_ID` (`User_ID`),
		CONSTRAINT `Pool_Job_ID` FOREIGN KEY (`Job_ID`) REFERENCES `Job` (`Job_ID`),
		CONSTRAINT `Pool_Collection` FOREIGN KEY (`Coll_ID`) REFERENCES `Collection` (`Coll_ID`),
		CONSTRAINT `Pool_JS` FOREIGN KEY (`JS_ID`) REFERENCES `JobStatus` (`JS_ID`),
		CONSTRAINT `Pool_Phase` FOREIGN KEY (`Phase_ID`) REFERENCES `Phase` (`Phase_ID`),
		CONSTRAINT `Pool_User` FOREIGN KEY (`User_ID`) REFERENCES `User` (`User_ID`),
		PRIMARY KEY (`Job_ID`)
	
	) ENGINE=HEAP;
	
	
	/*Fill Job_Pool*/
	insert into Job_Pool(Job_ID,Coll_ID,JS_ID,Phase_ID,User_ID)
	(select TransactionLog.Job_ID,
				Job_Collection.Coll_ID,
				TransactionLog.JS_ID,
				getNextPhase(TransactionLog.Job_ID),
				if(JS_ID=2,0,TransactionLog.User_ID)
		
	from Job
	inner join TransactionLog on TransactionLog.TL_ID=Job.TL_ID and Job.TL_ID>0
	inner join Job_Collection on Job_Collection.Job_ID=Job.Job_ID
	where JS_ID in (2,6)
	);


END $$




DROP PROCEDURE IF EXISTS `DAF02`.`User_ValidateLimit2`$$
CREATE  PROCEDURE  `DAF02`.`User_ValidateLimit2`(
currUser				Integer,
OUT Valid	TinyInt(1)
)
BEGIN
								-- Get Started Jobs Count
						select if(count(TransactionLog.TL_ID)< User.User_MaxJobs, 1,0)  into Valid  
						from User left outer join TransactionLog on (TransactionLog.JS_ID = 1
																		 									and User.User_ID = TransactionLog.User_ID)
											inner join Job on (Job.TL_ID = TransactionLog.TL_ID and Job.TL_ID>0)
						where User.User_ID = currUser;
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`UserRates`$$
CREATE  PROCEDURE  `DAF02`.`UserRates`(
JobType_Val						Integer,
usersVal						 nvarchar(500),
delimiterVal				 char(1),
fromDate 						DateTime,
toDate							DateTime,
countBooks					integer
)
BEGIN

		
START TRANSACTION;
	
	
	CALL SplitIDs(usersVal,delimiterVal);		
	CALL SplitIDsForOTL(usersVal,delimiterVal);		
	
	IF (countBooks = 0) THEN
			-- selection will be based on pages count
				SELECT  User_ID,User_Name,Phase_ID,Phase_Name,sum(filesNum)
				FROM 
				(
					( SELECT  OldTransactionLog.OTL_ID,OldTransactionLog.User_ID ,User.User_Name,
										OldTransactionLog.Phase_ID ,Phase.Phase_Name,
										-- if((min(OldTransactionLog.OTL_Date)>=fromDate AND min(OldTransactionLog.OTL_Date)<=toDate),max(OldTransactionLog.OTL_NoOfFiles),0) as filesNum,
										max(OldTransactionLog.OTL_NoOfFiles) as filesNum,
										min(OldTransactionLog.OTL_Date) as Tdate,OldTransactionLog.job_ID as j
							from User
							inner join SplittedTempTableOTL 
							on SplittedTempTableOTL.IDVal=User.User_ID
							INNER JOIN OldTransactionLog
							ON OldTransactionLog.User_ID = User.User_ID
							INNER JOIN Job
							ON OldTransactionLog.Job_ID=Job.Job_ID
							INNER JOIN Phase
							ON (Phase.Phase_ID=OldTransactionLog.Phase_ID and Phase.JT_ID=Job.JT_ID)
							where (OldTransactionLog.JS_ID=2) 
								and (Job.JT_ID=JobType_Val)
								group by OldTransactionLog.Phase_ID,OldTransactionLog.User_ID,OldTransactionLog.Job_ID
								Having if((min(OldTransactionLog.OTL_Date)>=fromDate AND min(OldTransactionLog.OTL_Date)<=toDate),True,False) 
					) 
					UNION
					(	SELECT  TransactionLog.TL_ID,TransactionLog.User_ID,User.User_Name,
										TransactionLog.Phase_ID ,Phase.Phase_Name,
										-- if((min(TransactionLog.TL_Date)>=fromDate AND min(TransactionLog.TL_Date)<=toDate),max(TransactionLog.TL_NoOfFiles),0) as filesNum,
										max(TransactionLog.TL_NoOfFiles) as filesNum,
										min(TransactionLog.TL_Date) as Tdate,TransactionLog.Job_ID as j
						from User
						INNER JOIN SplittedTempTable
						on SplittedTempTable.IDVal=User.User_ID
						INNER JOIN TransactionLog
						ON TransactionLog.User_ID = User.User_ID
						INNER JOIN Job
						ON TransactionLog.Job_ID=Job.Job_ID
						INNER JOIN Phase
						ON (Phase.Phase_ID=TransactionLog.Phase_ID and Phase.JT_ID=Job.JT_ID)
						where (TransactionLog.JS_ID=2 ) 
							and (Job.JT_ID=JobType_Val)
						group by TransactionLog.Phase_ID,TransactionLog.User_ID,TransactionLog.Job_ID
						Having if((min(TransactionLog.TL_Date)>=fromDate AND min(TransactionLog.TL_Date)<=toDate),True,False) 
														
						)
			
				)RateTable
			GROUP by Phase_ID,User_ID
			order by User_ID;
			
		ELSE
		-- selection will be based on jobs count
			SELECT  User_ID,User_Name,Phase_ID,Phase_Name, count(Job_ID)
				FROM 
				(
					( SELECT   OldTransactionLog.OTL_ID,OldTransactionLog.User_ID ,User.User_Name,
										OldTransactionLog.Phase_ID ,Phase.Phase_Name,
										OldTransactionLog.Job_ID
							from User
							inner join SplittedTempTableOTL 
							on SplittedTempTableOTL.IDVal=User.User_ID
							INNER JOIN OldTransactionLog
							ON OldTransactionLog.User_ID = User.User_ID
							INNER JOIN Job
						  ON OldTransactionLog.Job_ID=Job.Job_ID
							INNER JOIN Phase
							ON (Phase.Phase_ID=OldTransactionLog.Phase_ID and Phase.JT_ID=Job.JT_ID)
							where (OldTransactionLog.JS_ID=2) 
								AND (isFirst(OldTransactionLog.Job_ID,OldTransactionLog.Phase_ID,OldTransactionLog.User_ID,fromDate,toDate,1)=1)
								and (Job.JT_ID=JobType_Val)
								group by 	OldTransactionLog.Job_ID,OldTransactionLog.Phase_ID
						-- 		Having if((min(OldTransactionLog.OTL_Date)>=fromDate AND min(OldTransactionLog.OTL_Date)<=toDate),True,False) 
													
					) 
					UNION
					(	SELECT  TransactionLog.TL_ID,TransactionLog.User_ID,User.User_Name,
										TransactionLog.Phase_ID ,Phase.Phase_Name,
										TransactionLog.Job_ID
						from User
						INNER JOIN SplittedTempTable
						on SplittedTempTable.IDVal=User.User_ID
						INNER JOIN TransactionLog
						ON TransactionLog.User_ID = User.User_ID
						INNER JOIN Job
						ON TransactionLog.Job_ID=Job.Job_ID
						INNER JOIN Phase
				  	ON (Phase.Phase_ID=TransactionLog.Phase_ID and Phase.JT_ID=Job.JT_ID)
						where (TransactionLog.JS_ID=2) 
					 	 AND (isFirst(TransactionLog.Job_ID,TransactionLog.Phase_ID,TransactionLog.User_ID,fromDate,toDate,0)=1)
							and (Job.JT_ID=JobType_Val)
							group by 	TransactionLog.Job_ID,TransactionLog.Phase_ID
						-- 	Having if((min(TransactionLog.TL_Date)>=fromDate AND min(TransactionLog.TL_Date)<=toDate),True,False) 
																		
						)
			
				)RateTable
		  GROUP by Phase_ID,User_ID
			order by User_ID;
			
END IF;

Drop Temporary Table If Exists `SplittedTempTable`;
Drop Temporary Table If Exists `SplittedTempTableOTL`;
				

COMMIT;									
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Validate_UserWSPhase`$$
CREATE  PROCEDURE  `DAF02`.`Validate_UserWSPhase`(
		FKJobID_Val					Integer		,
		FKUserID_Val 			  Integer	  ,
		FKWrkstID_Val 			Integer		,
		FKPhaseID_Val				Integer   ,
		OUT Valid						TinyInt(1)
	)
BEGIN
	Declare CollID	  		 Integer Default 0;
	Declare validUserPhase Integer Default 0;
	Declare validWSPhase	 Integer Default 0;
	Declare validUserColl	 Integer Default 0;
	Declare validWSColl 	 Integer Default 0;
	Declare collAnyUser 	 Integer Default 0;
	Declare collAnyWS 	 	 Integer Default 0;
	Declare wsAnyPhase 	 	 Integer Default 0;
	Declare userAnyPhase 	 	 Integer Default 0;
	
	
	/*Get Job Collection */
	SELECT  Collection.Coll_ID,Collection.Coll_AnyUser,Collection.Coll_AnyWorkstation
	INTO CollID,collAnyUser,collAnyWS
	FROM Collection
	INNER JOIN Batch
	ON Batch.Coll_ID = Collection.Coll_ID
	INNER JOIN Job
	ON Job.Batch_ID = Batch.Batch_ID
	WHERE (Job.Job_ID= FKJobID_Val) AND (Collection.Coll_Active=1)
;
		
	SELECT Workstation.Wrkst_AnyPhase
	INTO wsAnyPhase
	FROM Workstation
	WHERE (Workstation.Wrkst_ID=FKWrkstID_Val)
		AND (Workstation.Wrkst_IsActive=1)
		;
		
	SELECT User.User_AnyPhase
	INTO userAnyPhase
	FROM User
	WHERE (User.User_ID=FKUserID_Val)
		AND (User.User_IsActive=1)
		;
	
	
	SELECT COUNT(*)
	INTO validUserPhase
	FROM User_Phase
	INNER JOIN User
	ON User_Phase.User_ID=User.User_ID
	WHERE (User_Phase.Phase_ID=FKPhaseID_Val)
		AND (User_Phase.User_ID=FKUserID_Val)
		AND (User.User_IsActive=1)
	;
	
		
	SELECT COUNT(*)
	INTO validWSPhase
	FROM Workstation_Phase
	INNER  JOIN Workstation
	ON Workstation_Phase.Wrkst_ID=Workstation.Wrkst_ID
	WHERE (Workstation_Phase.Phase_ID=FKPhaseID_Val)
		AND (Workstation_Phase.Wrkst_ID=FKWrkstID_Val)
		AND (Workstation.Wrkst_IsActive=1)
		;
		
	SELECT COUNT(*)
	INTO validUserColl
	FROM User_Collection
	INNER JOIN Collection
	ON User_Collection.Coll_ID=Collection.Coll_ID
	INNER JOIN User
	ON User_Collection.User_ID=User.User_ID
	WHERE (User_Collection.Coll_ID=CollID)
		AND (User_Collection.User_ID=FKUserID_Val)
		AND (User.User_IsActive=1)
		AND (Collection.Coll_Active=1)
		;
		
		
	SELECT COUNT(*)
	INTO validWSColl
	FROM Workstation_Collection
	INNER JOIN Collection
	ON Workstation_Collection.Coll_ID= Collection.Coll_ID
	INNER JOIN Workstation
	ON Workstation_Collection.Wrkst_ID= Workstation.Wrkst_ID
	WHERE (Workstation_Collection.Coll_ID=CollID)
		AND (Workstation_Collection.Wrkst_ID=FKWrkstID_Val)
		AND (Workstation.Wrkst_IsActive=1)
		AND (Collection.Coll_Active=1)
		;


/*Special handling for auto and archiving phase
* both of them should be valid with any user and any workstation
*/
IF (FKPhaseID_Val = 0) THEN
 SET validUserPhase=1;
 SET validWSPhase=1;
END IF;

	
IF   ((validUserPhase>0) OR (userAnyPhase=1)) AND
		 ((validWSPhase  >0) OR (wsAnyPhase=1)) AND
		 ((validUserColl >0) OR (collAnyUser=1)) AND
		 ((validWSColl   >0) OR (collAnyWS=1))	THEN
	SET Valid=1;
	ELSE
	SET Valid=0;
	END IF;
	
	
			
						
	
	
END $$





DROP FUNCTION IF EXISTS `DAF02`.`validateWS`$$
CREATE  FUNCTION  `DAF02`.`validateWS`(
													 WrkstID_Val 		integer,
													 Phase_ID_Val	 integer,
													 Coll_ID_Val integer
													 	) RETURNS int(11)
BEGIN
  /*
	This function is to validate that the Workstation can perform the given Phase
	*/
	declare WSID Integer default 0; 
	
	DECLARE CONTINUE HANDLER FOR SQLWARNING RETURN (0);
	
	select Workstation.Wrkst_ID into WSID
	from Workstation 
	left outer join Workstation_Phase on Workstation_Phase.Wrkst_ID = Workstation.Wrkst_ID
	left outer join Workstation_Collection on Workstation_Collection.Wrkst_ID=Workstation.Wrkst_ID
	left outer join Collection on Collection.Coll_ID=Workstation_Collection.Coll_ID and Collection.Coll_ID=Coll_ID_Val
	
	where Workstation.Wrkst_ID = WrkstID_Val
		and (Workstation_Phase.Phase_ID = Phase_ID_Val or Workstation.Wrkst_AnyPhase = 1)		
		and (Workstation_Collection.Coll_ID = Coll_ID_Val or Collection.Coll_AnyWorkstation = 1)
		limit 1;
		

	RETURN (WSID);
END;

 $$





DROP PROCEDURE IF EXISTS `DAF02`.`WorkFlow_getDetails`$$
CREATE  PROCEDURE  `DAF02`.`WorkFlow_getDetails`(
CollIDs nvarchar(200),
BatcheIDs nvarchar(300),
LangIDs nvarchar(100),
StorageIDs nvarchar(100),
JobTypeIDs nvarchar(200),
PhaseIDs nvarchar(300),
ExtTypeIDs nvarchar(100),
UserIDs nvarchar(500),
StatusIDs nvarchar(100),
OldNewIDs nvarchar(100),
jobID		integer,
jobExtID  nvarchar(100),
fromDate 	DateTime,
toDate		DateTime,
checkInOnly integer
)
BEGIN
Declare selectStmt text;
Declare compare Integer default -1;

drop table if exists finishAll;
drop table if exists finishReDo;
CREATE TEMPORARY TABLE finishAll ( PhaseID int, PhaseSeq int, JobsCount int) ENGINE=HEAP;
CREATE TEMPORARY TABLE finishReDo ( PhaseID int, PhaseSeq int, JobsCount int) ENGINE=HEAP;

/*check if old or new job
 * -1 -- any
 * 0 --> old
 * 1 -->new
*/
-- check if the jobs to be searched New or Old
-- 1) Any Jobs
SELECT STRCMP(OldNewIDs,"-1") into compare;
-- STRCMP return 0 on equality
-- OR no entries selected (0) length
-- OR Old + ane selected (1,2) (3) length
IF (compare=0 OR Length(OldNewIDs)=0 OR  Length(OldNewIDs)=3) THEN
	-- Any Job
 /*first select, get all finished jobs*/
  SET selectStmt ='insert into finishAll select PhaseID,seq,count(jobs) as finishAll from ( ';
	SET selectStmt =concat(selectStmt,'select 1,Phase.Phase_ID as PhaseID ,Phase.Phase_Sequence as seq,TransactionLog.Job_ID as jobs ');
	SET selectStmt =concat(selectStmt,'from Phase ');
	SET selectStmt =concat(selectStmt,'inner join TransactionLog on Phase.Phase_ID=TransactionLog.Phase_ID ');
	SET selectStmt =concat(selectStmt,'inner join Metadata.JobView on Metadata.JobView.Job_ID=TransactionLog.Job_ID ');
	SET selectStmt =concat(selectStmt,' inner join Job on TransactionLog.Job_ID=Job.Job_ID  INNER JOIN Storage ON (Job.Storage_ID=Storage.Storage_ID) INNER JOIN Metadata.LanguageView ON (Metadata.JobView.Lang_ID=Metadata.LanguageView.Lang_ID) INNER JOIN JobType on (Job.JT_ID=JobType.JT_ID) INNER JOIN Batch ON (Job.Batch_ID=Batch.Batch_ID) INNER JOIN Collection ON (Batch.Coll_ID=Collection.Coll_ID) ');
	SET selectStmt =concat(selectStmt,'where Phase.Phase_ID>2  and TransactionLog.TL_Date>=''',fromDate,'''  and TransactionLog.TL_Date<=''',toDate,''' ');
			IF (Length(PhaseIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND TransactionLog.Phase_ID in (',PhaseIDs,')');
			END IF;
			
			IF (Length(UserIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND TransactionLog.User_ID in (',UserIDs,')');
			END IF;
		
			IF (Length(StatusIDs)>0) Then
				SET selectStmt = concat(selectStmt,' AND TransactionLog.JS_ID in (',StatusIDs,')');
			END IF;
			
			IF (Length(StorageIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND Storage.Storage_ID in (',StorageIDs,')');
			END IF;
			IF (Length(CollIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND Collection.Coll_ID in (',CollIDs,')');
		END IF;
		
		IF (Length(BatcheIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND Batch.Batch_ID in (',BatcheIDs,')');
		END IF;
		
		IF (Length(LangIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND Metadata.LanguageView.Lang_ID in (',LangIDs,')');
		END IF;
		
		IF (Length(JobTypeIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND JobType.JT_ID in (',JobTypeIDs,')');
		END IF;
		
		IF (jobID>-1) Then
			SET selectStmt = concat(selectStmt,' AND Job.Job_ID = (',jobID,')');
		END IF;
		-- checkInOnly = 1 will retrieve checked in Jobs only between the specified dates
		IF (checkInOnly=1) Then
			SET selectStmt = concat(selectStmt,' AND Job.Job_Date>=''',fromDate,'''  and Job.Job_Date<=''',toDate,''' ');
		END IF;
	
	SET selectStmt =concat(selectStmt,'group by Phase.Phase_ID,TransactionLog.Job_ID ');
	SET selectStmt =concat(selectStmt,'union ');
	SET selectStmt =concat(selectStmt,'select  0,Phase.Phase_ID as PhaseID ,Phase.Phase_Sequence as seq,OldTransactionLog.Job_ID as jobs ');
	SET selectStmt =concat(selectStmt,'from Phase ');
	SET selectStmt =concat(selectStmt,'inner join OldTransactionLog on Phase.Phase_ID=OldTransactionLog.Phase_ID ');
	SET selectStmt =concat(selectStmt,'inner join Metadata.JobView on Metadata.JobView.Job_ID=OldTransactionLog.Job_ID ');
	SET selectStmt =concat(selectStmt,' inner join Job on OldTransactionLog.Job_ID=Job.Job_ID  INNER JOIN Storage ON (Job.Storage_ID=Storage.Storage_ID) INNER JOIN Metadata.LanguageView ON (Metadata.JobView.Lang_ID=Metadata.LanguageView.Lang_ID) INNER JOIN JobType on (Job.JT_ID=JobType.JT_ID)  INNER JOIN Batch ON (Job.Batch_ID=Batch.Batch_ID) INNER JOIN Collection ON (Batch.Coll_ID=Collection.Coll_ID) ');
	SET selectStmt =concat(selectStmt,'where  Phase.Phase_ID>2 and OldTransactionLog.OTL_Date>=''',fromDate,'''  and OldTransactionLog.OTL_Date<''',toDate,''' ');
		IF (Length(PhaseIDs)>0) Then
		SET selectStmt = concat(selectStmt,' AND OldTransactionLog.Phase_ID in (',PhaseIDs,')');
		END IF;
		
		IF (Length(UserIDs)>0) Then
		SET selectStmt = concat(selectStmt,' AND OldTransactionLog.User_ID in (',UserIDs,')');
		END IF;
	
		IF (Length(StatusIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND OldTransactionLog.JS_ID in (',StatusIDs,')');
		END IF;
		
		IF (Length(StorageIDs)>0) Then
		SET selectStmt = concat(selectStmt,' AND Storage.Storage_ID in (',StorageIDs,')');
		END IF;
		IF (Length(CollIDs)>0) Then
		SET selectStmt = concat(selectStmt,' AND Collection.Coll_ID in (',CollIDs,')');
		END IF;
		
		IF (Length(BatcheIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND Batch.Batch_ID in (',BatcheIDs,')');
		END IF;
		
		IF (Length(LangIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND Metadata.LanguageView.Lang_ID in (',LangIDs,')');
		END IF;
		
		IF (Length(JobTypeIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND JobType.JT_ID in (',JobTypeIDs,')');
		END IF;
		
		
		IF (jobID>-1) Then
			SET selectStmt = concat(selectStmt,' AND Job.Job_ID = (',jobID,')');
		END IF;
		
		-- checkInOnly = 1 will retrieve checked in Jobs only between the specified dates
		IF (checkInOnly=1) Then
			SET selectStmt = concat(selectStmt,' AND Job.Job_Date>=''',fromDate,'''  and Job.Job_Date<=''',toDate,''' ');
		END IF;
		
		

	SET selectStmt =concat(selectStmt,'group by Phase.Phase_ID,OldTransactionLog.Job_ID ');
	SET selectStmt =concat(selectStmt,')All_ ');
	SET selectStmt =concat(selectStmt,'group by PhaseID;');

/*first select execution*/
select @a:=selectStmt;
Prepare stmt from @a;
execute stmt;
DEALLOCATE PREPARE stmt;

/*second select, get ReDo items*/

SET selectStmt ='insert into finishReDo select PhaseID,seq,count(jobs) as finishReDo from ( ';
	SET selectStmt =concat(selectStmt,'select 1,Phase.Phase_ID as PhaseID ,Phase.Phase_Sequence as seq,TransactionLog.Job_ID as jobs ');
	SET selectStmt =concat(selectStmt,'from Phase ');
	SET selectStmt =concat(selectStmt,'inner join TransactionLog on Phase.Phase_ID=TransactionLog.Phase_ID ');
	SET selectStmt =concat(selectStmt,'inner join Metadata.JobView on Metadata.JobView.Job_ID=TransactionLog.Job_ID ');
	SET selectStmt =concat(selectStmt,' inner join Job on TransactionLog.Job_ID=Job.Job_ID  INNER JOIN Storage ON (Job.Storage_ID=Storage.Storage_ID) INNER JOIN Metadata.LanguageView ON (Metadata.JobView.Lang_ID=Metadata.LanguageView.Lang_ID) INNER JOIN JobType on (Job.JT_ID=JobType.JT_ID) INNER JOIN Batch ON (Job.Batch_ID=Batch.Batch_ID) INNER JOIN Collection ON (Batch.Coll_ID=Collection.Coll_ID) ');
	SET selectStmt =concat(selectStmt,'where Phase.Phase_ID>2  and TransactionLog.TL_Date>=''',fromDate,'''  and TransactionLog.TL_Date<=''',toDate,''' ');
			IF (Length(PhaseIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND TransactionLog.Phase_ID in (',PhaseIDs,')');
			END IF;
			
			IF (Length(UserIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND TransactionLog.User_ID in (',UserIDs,')');
			END IF;
		
			IF (Length(StatusIDs)>0) Then
				SET selectStmt = concat(selectStmt,' AND TransactionLog.JS_ID in (',StatusIDs,')');
			END IF;
			
			IF (Length(StorageIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND Storage.Storage_ID in (',StorageIDs,')');
			END IF;
			IF (Length(CollIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND Collection.Coll_ID in (',CollIDs,')');
		END IF;
		
		IF (Length(BatcheIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND Batch.Batch_ID in (',BatcheIDs,')');
		END IF;
		
		IF (Length(LangIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND Metadata.LanguageView.Lang_ID in (',LangIDs,')');
		END IF;
		
		IF (Length(JobTypeIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND JobType.JT_ID in (',JobTypeIDs,')');
		END IF;
		
		IF (jobID>-1) Then
			SET selectStmt = concat(selectStmt,' AND Job.Job_ID = (',jobID,')');
		END IF;
		
		-- checkInOnly = 1 will retrieve checked in Jobs only between the specified dates
		IF (checkInOnly=1) Then
			SET selectStmt = concat(selectStmt,' AND Job.Job_Date>=''',fromDate,'''  and Job.Job_Date<=''',toDate,''' ');
		END IF;

	SET selectStmt =concat(selectStmt,'group by Phase.Phase_ID,TransactionLog.Job_ID ');
	SET selectStmt =concat(selectStmt,'having count(TransactionLog.TL_ID)>1 ');
	SET selectStmt =concat(selectStmt,'union ');
	SET selectStmt =concat(selectStmt,'select  0,Phase.Phase_ID as PhaseID ,Phase.Phase_Sequence as seq,OldTransactionLog.Job_ID as jobs ');
	SET selectStmt =concat(selectStmt,'from Phase ');
	SET selectStmt =concat(selectStmt,'inner join OldTransactionLog on Phase.Phase_ID=OldTransactionLog.Phase_ID ');
	SET selectStmt =concat(selectStmt,'inner join Metadata.JobView on Metadata.JobView.Job_ID=OldTransactionLog.Job_ID ');
	SET selectStmt =concat(selectStmt,' inner join Job on OldTransactionLog.Job_ID=Job.Job_ID  INNER JOIN Storage ON (Job.Storage_ID=Storage.Storage_ID) INNER JOIN Metadata.LanguageView ON (Metadata.JobView.Lang_ID=Metadata.LanguageView.Lang_ID) INNER JOIN JobType on (Job.JT_ID=JobType.JT_ID)  INNER JOIN Batch ON (Job.Batch_ID=Batch.Batch_ID) INNER JOIN Collection ON (Batch.Coll_ID=Collection.Coll_ID) ');
	SET selectStmt =concat(selectStmt,'where  Phase.Phase_ID>2  and OldTransactionLog.OTL_Date>=''',fromDate,'''  and OldTransactionLog.OTL_Date<''',toDate,''' ');
		IF (Length(PhaseIDs)>0) Then
		SET selectStmt = concat(selectStmt,' AND OldTransactionLog.Phase_ID in (',PhaseIDs,')');
		END IF;
		
		IF (Length(UserIDs)>0) Then
		SET selectStmt = concat(selectStmt,' AND OldTransactionLog.User_ID in (',UserIDs,')');
		END IF;
	
		IF (Length(StatusIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND OldTransactionLog.JS_ID in (',StatusIDs,')');
		END IF;
		
		IF (Length(StorageIDs)>0) Then
		SET selectStmt = concat(selectStmt,' AND Storage.Storage_ID in (',StorageIDs,')');
		END IF;
		IF (Length(CollIDs)>0) Then
		SET selectStmt = concat(selectStmt,' AND Collection.Coll_ID in (',CollIDs,')');
		END IF;
		
		IF (Length(BatcheIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND Batch.Batch_ID in (',BatcheIDs,')');
		END IF;
		
		IF (Length(LangIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND Metadata.LanguageView.Lang_ID in (',LangIDs,')');
		END IF;
		
		IF (Length(JobTypeIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND JobType.JT_ID in (',JobTypeIDs,')');
		END IF;
		
		IF (jobID>-1) Then
			SET selectStmt = concat(selectStmt,' AND Job.Job_ID = (',jobID,')');
		END IF;
		-- checkInOnly = 1 will retrieve checked in Jobs only between the specified dates
		IF (checkInOnly=1) Then
			SET selectStmt = concat(selectStmt,' AND Job.Job_Date>=''',fromDate,'''  and Job.Job_Date<=''',toDate,''' ');
		END IF;
		
	
	SET selectStmt =concat(selectStmt,'group by Phase.Phase_ID,OldTransactionLog.Job_ID ');
	SET selectStmt =concat(selectStmt,'having count(OldTransactionLog.OTL_ID)>1 ');
	SET selectStmt =concat(selectStmt,')Redo ');
	SET selectStmt =concat(selectStmt,'group by PhaseID;');

/*first select execution*/
select @a:=selectStmt;
Prepare stmt from @a;
execute stmt;
DEALLOCATE PREPARE stmt;

		
END IF;

-- 2) Old Jobs
SELECT STRCMP(OldNewIDs,"0") into compare;
-- STRCMP return 0 on equality
IF (compare=0) THEN
			 /*first select, get all finished jobs*/
  SET selectStmt ='insert into finishAll select PhaseID,seq,count(jobs) as finishAll from ( ';
	SET selectStmt =concat(selectStmt,'select  Phase.Phase_ID as PhaseID ,Phase.Phase_Sequence as seq,OldTransactionLog.Job_ID as jobs ');
	SET selectStmt =concat(selectStmt,'from Phase ');
	SET selectStmt =concat(selectStmt,'inner join OldTransactionLog on Phase.Phase_ID=OldTransactionLog.Phase_ID ');
	SET selectStmt =concat(selectStmt,'inner join Metadata.JobView on Metadata.JobView.Job_ID=OldTransactionLog.Job_ID ');
	SET selectStmt =concat(selectStmt,' inner join Job on OldTransactionLog.Job_ID=Job.Job_ID  INNER JOIN Storage ON (Job.Storage_ID=Storage.Storage_ID) INNER JOIN Metadata.LanguageView ON (Metadata.JobView.Lang_ID=Metadata.LanguageView.Lang_ID) INNER JOIN JobType on (Job.JT_ID=JobType.JT_ID)  INNER JOIN Batch ON (Job.Batch_ID=Batch.Batch_ID) INNER JOIN Collection ON (Batch.Coll_ID=Collection.Coll_ID) ');
	SET selectStmt =concat(selectStmt,'where  Phase.Phase_ID>2  and OldTransactionLog.OTL_Date>=''',fromDate,'''  and OldTransactionLog.OTL_Date<''',toDate,''' ');
		IF (Length(PhaseIDs)>0) Then
		SET selectStmt = concat(selectStmt,' AND OldTransactionLog.Phase_ID in (',PhaseIDs,')');
		END IF;
		
		IF (Length(UserIDs)>0) Then
		SET selectStmt = concat(selectStmt,' AND OldTransactionLog.User_ID in (',UserIDs,')');
		END IF;
	
		IF (Length(StatusIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND OldTransactionLog.JS_ID in (',StatusIDs,')');
		END IF;
		
		IF (Length(StorageIDs)>0) Then
		SET selectStmt = concat(selectStmt,' AND Storage.Storage_ID in (',StorageIDs,')');
		END IF;
		IF (Length(CollIDs)>0) Then
		SET selectStmt = concat(selectStmt,' AND Collection.Coll_ID in (',CollIDs,')');
		END IF;
		
		IF (Length(BatcheIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND Batch.Batch_ID in (',BatcheIDs,')');
		END IF;
		
		IF (Length(LangIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND Metadata.LanguageView.Lang_ID in (',LangIDs,')');
		END IF;
		
		IF (Length(JobTypeIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND JobType.JT_ID in (',JobTypeIDs,')');
		END IF;
				
		IF (jobID>-1) Then
			SET selectStmt = concat(selectStmt,' AND Job.Job_ID = (',jobID,')');
		END IF;
		-- checkInOnly = 1 will retrieve checked in Jobs only between the specified dates
		IF (checkInOnly=1) Then
			SET selectStmt = concat(selectStmt,' AND Job.Job_Date>=''',fromDate,'''  and Job.Job_Date<=''',toDate,''' ');
		END IF;
		


	SET selectStmt =concat(selectStmt,'group by Phase.Phase_ID,OldTransactionLog.Job_ID ');
	SET selectStmt =concat(selectStmt,')All_ ');
	SET selectStmt =concat(selectStmt,'group by PhaseID;');

/*first select execution*/
select @a:=selectStmt;
Prepare stmt from @a;
execute stmt;
DEALLOCATE PREPARE stmt;

/*second select, get ReDo items*/

SET selectStmt ='insert into finishReDo select PhaseID,seq,count(jobs) as finishReDo from ( ';
	SET selectStmt =concat(selectStmt,'select  Phase.Phase_ID as PhaseID ,Phase.Phase_Sequence as seq,OldTransactionLog.Job_ID as jobs ');
	SET selectStmt =concat(selectStmt,'from Phase ');
	SET selectStmt =concat(selectStmt,'inner join OldTransactionLog on Phase.Phase_ID=OldTransactionLog.Phase_ID ');
	SET selectStmt =concat(selectStmt,'inner join Metadata.JobView on Metadata.JobView.Job_ID=OldTransactionLog.Job_ID ');
	SET selectStmt =concat(selectStmt,' inner join Job on OldTransactionLog.Job_ID=Job.Job_ID  INNER JOIN Storage ON (Job.Storage_ID=Storage.Storage_ID) INNER JOIN Metadata.LanguageView ON (Metadata.JobView.Lang_ID=Metadata.LanguageView.Lang_ID) INNER JOIN JobType on (Job.JT_ID=JobType.JT_ID)  INNER JOIN Batch ON (Job.Batch_ID=Batch.Batch_ID) INNER JOIN Collection ON (Batch.Coll_ID=Collection.Coll_ID) ');
	SET selectStmt =concat(selectStmt,'where  Phase.Phase_ID>2  and OldTransactionLog.OTL_Date>=''',fromDate,'''  and OldTransactionLog.OTL_Date<''',toDate,''' ');
		IF (Length(PhaseIDs)>0) Then
		SET selectStmt = concat(selectStmt,' AND OldTransactionLog.Phase_ID in (',PhaseIDs,')');
		END IF;
		
		IF (Length(UserIDs)>0) Then
		SET selectStmt = concat(selectStmt,' AND OldTransactionLog.User_ID in (',UserIDs,')');
		END IF;
	
		IF (Length(StatusIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND OldTransactionLog.JS_ID in (',StatusIDs,')');
		END IF;
		
		IF (Length(StorageIDs)>0) Then
		SET selectStmt = concat(selectStmt,' AND Storage.Storage_ID in (',StorageIDs,')');
		END IF;
		IF (Length(CollIDs)>0) Then
		SET selectStmt = concat(selectStmt,' AND Collection.Coll_ID in (',CollIDs,')');
		END IF;
		
		IF (Length(BatcheIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND Batch.Batch_ID in (',BatcheIDs,')');
		END IF;
		
		IF (Length(LangIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND Metadata.LanguageView.Lang_ID in (',LangIDs,')');
		END IF;
		
		IF (Length(JobTypeIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND JobType.JT_ID in (',JobTypeIDs,')');
		END IF;
				
		IF (jobID>-1) Then
			SET selectStmt = concat(selectStmt,' AND Job.Job_ID = (',jobID,')');
		END IF;
		-- checkInOnly = 1 will retrieve checked in Jobs only between the specified dates
		IF (checkInOnly=1) Then
			SET selectStmt = concat(selectStmt,' AND Job.Job_Date>=''',fromDate,'''  and Job.Job_Date<=''',toDate,''' ');
		END IF;
		

	SET selectStmt =concat(selectStmt,'group by Phase.Phase_ID,OldTransactionLog.Job_ID ');
	SET selectStmt =concat(selectStmt,'having count(OldTransactionLog.OTL_ID)>1 ');
	SET selectStmt =concat(selectStmt,')Redo ');
	SET selectStmt =concat(selectStmt,'group by PhaseID;');

/*first select execution*/
select @a:=selectStmt;
Prepare stmt from @a;
execute stmt;
DEALLOCATE PREPARE stmt;

END IF;

-- 3) New Jobs
SELECT STRCMP(OldNewIDs,"1") into compare;
-- STRCMP return 0 on equality
IF (compare=0) THEN
/*first select, get all finished jobs*/
  SET selectStmt ='insert into finishAll select PhaseID,seq,count(jobs) as finishAll from ( ';
	SET selectStmt =concat(selectStmt,'select Phase.Phase_ID as PhaseID ,Phase.Phase_Sequence as seq,TransactionLog.Job_ID as jobs ');
	SET selectStmt =concat(selectStmt,'from Phase ');
	SET selectStmt =concat(selectStmt,'inner join TransactionLog on Phase.Phase_ID=TransactionLog.Phase_ID ');
	SET selectStmt =concat(selectStmt,'inner join Metadata.JobView on Metadata.JobView.Job_ID=TransactionLog.Job_ID ');
	SET selectStmt =concat(selectStmt,' inner join Job on TransactionLog.Job_ID=Job.Job_ID  INNER JOIN Storage ON (Job.Storage_ID=Storage.Storage_ID) INNER JOIN Metadata.LanguageView ON (Metadata.JobView.Lang_ID=Metadata.LanguageView.Lang_ID) INNER JOIN JobType on (Job.JT_ID=JobType.JT_ID) INNER JOIN Batch ON (Job.Batch_ID=Batch.Batch_ID) INNER JOIN Collection ON (Batch.Coll_ID=Collection.Coll_ID) ');
	SET selectStmt =concat(selectStmt,'where Phase.Phase_ID>2  and TransactionLog.TL_Date>=''',fromDate,'''  and TransactionLog.TL_Date<=''',toDate,''' ');
			IF (Length(PhaseIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND TransactionLog.Phase_ID in (',PhaseIDs,')');
			END IF;
			
			IF (Length(UserIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND TransactionLog.User_ID in (',UserIDs,')');
			END IF;
		
			IF (Length(StatusIDs)>0) Then
				SET selectStmt = concat(selectStmt,' AND TransactionLog.JS_ID in (',StatusIDs,')');
			END IF;
			
			IF (Length(StorageIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND Storage.Storage_ID in (',StorageIDs,')');
			END IF;
			IF (Length(CollIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND Collection.Coll_ID in (',CollIDs,')');
		END IF;
		
		IF (Length(BatcheIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND Batch.Batch_ID in (',BatcheIDs,')');
		END IF;
		
		IF (Length(LangIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND Metadata.LanguageView.Lang_ID in (',LangIDs,')');
		END IF;
		
		IF (Length(JobTypeIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND JobType.JT_ID in (',JobTypeIDs,')');
		END IF;
			
		IF (jobID>-1) Then
			SET selectStmt = concat(selectStmt,' AND Job.Job_ID = (',jobID,')');
		END IF;
			-- checkInOnly = 1 will retrieve checked in Jobs only between the specified dates
		IF (checkInOnly=1) Then
			SET selectStmt = concat(selectStmt,' AND Job.Job_Date>=''',fromDate,'''  and Job.Job_Date<=''',toDate,''' ');
		END IF;
		
		
	SET selectStmt =concat(selectStmt,'group by Phase.Phase_ID,TransactionLog.Job_ID ');
	SET selectStmt =concat(selectStmt,')All_ ');
	SET selectStmt =concat(selectStmt,'group by PhaseID;');

/*first select execution*/
select @b:=selectStmt;
Prepare stmt from @b;
execute stmt;
DEALLOCATE PREPARE stmt;

/*second select, get ReDo items*/
SET selectStmt ='insert into finishReDo select PhaseID,seq,count(jobs) as finishReDo from ( ';
	SET selectStmt =concat(selectStmt,'select Phase.Phase_ID as PhaseID ,Phase.Phase_Sequence as seq,TransactionLog.Job_ID as jobs ');
	SET selectStmt =concat(selectStmt,'from Phase ');
	SET selectStmt =concat(selectStmt,'inner join TransactionLog on Phase.Phase_ID=TransactionLog.Phase_ID ');
	SET selectStmt =concat(selectStmt,'inner join Metadata.JobView on Metadata.JobView.Job_ID=TransactionLog.Job_ID ');
	SET selectStmt =concat(selectStmt,' inner join Job on TransactionLog.Job_ID=Job.Job_ID  INNER JOIN Storage ON (Job.Storage_ID=Storage.Storage_ID) INNER JOIN Metadata.LanguageView ON (Metadata.JobView.Lang_ID=Metadata.LanguageView.Lang_ID) INNER JOIN JobType on (Job.JT_ID=JobType.JT_ID)  INNER JOIN Batch ON (Job.Batch_ID=Batch.Batch_ID) INNER JOIN Collection ON (Batch.Coll_ID=Collection.Coll_ID) ');
	SET selectStmt =concat(selectStmt,'where Phase.Phase_ID>2  and TransactionLog.TL_Date>=''',fromDate,'''  and TransactionLog.TL_Date<=''',toDate,''' ');
			IF (Length(PhaseIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND TransactionLog.Phase_ID in (',PhaseIDs,')');
			END IF;
			
			IF (Length(UserIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND TransactionLog.User_ID in (',UserIDs,')');
			END IF;
		
			IF (Length(StatusIDs)>0) Then
				SET selectStmt = concat(selectStmt,' AND TransactionLog.JS_ID in (',StatusIDs,')');
			END IF;
			
			IF (Length(StorageIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND Storage.Storage_ID in (',StorageIDs,')');
			END IF;
			IF (Length(CollIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND Collection.Coll_ID in (',CollIDs,')');
		END IF;
		
		IF (Length(BatcheIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND Batch.Batch_ID in (',BatcheIDs,')');
		END IF;
		
		IF (Length(LangIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND Metadata.LanguageView.Lang_ID in (',LangIDs,')');
		END IF;
		
		IF (Length(JobTypeIDs)>0) Then
			SET selectStmt = concat(selectStmt,' AND JobType.JT_ID in (',JobTypeIDs,')');
		END IF;
	
		IF (jobID>-1) Then
			SET selectStmt = concat(selectStmt,' AND Job.Job_ID = (',jobID,')');
		END IF;
			-- checkInOnly = 1 will retrieve checked in Jobs only between the specified dates
		IF (checkInOnly=1) Then
			SET selectStmt = concat(selectStmt,' AND Job.Job_Date>=''',fromDate,'''  and Job.Job_Date<=''',toDate,''' ');
		END IF;
		
	
	SET selectStmt =concat(selectStmt,'group by Phase.Phase_ID,TransactionLog.Job_ID ');
	SET selectStmt =concat(selectStmt,'having count(TransactionLog.TL_ID)>1 ');
	SET selectStmt =concat(selectStmt,')Redo ');
	SET selectStmt =concat(selectStmt,'group by PhaseID;');

/*first select execution*/
select @a:=selectStmt;
Prepare stmt from @a;
execute stmt;
DEALLOCATE PREPARE stmt;


END IF;

	/*get results*/
	
select Phase.Phase_ID,Phase.Phase_Sequence,concat(JobType.JT_Name,':',Phase.Phase_Name) as PhaseName,finishAll.JobsCount as finishAll,(ifnull(finishAll.JobsCount,0)-ifnull(finishReDo.JobsCount,0)) as finishOnce,ifnull(finishReDo.JobsCount,0) as finishRedo
from Phase 
inner join JobType on JobType.JT_ID=Phase.JT_ID  
left outer join finishAll on finishAll.PhaseID=Phase.Phase_ID
left outer join finishReDo on finishReDo.PhaseID=Phase.Phase_ID
 where  finishAll.JobsCount > 0 and Phase.Phase_ID>2
-- where  Phase.Phase_ID>1 -- and finishAll.JobsCount is not null
order by Phase.Phase_Sequence;


END $$





DROP PROCEDURE IF EXISTS `DAF02`.`WorkFlowReport`$$
CREATE  PROCEDURE  `DAF02`.`WorkFlowReport`(
JobType_Val		Integer,
CollID_Val		Integer,
BatchID_Val		Integer
)
BEGIN
	
CREATE TEMPORARY TABLE WorkflowTempTable ( JobsCount int, JobStatus int, PhaseID int, PhaseName varchar(500), PhaseSequence int ) ENGINE=HEAP;
CREATE TEMPORARY TABLE PendingJobsTempTable ( JobsCount int, JobStatus int, PhaseID int, PhaseName varchar(500), PhaseSequence int ) ENGINE=HEAP;
CREATE TEMPORARY TABLE ProcessingJobsTempTable ( JobsCount int, JobStatus int, PhaseID int, PhaseName varchar(500), PhaseSequence int ) ENGINE=HEAP;
CREATE TEMPORARY TABLE FinishedJobsTempTable ( JobsCount int, JobStatus int, PhaseID int, PhaseName varchar(500), PhaseSequence int ) ENGINE=HEAP;

/*test if the collection, batch filter are used or not
* there are 4 combinations (2^2) 0 0 ,0 1 ,1 0 , 1 1 
*/
IF (CollID_Val>-1 AND BatchID_Val>-1) THEN-- CollID_Val=-1 means any collection, BatchID_Val=-1 means any batch
	/*first case: the 2 values <> any*/
	INSERT INTO WorkflowTempTable
	Select Count(Job.Job_ID) as JobsCount, TransactionLog.JS_ID, TransactionLog.Phase_ID, Phase.Phase_Name, Phase.Phase_Sequence from Job
	inner Join Job_Collection on (Job.Job_ID= Job_Collection.Job_ID and Job_Collection.Coll_ID=CollID_Val)
	inner join TransactionLog on Job.TL_ID = TransactionLog.TL_ID
	Inner Join Phase on TransactionLog.Phase_ID = Phase.Phase_ID And Phase.JT_ID = JobType_Val
	Where Job.TL_ID <> 0  And Job.JT_ID = JobType_Val AND Job.Batch_ID=BatchID_Val
	Group By Phase.Phase_Sequence,TransactionLog.Phase_ID,Phase.Phase_Name, TransactionLog.JS_ID;
	
ELSEIF (CollID_Val>-1 AND BatchID_Val=-1) THEN
/*second case: only batch value = any*/
	INSERT INTO WorkflowTempTable
	Select Count(Job.Job_ID) as JobsCount, TransactionLog.JS_ID, TransactionLog.Phase_ID, Phase.Phase_Name, Phase.Phase_Sequence from Job
	inner Join Job_Collection on (Job.Job_ID= Job_Collection.Job_ID and Job_Collection.Coll_ID=CollID_Val)
	inner join TransactionLog on Job.TL_ID = TransactionLog.TL_ID
	Inner Join Phase on TransactionLog.Phase_ID = Phase.Phase_ID And Phase.JT_ID = JobType_Val
	Where Job.TL_ID <> 0  And Job.JT_ID = JobType_Val
	Group By Phase.Phase_Sequence,TransactionLog.Phase_ID,Phase.Phase_Name, TransactionLog.JS_ID;

ELSEIF (CollID_Val=-1 AND BatchID_Val>-1) THEN
/*third case: only collection value = any*/
	INSERT INTO WorkflowTempTable
	Select Count(Job.Job_ID) as JobsCount, TransactionLog.JS_ID, TransactionLog.Phase_ID, Phase.Phase_Name, Phase.Phase_Sequence from Job
	inner join TransactionLog on Job.TL_ID = TransactionLog.TL_ID
	Inner Join Phase on TransactionLog.Phase_ID = Phase.Phase_ID And Phase.JT_ID = JobType_Val
	Where Job.TL_ID <> 0  And Job.JT_ID = JobType_Val AND Job.Batch_ID=BatchID_Val
	Group By Phase.Phase_Sequence,TransactionLog.Phase_ID,Phase.Phase_Name, TransactionLog.JS_ID;

ELSEIF (CollID_Val=-1 AND BatchID_Val=-1) THEN
/*fourth case: both values = any*/
	INSERT INTO WorkflowTempTable
	Select Count(Job.Job_ID) as JobsCount, TransactionLog.JS_ID, TransactionLog.Phase_ID, Phase.Phase_Name, Phase.Phase_Sequence from Job
	inner join TransactionLog on Job.TL_ID = TransactionLog.TL_ID
	Inner Join Phase on TransactionLog.Phase_ID = Phase.Phase_ID And Phase.JT_ID = JobType_Val
	Where Job.TL_ID <> 0  And Job.JT_ID = JobType_Val
	Group By Phase.Phase_Sequence,TransactionLog.Phase_ID,Phase.Phase_Name, TransactionLog.JS_ID;

END IF;


Insert Into PendingJobsTempTable Select * from WorkflowTempTable;
Insert Into ProcessingJobsTempTable Select * from WorkflowTempTable;
Insert Into FinishedJobsTempTable Select * from WorkflowTempTable;

Insert Into WorkflowTempTable 
Select 0, 0, Phase.Phase_ID, Phase.Phase_Name, Phase.Phase_Sequence 
from Phase Where Phase.JT_ID = JobType_Val and Phase.Phase_ID <> 0 And Phase.Phase_ID not in 
(Select PendingJobsTempTable.PhaseID from PendingJobsTempTable);

Select PhaseID,PhaseName,
(SELECT case when Sum(JobsCount) is not null then Sum(JobsCount) else 0 end FROM PendingJobsTempTable Where 
(JobStatus = 4 or JobStatus = 5 or JobStatus = 6)
And PendingJobsTempTable.PhaseID = WorkflowTempTable.PhaseID) as PendingJobs,
(SELECT case when Sum(JobsCount) is not null then Sum(JobsCount) else 0 end FROM ProcessingJobsTempTable Where 
JobStatus = 1
And ProcessingJobsTempTable.PhaseID = WorkflowTempTable.PhaseID) as ProcessingJobs,
(SELECT case when Sum(JobsCount) is not null then Sum(JobsCount) else 0 end FROM FinishedJobsTempTable Where 
JobStatus = 2
And FinishedJobsTempTable.PhaseID = WorkflowTempTable.PhaseID) as FinishedJobs 
from WorkflowTempTable
Group By PhaseSequence,PhaseName;

DROP TABLE WorkflowTempTable;
DROP TABLE ProcessingJobsTempTable;
DROP TABLE PendingJobsTempTable;
DROP TABLE FinishedJobsTempTable;


End $$





DROP PROCEDURE IF EXISTS `DAF02`.`WorkFlowReportExpanded`$$
CREATE  PROCEDURE  `DAF02`.`WorkFlowReportExpanded`(
JobType_Val		Integer,
CollID_Val		Integer,
BatchID_Val		Integer)
BEGIN
	
CREATE TEMPORARY TABLE WorkflowTempTable ( JobsCount int, JobStatus int, PhaseID int, PhaseName varchar(500), PhaseSequence int, OldOrNew int ) ENGINE=HEAP;
CREATE TEMPORARY TABLE PendingJobsOnceTempTable ( JobsCount int, JobStatus int, PhaseID int, PhaseName varchar(500), PhaseSequence int, OldOrNew int  ) ENGINE=HEAP;
CREATE TEMPORARY TABLE PendingJobsMoreTempTable ( JobsCount int, JobStatus int, PhaseID int, PhaseName varchar(500), PhaseSequence int, OldOrNew int  ) ENGINE=HEAP;
CREATE TEMPORARY TABLE ProcessingJobsOnceTempTable ( JobsCount int, JobStatus int, PhaseID int, PhaseName varchar(500), PhaseSequence int, OldOrNew int  ) ENGINE=HEAP;
CREATE TEMPORARY TABLE ProcessingJobsMoreTempTable ( JobsCount int, JobStatus int, PhaseID int, PhaseName varchar(500), PhaseSequence int, OldOrNew int  ) ENGINE=HEAP;
CREATE TEMPORARY TABLE FinishedJobsOnceTempTable ( JobsCount int, JobStatus int, PhaseID int, PhaseName varchar(500), PhaseSequence int, OldOrNew int  ) ENGINE=HEAP;
CREATE TEMPORARY TABLE FinishedJobsMoreTempTable ( JobsCount int, JobStatus int, PhaseID int, PhaseName varchar(500), PhaseSequence int, OldOrNew int  ) ENGINE=HEAP;

/*test if the collection, batch filter are used or not
* there are 4 combinations (2^2) 0 0 ,0 1 ,1 0 , 1 1 
*/
IF (CollID_Val>-1 AND BatchID_Val>-1) THEN-- CollID_Val=-1 means any collection, BatchID_Val=-1 means any batch
	/*first case: the 2 values <> any*/
		
		INSERT INTO WorkflowTempTable
		Select Count(Job_ID) as JobsCount, JS_ID, Phase_ID, Phase_Name, Phase_Sequence, OldOrNew
		From (
		Select Job.Job_ID, TransactionLog.JS_ID, TransactionLog.Phase_ID, Phase.Phase_Name, Phase.Phase_Sequence, TransactionLog.TL_ID, case When Count(TL2.TL_ID) = 0 then 0 else 1 end as OldOrNew
		from Job 
		inner Join Job_Collection on (Job.Job_ID= Job_Collection.Job_ID and Job_Collection.Coll_ID=CollID_Val)
		Inner join TransactionLog on Job.TL_ID = TransactionLog.TL_ID
		Inner Join Phase on TransactionLog.Phase_ID = Phase.Phase_ID And Phase.JT_ID = JobType_Val
		Left Outer Join TransactionLog as TL2 on 
			(TL2.Job_ID = Job.Job_ID 
			And TransactionLog.Phase_ID = TL2.Phase_ID
			And TL2.JS_ID=2
			And TL2.TL_ID <> TransactionLog.TL_ID)
		Where Job.TL_ID <> 0  And Job.JT_ID = JobType_Val AND Job.Batch_ID=BatchID_Val
		Group By Job.Job_ID, TransactionLog.JS_ID, TransactionLog.Phase_ID, Phase.Phase_Name, Phase.Phase_Sequence, TransactionLog.TL_ID) as InnerTable
		Group By Phase_Sequence,Phase_ID, Phase_Name, JS_ID, OldOrNew;
			
ELSEIF (CollID_Val>-1 AND BatchID_Val=-1) THEN
/*second case: only batch value = any*/
	
		INSERT INTO WorkflowTempTable
		Select Count(Job_ID) as JobsCount, JS_ID, Phase_ID, Phase_Name, Phase_Sequence, OldOrNew
		From (
		Select Job.Job_ID, TransactionLog.JS_ID, TransactionLog.Phase_ID, Phase.Phase_Name, Phase.Phase_Sequence, TransactionLog.TL_ID, case When Count(TL2.TL_ID) = 0 then 0 else 1 end as OldOrNew
		from Job 
		inner Join Job_Collection on (Job.Job_ID= Job_Collection.Job_ID and Job_Collection.Coll_ID=CollID_Val)
		Inner join TransactionLog on Job.TL_ID = TransactionLog.TL_ID
		Inner Join Phase on TransactionLog.Phase_ID = Phase.Phase_ID And Phase.JT_ID = JobType_Val
		Left Outer Join TransactionLog as TL2 on 
			(TL2.Job_ID = Job.Job_ID 
			And TransactionLog.Phase_ID = TL2.Phase_ID
			And TL2.JS_ID=2
			And TL2.TL_ID <> TransactionLog.TL_ID)
		Where Job.TL_ID <> 0  And Job.JT_ID = JobType_Val
		Group By Job.Job_ID, TransactionLog.JS_ID, TransactionLog.Phase_ID, Phase.Phase_Name, Phase.Phase_Sequence, TransactionLog.TL_ID) as InnerTable
		Group By Phase_Sequence,Phase_ID, Phase_Name, JS_ID, OldOrNew;
	
	
ELSEIF (CollID_Val=-1 AND BatchID_Val>-1) THEN
/*third case: only collection value = any*/

		INSERT INTO WorkflowTempTable
		Select Count(Job_ID) as JobsCount, JS_ID, Phase_ID, Phase_Name, Phase_Sequence, OldOrNew
		From (
		Select Job.Job_ID, TransactionLog.JS_ID, TransactionLog.Phase_ID, Phase.Phase_Name, Phase.Phase_Sequence, TransactionLog.TL_ID, case When Count(TL2.TL_ID) = 0 then 0 else 1 end as OldOrNew
		from Job 
		Inner join TransactionLog on Job.TL_ID = TransactionLog.TL_ID
		Inner Join Phase on TransactionLog.Phase_ID = Phase.Phase_ID And Phase.JT_ID = JobType_Val
		Left Outer Join TransactionLog as TL2 on 
			(TL2.Job_ID = Job.Job_ID 
			And TransactionLog.Phase_ID = TL2.Phase_ID
			And TL2.JS_ID=2
			And TL2.TL_ID <> TransactionLog.TL_ID)
		Where Job.TL_ID <> 0  And Job.JT_ID = JobType_Val AND Job.Batch_ID=BatchID_Val
		Group By Job.Job_ID, TransactionLog.JS_ID, TransactionLog.Phase_ID, Phase.Phase_Name, Phase.Phase_Sequence, TransactionLog.TL_ID) as InnerTable
		Group By Phase_Sequence,Phase_ID, Phase_Name, JS_ID, OldOrNew;
	

ELSEIF (CollID_Val=-1 AND BatchID_Val=-1) THEN
/*fourth case: both values = any*/
		INSERT INTO WorkflowTempTable
		Select Count(Job_ID) as JobsCount, JS_ID, Phase_ID, Phase_Name, Phase_Sequence, OldOrNew
		From (
		Select Job.Job_ID, TransactionLog.JS_ID, TransactionLog.Phase_ID, Phase.Phase_Name, Phase.Phase_Sequence, TransactionLog.TL_ID, case When Count(TL2.TL_ID) = 0 then 0 else 1 end as OldOrNew
		from Job Inner join TransactionLog on Job.TL_ID = TransactionLog.TL_ID
		Inner Join Phase on TransactionLog.Phase_ID = Phase.Phase_ID And Phase.JT_ID = JobType_Val
		Left Outer Join TransactionLog as TL2 on 
			(TL2.Job_ID = Job.Job_ID 
			And TransactionLog.Phase_ID = TL2.Phase_ID
			And  TL2.JS_ID=2
			And TL2.TL_ID <> TransactionLog.TL_ID)
		Where Job.TL_ID <> 0  And Job.JT_ID = JobType_Val
		Group By Job.Job_ID, TransactionLog.JS_ID, TransactionLog.Phase_ID, Phase.Phase_Name, Phase.Phase_Sequence, TransactionLog.TL_ID) as InnerTable
		Group By Phase_Sequence,Phase_ID, Phase_Name, JS_ID, OldOrNew;

END IF;

Insert Into PendingJobsOnceTempTable Select * from WorkflowTempTable;
Insert Into PendingJobsMoreTempTable Select * from WorkflowTempTable;
Insert Into ProcessingJobsOnceTempTable Select * from WorkflowTempTable;
Insert Into ProcessingJobsMoreTempTable Select * from WorkflowTempTable;
Insert Into FinishedJobsOnceTempTable Select * from WorkflowTempTable;
Insert Into FinishedJobsMoreTempTable Select * from WorkflowTempTable;

Insert Into WorkflowTempTable 
Select 0, 0, Phase.Phase_ID, Phase.Phase_Name, Phase.Phase_Sequence, -1
from Phase Where Phase.JT_ID = JobType_Val and Phase.Phase_ID <> 0 And Phase.Phase_ID not in 
(Select PendingJobsOnceTempTable.PhaseID from PendingJobsOnceTempTable);


Select PhaseID,PhaseName,
(SELECT case when Sum(JobsCount) is not null then Sum(JobsCount) else 0 end FROM PendingJobsOnceTempTable Where 
(JobStatus = 4 or JobStatus = 5 or JobStatus = 6)
And PendingJobsOnceTempTable.PhaseID = WorkflowTempTable.PhaseID And OldOrNew = 0) as PendingJobsOnce,
(SELECT case when Sum(JobsCount) is not null then Sum(JobsCount) else 0 end FROM PendingJobsMoreTempTable Where 
(JobStatus = 4 or JobStatus = 5 or JobStatus = 6)
And PendingJobsMoreTempTable.PhaseID = WorkflowTempTable.PhaseID And OldOrNew = 1) as PendingJobsMore,
(SELECT case when Sum(JobsCount) is not null then Sum(JobsCount) else 0 end FROM ProcessingJobsOnceTempTable Where 
JobStatus = 1
And ProcessingJobsOnceTempTable.PhaseID = WorkflowTempTable.PhaseID And OldOrNew = 0) as ProcessingJobsOnce,
(SELECT case when Sum(JobsCount) is not null then Sum(JobsCount) else 0 end FROM ProcessingJobsMoreTempTable Where 
JobStatus = 1
And ProcessingJobsMoreTempTable.PhaseID = WorkflowTempTable.PhaseID And OldOrNew = 1) as ProcessingJobsMore,
(SELECT case when Sum(JobsCount) is not null then Sum(JobsCount) else 0 end FROM FinishedJobsOnceTempTable Where 
JobStatus = 2
And FinishedJobsOnceTempTable.PhaseID = WorkflowTempTable.PhaseID And OldOrNew = 0) as FinishedJobsOnce,
(SELECT case when Sum(JobsCount) is not null then Sum(JobsCount) else 0 end FROM FinishedJobsMoreTempTable Where 
JobStatus = 2
And FinishedJobsMoreTempTable.PhaseID = WorkflowTempTable.PhaseID And OldOrNew = 1) as FinishedJobsMore
from WorkflowTempTable
Group By PhaseSequence,PhaseName;

DROP TABLE WorkflowTempTable;
DROP TABLE PendingJobsOnceTempTable;
DROP TABLE PendingJobsMoreTempTable;
DROP TABLE ProcessingJobsOnceTempTable;
DROP TABLE ProcessingJobsMoreTempTable;
DROP TABLE FinishedJobsMoreTempTable;
DROP TABLE FinishedJobsOnceTempTable;

End $$





DROP PROCEDURE IF EXISTS `DAF02`.`Workstation_Add`$$
CREATE  PROCEDURE  `DAF02`.`Workstation_Add`(
		WrkstName_Val   					nvarchar(50)		,
		WrkstWorkingDirectory_Val nvarchar(200)	,
		WrkstAnyPhase_Val 				TinyInt(1)		,
		WrkstIsActive_Val 				TinyInt(1)		,
		WrkstComment_Val					Text					,
		FKOSID_Val								Integer				,
		WrkstLocation_Val					nvarchar(50)
	 )
BEGIN
	START TRANSACTION;
				INSERT INTO Workstation (Wrkst_Name								,
																 Wrkst_WorkingDirectory		,
																 Wrkst_AnyPhase						,
															   Wrkst_IsActive						,
																 Wrkst_Comment						,
																 OS_ID									,
																 Wrkst_Location									
																 )
													values (WrkstName_Val								,
																	WrkstWorkingDirectory_Val		,
																	WrkstAnyPhase_Val						,
																	WrkstIsActive_Val						,
																	WrkstComment_Val						,
																	FKOSID_Val									,
																	WrkstLocation_Val															
																 );			
														
				SELECT * FROM Workstation WHERE Wrkst_ID=Last_Insert_ID();										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Workstation_Delete`$$
CREATE  PROCEDURE  `DAF02`.`Workstation_Delete`(
		PKWrkstID_Val		Integer
	)
BEGIN
	START TRANSACTION;
				DELETE FROM Workstation	WHERE Wrkst_ID=PKWrkstID_Val;
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Workstation_DeleteCascade`$$
CREATE  PROCEDURE  `DAF02`.`Workstation_DeleteCascade`(
		PKWS_Val		Integer
	)
BEGIN
	START TRANSACTION;
				
				DELETE FROM Workstation_MediaType WHERE Workstation_MediaType.Wrkst_ID=PKWS_Val;
				DELETE FROM Workstation_Collection WHERE Workstation_Collection.Wrkst_ID=PKWS_Val;
				DELETE FROM Workstation_Device WHERE Workstation_Device.Wrkst_ID=PKWS_Val;
				DELETE FROM Workstation_Phase WHERE Workstation_Phase.Wrkst_ID=PKWS_Val;
				DELETE FROM Workstation	WHERE (Workstation.Wrkst_ID=PKWS_Val);
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Workstation_getAssignedPhases`$$
CREATE  PROCEDURE  `DAF02`.`Workstation_getAssignedPhases`(
		PKWrkstID_Val		Integer
	)
BEGIN
	
				
				SELECT Phase.Phase_ID,
							 Phase_Sequence,
							 Phase_MaxPeriod,
						   Phase_Description,
			  			 Phase_XMLDescription,
							 JT_ID,
							 Phase_Name
				FROM Phase
				INNER JOIN Workstation_Phase
				ON Phase.Phase_ID= Workstation_Phase.Phase_ID
				WHERE Workstation_Phase.Wrkst_ID=PKWrkstID_Val
				;
								
																
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Workstation_getAssignedPhasesSpecial`$$
CREATE  PROCEDURE  `DAF02`.`Workstation_getAssignedPhasesSpecial`(
		PKWrkstID_Val		Integer
	)
BEGIN
	
				
				SELECT Phase.Phase_ID,
							 Phase_Sequence,
							 Phase_MaxPeriod,
						   Phase_Description,
			  			 Phase_XMLDescription,
							 Phase.JT_ID,
							 concat(JobType.JT_Name,':',Phase_Name)
				FROM JobType
				INNER JOIN Phase
				ON JobType.JT_ID=Phase.JT_ID
				INNER JOIN Workstation_Phase
				ON Phase.Phase_ID= Workstation_Phase.Phase_ID
				WHERE Workstation_Phase.Wrkst_ID=PKWrkstID_Val
				;
								

END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Workstation_getByID`$$
CREATE  PROCEDURE  `DAF02`.`Workstation_getByID`(
		PKWrkstID_Val		Integer
	)
BEGIN
	
	SELECT * FROM Workstation	WHERE Wrkst_ID=PKWrkstID_Val;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Workstation_getByName`$$
CREATE  PROCEDURE  `DAF02`.`Workstation_getByName`(
		WSName_Val		nvarchar(50)
	)
BEGIN

		SELECT * FROM Workstation	WHERE Workstation.Wrkst_Name= WSName_Val;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Workstation_getDevices`$$
CREATE  PROCEDURE  `DAF02`.`Workstation_getDevices`(PKWrkstID_Val		Integer)
BEGIN
	
			SELECT Device.Device_ID,Device.Device_Name
						 
			FROM Device
			INNER JOIN Workstation_Device
			ON Device.Device_ID=Workstation_Device.Device_ID
			WHERE Workstation_Device.Wrkst_ID=PKWrkstID_Val
			;
						
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Workstation_getMediaTypes`$$
CREATE  PROCEDURE  `DAF02`.`Workstation_getMediaTypes`(WrkstID_Val		Integer)
BEGIN
	
			SELECT MediaType.MT_ID,MediaType.MT_Name,MediaType.MT_Size						 
			FROM MediaType
			INNER JOIN Workstation_MediaType
			ON MediaType.MT_ID=Workstation_MediaType.MT_ID
			WHERE Workstation_MediaType.Wrkst_ID=WrkstID_Val
			;
						
			
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Workstation_loadAll`$$
CREATE  PROCEDURE  `DAF02`.`Workstation_loadAll`()
BEGIN
	
	SELECT * FROM Workstation 
	WHERE Workstation.Wrkst_ID>0
	order by Workstation.Wrkst_Name;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Workstation_loadAllDevices`$$
CREATE  PROCEDURE  `DAF02`.`Workstation_loadAllDevices`()
BEGIN
	
			SELECT Device.Device_ID,Device.Device_Name
			FROM Device;
								
			
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Workstation_loadAllGUI`$$
CREATE  PROCEDURE  `DAF02`.`Workstation_loadAllGUI`()
BEGIN
	
			SELECT  Workstation.Wrkst_ID,
							Workstation.Wrkst_Name,
							Workstation.Wrkst_Location,
							OperatingSystem.OS_Name,
							Workstation.Wrkst_WorkingDirectory,
							Workstation.Wrkst_AnyPhase,
							Workstation.Wrkst_IsActive,
							Workstation.OS_ID,
							Workstation.Wrkst_Comment
				FROM OperatingSystem
				INNER JOIN Workstation
				ON Workstation.OS_ID = OperatingSystem.OS_ID
				WHERE Workstation.Wrkst_ID>0
				order by Workstation.Wrkst_Name	;
	
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`Workstation_Update`$$
CREATE  PROCEDURE  `DAF02`.`Workstation_Update`(
		PKWrkstID_Val		  				Integer				,
		WrkstName_Val   					nvarchar(50)		,
		WrkstWorkingDirectory_Val nvarchar(200)	,
		WrkstAnyPhase_Val 				TinyInt(1)		,
		WrkstIsActive_Val 				TinyInt(1)		,
		WrkstComment_Val					Text					,
		FKOSID_Val								Integer				,
		WrkstLocation_Val					nvarchar(50)	
)
BEGIN
	START TRANSACTION;
				UPDATE Workstation  SET  	Wrkst_ID						 = PKWrkstID_Val						 ,
																	Wrkst_Name						 = WrkstName_Val 						 ,
																	Wrkst_WorkingDirectory = WrkstWorkingDirectory_Val ,
																	Wrkst_AnyPhase				 = WrkstAnyPhase_Val				 ,
																	Wrkst_IsActive				 = WrkstIsActive_Val				 ,
																	Wrkst_Comment					 = WrkstComment_Val					 ,
																	OS_ID							 = FKOSID_Val								 ,
																	Wrkst_Location				 = WrkstLocation_Val
												
													WHERE Wrkst_ID= PKWrkstID_Val;
								
				SELECT * FROM Workstation WHERE Wrkst_ID=PKWrkstID_Val;										
	COMMIT;
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`WorkStation_updateDevices`$$
CREATE  PROCEDURE  `DAF02`.`WorkStation_updateDevices`(
		wsID_Val 					 Integer ,			
		devicesVal						 nvarchar(500),
		delimiterVal				 char(1)
	)
BEGIN
	START TRANSACTION;
			DELETE FROM Workstation_Device	
			WHERE (Workstation_Device.Wrkst_ID=wsID_Val);
			
			CALL SplitIDs(devicesVal,delimiterVal);
			INSERT INTO Workstation_Device (Wrkst_ID,Device_ID) 
  										( SELECT   wsID_Val,IDVal
												FROM SplittedTempTable
											);											
				
		Drop Temporary Table If Exists `SplittedTempTable`;
		
		SELECT * FROM Workstation_Device 
		WHERE (Workstation_Device.Wrkst_ID=wsID_Val);
										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`WorkStation_updateMediaType`$$
CREATE  PROCEDURE  `DAF02`.`WorkStation_updateMediaType`(
		wsID_Val 					 Integer ,			
		mediaTypesVal			 nvarchar(500),
		delimiterVal			 char(1)
	)
BEGIN
	START TRANSACTION;
			DELETE FROM Workstation_MediaType	
			WHERE (Workstation_MediaType.Wrkst_ID=wsID_Val);
			
			CALL SplitIDs(mediaTypesVal,delimiterVal);
			INSERT INTO Workstation_MediaType (Wrkst_ID,MT_ID) 
  										( SELECT   wsID_Val,IDVal
												FROM SplittedTempTable
											);											
				
		Drop Temporary Table If Exists `SplittedTempTable`;
		
		SELECT * FROM Workstation_MediaType 
		WHERE (Workstation_MediaType.Wrkst_ID=wsID_Val);
										
	COMMIT;
	
END $$





DROP PROCEDURE IF EXISTS `DAF02`.`WorkStation_updatePhases`$$
CREATE  PROCEDURE  `DAF02`.`WorkStation_updatePhases`(
		wsID_Val 					 Integer ,			
		phasesVal						 nvarchar(500),
		delimiterVal				 char(1)
	)
BEGIN
	START TRANSACTION;
			DELETE FROM Workstation_Phase	
			WHERE (Workstation_Phase.Wrkst_ID=wsID_Val);
			
			CALL SplitIDs(phasesVal,delimiterVal);
			
			INSERT INTO Workstation_Phase (Wrkst_ID,Phase_ID) 
  										( SELECT    wsID_Val,IDVal
												FROM SplittedTempTable
												WHERE IDVal not in (1,2)
											);											
				
		IF (1 in (select IDVal from SplittedTempTable) )THEN
				INSERT INTO Workstation_Phase (Wrkst_ID,Phase_ID) values (wsID_Val,1);
		END IF;
		
		IF (2 in (select IDVal from SplittedTempTable) )THEN
				INSERT INTO Workstation_Phase (Wrkst_ID,Phase_ID) values (wsID_Val,2);
		END IF;
		Drop Temporary Table If Exists `SplittedTempTable`;
		
		SELECT * FROM Workstation_Phase 
		WHERE (Workstation_Phase.Wrkst_ID=wsID_Val);
										
COMMIT;
	
END $$


DROP PROCEDURE IF EXISTS `DAF02`.`Workstation_ValidateMediaType`$$
CREATE  PROCEDURE  `DAF02`.`Workstation_ValidateMediaType`(WrkstID_Val		Integer, MediaType_Val Integer)
BEGIN

			SELECT *
			FROM Workstation_MediaType
			WHERE (Workstation_MediaType.Wrkst_ID=WrkstID_Val)
			  AND (Workstation_MediaType.MT_ID=MediaType_Val)
			;
						

	
END $$

DROP TRIGGER IF EXISTS `DAF02`.`updatePool`$$
CREATE  TRIGGER  `DAF02`.`updatePool` AFTER UPDATE ON `DAF02`.`Job`
 FOR EACH ROW 
	BEGIN
	Declare Job_Coll	Integer Default 0;
	Declare Job_JS	Integer Default 0;
	Declare Job_User Integer Default 0;
	Declare tableExists	Integer Default 0;
	/*Check Pool Existence*/
	select count(*) into tableExists FROM information_schema.tables 
	WHERE table_schema = 'DAF02' AND table_name = 'Job_Pool';
	if(tableExists=0)THEN
		call Job_CreatePool();
	END IF;

	/*get Collection*/
	Select Collection.Coll_ID
	into Job_Coll
	From Job
	inner join Batch on Batch.Batch_ID=Job.Batch_ID
	inner join 	Collection on Batch.Coll_ID=Collection.Coll_ID
	where Job.Job_ID=New.Job_ID;
 
	/*getCurrent Status*/
	Select JS_ID,if(JS_ID=2,0,User_ID)
	into Job_JS,Job_User
	From TransactionLog where TL_ID=New.TL_ID;
	/*Remove entry from Pool*/
	Delete from Job_Pool where Job_Pool.Job_ID=New.Job_ID;
	/*Filter on Status*/
	IF(Job_JS in (2,6))THEN
	/*insert into pool*/
	insert into Job_Pool(Job_ID,Coll_ID,JS_ID,Phase_ID,User_ID)values(New.Job_ID,Job_Coll,Job_JS,getNextPhase(New.Job_ID),Job_User);
	END IF;
	
END $$


/*Metadata SPs*/


DROP PROCEDURE IF EXISTS `Metadata`.`ExternalID_Add`$$
CREATE  PROCEDURE  `Metadata`.`ExternalID_Add`(
ExtID_Value_Val Varchar(50),
ExtIDType_ID_Val Integer,
ExtID_isDefault_Val Tinyint(1),
Job_ID_Val Integer
)
BEGIN
	Declare ObjID integer default -1;
	START TRANSACTION;
		/*get Object ID*/
		select Metadata.Object.Obj_ID
		into ObjID
		from Object 
		where Metadata.Object.Job_ID=Job_ID_Val;
	
		INSERT INTO Metadata.ExternalID (ExtID_Value, ExtIDType_ID, ExtID_isDefault, Obj_ID)
		VALUES (ExtID_Value_Val, ExtIDType_ID_Val, ExtID_isDefault_Val, ObjID);
		
		SELECT ExtID_ID, ExtID_Value, ExtIDType_ID, ExtID_isDefault, Job_ID_Val as Job_ID, ExtID_TimeStamp  FROM Metadata.ExternalID WHERE Metadata.ExternalID.ExtID_ID = Last_Insert_ID();
	
	COMMIT;
END $$





DROP PROCEDURE IF EXISTS `Metadata`.`Object_Add`$$
CREATE PROCEDURE Metadata.`Object_Add`(
	JobTitle_Val 					 nvarchar(500) ,
	JobCreator_Val 				 nvarchar(100) ,
	JobInfo1_Val 					 nvarchar(500) ,
	JobInfo2_Val 					 nvarchar(500) ,
	JobInfo3_Val 					 nvarchar(500) ,
	JobIdentifyingLob_Val  Blob		,
	CollOwnID_Val 					Integer,
	Prj_ID_Val 					Integer,
	Icg_ID_Val 					Integer,
	LangID_Val				   Integer	,
	JobID_Val							integer
	
)
BEGIN
			/*add Object metadata into Metadata DB*/
				INSERT INTO Object (	Obj_Title					,
													Obj_Creator				,
													Obj_Info1					,
													Obj_Info2					,
													Obj_Info3					,
													Obj_BinaryMarc21,
													Own_ID,
													Prj_ID,
													Icg_ID,
													Lang_ID,
													Job_ID,
													Obj_Date
													)
									values (JobTitle_Val 			 			,
													JobCreator_Val 		 			,
													JobInfo1_Val 			 			,
													JobInfo2_Val 			 			,
													JobInfo3_Val 			 			,
													JobIdentifyingLob_Val 	,
													CollOwnID_Val,
													Prj_ID_Val,
													Icg_ID_Val,
													LangID_Val,
													JobID_Val,
													now()
													);
			
			  

END  $$


DROP PROCEDURE IF EXISTS `Metadata`.`Object_DeleteCascade`$$
CREATE  PROCEDURE  `Metadata`.`Object_DeleteCascade`(JobID_Val		Integer	)
BEGIN
		Delete from Metadata.ExternalID where Metadata.ExternalID.Obj_ID in(
																																				Select Metadata.Object.Obj_ID 
																																				from Metadata.Object 
																																				where Metadata.Object.Job_ID=JobID_Val
																																				);
			
		
		
		DELETE FROM Metadata.Object WHERE Metadata.Object.Job_ID=JobID_Val;

END $$


